@@ -29,7 +29,9 @@ from typing import List
 from urllib.parse import urlparse
 
 import requests
+# from sseclient-py
 import sseclient
+# from ansicolors
 from colors import color
 from tqdm import tqdm
 import yaml
@@ -58,15 +60,15 @@ def main(url, team, pipeline, job, number_of_builds, authorization_cookie, threa
     builds = get_builds_summary_sheet(url, team, pipeline, job, number_of_builds+10, authorization_cookie)
 
     build_to_examine = get_builds_to_examine(builds, number_of_builds)
-    expected_failed_builds = [int(b['name']) for b in build_to_examine if b['status'] == 'failed']
-    expected_failed_builds_count = len(expected_failed_builds)
-    logging.info(f"Expecting {expected_failed_builds_count} runs to have failure strings: {expected_failed_builds}")
+    completed_builds = [int(b['name']) for b in build_to_examine if b['status'] in ['failed', 'succeeded']]
+    completed_builds_count = len(completed_builds)
+    logging.info(f"Expecting {completed_builds_count} runs to have failure strings: {completed_builds}")
 
     long_list_of_failures = aggregate_failure_information(authorization_cookie, build_to_examine, threaded, url)
 
     failure_url_base = f"{url}/teams/{team}/pipelines/{pipeline}/jobs/{job}/builds/"
 
-    print_results(len(build_to_examine), expected_failed_builds, long_list_of_failures, url, failure_url_base)
+    print_results(len(build_to_examine), completed_builds, long_list_of_failures, url, failure_url_base)
 
 
 def get_cookie(url):
@@ -183,7 +185,6 @@ def print_failures(completed, expected_failed_builds, long_list_of_failures, url
                                                failure_url_base)
     print_failures_in_classes_that_share_method_names(completed, long_list_of_failures)
     print_class_and_test_failures_with_links(completed, long_list_of_failures, url)
-    print_list_of_failures(long_list_of_failures, url)
     # Then highlight any build runs that failed hard / timed out.
 
 
@@ -262,7 +263,7 @@ def print_success_rate_and_expectation_warning(completed, expected_failed_builds
     # "Build failures" will refer to jobs that went red
     # "Test failures" will refer to jobs whose output matched our parsing regex
 
-    build_failure_count = len(expected_failed_builds)
+    build_review_count = len(expected_failed_builds)
     test_failure_set = {int(failure.build_json['name']) for failure in long_list_of_test_failures}
     test_failure_count = sum(1 for _ in test_failure_set)
 
@@ -278,12 +279,9 @@ def print_success_rate_and_expectation_warning(completed, expected_failed_builds
           color(f"{rate:.5f}% ({completed - test_failure_count} of {completed})", fg='blue'))
 
     if build_failure_not_test_failure:
-        print(color(f'>>>>> {build_failure_count} jobs "went red," '
-                    f'but only {test_failure_count} were detected test failures. <<<<<',
+        print(color(f'>>>>> Analyzing {build_review_count} jobs, '
+                    f'of which {test_failure_count} were detected test failures. <<<<<',
                     fg='red', style='bold'))
-        print(f"Maybe you have some timeouts or other issues please manually inspect the following builds:")
-        for build_failure in build_failure_not_test_failure:
-            print(f"  {failure_url_base}{build_failure}")
     if test_failure_not_build_failure:
         print(color(f'>>>>> OH NO!  A test failure was detected, but the job "went green" anyway!! <<<<',
                     fg='red', style='bold'))
