@@ -108,13 +108,13 @@ is_source_from_pr_testable() {
           local files=$(git diff --name-only $(cat "${github_pr_dir}/base_sha") $(cat "${github_pr_dir}/head_sha") -- . $(echo ${exclude_pathspec}))
         popd &> /dev/null
         if [[ -z "${files}" ]]; then
-          >&2 echo "CI changes only, skipping tests..."
+          >&2 echo "Code changes are from CI only"
           return_code=1
         else
-          >&2 echo "Running PR tests..."
+          >&2 echo "real code change here!"
         fi
       else
-        >&2 echo "Running tests..."
+        >&2 echo "repo is not from a PR"
       fi
     popd 2>&1 >> /dev/null
   popd 2>&1 >> /dev/null
