@@ -15,6 +15,7 @@
 
 package org.apache.geode.management;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.IOException;
@@ -79,7 +80,7 @@ public class JQFilterVerificationDUnitTest {
     Index index1 = new Index();
     index1.setName("index1");
     index1.setExpression("id");
-    index1.setRegionPath("/regionA");
+    index1.setRegionPath(SEPARATOR + "regionA");
     index1.setIndexType(IndexType.RANGE);
     cms.create(index1);
 
@@ -121,7 +122,7 @@ public class JQFilterVerificationDUnitTest {
         getJqResponse(uri, apiWithJQFilters.remove(uri).get("jqFilter").textValue());
     Assertions.assertThat(response.hasErrors()).isFalse();
     System.out.println("JQ output: " + response.getOutput());
-    Assertions.assertThat(response.getOutput()).contains("\"name\": \"locator-0\"");
+    Assertions.assertThat(response.getOutput()).contains("\"name\":\"locator-0\"");
   }
 
   @Test
@@ -131,7 +132,7 @@ public class JQFilterVerificationDUnitTest {
         apiWithJQFilters.remove("/v1/members/{id}").get("jqFilter").textValue());
     Assertions.assertThat(response.hasErrors()).isFalse();
     System.out.println("JQ output: " + response.getOutput());
-    Assertions.assertThat(response.getOutput()).contains("\"name\": \"locator-0\"");
+    Assertions.assertThat(response.getOutput()).contains("\"name\":\"locator-0\"");
   }
 
   @Test
@@ -141,7 +142,7 @@ public class JQFilterVerificationDUnitTest {
         getJqResponse(uri, apiWithJQFilters.remove(uri).get("jqFilter").textValue());
     Assertions.assertThat(response.hasErrors()).isFalse();
     System.out.println("JQ output: " + response.getOutput());
-    Assertions.assertThat(response.getOutput()).contains("\"name\": \"regionA\"");
+    Assertions.assertThat(response.getOutput()).contains("\"name\":\"regionA\"");
   }
 
   JqResponse getJqResponse(String uri, String jqFilter) throws IOException {
@@ -158,7 +159,7 @@ public class JQFilterVerificationDUnitTest {
         apiWithJQFilters.remove("/v1/regions/{id}").get("jqFilter").textValue());
     Assertions.assertThat(response.hasErrors()).isFalse();
     System.out.println("JQ output: " + response.getOutput());
-    Assertions.assertThat(response.getOutput()).contains("\"name\": \"regionA\"");
+    Assertions.assertThat(response.getOutput()).contains("\"name\":\"regionA\"");
   }
 
   @Test
@@ -168,7 +169,7 @@ public class JQFilterVerificationDUnitTest {
         getJqResponse(uri, apiWithJQFilters.remove(uri).get("jqFilter").textValue());
     Assertions.assertThat(response.hasErrors()).isFalse();
     System.out.println("JQ output: " + response.getOutput());
-    Assertions.assertThat(response.getOutput()).contains("\"name\": \"index1\"");
+    Assertions.assertThat(response.getOutput()).contains("\"name\":\"index1\"");
   }
 
   @Test
@@ -178,7 +179,7 @@ public class JQFilterVerificationDUnitTest {
         .remove("/v1/regions/{regionName}/indexes").get("jqFilter").textValue());
     Assertions.assertThat(response.hasErrors()).isFalse();
     System.out.println("JQ output: " + response.getOutput());
-    Assertions.assertThat(response.getOutput()).contains("\"name\": \"index1\"");
+    Assertions.assertThat(response.getOutput()).contains("\"name\":\"index1\"");
   }
 
   @Test
@@ -188,7 +189,7 @@ public class JQFilterVerificationDUnitTest {
         .remove("/v1/regions/{regionName}/indexes/{id}").get("jqFilter").textValue());
     Assertions.assertThat(response.hasErrors()).isFalse();
     System.out.println("JQ output: " + response.getOutput());
-    Assertions.assertThat(response.getOutput()).contains("\"name\": \"index1\"");
+    Assertions.assertThat(response.getOutput()).contains("\"name\":\"index1\"");
   }
 
   @Test
@@ -198,8 +199,8 @@ public class JQFilterVerificationDUnitTest {
         getJqResponse(uri, apiWithJQFilters.remove(uri).get("jqFilter").textValue());
     Assertions.assertThat(response.hasErrors()).isFalse();
     System.out.println("JQ output: " + response.getOutput());
-    Assertions.assertThat(response.getOutput()).contains("\"Member\": \"server-1\"");
-    Assertions.assertThat(response.getOutput()).contains("\"Disk Store Name\": \"diskstore1\"");
+    Assertions.assertThat(response.getOutput()).contains("\"Member\":\"server-1\"");
+    Assertions.assertThat(response.getOutput()).contains("\"Disk Store Name\":\"diskstore1\"");
   }
 
   @Test
@@ -211,7 +212,7 @@ public class JQFilterVerificationDUnitTest {
     response.getErrors().forEach(System.out::println);
     Assertions.assertThat(response.hasErrors()).isFalse();
     System.out.println("JQ output: " + response.getOutput());
-    Assertions.assertThat(response.getOutput()).contains("\"Member\": \"server-1\"");
-    Assertions.assertThat(response.getOutput()).contains("\"Disk Store Name\": \"diskstore1\"");
+    Assertions.assertThat(response.getOutput()).contains("\"Member\":\"server-1\"");
+    Assertions.assertThat(response.getOutput()).contains("\"Disk Store Name\":\"diskstore1\"");
   }
 }
