@@ -15,7 +15,7 @@
 package org.apache.geode.rest.internal.web;
 
 import static java.lang.System.lineSeparator;
-import static java.util.concurrent.TimeUnit.MILLISECONDS;
+import static java.util.concurrent.TimeUnit.MINUTES;
 import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.cache.RegionShortcut.REPLICATE;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.getTimeout;
@@ -382,7 +382,7 @@ public class RestRegionAPIIntegrationTest {
     }));
 
     for (Future<Void> future : futures) {
-      future.get(getTimeout().getValueInMS(), MILLISECONDS);
+      future.get(getTimeout().toMinutes(), MINUTES);
     }
   }
 
