@@ -20,6 +20,7 @@ import static org.apache.geode.internal.Retry.tryFor;
 import java.net.Inet4Address;
 import java.net.Inet6Address;
 import java.net.InetAddress;
+import java.net.InetSocketAddress;
 import java.net.NetworkInterface;
 import java.net.SocketException;
 import java.net.UnknownHostException;
@@ -233,6 +234,14 @@ public class LocalHostUtil {
     return localHost;
   }
 
+  /**
+   * Returns the special address that can be used to bind to all local addresses.
+   * In most cases this will be "0.0.0.0".
+   */
+  public static InetAddress getAnyLocalAddress() {
+    return new InetSocketAddress(0).getAddress();
+  }
+
   /**
    * Returns true if host matches the LOCALHOST.
    */
@@ -243,6 +252,8 @@ public class LocalHostUtil {
         return true;
       } else if (inetAddress.isLoopbackAddress()) {
         return true;
+      } else if (inetAddress.isAnyLocalAddress()) {
+        return true;
       } else {
         try {
           Enumeration en = NetworkInterface.getNetworkInterfaces();
