@@ -14,6 +14,7 @@
  */
 package org.apache.geode.connectors.jdbc.internal.cli;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.connectors.jdbc.internal.cli.CreateMappingCommand.CREATE_MAPPING;
 import static org.apache.geode.connectors.jdbc.internal.cli.DescribeMappingCommand.DESCRIBE_MAPPING;
 import static org.apache.geode.connectors.jdbc.internal.cli.DestroyMappingCommand.DESTROY_MAPPING;
@@ -203,7 +204,7 @@ public class CreateMappingCommandForProxyRegionDUnitTest {
   }
 
   private static String convertRegionPathToName(String regionPath) {
-    if (regionPath.startsWith("/")) {
+    if (regionPath.startsWith(SEPARATOR)) {
       return regionPath.substring(1);
     }
     return regionPath;
@@ -253,7 +254,7 @@ public class CreateMappingCommandForProxyRegionDUnitTest {
   @Test
   @Parameters(method = "parametersToTestPRDR")
   public void createMappingTogetherForMultiServerGroupWithEmptyRegion(boolean isPR) {
-    String regionName = "/" + TEST_REGION;
+    String regionName = SEPARATOR + TEST_REGION;
     if (isPR) {
       setupGroupPartition(regionName, TEST_GROUP1, false);
       setupGroupPartition(regionName, TEST_GROUP2, true);
@@ -322,7 +323,7 @@ public class CreateMappingCommandForProxyRegionDUnitTest {
   @Test
   @Parameters(method = "parametersToTestPRDR")
   public void createMappingSeparatelyForMultiServerGroupWithEmptyRegion(boolean isPR) {
-    String regionName = "/" + TEST_REGION;
+    String regionName = SEPARATOR + TEST_REGION;
     if (isPR) {
       setupGroupPartition(regionName, TEST_GROUP1, false);
       setupGroupPartition(regionName, TEST_GROUP2, true);
@@ -419,7 +420,7 @@ public class CreateMappingCommandForProxyRegionDUnitTest {
   @Test
   @Parameters(method = "parametersToTestPRDR")
   public void createEmptyRegionAfterCreateMapping(boolean isPR) {
-    String regionName = "/" + TEST_REGION;
+    String regionName = SEPARATOR + TEST_REGION;
     if (isPR) {
       setupGroupPartition(regionName, TEST_GROUP1, false);
     } else {
