@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.client.internal;
 
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.apache.geode.test.dunit.IgnoredException.addIgnoredException;
 import static org.apache.geode.test.dunit.NetworkUtils.getServerHostName;
@@ -41,8 +42,7 @@ import org.apache.geode.cache.RegionDestroyedException;
 import org.apache.geode.cache.client.Pool;
 import org.apache.geode.cache.client.PoolManager;
 import org.apache.geode.cache.server.CacheServer;
-import org.apache.geode.distributed.internal.ServerLocation;
-import org.apache.geode.internal.AvailablePort;
+import org.apache.geode.distributed.internal.ServerLocationAndMemberId;
 import org.apache.geode.management.membership.ClientMembership;
 import org.apache.geode.management.membership.ClientMembershipEvent;
 import org.apache.geode.management.membership.ClientMembershipListenerAdapter;
@@ -106,8 +106,7 @@ public class AutoConnectionSourceDUnitTest extends LocatorTestBase {
 
     try {
       vm0.invoke("StartBridgeClient",
-          () -> startBridgeClient(null, getServerHostName(),
-              AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET)));
+          () -> startBridgeClient(null, getServerHostName(), getRandomAvailableTCPPort()));
       checkLocators(vm0, new InetSocketAddress[] {}, new InetSocketAddress[] {});
       putInVM(vm0);
       fail("Client cache should not have been able to start");
@@ -250,7 +249,7 @@ public class AutoConnectionSourceDUnitTest extends LocatorTestBase {
     VM vm0 = VM.getVM(0);
     VM vm1 = VM.getVM(1);
 
-    int locatorPort = AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET);
+    int locatorPort = getRandomAvailableTCPPort();
 
     String locators = getLocatorString(getServerHostName(), locatorPort);
 
@@ -496,12 +495,12 @@ public class AutoConnectionSourceDUnitTest extends LocatorTestBase {
         expectedEndpointPorts.add(expectedPort);
       }
       await().untilAsserted(() -> {
-        List<ServerLocation> endpoints;
+        List<ServerLocationAndMemberId> endpoints;
         HashSet<Integer> actualEndpointPorts;
         endpoints = pool.getCurrentServers();
         actualEndpointPorts = new HashSet<>();
-        for (ServerLocation sl : endpoints) {
-          actualEndpointPorts.add(sl.getPort());
+        for (ServerLocationAndMemberId slAndMemberId : endpoints) {
+          actualEndpointPorts.add(slAndMemberId.getServerLocation().getPort());
         }
         assertEquals(expectedEndpointPorts, actualEndpointPorts);
       });
