@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query.dunit;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.CACHE_XML_FILE;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.test.dunit.IgnoredException.addIgnoredException;
@@ -102,7 +103,7 @@ public class PersistentRegionCompactRangeIndexDUnitTest implements Serializable
   public void testGIIUpdateWithIndexDoesNotDuplicateEntryInIndexWhenAlreadyRecoveredFromPersistence() {
     // this region is created via cache.xml
     String regionName = "testRegion";
-    String idQuery = "select * from /" + regionName + " p where p.ID = 1";
+    String idQuery = "select * from " + SEPARATOR + regionName + " p where p.ID = 1";
     int idQueryExpectedSize = 1;
     int numEntries = 100;
     Map<String, Portfolio> entries = new HashMap<>();
@@ -156,15 +157,15 @@ public class PersistentRegionCompactRangeIndexDUnitTest implements Serializable
     // invoke the query enough times to hopefully randomize bucket to server targeting enough to
     // target both secondary/primary servers
     server3.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + " where ID = ",
+      verifyAllEntries("select key, value from " + SEPARATOR + regionName + " where ID = ",
           () -> IntStream.range(0, numEntries), 8, 1);
     });
     server2.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + " where ID = ",
+      verifyAllEntries("select key, value from " + SEPARATOR + regionName + " where ID = ",
           () -> IntStream.range(0, numEntries), 8, 1);
     });
     server1.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + " where ID = ",
+      verifyAllEntries("select key, value from " + SEPARATOR + regionName + " where ID = ",
           () -> IntStream.range(0, numEntries), 8, 1);
     });
   }
@@ -200,15 +201,15 @@ public class PersistentRegionCompactRangeIndexDUnitTest implements Serializable
     // invoke the query enough times to hopefully randomize bucket to server targeting enough to
     // target both secondary/primary servers
     server1.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + " where ID = ",
+      verifyAllEntries("select key, value from " + SEPARATOR + regionName + " where ID = ",
           () -> IntStream.range(0, numEntries).filter(i -> i % 2 != 0), 8, 1);
     });
     server2.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + " where ID = ",
+      verifyAllEntries("select key, value from " + SEPARATOR + regionName + " where ID = ",
           () -> IntStream.range(0, numEntries).filter(i -> i % 2 != 0), 8, 1);
     });
     server1.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + " where ID = ",
+      verifyAllEntries("select key, value from " + SEPARATOR + regionName + " where ID = ",
           () -> IntStream.range(0, numEntries).filter(i -> i % 2 != 0), 8, 1);
     });
   }
@@ -245,15 +246,15 @@ public class PersistentRegionCompactRangeIndexDUnitTest implements Serializable
     // invoke the query enough times to hopefully randomize bucket to server targeting enough to
     // target both secondary/primary servers
     server3.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + " where ID = ",
+      verifyAllEntries("select key, value from " + SEPARATOR + regionName + " where ID = ",
           () -> IntStream.range(0, numEntries), 8, 1);
     });
     server2.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + " where ID = ",
+      verifyAllEntries("select key, value from " + SEPARATOR + regionName + " where ID = ",
           () -> IntStream.range(0, numEntries), 8, 1);
     });
     server1.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + " where ID = ",
+      verifyAllEntries("select key, value from " + SEPARATOR + regionName + " where ID = ",
           () -> IntStream.range(0, numEntries), 8, 1);
     });
   }
@@ -291,15 +292,18 @@ public class PersistentRegionCompactRangeIndexDUnitTest implements Serializable
     // invoke the query enough times to hopefully randomize bucket to server targeting enough to
     // target both secondary/primary servers
     server3.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + ".entrySet where value.ID = ",
+      verifyAllEntries(
+          "select key, value from " + SEPARATOR + regionName + ".entrySet where value.ID = ",
           () -> IntStream.range(0, numEntries), 8, 1);
     });
     server2.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + ".entrySet where value.ID = ",
+      verifyAllEntries(
+          "select key, value from " + SEPARATOR + regionName + ".entrySet where value.ID = ",
           () -> IntStream.range(0, numEntries), 8, 1);
     });
     server1.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + ".entrySet where value.ID = ",
+      verifyAllEntries(
+          "select key, value from " + SEPARATOR + regionName + ".entrySet where value.ID = ",
           () -> IntStream.range(0, numEntries), 8, 1);
     });
   }
@@ -333,15 +337,18 @@ public class PersistentRegionCompactRangeIndexDUnitTest implements Serializable
     // invoke the query enough times to hopefully randomize bucket to server targeting enough to
     // target both secondary/primary servers
     server3.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + ".entrySet where value.ID = ",
+      verifyAllEntries(
+          "select key, value from " + SEPARATOR + regionName + ".entrySet where value.ID = ",
           () -> IntStream.range(0, numEntries), 8, 0);
     });
     server2.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + ".entrySet where value.ID = ",
+      verifyAllEntries(
+          "select key, value from " + SEPARATOR + regionName + ".entrySet where value.ID = ",
           () -> IntStream.range(0, numEntries), 8, 0);
     });
     server1.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + ".entrySet where value.ID = ",
+      verifyAllEntries(
+          "select key, value from " + SEPARATOR + regionName + ".entrySet where value.ID = ",
           () -> IntStream.range(0, numEntries), 8, 0);
     });
   }
@@ -413,15 +420,15 @@ public class PersistentRegionCompactRangeIndexDUnitTest implements Serializable
     // invoke the query enough times to hopefully randomize bucket to server targeting enough to
     // target both secondary/primary servers
     server3.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + " where ID = ",
+      verifyAllEntries("select key, value from " + SEPARATOR + regionName + " where ID = ",
           () -> IntStream.range(0, numEntries), 8, 0);
     });
     server2.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + " where ID = ",
+      verifyAllEntries("select key, value from " + SEPARATOR + regionName + " where ID = ",
           () -> IntStream.range(0, numEntries), 8, 0);
     });
     server1.invoke(() -> {
-      verifyAllEntries("select key, value from /" + regionName + " where ID = ",
+      verifyAllEntries("select key, value from " + SEPARATOR + regionName + " where ID = ",
           () -> IntStream.range(0, numEntries), 8, 0);
     });
   }
@@ -501,14 +508,14 @@ public class PersistentRegionCompactRangeIndexDUnitTest implements Serializable
   }
 
   private void populateRegion(String regionName, Map<String, Portfolio> entries) {
-    Region r = ClusterStartupRule.getCache().getRegion("/" + regionName);
+    Region r = ClusterStartupRule.getCache().getRegion(SEPARATOR + regionName);
     entries.entrySet().forEach(e -> {
       r.put(e.getKey(), e.getValue());
     });
   }
 
   private void destroyFromRegion(String regionName, Collection keys) {
-    Region r = ClusterStartupRule.getCache().getRegion("/" + regionName);
+    Region r = ClusterStartupRule.getCache().getRegion(SEPARATOR + regionName);
     keys.forEach(i -> r.remove(i));
   }
 }
