@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query.dunit;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.fail;
 
@@ -292,14 +293,15 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
           }
         }
 
-        String[] qString = new String[] {"SELECT * FROM /REGION_NAME pf WHERE pf.ID = 1",
-            "SELECT ID FROM /REGION_NAME pf WHERE pf.ID = 1",
-            "SELECT * FROM /REGION_NAME pf WHERE pf.ID > 5",
-            "SELECT ID FROM /REGION_NAME pf WHERE pf.ID > 5",
-            "SELECT * FROM /REGION_NAME.keys key WHERE key.ID = 1",
-            "SELECT ID FROM /REGION_NAME.keys key WHERE key.ID = 1",
-            "SELECT * FROM /REGION_NAME.keys key WHERE key.ID > 5",
-            "SELECT ID FROM /REGION_NAME.keys key WHERE key.ID > 5",};
+        String[] qString =
+            new String[] {"SELECT * FROM " + SEPARATOR + "REGION_NAME pf WHERE pf.ID = 1",
+                "SELECT ID FROM " + SEPARATOR + "REGION_NAME pf WHERE pf.ID = 1",
+                "SELECT * FROM " + SEPARATOR + "REGION_NAME pf WHERE pf.ID > 5",
+                "SELECT ID FROM " + SEPARATOR + "REGION_NAME pf WHERE pf.ID > 5",
+                "SELECT * FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID = 1",
+                "SELECT ID FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID = 1",
+                "SELECT * FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID > 5",
+                "SELECT ID FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID > 5",};
 
         // Execute Query without index.
         SelectResults[] srWithoutIndex = new SelectResults[qString.length * regionNames.length];
@@ -333,14 +335,15 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
                 cache.getLogger()
                     .fine("createIndexOnOverFlowRegions() Index doesn't exist, creating index: "
                         + indexName);
-                Index i1 = qs.createIndex(indexName, "pf.ID", "/" + regionNames[i] + " pf");
+                Index i1 = qs.createIndex(indexName, "pf.ID", SEPARATOR + regionNames[i] + " pf");
               }
               indexName = "keyIdIndex" + regionNames[i];
               if (qs.getIndex(region, indexName) == null) {
                 cache.getLogger()
                     .fine("createIndexOnOverFlowRegions() Index doesn't exist, creating index: "
                         + indexName);
-                Index i2 = qs.createIndex(indexName, "key.ID", "/" + regionNames[i] + ".keys key");
+                Index i2 =
+                    qs.createIndex(indexName, "key.ID", SEPARATOR + regionNames[i] + ".keys key");
               }
             } catch (IndexNameConflictException ice) {
               // Ignore. The pr may have created the index through
@@ -459,15 +462,20 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
           }
         }
 
-        String[] qString = new String[] {"SELECT * FROM /REGION_NAME pf WHERE pf = 'XX1'",
-            "SELECT * FROM /REGION_NAME pf WHERE pf IN SET( 'XX5', 'XX6', 'XX7')",
-            "SELECT * FROM /REGION_NAME.values pf WHERE pf IN SET( 'XX5', 'XX6', 'XX7')",
-            "SELECT * FROM /REGION_NAME.keys k WHERE k.ID = 1",
-            "SELECT key.ID FROM /REGION_NAME.keys key WHERE key.ID = 1",
-            "SELECT ID, status FROM /REGION_NAME.keys WHERE ID = 1",
-            "SELECT k.ID, k.status FROM /REGION_NAME.keys k WHERE k.ID = 1 and k.status = 'active'",
-            "SELECT * FROM /REGION_NAME.keys key WHERE key.ID > 5",
-            "SELECT key.ID FROM /REGION_NAME.keys key WHERE key.ID > 5 and key.status = 'active'",};
+        String[] qString =
+            new String[] {"SELECT * FROM " + SEPARATOR + "REGION_NAME pf WHERE pf = 'XX1'",
+                "SELECT * FROM " + SEPARATOR
+                    + "REGION_NAME pf WHERE pf IN SET( 'XX5', 'XX6', 'XX7')",
+                "SELECT * FROM " + SEPARATOR
+                    + "REGION_NAME.values pf WHERE pf IN SET( 'XX5', 'XX6', 'XX7')",
+                "SELECT * FROM " + SEPARATOR + "REGION_NAME.keys k WHERE k.ID = 1",
+                "SELECT key.ID FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID = 1",
+                "SELECT ID, status FROM " + SEPARATOR + "REGION_NAME.keys WHERE ID = 1",
+                "SELECT k.ID, k.status FROM " + SEPARATOR
+                    + "REGION_NAME.keys k WHERE k.ID = 1 and k.status = 'active'",
+                "SELECT * FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID > 5",
+                "SELECT key.ID FROM " + SEPARATOR
+                    + "REGION_NAME.keys key WHERE key.ID > 5 and key.status = 'active'",};
 
         // Execute Query without index.
         SelectResults[] srWithoutIndex = new SelectResults[qString.length * regionNames.length];
@@ -502,21 +510,23 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
                 cache.getLogger()
                     .fine("createIndexOnOverFlowRegions() Index doesn't exist, creating index: "
                         + indexName);
-                Index i1 = qs.createIndex(indexName, "pf", "/" + regionNames[i] + " pf");
+                Index i1 = qs.createIndex(indexName, "pf", SEPARATOR + regionNames[i] + " pf");
               }
               indexName = "valueIndex" + regionNames[i];
               if (qs.getIndex(region, indexName) == null) {
                 cache.getLogger()
                     .fine("createIndexOnOverFlowRegions() Index doesn't exist, creating index: "
                         + indexName);
-                Index i1 = qs.createIndex(indexName, "pf", "/" + regionNames[i] + ".values pf");
+                Index i1 =
+                    qs.createIndex(indexName, "pf", SEPARATOR + regionNames[i] + ".values pf");
               }
               indexName = "keyIdIndex" + regionNames[i];
               if (qs.getIndex(region, indexName) == null) {
                 cache.getLogger()
                     .fine("createIndexOnOverFlowRegions() Index doesn't exist, creating index: "
                         + indexName);
-                Index i2 = qs.createIndex(indexName, "key.ID", "/" + regionNames[i] + ".keys key");
+                Index i2 =
+                    qs.createIndex(indexName, "key.ID", SEPARATOR + regionNames[i] + ".keys key");
               }
               indexName = "keyIdIndex2" + regionNames[i];
 
@@ -628,14 +638,15 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
         Region region = null;
 
 
-        String[] qString = new String[] {"SELECT * FROM /REGION_NAME pf WHERE pf.ID = 1",
-            "SELECT ID FROM /REGION_NAME pf WHERE pf.ID = 1",
-            "SELECT * FROM /REGION_NAME pf WHERE pf.ID > 5",
-            "SELECT ID FROM /REGION_NAME pf WHERE pf.ID > 5",
-            "SELECT * FROM /REGION_NAME.keys key WHERE key.ID = 1",
-            "SELECT ID FROM /REGION_NAME.keys key WHERE key.ID = 1",
-            "SELECT * FROM /REGION_NAME.keys key WHERE key.ID > 5",
-            "SELECT ID FROM /REGION_NAME.keys key WHERE key.ID > 5",};
+        String[] qString =
+            new String[] {"SELECT * FROM " + SEPARATOR + "REGION_NAME pf WHERE pf.ID = 1",
+                "SELECT ID FROM " + SEPARATOR + "REGION_NAME pf WHERE pf.ID = 1",
+                "SELECT * FROM " + SEPARATOR + "REGION_NAME pf WHERE pf.ID > 5",
+                "SELECT ID FROM " + SEPARATOR + "REGION_NAME pf WHERE pf.ID > 5",
+                "SELECT * FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID = 1",
+                "SELECT ID FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID = 1",
+                "SELECT * FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID > 5",
+                "SELECT ID FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID > 5",};
 
         // Execute Query without index.
         SelectResults[] srWithoutIndex = new SelectResults[qString.length * regionNames.length];
@@ -669,14 +680,15 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
                 cache.getLogger()
                     .fine("createIndexOnOverFlowRegions() Index doesn't exist, creating index: "
                         + indexName);
-                Index i1 = qs.createIndex(indexName, "pf.ID", "/" + regionNames[i] + " pf");
+                Index i1 = qs.createIndex(indexName, "pf.ID", SEPARATOR + regionNames[i] + " pf");
               }
               indexName = "keyIdIndex" + regionNames[i];
               if (qs.getIndex(region, indexName) == null) {
                 cache.getLogger()
                     .fine("createIndexOnOverFlowRegions() Index doesn't exist, creating index: "
                         + indexName);
-                Index i2 = qs.createIndex(indexName, "key.ID", "/" + regionNames[i] + ".keys key");
+                Index i2 =
+                    qs.createIndex(indexName, "key.ID", SEPARATOR + regionNames[i] + ".keys key");
               }
             } catch (IndexNameConflictException ice) {
               // Ignore. The pr may have created the index through
@@ -787,15 +799,18 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
           }
         }
 
-        String[] qString = new String[] {"SELECT * FROM /REGION_NAME pf WHERE pf = $1",
-            "SELECT * FROM /REGION_NAME pf WHERE pf > $1",
-            "SELECT * FROM /REGION_NAME.values pf WHERE pf < $1",
-            "SELECT * FROM /REGION_NAME.keys k WHERE k.ID = $1",
-            "SELECT key.ID FROM /REGION_NAME.keys key WHERE key.ID = $1",
-            "SELECT ID, status FROM /REGION_NAME.keys WHERE ID = $1",
-            "SELECT k.ID, k.status FROM /REGION_NAME.keys k WHERE k.ID = $1 and k.status = $2",
-            "SELECT * FROM /REGION_NAME.keys key WHERE key.ID > $1",
-            "SELECT key.ID FROM /REGION_NAME.keys key WHERE key.ID > $1 and key.status = $2",};
+        String[] qString =
+            new String[] {"SELECT * FROM " + SEPARATOR + "REGION_NAME pf WHERE pf = $1",
+                "SELECT * FROM " + SEPARATOR + "REGION_NAME pf WHERE pf > $1",
+                "SELECT * FROM " + SEPARATOR + "REGION_NAME.values pf WHERE pf < $1",
+                "SELECT * FROM " + SEPARATOR + "REGION_NAME.keys k WHERE k.ID = $1",
+                "SELECT key.ID FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID = $1",
+                "SELECT ID, status FROM " + SEPARATOR + "REGION_NAME.keys WHERE ID = $1",
+                "SELECT k.ID, k.status FROM " + SEPARATOR
+                    + "REGION_NAME.keys k WHERE k.ID = $1 and k.status = $2",
+                "SELECT * FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID > $1",
+                "SELECT key.ID FROM " + SEPARATOR
+                    + "REGION_NAME.keys key WHERE key.ID > $1 and key.status = $2",};
 
         // Execute Query without index.
         SelectResults[] srWithoutIndex = new SelectResults[qString.length * regionNames.length];
@@ -831,21 +846,23 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
                 cache.getLogger()
                     .fine("createIndexOnOverFlowRegions() Index doesn't exist, creating index: "
                         + indexName);
-                Index i1 = qs.createIndex(indexName, "pf", "/" + regionNames[i] + " pf");
+                Index i1 = qs.createIndex(indexName, "pf", SEPARATOR + regionNames[i] + " pf");
               }
               indexName = "valueIndex" + regionNames[i];
               if (qs.getIndex(region, indexName) == null) {
                 cache.getLogger()
                     .fine("createIndexOnOverFlowRegions() Index doesn't exist, creating index: "
                         + indexName);
-                Index i1 = qs.createIndex(indexName, "pf", "/" + regionNames[i] + ".values pf");
+                Index i1 =
+                    qs.createIndex(indexName, "pf", SEPARATOR + regionNames[i] + ".values pf");
               }
               indexName = "keyIdIndex" + regionNames[i];
               if (qs.getIndex(region, indexName) == null) {
                 cache.getLogger()
                     .fine("createIndexOnOverFlowRegions() Index doesn't exist, creating index: "
                         + indexName);
-                Index i2 = qs.createIndex(indexName, "key.ID", "/" + regionNames[i] + ".keys key");
+                Index i2 =
+                    qs.createIndex(indexName, "key.ID", SEPARATOR + regionNames[i] + ".keys key");
               }
             } catch (IndexNameConflictException ice) {
               // Ignore. The pr may have created the index through
@@ -1059,19 +1076,25 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
     QueryService qs = cache.getQueryService();
     Region region = null;
 
-    String[] qString = new String[] {"SELECT * FROM /REGION_NAME pf WHERE pf.ID = 1",
-        "SELECT ID FROM /REGION_NAME pf WHERE pf.ID = 1",
-        "SELECT * FROM /REGION_NAME pf WHERE pf.ID > 10",
-        "SELECT ID FROM /REGION_NAME pf WHERE pf.ID > 10",
-        "SELECT * FROM /REGION_NAME.keys key WHERE key.ID = 1",
-        "SELECT ID FROM /REGION_NAME.keys key WHERE key.ID = 1",
-        "SELECT * FROM /REGION_NAME.keys key WHERE key.ID > 10",
-        "SELECT ID FROM /REGION_NAME.keys key WHERE key.ID > 10",
-        "SELECT entry.value FROM /REGION_NAME.entries entry WHERE entry.value.ID = 1",
-        "SELECT entry.key FROM /REGION_NAME.entries entry WHERE entry.value.ID > 10",
-        "SELECT entry.getValue() FROM /REGION_NAME.entries entry WHERE entry.getValue().getID() = 1",
-        "SELECT entry.getKey() FROM /REGION_NAME.entries entry WHERE entry.getValue().getID() > 10",
-        "SELECT entry.getValue() FROM /REGION_NAME.entries entry WHERE entry.getValue().boolFunction('active') = false",};
+    String[] qString =
+        new String[] {"SELECT * FROM " + SEPARATOR + "REGION_NAME pf WHERE pf.ID = 1",
+            "SELECT ID FROM " + SEPARATOR + "REGION_NAME pf WHERE pf.ID = 1",
+            "SELECT * FROM " + SEPARATOR + "REGION_NAME pf WHERE pf.ID > 10",
+            "SELECT ID FROM " + SEPARATOR + "REGION_NAME pf WHERE pf.ID > 10",
+            "SELECT * FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID = 1",
+            "SELECT ID FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID = 1",
+            "SELECT * FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID > 10",
+            "SELECT ID FROM " + SEPARATOR + "REGION_NAME.keys key WHERE key.ID > 10",
+            "SELECT entry.value FROM " + SEPARATOR
+                + "REGION_NAME.entries entry WHERE entry.value.ID = 1",
+            "SELECT entry.key FROM " + SEPARATOR
+                + "REGION_NAME.entries entry WHERE entry.value.ID > 10",
+            "SELECT entry.getValue() FROM " + SEPARATOR
+                + "REGION_NAME.entries entry WHERE entry.getValue().getID() = 1",
+            "SELECT entry.getKey() FROM " + SEPARATOR
+                + "REGION_NAME.entries entry WHERE entry.getValue().getID() > 10",
+            "SELECT entry.getValue() FROM " + SEPARATOR
+                + "REGION_NAME.entries entry WHERE entry.getValue().boolFunction('active') = false",};
 
     for (int q = 0; q < qString.length; q++) {
       for (int i = 0; i < regionNames.length; i++) {
@@ -1106,35 +1129,36 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
           cache.getLogger().fine(
               "createIndexOnOverFlowRegions() Index doesn't exist, creating index: " + indexName);
           Index i1 = qs.createIndex(indexName, IndexType.FUNCTIONAL, "pf.ID",
-              "/" + regionNames[i] + " pf");
+              SEPARATOR + regionNames[i] + " pf");
         }
         indexName = "keyIdIndex" + regionNames[i];
         if (qs.getIndex(region, indexName) == null) {
           cache.getLogger().fine(
               "createIndexOnOverFlowRegions() Index doesn't exist, creating index: " + indexName);
           Index i2 = qs.createIndex(indexName, IndexType.FUNCTIONAL, "key.ID",
-              "/" + regionNames[i] + ".keys key");
+              SEPARATOR + regionNames[i] + ".keys key");
         }
         indexName = "entryIdIndex" + regionNames[i];
         if (qs.getIndex(region, indexName) == null) {
           cache.getLogger().fine(
               "createIndexOnOverFlowRegions() Index doesn't exist, creating index: " + indexName);
           Index i2 = qs.createIndex(indexName, IndexType.FUNCTIONAL, "entry.value.ID",
-              "/" + regionNames[i] + ".entries entry");
+              SEPARATOR + regionNames[i] + ".entries entry");
         }
         indexName = "entryMethodIndex" + regionNames[i];
         if (qs.getIndex(region, indexName) == null) {
           cache.getLogger().fine(
               "createIndexOnOverFlowRegions() Index doesn't exist, creating index: " + indexName);
           Index i2 = qs.createIndex(indexName, IndexType.FUNCTIONAL, "entry.getValue().getID()",
-              "/" + regionNames[i] + ".entries entry");
+              SEPARATOR + regionNames[i] + ".entries entry");
         }
         indexName = "entryMethodWithArgIndex" + regionNames[i];
         if (qs.getIndex(region, indexName) == null) {
           cache.getLogger().fine(
               "createIndexOnOverFlowRegions() Index doesn't exist, creating index: " + indexName);
           Index i2 = qs.createIndex(indexName, IndexType.FUNCTIONAL,
-              "entry.getValue().boolFunction('active')", "/" + regionNames[i] + ".entries entry");
+              "entry.getValue().boolFunction('active')",
+              SEPARATOR + regionNames[i] + ".entries entry");
         }
       } catch (IndexNameConflictException ice) {
         // Ignore. The pr may have created the index through
@@ -1203,7 +1227,8 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
 
   private static void validateIndexUpdate(Integer a, Integer b) {
     QueryService qs = basicGetCache().getQueryService();
-    Query q = qs.newQuery("SELECT DISTINCT * FROM /portfolios where status = 'active'");
+    Query q =
+        qs.newQuery("SELECT DISTINCT * FROM " + SEPARATOR + "portfolios where status = 'active'");
     QueryObserverImpl observer = new QueryObserverImpl();
     QueryObserverHolder.setInstance(observer);
     Object r;
@@ -1220,7 +1245,7 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
       fail("Index not used for query");
     }
 
-    q = qs.newQuery("SELECT DISTINCT * FROM /portfolios where status = 'inactive'");
+    q = qs.newQuery("SELECT DISTINCT * FROM " + SEPARATOR + "portfolios where status = 'inactive'");
     observer = new QueryObserverImpl();
     QueryObserverHolder.setInstance(observer);
 
@@ -1248,7 +1273,7 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
         QueryService qs = basicGetCache().getQueryService();
         if (qs != null) {
           try {
-            qs.createIndex("statusIndex", "status", "/portfolios");
+            qs.createIndex("statusIndex", "status", SEPARATOR + "portfolios");
             logger.info("Index statusIndex Created successfully");
           } catch (IndexNameConflictException e) {
             Assert.fail("Caught IndexNameConflictException", e);
@@ -1261,14 +1286,15 @@ public class QueryIndexDUnitTest extends JUnit4CacheTestCase {
           fail("Could not obtain QueryService for the cache ");
         }
       } else {
-        fail("Region.isDestroyed() returned true for region : " + "/portfolios");
+        fail("Region.isDestroyed() returned true for region : " + SEPARATOR + "portfolios");
       }
     }
   }
 
   private static void validateIndexUsage() {
     QueryService qs = basicGetCache().getQueryService();
-    Query q = qs.newQuery("SELECT DISTINCT * FROM /portfolios where status = 'active'");
+    Query q =
+        qs.newQuery("SELECT DISTINCT * FROM " + SEPARATOR + "portfolios where status = 'active'");
     QueryObserverImpl observer = new QueryObserverImpl();
     QueryObserverHolder.setInstance(observer);
     Object r;
