@@ -15,6 +15,7 @@
 package org.apache.geode.cache.query.dunit;
 
 import static java.util.concurrent.TimeUnit.MILLISECONDS;
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
 import static org.apache.geode.internal.cache.control.MemoryThresholds.MemoryState.EVICTION_DISABLED;
@@ -282,7 +283,8 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
       // Check to see if query execution is ok under "normal" or "healthy" conditions
       client.invoke("Executing query when system is 'Normal'", () -> {
 
-        Query query = getCache().getQueryService().newQuery("Select * From /" + "portfolios");
+        Query query =
+            getCache().getQueryService().newQuery("Select * From " + SEPARATOR + "portfolios");
         SelectResults results = (SelectResults) query.execute();
         assertThat(results.size()).isEqualTo(numObjects);
 
@@ -303,7 +305,8 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
   private AsyncInvocation executeQueryOnClient(VM client) {
     return client.invokeAsync("execute query from client", () -> {
       try {
-        Query query1 = getCache().getQueryService().newQuery("Select * From /" + "portfolios");
+        Query query1 =
+            getCache().getQueryService().newQuery("Select * From " + SEPARATOR + "portfolios");
         query1.execute();
         throw new CacheException("Exception should have been thrown due to low memory") {};
       } catch (Exception e2) {
@@ -364,7 +367,7 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
         QueryService qs;
         try {
           qs = getCache().getQueryService();
-          Query query = qs.newQuery("Select * From /" + "portfolios");
+          Query query = qs.newQuery("Select * From " + SEPARATOR + "portfolios");
           query.execute();
         } catch (ServerOperationException soe) {
           if (soe.getRootCause() instanceof QueryException) {
@@ -391,7 +394,7 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
       client.invoke("Executing query when system is 'Normal'", () -> {
 
         QueryService qs = getCache().getQueryService();
-        Query query = qs.newQuery("Select * From /" + "portfolios");
+        Query query = qs.newQuery("Select * From " + SEPARATOR + "portfolios");
         SelectResults results = (SelectResults) query.execute();
         assertThat(results.size()).isEqualTo(numObjects);
       });
@@ -425,7 +428,7 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
         QueryService qs;
         try {
           qs = getCache().getQueryService();
-          Query query = qs.newQuery("Select * From /" + "portfolios");
+          Query query = qs.newQuery("Select * From " + SEPARATOR + "portfolios");
           query.execute();
           throw new CacheException("should have hit low memory") {};
         } catch (Exception e) {
@@ -442,7 +445,7 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
       // Check to see if query execution is ok under "normal" or "healthy" conditions
       client.invoke("Executing query when system is 'Normal'", () -> {
         QueryService qs = getCache().getQueryService();
-        Query query = qs.newQuery("Select * From /" + "portfolios");
+        Query query = qs.newQuery("Select * From " + SEPARATOR + "portfolios");
         SelectResults results = (SelectResults) query.execute();
         assertThat(results.size()).isEqualTo(numObjects);
       });
@@ -521,7 +524,7 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
       // Check to see if query execution is ok under "normal" or "healthy" conditions
       client.invoke("Executing query when system is 'Normal'", () -> {
         QueryService qs = getCache().getQueryService();
-        Query query = qs.newQuery("Select * From /" + "portfolios");
+        Query query = qs.newQuery("Select * From " + SEPARATOR + "portfolios");
         SelectResults results = (SelectResults) query.execute();
         assertThat(results.size()).isEqualTo(numObjects);
 
@@ -565,9 +568,9 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
           qs = getCache().getQueryService();
           Index index = null;
           if (indexType.equals("compact")) {
-            index = qs.createIndex("newIndex", "ID", "/" + "portfolios");
+            index = qs.createIndex("newIndex", "ID", SEPARATOR + "portfolios");
           } else if (indexType.equals("hash")) {
-            index = qs.createIndex("newIndex", "ID", "/" + "portfolios");
+            index = qs.createIndex("newIndex", "ID", SEPARATOR + "portfolios");
           }
           assertThat(index).isNotNull();
           assertThat(((CancelDuringGatherHook) DefaultQuery.testHook).triggeredOOME).isTrue();
@@ -623,7 +626,7 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
       // Check to see if query execution is ok under "normal" or "healthy" conditions
       server.invoke("Executing query when system is 'Normal'", () -> {
         QueryService qs = getCache().getQueryService();
-        Query query = qs.newQuery("Select * From /" + "portfolios");
+        Query query = qs.newQuery("Select * From " + SEPARATOR + "portfolios");
         SelectResults results = (SelectResults) query.execute();
         assertThat(results.size()).isEqualTo(numObjects);
       });
@@ -704,7 +707,7 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
       QueryService qs;
       try {
         qs = getCache().getQueryService();
-        Query query = qs.newQuery("Select * From /" + "portfolios");
+        Query query = qs.newQuery("Select * From " + SEPARATOR + "portfolios");
         query.execute();
 
       } catch (Exception e) {
@@ -744,7 +747,7 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
       QueryService qs = null;
       try {
         qs = getCache().getQueryService();
-        Query query = qs.newQuery("Select * From /" + "portfolios");
+        Query query = qs.newQuery("Select * From " + SEPARATOR + "portfolios");
         callbackToVM
             .invoke(() -> ResourceManagerWithQueryMonitorDUnitTest.criticalMemoryCountDownLatch
                 .countDown());
@@ -769,7 +772,7 @@ public class ResourceManagerWithQueryMonitorDUnitTest extends ClientServerTestCa
       }
 
       try {
-        Query query = qs.newQuery("Select * From /" + "portfolios");
+        Query query = qs.newQuery("Select * From " + SEPARATOR + "portfolios");
 
         query.execute();
 
