@@ -20,6 +20,7 @@ import static java.util.concurrent.TimeUnit.MINUTES;
 import static java.util.concurrent.TimeUnit.SECONDS;
 import static org.apache.geode.cache.DataPolicy.REPLICATE;
 import static org.apache.geode.cache.LossAction.RECONNECT;
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.cache.ResumptionAction.NONE;
 import static org.apache.geode.cache.Scope.DISTRIBUTED_ACK;
 import static org.apache.geode.distributed.ConfigurationProperties.CACHE_XML_FILE;
@@ -37,6 +38,7 @@ import static org.apache.geode.distributed.ConfigurationProperties.SECURITY_MANA
 import static org.apache.geode.distributed.ConfigurationProperties.START_LOCATOR;
 import static org.apache.geode.distributed.Locator.getLocator;
 import static org.apache.geode.distributed.internal.membership.api.MembershipManagerHelper.getDistribution;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.getTimeout;
 import static org.apache.geode.test.dunit.Host.getHost;
@@ -93,7 +95,6 @@ import org.apache.geode.distributed.internal.ServerLocator;
 import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
 import org.apache.geode.distributed.internal.membership.api.MembershipManagerHelper;
 import org.apache.geode.examples.SimpleSecurityManager;
-import org.apache.geode.internal.AvailablePort;
 import org.apache.geode.internal.AvailablePortHelper;
 import org.apache.geode.internal.cache.GemFireCacheImpl;
 import org.apache.geode.internal.cache.InternalCache;
@@ -133,7 +134,9 @@ public class ReconnectDUnitTest extends JUnit4CacheTestCase {
 
   @Override
   public final void postSetUp() throws Exception {
-    locatorPort = AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET);
+    IgnoredException.addIgnoredException("ForcedDisconnectException");
+    IgnoredException.addIgnoredException("Possible loss of quorum");
+    locatorPort = getRandomAvailableTCPPort();
     final int locPort = locatorPort;
     Host.getHost(0).getVM(locatorVMNumber).invoke(new SerializableRunnable("start locator") {
       @Override
@@ -147,8 +150,6 @@ public class ReconnectDUnitTest extends JUnit4CacheTestCase {
           system = (InternalDistributedSystem) locator.getDistributedSystem();
           cache = ((InternalLocator) locator).getCache();
           ReconnectDUnitTest.savedSystem = locator.getDistributedSystem();
-          IgnoredException.addIgnoredException(
-              "org.apache.geode.ForcedDisconnectException||Possible loss of quorum");
           // MembershipManagerHelper.getMembershipManager(InternalDistributedSystem.getConnectedInstance()).setDebugJGroups(true);
         } catch (IOException e) {
           Assert.fail("unable to start locator", e);
@@ -264,9 +265,9 @@ public class ReconnectDUnitTest extends JUnit4CacheTestCase {
             props.put(MAX_NUM_RECONNECT_TRIES, "2");
             // props.put("log-file", "autoReconnectVM"+VM.getCurrentVMNum()+"_"+getPID()+".log");
             cache = (InternalCache) new CacheFactory(props).create();
-            IgnoredException.addIgnoredException(
-                "org.apache.geode.ForcedDisconnectException||Possible loss of quorum");
-            Region myRegion = cache.getRegion("root/myRegion");
+            IgnoredException.addIgnoredException("org.apache.geode.ForcedDisconnectException");
+            IgnoredException.addIgnoredException("Possible loss of quorum");
+            Region myRegion = cache.getRegion("root" + SEPARATOR + "myRegion");
             ReconnectDUnitTest.savedSystem = cache.getDistributedSystem();
             myRegion.put("MyKey1", "MyValue1");
             return savedSystem.getDistributedMember();
@@ -332,7 +333,7 @@ public class ReconnectDUnitTest extends JUnit4CacheTestCase {
             props.put(CACHE_XML_FILE, xmlFileLoc + fileSeparator + "MyDisconnect-cache.xml");
             props.put(MAX_WAIT_TIME_RECONNECT, "1000");
             cache = (InternalCache) new CacheFactory(props).create();
-            Region myRegion = cache.getRegion("root/myRegion");
+            Region myRegion = cache.getRegion("root" + SEPARATOR + "myRegion");
             ReconnectDUnitTest.savedSystem = cache.getDistributedSystem();
             myRegion.put("MyKey1", "MyValue1");
             return savedSystem.getDistributedMember();
@@ -352,7 +353,7 @@ public class ReconnectDUnitTest extends JUnit4CacheTestCase {
             getSystem(props);
             cache = getCache();
             ReconnectDUnitTest.savedSystem = cache.getDistributedSystem();
-            Region myRegion = cache.getRegion("root/myRegion");
+            Region myRegion = cache.getRegion("root" + SEPARATOR + "myRegion");
             myRegion.put("Mykey2", "MyValue2");
             assertNotNull(myRegion.get("MyKey1"));
             if (createInAppToo) {
@@ -585,7 +586,7 @@ public class ReconnectDUnitTest extends JUnit4CacheTestCase {
       props.put(MAX_WAIT_TIME_RECONNECT, "1000");
       ReconnectDUnitTest.savedSystem = getSystem(props);
       cache = getCache();
-      Region myRegion = cache.getRegion("root/myRegion");
+      Region myRegion = cache.getRegion("root" + SEPARATOR + "myRegion");
       myRegion.put("MyKey1", "MyValue1");
       return savedSystem.getDistributedMember();
     });
@@ -678,7 +679,8 @@ public class ReconnectDUnitTest extends JUnit4CacheTestCase {
 
   @Test
   public void testReconnectWithRoleLoss() throws TimeoutException, RegionExistsException {
-
+    IgnoredException.addIgnoredException(CacheClosedException.class);
+    IgnoredException.addIgnoredException(DistributedSystemDisconnectedException.class);
     final String rr1 = "RoleA";
     final String rr2 = "RoleB";
     final String[] requiredRoles = {rr1, rr2};
@@ -809,6 +811,7 @@ public class ReconnectDUnitTest extends JUnit4CacheTestCase {
   // for the 2014 8.0 release.
   @Test
   public void testReconnectWithRequiredRoleRegained() throws Throwable {
+    IgnoredException.addIgnoredException(DistributedSystemDisconnectedException.class);
 
     final String rr1 = "RoleA";
     // final String rr2 = "RoleB";
@@ -1115,6 +1118,9 @@ public class ReconnectDUnitTest extends JUnit4CacheTestCase {
    */
   @Test
   public void testReconnectFailsDueToBadCacheXML() throws Exception {
+    IgnoredException.addIgnoredException(DistributedSystemDisconnectedException.class);
+    IgnoredException.addIgnoredException("Cause parsing to fail");
+    IgnoredException.addIgnoredException("Exception while initializing an instance");
 
     Host host = getHost(0);
     VM vm0 = host.getVM(0);
