@@ -30,19 +30,15 @@ import static org.apache.geode.distributed.ConfigurationProperties.START_LOCATOR
 import static org.apache.geode.distributed.ConfigurationProperties.TCP_PORT;
 import static org.apache.geode.distributed.internal.DistributionConfig.DEFAULT_ACK_WAIT_THRESHOLD;
 import static org.apache.geode.distributed.internal.OperationExecutors.SERIAL_EXECUTOR;
-import static org.apache.geode.internal.AvailablePort.MULTICAST;
-import static org.apache.geode.internal.AvailablePort.SOCKET;
-import static org.apache.geode.internal.AvailablePort.getRandomAvailablePort;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPortRange;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableUDPPort;
 import static org.apache.geode.internal.inet.LocalHostUtil.getLocalHost;
 import static org.apache.geode.test.dunit.DistributedTestUtils.getDUnitLocatorPort;
 import static org.apache.geode.test.dunit.LogWriterUtils.getLogWriter;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 
-import java.io.DataInput;
-import java.io.DataOutput;
-import java.io.IOException;
 import java.net.Inet4Address;
 import java.net.Inet6Address;
 import java.net.InetAddress;
@@ -59,7 +55,6 @@ import org.junit.Test;
 import org.junit.experimental.categories.Category;
 
 import org.apache.geode.CancelException;
-import org.apache.geode.DataSerializable;
 import org.apache.geode.GemFireConfigException;
 import org.apache.geode.SerializationException;
 import org.apache.geode.SystemConnectException;
@@ -67,7 +62,6 @@ import org.apache.geode.cache.AttributesFactory;
 import org.apache.geode.cache.Cache;
 import org.apache.geode.cache.CacheFactory;
 import org.apache.geode.cache.Region;
-import org.apache.geode.cache.execute.FunctionContext;
 import org.apache.geode.cache.execute.FunctionService;
 import org.apache.geode.distributed.internal.ClusterDistributionManager;
 import org.apache.geode.distributed.internal.Distribution;
@@ -98,9 +92,9 @@ public class DistributedSystemDUnitTest extends JUnit4DistributedTestCase {
   public void before() throws Exception {
     disconnectAllFromDS();
 
-    this.mcastPort = getRandomAvailablePort(MULTICAST);
-    this.locatorPort = getRandomAvailablePort(SOCKET);
-    this.tcpPort = getRandomAvailablePort(SOCKET);
+    this.mcastPort = getRandomAvailableUDPPort();
+    this.locatorPort = getRandomAvailableTCPPort();
+    this.tcpPort = getRandomAvailableTCPPort();
 
     int[] portRange = getRandomAvailableTCPPortRange(3, true);
     this.lowerBoundOfPortRange = portRange[0];
@@ -462,28 +456,4 @@ public class DistributedSystemDUnitTest extends JUnit4DistributedTestCase {
       return "FakeMessage(blocking=" + (this.blocked != null) + ")";
     }
   }
-
-  /**
-   * A function that cannot be deserialized, used for failure handling
-   */
-  public static class FailDeserializationFunction
-      implements org.apache.geode.cache.execute.Function,
-      DataSerializable {
-    @Override
-    public void execute(FunctionContext context) {
-
-    }
-
-
-    @Override
-    public void toData(DataOutput out) throws IOException {
-
-    }
-
-    @Override
-    public void fromData(DataInput in) throws IOException, ClassNotFoundException {
-      throw new ClassNotFoundException("Fake class not found");
-
-    }
-  }
 }
