@@ -21,6 +21,7 @@ import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
 import static org.apache.geode.distributed.ConfigurationProperties.NAME;
 import static org.apache.geode.distributed.internal.membership.gms.membership.GMSJoinLeave.BYPASS_DISCOVERY_PROPERTY;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
+import static org.apache.geode.test.awaitility.GeodeAwaitility.getTimeout;
 import static org.apache.geode.test.dunit.IgnoredException.addIgnoredException;
 import static org.apache.geode.test.dunit.Invoke.invokeInEveryVM;
 import static org.apache.geode.test.dunit.NetworkUtils.getIPLiteral;
@@ -34,8 +35,14 @@ import java.io.File;
 import java.net.InetAddress;
 import java.util.HashSet;
 import java.util.Properties;
+import java.util.concurrent.BrokenBarrierException;
+import java.util.concurrent.CyclicBarrier;
+import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
+import java.util.concurrent.Future;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 import org.apache.logging.log4j.Logger;
@@ -58,9 +65,11 @@ import org.apache.geode.cache.Region;
 import org.apache.geode.cache.RegionEvent;
 import org.apache.geode.cache.RegionFactory;
 import org.apache.geode.cache.Scope;
+import org.apache.geode.cache.execute.FunctionService;
 import org.apache.geode.cache.util.CacheListenerAdapter;
 import org.apache.geode.distributed.ConfigurationProperties;
 import org.apache.geode.distributed.DistributedMember;
+import org.apache.geode.distributed.FailDeserializationFunction;
 import org.apache.geode.distributed.Locator;
 import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
 import org.apache.geode.distributed.internal.membership.api.MemberDisconnectedException;
@@ -92,6 +101,7 @@ public class ClusterDistributionManagerDUnitTest extends CacheTestCase {
 
   private VM locatorvm;
   private VM vm1;
+  private VM vm2;
 
   @Rule
   public DistributedRestoreSystemProperties restoreSystemProperties =
@@ -107,12 +117,14 @@ public class ClusterDistributionManagerDUnitTest extends CacheTestCase {
 
     locatorvm = VM.getVM(0);
     vm1 = VM.getVM(1);
+    vm2 = VM.getVM(2);
     Invoke.invokeInEveryVM(() -> System.setProperty("p2p.joinTimeout", "120000"));
     final int port = locatorvm.invoke(() -> {
       System.setProperty(BYPASS_DISCOVERY_PROPERTY, "true");
       return Locator.startLocatorAndDS(0, new File(""), new Properties()).getPort();
     });
     vm1.invoke(() -> locatorPort = port);
+    vm2.invoke(() -> locatorPort = port);
     locatorPort = port;
   }
 
@@ -286,10 +298,12 @@ public class ClusterDistributionManagerDUnitTest extends CacheTestCase {
     assertThat(getCache().isClosed()).isFalse();
     Region<String, String> region = regionFactory.create("testRegion");
 
+    addIgnoredException("elapsed while waiting for replies");
+    // Ignore logging from Connection.doSevereAlertProcessing()
+    addIgnoredException("seconds have elapsed waiting for a response from");
     vm1.invoke("Connect to distributed system", () -> {
       config.setProperty(NAME, "sleeper");
       getSystem(config);
-      addIgnoredException("elapsed while waiting for replies");
 
       RegionFactory<String, String> regionFactory2 = getCache().createRegionFactory();
       regionFactory2.setScope(Scope.DISTRIBUTED_ACK);
@@ -338,6 +352,8 @@ public class ClusterDistributionManagerDUnitTest extends CacheTestCase {
     Region<String, String> region = regionFactory.create("testRegion");
 
     addIgnoredException("sec have elapsed while waiting for replies");
+    // Ignore logging from Connection.doSevereAlertProcessing()
+    addIgnoredException("seconds have elapsed waiting for a response from");
 
     vm1.invoke(new SerializableRunnable("Connect to distributed system") {
       @Override
@@ -428,6 +444,54 @@ public class ClusterDistributionManagerDUnitTest extends CacheTestCase {
         .untilAsserted(() -> assertThat(waitForViewInstallationDone.get()).isTrue());
   }
 
+  /**
+   * show that waitForViewInstallation works as expected when distribution manager is closed
+   * while waiting for the latest membership view to install
+   */
+  @Test
+  public void testWaitForViewInstallationDisconnectDS()
+      throws InterruptedException, TimeoutException, BrokenBarrierException, ExecutionException {
+    InternalDistributedSystem system = getSystem();
+    ClusterDistributionManager dm = (ClusterDistributionManager) system.getDM();
+    MembershipView<InternalDistributedMember> view = dm.getDistribution().getView();
+
+    CyclicBarrier cyclicBarrier = new CyclicBarrier(2);
+    Future future = executorService.submit(() -> {
+      try {
+        cyclicBarrier.await(getTimeout().toMillis(), TimeUnit.MILLISECONDS);
+        dm.waitForViewInstallation(view.getViewId() + 1);
+      } catch (InterruptedException | BrokenBarrierException | TimeoutException e) {
+        errorCollector.addError(e);
+      }
+    });
+
+    cyclicBarrier.await(getTimeout().toMillis(), TimeUnit.MILLISECONDS);
+    system.disconnect();
+    future.get(getTimeout().toMillis(), TimeUnit.MILLISECONDS);
+  }
+
+  @Test
+  public void testMemberJoinsAfterNewViewIsInstalled() {
+    vm1.invoke("join the cluster", () -> getSystem().getDistributedMember());
+    vm1.invoke(
+        () -> system.getDistributionManager().addMembershipListener(new MembershipListener() {
+          @Override
+          public void memberJoined(DistributionManager distributionManager,
+              InternalDistributedMember id) {
+            if (!distributionManager.getDistribution().getMembership().memberExists(id)) {
+              // if MemberJoinedEvent is triggered before the new view is installed,
+              // the test will throw an exception
+              FunctionService.onMember(id)
+                  .execute(new FailDeserializationFunction());
+            }
+          }
+        }));
+    // trigger MemberJoinedEvent
+    DistributedMember member =
+        vm2.invoke("join the cluster", () -> getSystem().getDistributedMember());
+    assertThat(member).isNotNull();
+  }
+
   private CacheListener<String, String> getSleepingListener(final boolean playDead) {
     regionDestroyedInvoked = false;
 
