@@ -14,8 +14,10 @@
  */
 package org.apache.geode.internal.cache.ha;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
@@ -40,7 +42,6 @@ import org.apache.geode.cache.util.CacheListenerAdapter;
 import org.apache.geode.cache30.CacheSerializableRunnable;
 import org.apache.geode.cache30.ClientServerTestCase;
 import org.apache.geode.distributed.DistributedSystem;
-import org.apache.geode.internal.AvailablePort;
 import org.apache.geode.internal.cache.CacheObserverAdapter;
 import org.apache.geode.internal.cache.CacheObserverHolder;
 import org.apache.geode.internal.cache.CacheServerImpl;
@@ -128,7 +129,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
     server2.invoke(checkSizeRegion(regionSize));
     client1.invoke(checkSizeRegion(regionSize));
     client2.invoke(checkSizeRegion(regionSize));
-    Region region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region region = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(region);
     assertEquals(region.size(), regionSize);
     clearRegion();
@@ -197,7 +198,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
     server2.invoke(checkSizeRegion(regionSize));
     client1.invoke(checkSizeRegion(regionSize));
     client2.invoke(checkSizeRegion(regionSize));
-    Region region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region region = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(region);
     assertEquals(region.size(), NO_OF_PUTS);
     server1.invoke(clearRegionFromServer());
@@ -244,7 +245,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
     });
 
     regionSize = 0;
-    region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    region = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(region);
     synchronized (HAClearDUnitTest.class) {
       while (!gotClearCallback) {
@@ -281,7 +282,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
     putKnownKeys();
     Thread.sleep(5000);
     int regionSize = NO_OF_PUTS;
-    Region region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region region = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(region);
     assertEquals(region.size(), regionSize);
     server1.invoke(checkSizeRegion(regionSize));
@@ -333,7 +334,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
       }
     });
 
-    region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    region = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNull(region);
     client1.invoke(checkDestroyRegion());
     client2.invoke(checkDestroyRegion());
@@ -357,7 +358,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
     server2.invoke(checkSizeRegion(regionSize));
     client1.invoke(checkSizeRegion(regionSize));
     client2.invoke(checkSizeRegion(regionSize));
-    Region region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region region = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(region);
     assertEquals(region.size(), NO_OF_PUTS);
     server1.invoke(destroyRegionFromServer());
@@ -417,7 +418,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
     }
     gotDestroyRegionCallback = false;
 
-    region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    region = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNull(region);
     client1.invoke(checkDestroyRegion());
     client2.invoke(checkDestroyRegion());
@@ -431,7 +432,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
     CacheSerializableRunnable putFromServer = new CacheSerializableRunnable("putFromServer") {
       @Override
       public void run2() throws CacheException {
-        Region region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+        Region region = cache.getRegion(SEPARATOR + REGION_NAME);
         assertNotNull(region);
         for (int i = 0; i < NO_OF_PUTS; i++) {
           region.put("key" + i, "value" + i);
@@ -444,7 +445,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
 
   // function to perform put operations for the known set of keys.
   private void putKnownKeys() {
-    Region region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region region = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(region);
     for (int i = 0; i < NO_OF_PUTS; i++) {
       region.put("key" + i, "value" + i);
@@ -453,14 +454,14 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
 
   // function to perform clear operation from client.
   private void clearRegion() {
-    LocalRegion region = (LocalRegion) cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    LocalRegion region = (LocalRegion) cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(region);
     region.clear();
   }
 
   // function to perform destroyRegion operation from client.
   private void destroyRegion() {
-    LocalRegion region = (LocalRegion) cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    LocalRegion region = (LocalRegion) cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(region);
     region.destroyRegion();
   }
@@ -471,7 +472,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
     CacheSerializableRunnable clearFromServer = new CacheSerializableRunnable("clearFromServer") {
       @Override
       public void run2() {
-        LocalRegion region = (LocalRegion) cache.getRegion(Region.SEPARATOR + REGION_NAME);
+        LocalRegion region = (LocalRegion) cache.getRegion(SEPARATOR + REGION_NAME);
         assertNotNull(region);
         region.clear();
       }
@@ -485,7 +486,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
         new CacheSerializableRunnable("destroyRegionFromServer") {
           @Override
           public void run2() {
-            LocalRegion region = (LocalRegion) cache.getRegion(Region.SEPARATOR + REGION_NAME);
+            LocalRegion region = (LocalRegion) cache.getRegion(SEPARATOR + REGION_NAME);
             assertNotNull(region);
             region.destroyRegion();
           }
@@ -500,7 +501,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
 
       @Override
       public void run2() throws CacheException {
-        Region region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+        Region region = cache.getRegion(SEPARATOR + REGION_NAME);
         assertNotNull(region);
         LogWriterUtils.getLogWriter().info("Size of the region " + region.size());
         assertEquals(size, region.size());
@@ -514,7 +515,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
     CacheSerializableRunnable destroyRegion = new CacheSerializableRunnable("checkDestroyRegion") {
       @Override
       public void run2() throws CacheException {
-        Region region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+        Region region = cache.getRegion(SEPARATOR + REGION_NAME);
         LogWriterUtils.getLogWriter().warning("Found region " + region);
         assertNull(region);
       }
@@ -546,7 +547,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
     cache.createRegion(REGION_NAME, attrs);
     server = (CacheServerImpl) cache.addCacheServer();
     assertNotNull(server);
-    int port = AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET);
+    int port = getRandomAvailableTCPPort();
     server.setPort(port);
     server.start();
     return new Integer(server.getPort());
@@ -598,7 +599,7 @@ public class HAClearDUnitTest extends JUnit4DistributedTestCase {
     }
     RegionAttributes attrs = factory.create();
     cache.createRegion(REGION_NAME, attrs);
-    Region region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region region = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(region);
     if (isRegisterInterest) {
       region.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
