@@ -15,8 +15,10 @@
 package org.apache.geode.internal.cache.tier.sockets;
 
 import static java.lang.Thread.yield;
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
@@ -43,7 +45,6 @@ import org.apache.geode.cache.client.internal.PoolImpl;
 import org.apache.geode.cache.server.CacheServer;
 import org.apache.geode.cache.util.CacheListenerAdapter;
 import org.apache.geode.distributed.DistributedSystem;
-import org.apache.geode.internal.AvailablePort;
 import org.apache.geode.internal.cache.CacheServerImpl;
 import org.apache.geode.internal.cache.ClientServerObserverAdapter;
 import org.apache.geode.internal.cache.ClientServerObserverHolder;
@@ -495,8 +496,8 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
   }
 
   public static void waitForMarker() {
-    cache.getRegion(Region.SEPARATOR + REGION_NAME1);
-    cache.getRegion(Region.SEPARATOR + REGION_NAME2);
+    cache.getRegion(SEPARATOR + REGION_NAME1);
+    cache.getRegion(SEPARATOR + REGION_NAME2);
     long giveUpTime = System.currentTimeMillis() + 30000;
     synchronized (ConflationDUnitTest.class) {
       while (count != 2) {
@@ -518,8 +519,8 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
    */
   public static void assertValue() {
     try {
-      Region r1 = cache.getRegion(Region.SEPARATOR + REGION_NAME1);
-      Region r2 = cache.getRegion(Region.SEPARATOR + REGION_NAME2);
+      Region r1 = cache.getRegion(SEPARATOR + REGION_NAME1);
+      Region r2 = cache.getRegion(SEPARATOR + REGION_NAME2);
       assertTrue(r1.containsKey("key-1"));
       assertTrue(r1.get("key-1").equals("33"));
       assertTrue(r2.containsKey("key-1"));
@@ -557,7 +558,7 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
     cache.createRegion(REGION_NAME1, attrs);
     cache.createRegion(REGION_NAME2, attrs);
     CacheServer server = cache.addCacheServer();
-    int port = AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET);
+    int port = getRandomAvailableTCPPort();
     server.setPort(port);
     server.setNotifyBySubscription(true);
     server.setSocketBufferSize(32768);
@@ -582,8 +583,8 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
    */
   public static void registerInterest() {
     try {
-      Region region1 = cache.getRegion(Region.SEPARATOR + REGION_NAME1);
-      Region region2 = cache.getRegion(Region.SEPARATOR + REGION_NAME2);
+      Region region1 = cache.getRegion(SEPARATOR + REGION_NAME1);
+      Region region2 = cache.getRegion(SEPARATOR + REGION_NAME2);
       assertTrue(region1 != null);
       assertTrue(region2 != null);
       region1.registerInterest("ALL_KEYS");
@@ -601,8 +602,8 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
 
   public static void unregisterInterest() {
     try {
-      Region region1 = cache.getRegion(Region.SEPARATOR + REGION_NAME1);
-      Region region2 = cache.getRegion(Region.SEPARATOR + REGION_NAME2);
+      Region region1 = cache.getRegion(SEPARATOR + REGION_NAME1);
+      Region region2 = cache.getRegion(SEPARATOR + REGION_NAME2);
       region1.unregisterInterest("ALL_KEYS");
       region2.unregisterInterest("ALL_KEYS");
     } catch (CacheWriterException e) {
@@ -616,8 +617,8 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
    */
   public static void create() {
     try {
-      Region r1 = cache.getRegion(Region.SEPARATOR + REGION_NAME1);
-      Region r2 = cache.getRegion(Region.SEPARATOR + REGION_NAME2);
+      Region r1 = cache.getRegion(SEPARATOR + REGION_NAME1);
+      Region r2 = cache.getRegion(SEPARATOR + REGION_NAME2);
       r1.create("key-1", "value");
       r2.create("key-1", "value");
     } catch (Exception ex) {
@@ -632,8 +633,8 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
    */
   public static void put() {
     try {
-      Region r1 = cache.getRegion(Region.SEPARATOR + REGION_NAME1);
-      Region r2 = cache.getRegion(Region.SEPARATOR + REGION_NAME2);
+      Region r1 = cache.getRegion(SEPARATOR + REGION_NAME1);
+      Region r2 = cache.getRegion(SEPARATOR + REGION_NAME2);
       r1.put("key-1", "11");
       r1.put("key-1", "22");
       r1.put("key-1", "33");
@@ -648,8 +649,8 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
 
   public static void createMarker() {
     try {
-      Region r1 = cache.getRegion(Region.SEPARATOR + REGION_NAME1);
-      Region r2 = cache.getRegion(Region.SEPARATOR + REGION_NAME2);
+      Region r1 = cache.getRegion(SEPARATOR + REGION_NAME1);
+      Region r2 = cache.getRegion(SEPARATOR + REGION_NAME2);
       r1.put(MARKER, MARKER);
       r2.put(MARKER, MARKER);
     } catch (Exception ex) {
@@ -664,8 +665,8 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
    */
   public static void put200() {
     try {
-      Region r1 = cache.getRegion(Region.SEPARATOR + REGION_NAME1);
-      Region r2 = cache.getRegion(Region.SEPARATOR + REGION_NAME2);
+      Region r1 = cache.getRegion(SEPARATOR + REGION_NAME1);
+      Region r2 = cache.getRegion(SEPARATOR + REGION_NAME2);
       for (int i = 1; i < 100; i++) {
         r1.put("key-1", "11");
         r2.put("key-1", "11");
@@ -715,7 +716,7 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
    */
   public static void get() {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME1);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME1);
       r.get("key-1");
     } catch (Exception ex) {
       ex.printStackTrace();
@@ -729,11 +730,11 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
    */
   public static void destroyRegion() {
     try {
-      Region region1 = cache.getRegion("/region1");
+      Region region1 = cache.getRegion(SEPARATOR + "region1");
       if (region1 != null) {
         region1.destroyRegion();
       }
-      Region region2 = cache.getRegion("/region1");
+      Region region2 = cache.getRegion(SEPARATOR + "region1");
       if (region2 != null) {
         region2.destroyRegion();
       }
@@ -749,8 +750,8 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
    */
   public static void destroy() {
     try {
-      Region region1 = cache.getRegion(Region.SEPARATOR + REGION_NAME1);
-      Region region2 = cache.getRegion(Region.SEPARATOR + REGION_NAME2);
+      Region region1 = cache.getRegion(SEPARATOR + REGION_NAME1);
+      Region region2 = cache.getRegion(SEPARATOR + REGION_NAME2);
       region1.destroy("key-1");
       region2.destroy("key-1");
 
@@ -766,8 +767,8 @@ public class ConflationDUnitTest extends JUnit4DistributedTestCase {
    */
   public static void destroyMarker() {
     try {
-      Region region1 = cache.getRegion(Region.SEPARATOR + REGION_NAME1);
-      Region region2 = cache.getRegion(Region.SEPARATOR + REGION_NAME2);
+      Region region1 = cache.getRegion(SEPARATOR + REGION_NAME1);
+      Region region2 = cache.getRegion(SEPARATOR + REGION_NAME2);
       region1.destroy(MARKER);
       region2.destroy(MARKER);
       count = 0;
