@@ -18,6 +18,7 @@ import static org.apache.geode.distributed.ConfigurationProperties.DURABLE_CLIEN
 import static org.apache.geode.distributed.ConfigurationProperties.DURABLE_CLIENT_TIMEOUT;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
@@ -40,7 +41,6 @@ import org.apache.geode.cache.client.PoolFactory;
 import org.apache.geode.cache.client.PoolManager;
 import org.apache.geode.cache30.CacheSerializableRunnable;
 import org.apache.geode.distributed.internal.DistributionConfig;
-import org.apache.geode.internal.AvailablePort;
 import org.apache.geode.internal.cache.CacheServerImpl;
 import org.apache.geode.internal.cache.FilterProfile;
 import org.apache.geode.internal.cache.GemFireCacheImpl;
@@ -413,7 +413,7 @@ public class DurableRegistrationDUnitTest extends JUnit4DistributedTestCase {
   public void testDurableClientWithRegistrationHA() {
 
     // Step 1: Start server1
-    PORT2 = new Integer(AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET));
+    PORT2 = getRandomAvailableTCPPort();
 
     PORT1 = ((Integer) this.server1VM
         .invoke(() -> CacheServerTestUtil.createCacheServer(regionName, new Boolean(true))))
@@ -514,7 +514,7 @@ public class DurableRegistrationDUnitTest extends JUnit4DistributedTestCase {
   public void testDurableClientDisConnectWithRegistrationHA() {
 
     // Step 1: Start server1
-    PORT2 = new Integer(AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET));
+    PORT2 = getRandomAvailableTCPPort();
 
     PORT1 = ((Integer) this.server1VM
         .invoke(() -> CacheServerTestUtil.createCacheServer(regionName, new Boolean(true))))
