@@ -15,10 +15,12 @@
 package org.apache.geode.internal.cache.tier.sockets;
 
 import static org.apache.geode.cache.Region.Entry;
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.DURABLE_CLIENT_ID;
 import static org.apache.geode.distributed.ConfigurationProperties.DURABLE_CLIENT_TIMEOUT;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
@@ -42,7 +44,6 @@ import org.apache.geode.cache.client.PoolManager;
 import org.apache.geode.cache.client.internal.PoolImpl;
 import org.apache.geode.cache.server.CacheServer;
 import org.apache.geode.distributed.DistributedSystem;
-import org.apache.geode.internal.AvailablePort;
 import org.apache.geode.internal.cache.ClientServerObserverAdapter;
 import org.apache.geode.internal.cache.ClientServerObserverHolder;
 import org.apache.geode.test.awaitility.GeodeAwaitility;
@@ -87,7 +88,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
   @Test
   public void testRegisterInterestResponse_NonExistent_Invalid() throws Exception {
     server1.invoke(() -> DurableResponseMatrixDUnitTest.invalidateEntry(KEY));
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.registerInterest(KEY, InterestResultPolicy.KEYS_VALUES);
     assertFalse(r.containsValueForKey(KEY)); // invalidate
     assertEquals(null, r.getEntry(KEY).getValue()); // invalidate
@@ -96,7 +97,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
   @Test
   public void testRegisterInterestResponse_NonExistent_Valid() throws Exception {
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.registerInterest(KEY, InterestResultPolicy.KEYS_VALUES);
     assertEquals("ValueMatrix1", r.getEntry(KEY).getValue());
   }
@@ -104,7 +105,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
   @Ignore("TODO: test is broken and disabled")
   @Test
   public void testRegisterInterestResponse_Valid_Invalid() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.put(KEY, "ValueMatrix1");
     server1.invoke(() -> DurableResponseMatrixDUnitTest.invalidateEntry(KEY));
     r.registerInterest(KEY, InterestResultPolicy.KEYS_VALUES);
@@ -113,7 +114,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testRegisterInterestResponse_Valid_Valid() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.put(KEY, "ValueMatrix1");
     r.registerInterest(KEY, InterestResultPolicy.KEYS_VALUES);
     assertEquals("ValueMatrix1", r.getEntry(KEY).getValue());
@@ -121,7 +122,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testRegisterInterestResponse_Invalid_Invalid() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     invalidateEntry(KEY);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.invalidateEntry(KEY));
     r.registerInterest(KEY, InterestResultPolicy.KEYS_VALUES);
@@ -131,7 +132,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
   @Ignore("TODO: test is broken and disabled")
   @Test
   public void testRegisterInterestResponse_Invalid_Valid() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     invalidateEntry(KEY);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
     r.registerInterest(KEY, InterestResultPolicy.KEYS_VALUES);
@@ -140,7 +141,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testRegisterInterestResponse_Destroyed_Invalid() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.put(KEY, "DummyValue");
     r.destroy(KEY);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.invalidateEntry(KEY));
@@ -151,7 +152,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testRegisterInterestResponse_Destroyed_Valid() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.put(KEY, "DummyValue");
     r.destroy(KEY);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
@@ -165,14 +166,14 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
     ClientServerObserverHolder.setInstance(new ClientServerObserverAdapter() {
       @Override
       public void beforeInterestRegistration() {
-        Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+        Region r = cache.getRegion(SEPARATOR + REGION_NAME);
         r.put(KEY, "AgainDummyValue");
         r.destroy(KEY);
         PoolImpl.BEFORE_REGISTER_CALLBACK_FLAG = false;
       }
     });
 
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.put(KEY, "DummyValue");
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
 
@@ -209,7 +210,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_NonExistent_Create() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
     waitForValue(r, KEY, "ValueMatrix1");
@@ -217,7 +218,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_NonExistent_Update() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix2"));
@@ -226,7 +227,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_NonExistent_Invalid() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.invalidateEntryOnly(KEY));
@@ -235,7 +236,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_NonExistent_Destroy() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.destroyEntry(KEY));
@@ -244,7 +245,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_Valid_Create() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.put(KEY, "DummyValue");
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
@@ -253,7 +254,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_Valid_Update() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.put(KEY, "DummyValue");
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix2"));
@@ -263,7 +264,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
   @Ignore("TODO: test is broken and disabled")
   @Test
   public void testNotification_Valid_Invalid() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.put(KEY, "DummyValue");
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.invalidateEntryOnly(KEY));
@@ -272,7 +273,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_Valid_Destroy() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     r.put(KEY, "DummyValue");
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.destroyEntry(KEY));
@@ -281,7 +282,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_Invalid_Create() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     invalidateEntry(KEY);
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
@@ -290,7 +291,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_Invalid_Update() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     invalidateEntry(KEY);
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
@@ -300,7 +301,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
   @Ignore("TODO: test is broken and disabled")
   @Test
   public void testNotification_Invalid_Invalid() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     invalidateEntry(KEY);
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.invalidateEntryOnly(KEY));
@@ -309,7 +310,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_Invalid_Destroy() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     invalidateEntry(KEY);
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.destroyEntry(KEY));
@@ -318,7 +319,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_LocalInvalid_Create() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     localInvalidateEntry(KEY);
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
@@ -327,7 +328,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_LocalInvalid_Update() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     localInvalidateEntry(KEY);
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.updateEntry(KEY, "ValueMatrix1"));
@@ -337,7 +338,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
   @Ignore("TODO: test is broken and disabled")
   @Test
   public void testNotification_LocalInvalid_Invalid() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     localInvalidateEntry(KEY);
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.invalidateEntryOnly(KEY));
@@ -346,7 +347,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   @Test
   public void testNotification_LocalInvalid_Destroy() throws Exception {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     invalidateEntry(KEY);
     r.registerInterest("ALL_KEYS", InterestResultPolicy.NONE);
     server1.invoke(() -> DurableResponseMatrixDUnitTest.destroyEntry(KEY));
@@ -355,7 +356,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   public static void updateEntry(String key, String value) throws Exception {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       r.put(key, value);
     } catch (Exception e) {
@@ -365,7 +366,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   public static void destroyEntry(String key) throws Exception {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       r.destroy(key);
     } catch (Exception e) {
@@ -375,7 +376,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   public static void invalidateEntryOnly(String key) throws Exception {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       r.invalidate(key);
     } catch (Exception e) {
@@ -385,7 +386,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   public static void invalidateEntry(String key) throws Exception {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       r.put(key, "DummyValue");
       r.invalidate(key);
@@ -396,7 +397,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
 
   public static void localInvalidateEntry(String key) throws Exception {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       r.put(key, "DummyValue");
       r.localInvalidate(key);
@@ -457,7 +458,7 @@ public class DurableResponseMatrixDUnitTest extends JUnit4DistributedTestCase {
     Region r = cache.createRegion(REGION_NAME, attrs);
     assertNotNull(r);
     CacheServer server1 = cache.addCacheServer();
-    int port = AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET);
+    int port = getRandomAvailableTCPPort();
     server1.setPort(port);
     server1.setNotifyBySubscription(true);
     server1.start();
