@@ -18,6 +18,7 @@ import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.DELTA_PROPAGATION;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.fail;
@@ -55,7 +56,6 @@ import org.apache.geode.cache.server.CacheServer;
 import org.apache.geode.cache.util.CacheListenerAdapter;
 import org.apache.geode.distributed.DistributedMember;
 import org.apache.geode.distributed.DistributedSystem;
-import org.apache.geode.internal.AvailablePort;
 import org.apache.geode.internal.cache.CacheServerImpl;
 import org.apache.geode.test.awaitility.GeodeAwaitility;
 import org.apache.geode.test.dunit.Assert;
@@ -626,7 +626,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
 
   private static CacheServer addCacheServer() throws Exception {
     CacheServer s = cache.addCacheServer();
-    int port = AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET);
+    int port = getRandomAvailableTCPPort();
     s.setPort(port);
     s.start();
     return s;
@@ -738,7 +738,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
 
   private static void createEntriesK1andK2() {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       if (!r.containsKey(key1)) {
         r.create(key1, key1_originalValue);
@@ -755,7 +755,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
   }
 
   private static void registerKeyOnly(Object key) {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(r);
     r.registerInterest(key);
   }
@@ -778,7 +778,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
     try {
       ClientSession cs = server.getClientSession(clientId);
       if (cs.isPrimary()) {
-        cs.registerInterest(Region.SEPARATOR + REGION_NAME, key, InterestResultPolicy.KEYS_VALUES,
+        cs.registerInterest(SEPARATOR + REGION_NAME, key, InterestResultPolicy.KEYS_VALUES,
             false);
       }
     } catch (Exception ex) {
@@ -798,7 +798,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
 
   private static void registerALL_KEYS() {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       r.registerInterest("ALL_KEYS");
     } catch (Exception ex) {
@@ -808,7 +808,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
 
   private static void put_ALL_KEYS() {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       r.put(key1, "vm1-key-1");
       r.put(key2, "vm1-key-2");
@@ -822,7 +822,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
 
   private static void validate_ALL_KEYS() {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       assertEquals(r.getEntry(key1).getValue(), "vm1-key-1");
       assertEquals(r.getEntry(key2).getValue(), "vm1-key-2");
@@ -834,7 +834,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
   private static void registerKeys() {
     List list = new ArrayList();
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       list.add("k1");
       list.add("k2");
@@ -847,7 +847,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
   private static void registerKeysAgain() {
     List list = new ArrayList();
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       list.add("k3");
       list.add("k4");
       list.add("k5");
@@ -858,7 +858,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
   }
 
   private static void unregisterKeyOnly(Object key) {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(r);
     r.unregisterInterest(key);
   }
@@ -881,7 +881,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
     try {
       ClientSession cs = server.getClientSession(clientId);
       if (cs.isPrimary()) {
-        cs.unregisterInterest(Region.SEPARATOR + REGION_NAME, key, false);
+        cs.unregisterInterest(SEPARATOR + REGION_NAME, key, false);
       }
     } catch (Exception ex) {
       Assert.fail("failed while un-registering key(" + key + ") for client " + clientId, ex);
@@ -893,7 +893,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
   }
 
   private static void validateRegionEntriesFromInterestListInVm1() {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(r);
     Region.Entry k1, k2;
     k1 = r.getEntry("k1");
@@ -905,7 +905,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
   }
 
   private static void validateRegionEntriesFromInterestListInVm2() {
-    Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region r = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(r);
     assertEquals(r.getEntry("k3").getValue(), "server3");
     assertEquals(r.getEntry("k4").getValue(), "server4");
@@ -914,7 +914,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
 
   private static void putSingleEntry(Object key, String value) {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       r.put(key, value);
       // Verify that no invalidates occurred to this region
@@ -926,7 +926,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
 
   private static void put(String vm) {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       if (vm.equals("vm1")) {
         r.put(key1, "vm1-key-1");
@@ -949,7 +949,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
 
   private static void multiple_put() {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       r.put("k1", "server1");
       r.put("k2", "server2");
@@ -964,7 +964,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
 
   private static void putAgain(String vm) {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       if (vm.equals("vm1")) {
         r.put(key1, "vm1-key-1-again");
@@ -1033,7 +1033,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
 
   private static void validateSingleEntry(Object key, String value) {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertEquals(value, r.getEntry(key).getValue());
     } catch (Exception ex) {
       Assert.fail("failed while validateSingleEntry()", ex);
@@ -1042,7 +1042,7 @@ public class InterestListDUnitTest extends JUnit4DistributedTestCase {
 
   private static void validateEntriesAgain(String vm) {
     try {
-      Region r = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+      Region r = cache.getRegion(SEPARATOR + REGION_NAME);
       assertNotNull(r);
       if (vm.equals("vm1")) {
         // Verify that neither 'key-1' 'key-2' was updated and contain the
