@@ -14,9 +14,11 @@
  */
 package org.apache.geode.internal.cache.versions;
 
-import static org.apache.geode.cache.RegionShortcut.PARTITION;
 import static org.apache.geode.cache.RegionShortcut.REPLICATE;
 import static org.apache.geode.cache.RegionShortcut.REPLICATE_PERSISTENT;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
+import static org.apache.geode.internal.cache.InitialImageOperation.GIITestHookType.DuringApplyDelta;
+import static org.apache.geode.internal.cache.InitialImageOperation.resetAllGIITestHooks;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.assertEquals;
@@ -26,6 +28,7 @@ import java.util.Arrays;
 import java.util.Properties;
 import java.util.concurrent.CountDownLatch;
 
+import org.apache.logging.log4j.Logger;
 import org.junit.After;
 import org.junit.Rule;
 import org.junit.Test;
@@ -37,18 +40,20 @@ import org.apache.geode.cache.RegionShortcut;
 import org.apache.geode.cache.client.ClientCache;
 import org.apache.geode.cache.client.ClientCacheFactory;
 import org.apache.geode.cache.client.ClientRegionShortcut;
+import org.apache.geode.cache.server.CacheServer;
 import org.apache.geode.distributed.internal.ClusterDistributionManager;
 import org.apache.geode.distributed.internal.DistributionMessage;
 import org.apache.geode.distributed.internal.DistributionMessageObserver;
 import org.apache.geode.internal.cache.DestroyOperation;
 import org.apache.geode.internal.cache.DistributedTombstoneOperation;
+import org.apache.geode.internal.cache.InitialImageOperation;
 import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.LocalRegion;
 import org.apache.geode.internal.cache.PartitionedRegion;
 import org.apache.geode.internal.cache.RegionEntry;
 import org.apache.geode.internal.cache.TombstoneService;
+import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.test.dunit.AsyncInvocation;
-import org.apache.geode.test.dunit.DistributedTestUtils;
 import org.apache.geode.test.dunit.NetworkUtils;
 import org.apache.geode.test.dunit.VM;
 import org.apache.geode.test.dunit.rules.DistributedRule;
@@ -67,6 +72,10 @@ public class TombstoneDUnitTest implements Serializable {
   public void close() {
     for (VM vm : Arrays.asList(VM.getVM(0), VM.getVM(1))) {
       vm.invoke(() -> {
+        resetAllGIITestHooks();
+        if (region != null && !region.isDestroyed()) {
+          region.destroyRegion();
+        }
         region = null;
         if (cache != null) {
           cache.close();
@@ -122,13 +131,13 @@ public class TombstoneDUnitTest implements Serializable {
 
     // Create a cache and load some boiler plate entries
     server1.invoke(() -> {
-      createCacheAndRegion(REPLICATE);
+      createCacheAndRegion(RegionShortcut.REPLICATE);
       for (int i = 0; i < count; i++) {
         region.put("K" + i, "V" + i);
       }
     });
 
-    server2.invoke(() -> createCacheAndRegion(REPLICATE));
+    server2.invoke(() -> createCacheAndRegion(RegionShortcut.REPLICATE));
 
     server1.invoke(() -> {
 
@@ -166,15 +175,16 @@ public class TombstoneDUnitTest implements Serializable {
     VM server2 = VM.getVM(1);
     final int FAR_INTO_THE_FUTURE = 1000000; // 1 million millis into the future
     final int count = 2000;
+    Logger logger = LogService.getLogger();
     // Create a cache and load some boiler plate entries
     server1.invoke(() -> {
-      createCacheAndRegion(PARTITION);
+      createCacheAndRegion(RegionShortcut.PARTITION);
       for (int i = 0; i < count; i++) {
         region.put("K" + i, "V" + i);
       }
     });
 
-    server2.invoke(() -> createCacheAndRegion(PARTITION));
+    server2.invoke(() -> createCacheAndRegion(RegionShortcut.PARTITION));
 
     server1.invoke(() -> {
 
@@ -217,13 +227,13 @@ public class TombstoneDUnitTest implements Serializable {
     VM server2 = VM.getVM(1);
     final int count = 10;
     server1.invoke(() -> {
-      createCacheAndRegion(REPLICATE);
+      createCacheAndRegion(RegionShortcut.REPLICATE);
       for (int i = 0; i < count; i++) {
         region.put("K" + i, "V" + i);
       }
     });
 
-    server2.invoke(() -> createCacheAndRegion(REPLICATE));
+    server2.invoke(() -> createCacheAndRegion(RegionShortcut.REPLICATE));
 
     server1.invoke(() -> {
       TombstoneService.TombstoneSweeper tombstoneSweeper =
@@ -247,17 +257,21 @@ public class TombstoneDUnitTest implements Serializable {
     VM client = VM.getVM(0);
     VM server = VM.getVM(1);
 
+
     // Fire up the server and put in some data that is deletable
     server.invoke(() -> {
       createCacheAndRegion(REPLICATE);
-      cache.addCacheServer().start();
+      int serverPort = getRandomAvailableTCPPort();
+      CacheServer cacheServer = cache.addCacheServer();
+      cacheServer.setPort(serverPort);
+      cacheServer.start();
       for (int i = 0; i < 1000; i++) {
         region.put("K" + i, "V" + i);
       }
     });
 
     String locatorHost = NetworkUtils.getServerHostName();
-    int locatorPort = DistributedTestUtils.getLocatorPort();
+    int locatorPort = DistributedRule.getLocatorPort();
     // Use the client to remove and entry, thus creating a tombstone
     client.invoke(() -> {
       createClientCacheAndRegion(locatorHost, locatorPort);
@@ -322,14 +336,17 @@ public class TombstoneDUnitTest implements Serializable {
     // Fire up the server and put in some data that is deletable
     server.invoke(() -> {
       createCacheAndRegion(REPLICATE);
-      cache.addCacheServer().start();
+      int serverPort = getRandomAvailableTCPPort();
+      CacheServer cacheServer = cache.addCacheServer();
+      cacheServer.setPort(serverPort);
+      cacheServer.start();
       for (int i = 0; i < 1000; i++) {
         region.put("K" + i, "V" + i);
       }
     });
 
     String locatorHost = NetworkUtils.getServerHostName();
-    int locatorPort = DistributedTestUtils.getLocatorPort();
+    int locatorPort = DistributedRule.getLocatorPort();
     // Use the client to remove and entry, thus creating a tombstone
     client.invoke(() -> {
       createClientCacheAndRegion(locatorHost, locatorPort);
@@ -348,7 +365,8 @@ public class TombstoneDUnitTest implements Serializable {
   }
 
   @Test
-  public void testTombstonesWithLowerVersionThanTheRecordedVersionGetsGCed() throws Exception {
+  public void testTombstonesWithLowerVersionThanTheRecordedVersionGetsGCedAfterDestroy()
+      throws Exception {
     VM vm0 = VM.getVM(0);
     VM vm1 = VM.getVM(1);
     Properties props = DistributedRule.getDistributedSystemProperties();
@@ -391,6 +409,86 @@ public class TombstoneDUnitTest implements Serializable {
     });
   }
 
+  @Test
+  public void tombstoneGCDuringGIICorrectlySchedulesTombstonesForCollection() {
+    VM vm0 = VM.getVM(0);
+    VM vm1 = VM.getVM(1);
+    Properties props = DistributedRule.getDistributedSystemProperties();
+    props.setProperty("conserve-sockets", "false");
+
+    vm0.invoke(() -> {
+      createCacheAndRegion(REPLICATE_PERSISTENT, props);
+      region.put("K1", "V1");
+      region.put("K2", "V2");
+    });
+
+    vm1.invoke(() -> {
+      createCacheAndRegion(REPLICATE_PERSISTENT, props);
+      // Ensure that there are local tombstones to be recovered in the member that will request GII
+      region.destroy("K1");
+      region.destroy("K2");
+      cache.close();
+      region = null;
+    });
+
+    vm0.invoke(() -> {
+      // Ensure that there are newer tombstones that will be sent via GII
+      region.put("K1", "V3");
+      region.destroy("K1");
+      region.put("K2", "V4");
+      region.destroy("K2");
+      // Trigger a tombstone GC after receiving the GII request message
+      InitialImageOperation.setGIITestHook(new InitialImageOperation.GIITestHook(
+          InitialImageOperation.GIITestHookType.AfterReceivedRequestImage, REGION_NAME) {
+        private static final long serialVersionUID = -3790198435185240444L;
+
+        @Override
+        public void reset() {}
+
+        @Override
+        public void run() {
+          try {
+            performGC(((LocalRegion) region).getTombstoneCount());
+          } catch (Exception ignore) {
+          }
+        }
+      });
+    });
+
+    vm1.invoke(() -> {
+      cache = new CacheFactory(props).create();
+
+      InitialImageOperation.setGIITestHook(
+          new InitialImageOperation.GIITestHook(DuringApplyDelta, REGION_NAME) {
+            private static final long serialVersionUID = 637083883125364247L;
+            private int entryNumber = 0;
+
+            @Override
+            public void reset() {}
+
+            @Override
+            public void run() {
+              if (entryNumber == 0) {
+                await().alias("Waiting for scheduled tombstone count to be zero")
+                    .until(() -> ((InternalCache) cache).getTombstoneService()
+                        .getScheduledTombstoneCount() == 0);
+              }
+              // Confirm that tombstones are correctly scheduled for collection after processing
+              // each new entry received during GII
+              assertThat(((InternalCache) cache).getTombstoneService().getScheduledTombstoneCount())
+                  .as("Scheduled tombstone count did not match expected value")
+                  .isEqualTo(entryNumber++);
+            }
+          });
+
+      region = cache.<String, String>createRegionFactory(REPLICATE_PERSISTENT).create(REGION_NAME);
+
+      // Confirm that we are able to collect all tombstones once the region is initialized
+      performGC(((LocalRegion) region).getTombstoneCount());
+      assertEquals(0, ((LocalRegion) region).getTombstoneCount());
+    });
+  }
+
   // Client Cache
   private void createClientCacheAndRegion(String locatorHost, int locatorPort) {
     ClientCache clientcache =
@@ -409,9 +507,7 @@ public class TombstoneDUnitTest implements Serializable {
     createCacheAndRegion(regionShortCut, DistributedRule.getDistributedSystemProperties());
   }
 
-
   private static class RegionObserver extends DistributionMessageObserver implements Serializable {
-
     private static final long serialVersionUID = 6272522949825923089L;
     VersionTag<?> versionTag;
     CountDownLatch tombstoneGcLatch = new CountDownLatch(1);
