@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
@@ -94,7 +95,7 @@ public class PdxStringQueryJUnitTest {
 
   @Test
   public void testQueriesWithCompactRangeIndexPdxInstances() throws Exception {
-    Index index = queryService.createIndex("index1", "secId", "/exampleRegion");
+    Index index = queryService.createIndex("index1", "secId", SEPARATOR + "exampleRegion");
     assertTrue(index instanceof CompactRangeIndex);
     putPdxInstances();
     CloseableIterator<IndexStoreEntry> indexIterator = null;
@@ -114,7 +115,7 @@ public class PdxStringQueryJUnitTest {
 
   @Test
   public void testQueriesWithCompactRangeIndexPdxInstancesREUpdateInProgress() throws Exception {
-    Index index = queryService.createIndex("index1", "secId", "/exampleRegion");
+    Index index = queryService.createIndex("index1", "secId", SEPARATOR + "exampleRegion");
     assertTrue(index instanceof CompactRangeIndex);
     putPdxInstancesWithREUpdateInProgress();
     CloseableIterator<IndexStoreEntry> indexIterator = null;
@@ -142,7 +143,8 @@ public class PdxStringQueryJUnitTest {
   @Test
   public void testQueriesWithRangeIndex() throws Exception {
     Index index =
-        queryService.createIndex("index2", "p.secId", "/exampleRegion p, p.positions.values");
+        queryService.createIndex("index2", "p.secId",
+            SEPARATOR + "exampleRegion p, p.positions.values");
     assertTrue(index instanceof RangeIndex);
     PdxInstanceFactory pf = PdxInstanceFactoryImpl.newCreator("Portfolio", false, this.cache);
     pf.writeInt("ID", 111);
@@ -191,7 +193,8 @@ public class PdxStringQueryJUnitTest {
   @Test
   public void testQueriesWithRangeIndexWithREUpdateInProgress() throws Exception {
     Index index =
-        queryService.createIndex("index2", "p.secId", "/exampleRegion p, p.positions.values");
+        queryService.createIndex("index2", "p.secId",
+            SEPARATOR + "exampleRegion p, p.positions.values");
     assertTrue(index instanceof RangeIndex);
     PdxInstanceFactory pf = PdxInstanceFactoryImpl.newCreator("Portfolio", false, this.cache);
     pf.writeInt("ID", 111);
@@ -240,7 +243,7 @@ public class PdxStringQueryJUnitTest {
 
   @Test
   public void testQueriesWithPrimaryKeyIndex() throws Exception {
-    Index index = queryService.createKeyIndex("index3", "secId", "/exampleRegion");
+    Index index = queryService.createKeyIndex("index3", "secId", SEPARATOR + "exampleRegion");
     assertTrue(index instanceof PrimaryKeyIndex);
     putPdxInstances();
     executeQueriesValidateResults(INDEX_TYPE_PRIMARYKEY);
@@ -254,8 +257,9 @@ public class PdxStringQueryJUnitTest {
   @Test
   public void testStringMethods() throws Exception {
     putPdxInstances();
-    String queries[] = {"select secId from /exampleRegion where secId.toLowerCase()  = 'ibm'",
-        "select secId from /exampleRegion where secId.startsWith('I')"};
+    String queries[] =
+        {"select secId from " + SEPARATOR + "exampleRegion where secId.toLowerCase()  = 'ibm'",
+            "select secId from " + SEPARATOR + "exampleRegion where secId.startsWith('I')"};
     for (int i = 0; i < queries.length; i++) {
       SelectResults res = (SelectResults) queryService.newQuery(queries[i]).execute();
       assertEquals("Incorrect result size returned for query. " + queries[i], 1, res.size());
@@ -369,45 +373,56 @@ public class PdxStringQueryJUnitTest {
   private void executeQueriesValidateResults(int indexType) throws Exception {
     cache.setPdxReadSerializedOverride(true);
 
-    String[] query = {"select count(*) from /exampleRegion",
-        "select count(*) from /exampleRegion p, p.positions.values v",
-        "select count(*) from /exampleRegion"};
+    String[] query = {"select count(*) from " + SEPARATOR + "exampleRegion",
+        "select count(*) from " + SEPARATOR + "exampleRegion p, p.positions.values v",
+        "select count(*) from " + SEPARATOR + "exampleRegion"};
 
     SelectResults res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(4, res.iterator().next());
 
-    query = new String[] {"select secId from /exampleRegion where secId  = 'IBM'",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.secId = 'IBM'",
-        "select secId from /exampleRegion where secId  = 'IBM'"};
+    query = new String[] {"select secId from " + SEPARATOR + "exampleRegion where secId  = 'IBM'",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId = 'IBM'",
+        "select secId from " + SEPARATOR + "exampleRegion where secId  = 'IBM'"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(1, res.size());
     validateStringResult("IBM", res.iterator().next());
 
     query = new String[] {
-        "select p.secId from /exampleRegion p where p.secId  = ELEMENT(select e.secId from /exampleRegion e where e.secId  = 'IBM') ",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.secId = ELEMENT(select p1.secId from /exampleRegion p1, p.positions.values v1 where p1.secId = 'IBM')",
-        "select p.secId from /exampleRegion p where p.secId  = ELEMENT(select e.secId from /exampleRegion e where e.secId  = 'IBM' )"};
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p where p.secId  = ELEMENT(select e.secId from " + SEPARATOR
+            + "exampleRegion e where e.secId  = 'IBM') ",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId = ELEMENT(select p1.secId from "
+            + SEPARATOR + "exampleRegion p1, p.positions.values v1 where p1.secId = 'IBM')",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p where p.secId  = ELEMENT(select e.secId from " + SEPARATOR
+            + "exampleRegion e where e.secId  = 'IBM' )"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(1, res.size());
     validateStringResult("IBM", res.iterator().next());
 
-    query = new String[] {"select secId from /exampleRegion where secId LIKE 'VMW'",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.secId LIKE 'VMW'",
-        "select secId from /exampleRegion where secId LIKE 'VMW'"};
+    query = new String[] {"select secId from " + SEPARATOR + "exampleRegion where secId LIKE 'VMW'",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId LIKE 'VMW'",
+        "select secId from " + SEPARATOR + "exampleRegion where secId LIKE 'VMW'"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(1, res.size());
     validateStringResult("VMW", res.iterator().next());
 
-    query = new String[] {"select secId from /exampleRegion where secId LIKE 'VM%'",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.secId LIKE 'VM%'",
-        "select secId from /exampleRegion where secId LIKE 'VM%'"};
+    query = new String[] {"select secId from " + SEPARATOR + "exampleRegion where secId LIKE 'VM%'",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId LIKE 'VM%'",
+        "select secId from " + SEPARATOR + "exampleRegion where secId LIKE 'VM%'"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(1, res.size());
     validateStringResult("VMW", res.iterator().next());
 
-    query = new String[] {"select secId from /exampleRegion where secId IN SET ('YHOO', 'VMW')",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.secId  IN SET ('YHOO', 'VMW')",
-        "select secId from /exampleRegion where secId IN SET ('YHOO', 'VMW')"};
+    query = new String[] {
+        "select secId from " + SEPARATOR + "exampleRegion where secId IN SET ('YHOO', 'VMW')",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId  IN SET ('YHOO', 'VMW')",
+        "select secId from " + SEPARATOR + "exampleRegion where secId IN SET ('YHOO', 'VMW')"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(2, res.size());
     List secIdsList = new ArrayList();
@@ -420,9 +435,15 @@ public class PdxStringQueryJUnitTest {
     }
 
     query = new String[] {
-        "select p.secId from /exampleRegion p where p.secId IN  (select e.secId from /exampleRegion e where e.secId ='YHOO' or e.secId = 'VMW')",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.secId  IN  (select e.secId from /exampleRegion e where e.secId ='YHOO' or e.secId = 'VMW')",
-        "select p.secId from /exampleRegion p where p.secId IN  (select e.secId from /exampleRegion e where e.secId ='YHOO' or e.secId = 'VMW')"};
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p where p.secId IN  (select e.secId from " + SEPARATOR
+            + "exampleRegion e where e.secId ='YHOO' or e.secId = 'VMW')",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId  IN  (select e.secId from "
+            + SEPARATOR + "exampleRegion e where e.secId ='YHOO' or e.secId = 'VMW')",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p where p.secId IN  (select e.secId from " + SEPARATOR
+            + "exampleRegion e where e.secId ='YHOO' or e.secId = 'VMW')"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(2, res.size());
     secIdsList = new ArrayList();
@@ -434,9 +455,11 @@ public class PdxStringQueryJUnitTest {
       validateResult(secIdsList, iter.next());
     }
 
-    query = new String[] {"select secId, status from /exampleRegion where secId = 'IBM'",
-        "select p.secId, p.status from /exampleRegion p, p.positions.values v where p.secId = 'IBM'",
-        "select secId, status from /exampleRegion where secId = 'IBM'"};
+    query = new String[] {
+        "select secId, status from " + SEPARATOR + "exampleRegion where secId = 'IBM'",
+        "select p.secId, p.status from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId = 'IBM'",
+        "select secId, status from " + SEPARATOR + "exampleRegion where secId = 'IBM'"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(1, res.size());
     secIdsList = new ArrayList();
@@ -450,9 +473,10 @@ public class PdxStringQueryJUnitTest {
     validateResult(secIdsList, o2);
 
 
-    query = new String[] {"select secId from /exampleRegion where secId < 'YHOO'",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.secId < 'YHOO'",
-        "select secId from /exampleRegion where secId < 'YHOO'"};
+    query = new String[] {"select secId from " + SEPARATOR + "exampleRegion where secId < 'YHOO'",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId < 'YHOO'",
+        "select secId from " + SEPARATOR + "exampleRegion where secId < 'YHOO'"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(3, res.size());
     iter = res.iterator();
@@ -464,9 +488,10 @@ public class PdxStringQueryJUnitTest {
       validateResult(secIdsList, iter.next());
     }
 
-    query = new String[] {"select secId from /exampleRegion where 'YHOO' > secId",
-        "select p.secId from /exampleRegion p, p.positions.values v where 'YHOO' >  p.secId",
-        "select secId from /exampleRegion where 'YHOO' > secId"};
+    query = new String[] {"select secId from " + SEPARATOR + "exampleRegion where 'YHOO' > secId",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where 'YHOO' >  p.secId",
+        "select secId from " + SEPARATOR + "exampleRegion where 'YHOO' > secId"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(3, res.size());
     iter = res.iterator();
@@ -478,9 +503,10 @@ public class PdxStringQueryJUnitTest {
       validateResult(secIdsList, iter.next());
     }
 
-    query = new String[] {"select secId from /exampleRegion where secId > 'IBM'",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.secId > 'IBM'",
-        "select secId from /exampleRegion where secId > 'IBM'"};
+    query = new String[] {"select secId from " + SEPARATOR + "exampleRegion where secId > 'IBM'",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId > 'IBM'",
+        "select secId from " + SEPARATOR + "exampleRegion where secId > 'IBM'"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(2, res.size());
     iter = res.iterator();
@@ -491,9 +517,12 @@ public class PdxStringQueryJUnitTest {
       validateResult(secIdsList, iter.next());
     }
 
-    query = new String[] {"select secId from /exampleRegion where secId > 'IBM' or ID=333",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.secId > 'IBM' or p.ID=333",
-        "select secId from /exampleRegion where secId = 'VMW' or secId = 'YHOO' or secId = 'GOOGL'"};
+    query = new String[] {
+        "select secId from " + SEPARATOR + "exampleRegion where secId > 'IBM' or ID=333",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId > 'IBM' or p.ID=333",
+        "select secId from " + SEPARATOR
+            + "exampleRegion where secId = 'VMW' or secId = 'YHOO' or secId = 'GOOGL'"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(3, res.size());
     iter = res.iterator();
@@ -505,9 +534,11 @@ public class PdxStringQueryJUnitTest {
       validateResult(secIdsList, iter.next());
     }
 
-    query = new String[] {"select secId from /exampleRegion where secId > 'IBM' and secId < 'YHOO'",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.secId > 'IBM' and p.secId < 'YHOO'",
-        "select secId from /exampleRegion where secId > 'IBM' and secId < 'YHOO'"};
+    query = new String[] {
+        "select secId from " + SEPARATOR + "exampleRegion where secId > 'IBM' and secId < 'YHOO'",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId > 'IBM' and p.secId < 'YHOO'",
+        "select secId from " + SEPARATOR + "exampleRegion where secId > 'IBM' and secId < 'YHOO'"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(1, res.size());
     iter = res.iterator();
@@ -517,9 +548,10 @@ public class PdxStringQueryJUnitTest {
       validateResult(secIdsList, iter.next());
     }
 
-    query = new String[] {"select secId from /exampleRegion where ID = 111",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.ID = 111",
-        "select secId from /exampleRegion where secId = 'VMW' or secId = 'IBM'"};
+    query = new String[] {"select secId from " + SEPARATOR + "exampleRegion where ID = 111",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.ID = 111",
+        "select secId from " + SEPARATOR + "exampleRegion where secId = 'VMW' or secId = 'IBM'"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(2, res.size());
     iter = res.iterator();
@@ -530,21 +562,25 @@ public class PdxStringQueryJUnitTest {
       validateResult(secIdsList, iter.next());
     }
 
-    query = new String[] {"select distinct ID from /exampleRegion where ID = 111",
-        "select distinct p.ID from /exampleRegion p, p.positions.values v where p.ID = 111",
-        "select distinct secId from /exampleRegion where secId = 'VMW'"};
+    query = new String[] {"select distinct ID from " + SEPARATOR + "exampleRegion where ID = 111",
+        "select distinct p.ID from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.ID = 111",
+        "select distinct secId from " + SEPARATOR + "exampleRegion where secId = 'VMW'"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(1, res.size());
 
-    query = new String[] {"select ID from /exampleRegion where ID = 111 limit 1",
-        "select p.ID from /exampleRegion p, p.positions.values v where p.ID = 111 limit 1",
-        "select secId from /exampleRegion where secId = 'VMW' limit 1"};
+    query = new String[] {"select ID from " + SEPARATOR + "exampleRegion where ID = 111 limit 1",
+        "select p.ID from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.ID = 111 limit 1",
+        "select secId from " + SEPARATOR + "exampleRegion where secId = 'VMW' limit 1"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(1, res.size());
 
-    query = new String[] {"select distinct secId from /exampleRegion order by secId",
-        "select distinct p.secId from /exampleRegion p, p.positions.values order by p.secId",
-        "select distinct secId from /exampleRegion order by secId"};
+    query =
+        new String[] {"select distinct secId from " + SEPARATOR + "exampleRegion order by secId",
+            "select distinct p.secId from " + SEPARATOR
+                + "exampleRegion p, p.positions.values order by p.secId",
+            "select distinct secId from " + SEPARATOR + "exampleRegion order by secId"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(4, res.size());
     iter = res.iterator();
@@ -554,9 +590,10 @@ public class PdxStringQueryJUnitTest {
       validateStringResult(secIds[i++], iter.next());
     }
 
-    query = new String[] {"select distinct * from /exampleRegion order by secId",
-        "select distinct * from /exampleRegion p, p.positions.values v  order by p.secId",
-        "select distinct * from /exampleRegion order by secId"};
+    query = new String[] {"select distinct * from " + SEPARATOR + "exampleRegion order by secId",
+        "select distinct * from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v  order by p.secId",
+        "select distinct * from " + SEPARATOR + "exampleRegion order by secId"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(4, res.size());
     iter = res.iterator();
@@ -571,9 +608,11 @@ public class PdxStringQueryJUnitTest {
       }
     }
 
-    query = new String[] {"select distinct secId from /exampleRegion order by secId limit 2",
-        "select distinct p.secId from /exampleRegion p, p.positions.values v  order by p.secId limit 2",
-        "select distinct secId from /exampleRegion order by secId limit 2"};
+    query = new String[] {
+        "select distinct secId from " + SEPARATOR + "exampleRegion order by secId limit 2",
+        "select distinct p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v  order by p.secId limit 2",
+        "select distinct secId from " + SEPARATOR + "exampleRegion order by secId limit 2"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(2, res.size());
     iter = res.iterator();
@@ -583,9 +622,11 @@ public class PdxStringQueryJUnitTest {
       validateStringResult(secIds[i++], iter.next());
     }
 
-    query = new String[] {"select secId from /exampleRegion where NOT (secId = 'VMW')",
-        "select p.secId from /exampleRegion p, p.positions.values v where  NOT (p.secId = 'VMW')",
-        "select secId from /exampleRegion where NOT (secId = 'VMW')"};
+    query =
+        new String[] {"select secId from " + SEPARATOR + "exampleRegion where NOT (secId = 'VMW')",
+            "select p.secId from " + SEPARATOR
+                + "exampleRegion p, p.positions.values v where  NOT (p.secId = 'VMW')",
+            "select secId from " + SEPARATOR + "exampleRegion where NOT (secId = 'VMW')"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(3, res.size());
     iter = res.iterator();
@@ -597,9 +638,12 @@ public class PdxStringQueryJUnitTest {
       validateResult(secIdsList, iter.next());
     }
 
-    query = new String[] {"select secId from /exampleRegion p where NOT (p.ID IN SET(111, 222)) ",
-        "select p.secId from /exampleRegion p, p.positions.values v where NOT (p.ID IN SET(111, 222)) ",
-        "select secId from /exampleRegion where NOT (secId IN SET('VMW','IBM','YHOO'))"};
+    query = new String[] {
+        "select secId from " + SEPARATOR + "exampleRegion p where NOT (p.ID IN SET(111, 222)) ",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where NOT (p.ID IN SET(111, 222)) ",
+        "select secId from " + SEPARATOR
+            + "exampleRegion where NOT (secId IN SET('VMW','IBM','YHOO'))"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute();
     assertEquals(1, res.size());
     iter = res.iterator();
@@ -609,16 +653,19 @@ public class PdxStringQueryJUnitTest {
       validateResult(secIdsList, iter.next());
     }
 
-    query = new String[] {"select secId from /exampleRegion where secId  = $1",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.secId = $1",
-        "select secId from /exampleRegion where secId  = $1"};
+    query = new String[] {"select secId from " + SEPARATOR + "exampleRegion where secId  = $1",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId = $1",
+        "select secId from " + SEPARATOR + "exampleRegion where secId  = $1"};
     res = (SelectResults) queryService.newQuery(query[indexType]).execute(new Object[] {"IBM"});
     assertEquals(1, res.size());
     validateStringResult("IBM", res.iterator().next());
 
-    query = new String[] {"select secId from /exampleRegion where secId > $1 and secId < $2",
-        "select p.secId from /exampleRegion p, p.positions.values v where p.secId > $1 and p.secId < $2",
-        "select secId from /exampleRegion where secId > $1 and secId < $2"};
+    query = new String[] {
+        "select secId from " + SEPARATOR + "exampleRegion where secId > $1 and secId < $2",
+        "select p.secId from " + SEPARATOR
+            + "exampleRegion p, p.positions.values v where p.secId > $1 and p.secId < $2",
+        "select secId from " + SEPARATOR + "exampleRegion where secId > $1 and secId < $2"};
     res = (SelectResults) queryService.newQuery(query[indexType])
         .execute(new Object[] {"IBM", "YHOO"});
     assertEquals(1, res.size());
