@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query.functional;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
@@ -123,7 +124,7 @@ public class LimitClauseJUnitTest {
 
   @Test
   public void testLimitWithParameter() throws Exception {
-    String queryString = "SELECT * from /portfolios1 LIMIT $1 ";
+    String queryString = "SELECT * from " + SEPARATOR + "portfolios1 LIMIT $1 ";
     SelectResults result;
     Region region = CacheUtils.createRegion("portfolios1", Portfolio.class);
     for (int i = 0; i < 100; i++) {
@@ -155,7 +156,7 @@ public class LimitClauseJUnitTest {
 
   @Test
   public void testLimitWithParameterNotSet() throws Exception {
-    String queryString = "SELECT * from /portfolios1 LIMIT $1 ";
+    String queryString = "SELECT * from " + SEPARATOR + "portfolios1 LIMIT $1 ";
     SelectResults result;
     Region region = CacheUtils.createRegion("portfolios1", Portfolio.class);
     for (int i = 0; i < 100; i++) {
@@ -169,7 +170,7 @@ public class LimitClauseJUnitTest {
 
   @Test
   public void testLimitWithNullParameterObject() throws Exception {
-    String queryString = "SELECT * from /portfolios1 LIMIT $1 ";
+    String queryString = "SELECT * from " + SEPARATOR + "portfolios1 LIMIT $1 ";
     SelectResults result;
     Region region = CacheUtils.createRegion("portfolios1", Portfolio.class);
     for (int i = 0; i < 100; i++) {
@@ -187,7 +188,7 @@ public class LimitClauseJUnitTest {
   // queries.
   @Test
   public void testLimitWithParameterForNonAndIndexedQuery() throws Exception {
-    String queryString = "SELECT * from /portfolios1 WHERE shortID = $1 LIMIT $2 ";
+    String queryString = "SELECT * from " + SEPARATOR + "portfolios1 WHERE shortID = $1 LIMIT $2 ";
     SelectResults result;
     Region region = CacheUtils.createRegion("portfolios1", Portfolio.class);
     for (int i = 0; i < 100; i++) {
@@ -202,7 +203,8 @@ public class LimitClauseJUnitTest {
     for (int i = 0; i < limits.length; i++) {
       params[1] = limits[i];
 
-      SelectResults results = helpTestIndexForQuery(queryString, "shortID", "/portfolios1", params);
+      SelectResults results =
+          helpTestIndexForQuery(queryString, "shortID", SEPARATOR + "portfolios1", params);
       assertEquals(limits[i], results.size());
       // clear out indexes for next query.
       qs.removeIndexes();
@@ -221,7 +223,8 @@ public class LimitClauseJUnitTest {
     try {
       Query query;
       SelectResults result;
-      String queryString = "SELECT DISTINCT * FROM /portfolios pf WHERE pf.ID > 0 limit 5";
+      String queryString =
+          "SELECT DISTINCT * FROM " + SEPARATOR + "portfolios pf WHERE pf.ID > 0 limit 5";
       query = qs.newQuery(queryString);
       final int[] num = new int[1];
       num[0] = 0;
@@ -259,7 +262,8 @@ public class LimitClauseJUnitTest {
     try {
       Query query;
       SelectResults result;
-      String queryString = "SELECT DISTINCT pf.ID FROM /portfolios pf WHERE pf.ID > 0 limit 5";
+      String queryString =
+          "SELECT DISTINCT pf.ID FROM " + SEPARATOR + "portfolios pf WHERE pf.ID > 0 limit 5";
       query = qs.newQuery(queryString);
       final int[] num = new int[1];
       num[0] = 0;
@@ -328,7 +332,8 @@ public class LimitClauseJUnitTest {
         }
 
       });
-      String queryString = "SELECT DISTINCT * FROM /portfolios1  pf WHERE pf.ID > 10 limit 5";
+      String queryString =
+          "SELECT DISTINCT * FROM " + SEPARATOR + "portfolios1  pf WHERE pf.ID > 10 limit 5";
       query = qs.newQuery(queryString);
       result = (SelectResults) query.execute();
       assertEquals((5 + numRepeat[0]), num[0]);
@@ -387,7 +392,8 @@ public class LimitClauseJUnitTest {
           }
         }
       });
-      String queryString = "SELECT DISTINCT pf.ID FROM /portfolios1  pf WHERE pf.ID > 10 limit 5";
+      String queryString =
+          "SELECT DISTINCT pf.ID FROM " + SEPARATOR + "portfolios1  pf WHERE pf.ID > 10 limit 5";
       query = qs.newQuery(queryString);
       result = (SelectResults) query.execute();
       assertEquals((5 + numRepeat[0]), num[0]);
@@ -419,7 +425,8 @@ public class LimitClauseJUnitTest {
       Query query;
       SelectResults result;
       query = qs.newQuery(
-          "SELECT DISTINCT pf.ID, pf.createTime FROM /portfolios pf WHERE pf.ID > 0 limit 5");
+          "SELECT DISTINCT pf.ID, pf.createTime FROM " + SEPARATOR
+              + "portfolios pf WHERE pf.ID > 0 limit 5");
       final int[] num = new int[1];
       num[0] = 0;
       QueryObserver old = QueryObserverHolder.setInstance(new QueryObserverAdapter() {
@@ -455,7 +462,8 @@ public class LimitClauseJUnitTest {
       Query query;
       SelectResults result;
       String queryString =
-          "SELECT DISTINCT * FROM /portfolios pf, pf.positions.values WHERE pf.ID > 0 limit 5";
+          "SELECT DISTINCT * FROM " + SEPARATOR
+              + "portfolios pf, pf.positions.values WHERE pf.ID > 0 limit 5";
       query = qs.newQuery(queryString);
       final int[] num = new int[1];
       num[0] = 0;
@@ -492,15 +500,17 @@ public class LimitClauseJUnitTest {
       Query query;
       SelectResults result;
       String queryString =
-          "SELECT * FROM /portfolios pf, pf.positions.values pos WHERE pf.ID > 1  AND pos.secId = 'GOOG' limit 1";
+          "SELECT * FROM " + SEPARATOR
+              + "portfolios pf, pf.positions.values pos WHERE pf.ID > 1  AND pos.secId = 'GOOG' limit 1";
       query = qs.newQuery(queryString);
 
       MyQueryObserverAdapter observer = new MyQueryObserverAdapter();
       QueryObserver old = QueryObserverHolder.setInstance(observer);
 
-      Index index = qs.createIndex("idIndex", "pf.ID", "/portfolios pf");
+      Index index = qs.createIndex("idIndex", "pf.ID", SEPARATOR + "portfolios pf");
       Index posindex =
-          qs.createIndex("posIndex", "pos.secId", "/portfolios pf, pf.positions.values pos");
+          qs.createIndex("posIndex", "pos.secId",
+              SEPARATOR + "portfolios pf, pf.positions.values pos");
       assertNotNull(index);
       assertNotNull(posindex);
       result = (SelectResults) query.execute();
@@ -558,7 +568,8 @@ public class LimitClauseJUnitTest {
         }
       });
       String queryString =
-          "SELECT DISTINCT pf.ID , pf.createTime FROM /portfolios1  pf WHERE pf.ID > 10 limit 5";
+          "SELECT DISTINCT pf.ID , pf.createTime FROM " + SEPARATOR
+              + "portfolios1  pf WHERE pf.ID > 10 limit 5";
       query = qs.newQuery(queryString);
       result = (SelectResults) query.execute();
       assertEquals((5 + numRepeat[0]), num[0]);
@@ -617,7 +628,8 @@ public class LimitClauseJUnitTest {
         }
       });
       String queryString =
-          "SELECT DISTINCT * FROM /portfolios1  pf, pf.collectionHolderMap.keySet  WHERE pf.ID > 10 limit 20";
+          "SELECT DISTINCT * FROM " + SEPARATOR
+              + "portfolios1  pf, pf.collectionHolderMap.keySet  WHERE pf.ID > 10 limit 20";
       query = qs.newQuery(queryString);
       result = (SelectResults) query.execute();
       assertEquals((20 + 4 * numRepeat[0]), num[0]);
@@ -649,11 +661,12 @@ public class LimitClauseJUnitTest {
     try {
       Query query;
       SelectResults result;
-      String queryString = "SELECT DISTINCT * FROM /portfolios pf WHERE pf.ID > 0 limit 5";
+      String queryString =
+          "SELECT DISTINCT * FROM " + SEPARATOR + "portfolios pf WHERE pf.ID > 0 limit 5";
       query = qs.newQuery(queryString);
       MyQueryObserverAdapter observer = new MyQueryObserverAdapter();
       QueryObserver old = QueryObserverHolder.setInstance(observer);
-      Index index = qs.createIndex("idIndex", "pf.ID", "/portfolios pf");
+      Index index = qs.createIndex("idIndex", "pf.ID", SEPARATOR + "portfolios pf");
       assertNotNull(index);
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
@@ -683,12 +696,13 @@ public class LimitClauseJUnitTest {
     try {
       Query query;
       SelectResults result;
-      String queryString = "SELECT DISTINCT pf.ID FROM /portfolios pf WHERE pf.ID > 0 limit 5";
+      String queryString =
+          "SELECT DISTINCT pf.ID FROM " + SEPARATOR + "portfolios pf WHERE pf.ID > 0 limit 5";
       query = qs.newQuery(queryString);
 
       MyQueryObserverAdapter observer = new MyQueryObserverAdapter();
       QueryObserver old = QueryObserverHolder.setInstance(observer);
-      Index index = qs.createIndex("idIndex", "pf.ID", "/portfolios pf");
+      Index index = qs.createIndex("idIndex", "pf.ID", SEPARATOR + "portfolios pf");
       assertNotNull(index);
 
       result = (SelectResults) query.execute();
@@ -729,10 +743,11 @@ public class LimitClauseJUnitTest {
 
       MyQueryObserverAdapter observer = new MyQueryObserverAdapter();
       QueryObserver old = QueryObserverHolder.setInstance(observer);
-      Index index = qs.createIndex("idIndex", "pf.ID", "/portfolios1 pf");
+      Index index = qs.createIndex("idIndex", "pf.ID", SEPARATOR + "portfolios1 pf");
       assertNotNull(index);
 
-      String queryString = "SELECT DISTINCT * FROM /portfolios1  pf WHERE pf.ID > 10 limit 5";
+      String queryString =
+          "SELECT DISTINCT * FROM " + SEPARATOR + "portfolios1  pf WHERE pf.ID > 10 limit 5";
       query = qs.newQuery(queryString);
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
@@ -774,9 +789,10 @@ public class LimitClauseJUnitTest {
       MyQueryObserverAdapter observer = new MyQueryObserverAdapter();
       QueryObserver old = QueryObserverHolder.setInstance(observer);
 
-      Index index = qs.createIndex("idIndex", "pf.ID", "/portfolios1 pf");
+      Index index = qs.createIndex("idIndex", "pf.ID", SEPARATOR + "portfolios1 pf");
       assertNotNull(index);
-      String queryString = "SELECT DISTINCT pf.ID FROM /portfolios1  pf WHERE pf.ID > 10 limit 5";
+      String queryString =
+          "SELECT DISTINCT pf.ID FROM " + SEPARATOR + "portfolios1  pf WHERE pf.ID > 10 limit 5";
       query = qs.newQuery(queryString);
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
@@ -807,12 +823,13 @@ public class LimitClauseJUnitTest {
       Query query;
       SelectResults result;
       query = qs.newQuery(
-          "SELECT DISTINCT pf.ID, pf.createTime FROM /portfolios pf WHERE pf.ID > 0 limit 5");
+          "SELECT DISTINCT pf.ID, pf.createTime FROM " + SEPARATOR
+              + "portfolios pf WHERE pf.ID > 0 limit 5");
 
       MyQueryObserverAdapter observer = new MyQueryObserverAdapter();
       QueryObserver old = QueryObserverHolder.setInstance(observer);
 
-      Index index = qs.createIndex("idIndex", "pf.ID", "/portfolios pf");
+      Index index = qs.createIndex("idIndex", "pf.ID", SEPARATOR + "portfolios pf");
       assertNotNull(index);
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
@@ -841,13 +858,15 @@ public class LimitClauseJUnitTest {
       Query query;
       SelectResults result;
       String queryString =
-          "SELECT DISTINCT * FROM /portfolios pf, pf.positions.values WHERE pf.ID > 0 limit 5";
+          "SELECT DISTINCT * FROM " + SEPARATOR
+              + "portfolios pf, pf.positions.values WHERE pf.ID > 0 limit 5";
       query = qs.newQuery(queryString);
 
       MyQueryObserverAdapter observer = new MyQueryObserverAdapter();
       QueryObserver old = QueryObserverHolder.setInstance(observer);
 
-      Index index = qs.createIndex("idIndex", "pf.ID", "/portfolios pf, pf.positions.values");
+      Index index =
+          qs.createIndex("idIndex", "pf.ID", SEPARATOR + "portfolios pf, pf.positions.values");
       assertNotNull(index);
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
@@ -889,10 +908,11 @@ public class LimitClauseJUnitTest {
 
       MyQueryObserverAdapter observer = new MyQueryObserverAdapter();
       QueryObserver old = QueryObserverHolder.setInstance(observer);
-      Index index = qs.createIndex("idIndex", "pf.ID", "/portfolios1  pf");
+      Index index = qs.createIndex("idIndex", "pf.ID", SEPARATOR + "portfolios1  pf");
       assertNotNull(index);
       String queryString =
-          "SELECT DISTINCT pf.ID , pf.createTime FROM /portfolios1  pf WHERE pf.ID > 10 limit 5";
+          "SELECT DISTINCT pf.ID , pf.createTime FROM " + SEPARATOR
+              + "portfolios1  pf WHERE pf.ID > 10 limit 5";
       query = qs.newQuery(queryString);
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
@@ -934,11 +954,13 @@ public class LimitClauseJUnitTest {
       QueryObserver old = QueryObserverHolder.setInstance(observer);
 
       Index index =
-          qs.createIndex("idIndex", "pf.ID", "/portfolios1  pf, pf.collectionHolderMap.keySet");
+          qs.createIndex("idIndex", "pf.ID",
+              SEPARATOR + "portfolios1  pf, pf.collectionHolderMap.keySet");
       assertNotNull(index);
 
       String queryString =
-          "SELECT DISTINCT * FROM /portfolios1  pf, pf.collectionHolderMap.keySet  WHERE pf.ID > 10 limit 20";
+          "SELECT DISTINCT * FROM " + SEPARATOR
+              + "portfolios1  pf, pf.collectionHolderMap.keySet  WHERE pf.ID > 10 limit 20";
       query = qs.newQuery(queryString);
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
@@ -978,10 +1000,11 @@ public class LimitClauseJUnitTest {
       }
 
       // Create Index on ID
-      Index index = qs.createIndex("idIndex", "ID", "/portfolios1");
+      Index index = qs.createIndex("idIndex", "ID", SEPARATOR + "portfolios1");
       assertNotNull(index);
       String queryString =
-          "select DISTINCT * from /portfolios1 where status ='inactive' AND (ID > 0 AND ID < 100) limit 10";
+          "select DISTINCT * from " + SEPARATOR
+              + "portfolios1 where status ='inactive' AND (ID > 0 AND ID < 100) limit 10";
       query = qs.newQuery(queryString);
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
@@ -1011,15 +1034,16 @@ public class LimitClauseJUnitTest {
       }
 
       // Create Index on ID
-      Index index = qs.createIndex("idIndex", "ID", "/portfolios1");
+      Index index = qs.createIndex("idIndex", "ID", SEPARATOR + "portfolios1");
       assertNotNull(index);
-      index = qs.createIndex("statusIndex", "status", "/portfolios1");
+      index = qs.createIndex("statusIndex", "status", SEPARATOR + "portfolios1");
       assertNotNull(index);
       MyQueryObserverAdapter observer = new MyQueryObserverAdapter();
       QueryObserver old = QueryObserverHolder.setInstance(observer);
 
       String queryString =
-          "select DISTINCT * from /portfolios1 where status ='inactive' AND (ID > 0 AND ID < 100) limit 10";
+          "select DISTINCT * from " + SEPARATOR
+              + "portfolios1 where status ='inactive' AND (ID > 0 AND ID < 100) limit 10";
       query = qs.newQuery(queryString);
       result = (SelectResults) query.execute();
       assertTrue(result instanceof SelectResults);
@@ -1054,12 +1078,15 @@ public class LimitClauseJUnitTest {
       QueryObserver old = QueryObserverHolder.setInstance(observer);
 
       // Create Index on ID
-      Index index = qs.createIndex("idIndex", "ID", "/portfolios1");
+      Index index = qs.createIndex("idIndex", "ID", SEPARATOR + "portfolios1");
       assertNotNull(index);
       String[] queryString = new String[] {
-          "select * from /portfolios1 where status ='inactive' AND (ID > 0 AND ID < 100) limit 10",
-          "select * from /portfolios1 where (status > 'inactiva' AND status < 'xyz') AND (ID > 0 AND ID < 100) limit 10",
-          "select * from /portfolios1 where (status > 'inactiva' AND status < 'xyz') AND (ID > 0 AND ID < 100) AND (\"type\"='type1' OR \"type\"='type2') limit 10",};
+          "select * from " + SEPARATOR
+              + "portfolios1 where status ='inactive' AND (ID > 0 AND ID < 100) limit 10",
+          "select * from " + SEPARATOR
+              + "portfolios1 where (status > 'inactiva' AND status < 'xyz') AND (ID > 0 AND ID < 100) limit 10",
+          "select * from " + SEPARATOR
+              + "portfolios1 where (status > 'inactiva' AND status < 'xyz') AND (ID > 0 AND ID < 100) AND (\"type\"='type1' OR \"type\"='type2') limit 10",};
       for (String qstr : queryString) {
         query = qs.newQuery(qstr);
         result = (SelectResults) query.execute();
@@ -1092,12 +1119,13 @@ public class LimitClauseJUnitTest {
       QueryObserver old = QueryObserverHolder.setInstance(observer);
 
       // Create Index on ID
-      Index index = qs.createIndex("idIndex", "ID", "/portfolios1");
+      Index index = qs.createIndex("idIndex", "ID", SEPARATOR + "portfolios1");
       assertNotNull(index);
-      index = qs.createIndex("statusIndex", "status", "/portfolios1");
+      index = qs.createIndex("statusIndex", "status", SEPARATOR + "portfolios1");
       assertNotNull(index);
       String[] queryString = new String[] {
-          "select * from /portfolios1 where status ='inactive' AND (ID > 0 AND ID < 100) limit 10",};
+          "select * from " + SEPARATOR
+              + "portfolios1 where status ='inactive' AND (ID > 0 AND ID < 100) limit 10",};
       for (String qstr : queryString) {
         query = qs.newQuery(qstr);
         result = (SelectResults) query.execute();
@@ -1130,13 +1158,15 @@ public class LimitClauseJUnitTest {
       QueryObserver old = QueryObserverHolder.setInstance(observer);
 
       // Create Index on ID
-      Index index = qs.createIndex("idIndex", "ID", "/portfolios1");
+      Index index = qs.createIndex("idIndex", "ID", SEPARATOR + "portfolios1");
       assertNotNull(index);
-      index = qs.createIndex("statusIndex", "status", "/portfolios1");
+      index = qs.createIndex("statusIndex", "status", SEPARATOR + "portfolios1");
       assertNotNull(index);
       String[] queryString = new String[] {
-          "select * from /portfolios1 where (status > 'inactiva' AND status < 'xyz') AND (ID > 70 AND ID < 100) limit 10",
-          "select * from /portfolios1 where (status > 'inactiva' AND status < 'xyz') AND (ID > 60 AND ID < 100) AND (\"type\"='type1' OR \"type\"='type2') limit 10",};
+          "select * from " + SEPARATOR
+              + "portfolios1 where (status > 'inactiva' AND status < 'xyz') AND (ID > 70 AND ID < 100) limit 10",
+          "select * from " + SEPARATOR
+              + "portfolios1 where (status > 'inactiva' AND status < 'xyz') AND (ID > 60 AND ID < 100) AND (\"type\"='type1' OR \"type\"='type2') limit 10",};
       for (String qstr : queryString) {
         query = qs.newQuery(qstr);
         result = (SelectResults) query.execute();
@@ -1166,10 +1196,11 @@ public class LimitClauseJUnitTest {
       }
 
       // Create Index on ID
-      Index index = qs.createIndex("idIndex", "ID", "/portfolios1");
+      Index index = qs.createIndex("idIndex", "ID", SEPARATOR + "portfolios1");
       assertNotNull(index);
       String queryString =
-          "select DISTINCT * from /portfolios1 where status ='inactive' AND ID > 0 limit 2";
+          "select DISTINCT * from " + SEPARATOR
+              + "portfolios1 where status ='inactive' AND ID > 0 limit 2";
       query = qs.newQuery(queryString);
       result = (SelectResults) query.execute();
       assertEquals(2, result.size());
@@ -1196,14 +1227,17 @@ public class LimitClauseJUnitTest {
     }
 
     String queryString =
-        "<trace>SELECT * FROM /portfolios1 P, P.positions.values POS WHERE P.ID > 5 AND POS.secId = 'IBM' LIMIT 5";
+        "<trace>SELECT * FROM " + SEPARATOR
+            + "portfolios1 P, P.positions.values POS WHERE P.ID > 5 AND POS.secId = 'IBM' LIMIT 5";
     query = qs.newQuery(queryString);
     SelectResults resultsNoIndex = (SelectResults) query.execute();
 
     // Create Index on ID and secId
     Index secIndex =
-        qs.createIndex("secIdIndex", "pos.secId", "/portfolios1 p, p.positions.values pos");
-    Index idIndex = qs.createIndex("idIndex", IndexType.FUNCTIONAL, "P.ID", "/portfolios1 P");
+        qs.createIndex("secIdIndex", "pos.secId",
+            SEPARATOR + "portfolios1 p, p.positions.values pos");
+    Index idIndex =
+        qs.createIndex("idIndex", IndexType.FUNCTIONAL, "P.ID", SEPARATOR + "portfolios1 P");
 
     assertNotNull(secIndex);
     assertNotNull(idIndex);
@@ -1228,15 +1262,17 @@ public class LimitClauseJUnitTest {
     }
 
     String queryString =
-        "<trace>SELECT * FROM /portfolios1 P, P.positions.values POS WHERE P.ID > 4 and P.ID < 11 AND P.ID != 8 LIMIT 5";
+        "<trace>SELECT * FROM " + SEPARATOR
+            + "portfolios1 P, P.positions.values POS WHERE P.ID > 4 and P.ID < 11 AND P.ID != 8 LIMIT 5";
     query = qs.newQuery(queryString);
     SelectResults resultsNoIndex = (SelectResults) query.execute();
 
     // Create Index on ID and secId
     Index secIndex =
-        qs.createIndex("secIdIndex", "pos.secId", "/portfolios1 p, p.positions.values pos");
+        qs.createIndex("secIdIndex", "pos.secId",
+            SEPARATOR + "portfolios1 p, p.positions.values pos");
     Index idIndex = qs.createIndex("idIndex", IndexType.FUNCTIONAL, "P.ID",
-        "/portfolios1 P, P.positions.values pos");
+        SEPARATOR + "portfolios1 P, P.positions.values pos");
 
     // assertNotNull(secIndex);
     assertNotNull(idIndex);
@@ -1261,15 +1297,17 @@ public class LimitClauseJUnitTest {
     }
 
     String queryString =
-        "<trace>SELECT * FROM /portfolios1 P, P.positions.values POS WHERE P.ID < 4 OR P.ID > 11 AND P.ID != 13 LIMIT 5";
+        "<trace>SELECT * FROM " + SEPARATOR
+            + "portfolios1 P, P.positions.values POS WHERE P.ID < 4 OR P.ID > 11 AND P.ID != 13 LIMIT 5";
     query = qs.newQuery(queryString);
     SelectResults resultsNoIndex = (SelectResults) query.execute();
 
     // Create Index on ID and secId
     Index secIndex =
-        qs.createIndex("secIdIndex", "pos.secId", "/portfolios1 p, p.positions.values pos");
+        qs.createIndex("secIdIndex", "pos.secId",
+            SEPARATOR + "portfolios1 p, p.positions.values pos");
     Index idIndex = qs.createIndex("idIndex", IndexType.FUNCTIONAL, "P.ID",
-        "/portfolios1 P, P.positions.values pos");
+        SEPARATOR + "portfolios1 P, P.positions.values pos");
 
     // assertNotNull(secIndex);
     assertNotNull(idIndex);
@@ -1302,10 +1340,12 @@ public class LimitClauseJUnitTest {
     QueryObserver old = QueryObserverHolder.setInstance(observer);
 
     // Create Index on ID
-    Index idIndex = qs.createIndex("idIndex", IndexType.FUNCTIONAL, "P.ID", "/portfolios1 P");
+    Index idIndex =
+        qs.createIndex("idIndex", IndexType.FUNCTIONAL, "P.ID", SEPARATOR + "portfolios1 P");
 
     String queryString =
-        "SELECT * FROM /portfolios1 P, P.positions.values POS WHERE P.ID > 9 AND P.ID < 21 AND POS.secId = 'VMW' LIMIT 5";
+        "SELECT * FROM " + SEPARATOR
+            + "portfolios1 P, P.positions.values POS WHERE P.ID > 9 AND P.ID < 21 AND POS.secId = 'VMW' LIMIT 5";
     query = qs.newQuery(queryString);
 
     assertNotNull(idIndex);
@@ -1339,10 +1379,11 @@ public class LimitClauseJUnitTest {
 
     // Create Index on ID
     Index idIndex = qs.createIndex("idIndex", IndexType.FUNCTIONAL, "P.ID",
-        "/portfolios1 P, P.positions.values POS");
+        SEPARATOR + "portfolios1 P, P.positions.values POS");
 
     String queryString =
-        "SELECT * FROM /portfolios1 P, P.positions.values POS WHERE P.ID > 9 AND P.ID < 21 AND POS.secId = 'VMW' LIMIT 5";
+        "SELECT * FROM " + SEPARATOR
+            + "portfolios1 P, P.positions.values POS WHERE P.ID > 9 AND P.ID < 21 AND POS.secId = 'VMW' LIMIT 5";
     query = qs.newQuery(queryString);
 
     assertNotNull(idIndex);
@@ -1387,12 +1428,14 @@ public class LimitClauseJUnitTest {
 
     // Create Index on ID
     Index idIndex = qs.createIndex("idIndex", IndexType.FUNCTIONAL, "P.ID",
-        "/portfolios1 P, P.positions.values POS");
+        SEPARATOR + "portfolios1 P, P.positions.values POS");
     Index shortIdIndex =
-        qs.createIndex("shortIdIndex", IndexType.FUNCTIONAL, "P.shortID", "/portfolios1 P");
+        qs.createIndex("shortIdIndex", IndexType.FUNCTIONAL, "P.shortID",
+            SEPARATOR + "portfolios1 P");
 
     String queryString =
-        "<trace>SELECT * FROM /portfolios1 P WHERE P.ID > 9 AND P.ID < 21 AND P.shortID = 2 LIMIT 5";
+        "<trace>SELECT * FROM " + SEPARATOR
+            + "portfolios1 P WHERE P.ID > 9 AND P.ID < 21 AND P.shortID = 2 LIMIT 5";
     query = qs.newQuery(queryString);
 
     assertNotNull(idIndex);
@@ -1436,12 +1479,13 @@ public class LimitClauseJUnitTest {
 
     // Create Index on ID
     Index idIndex = qs.createIndex("idIndex", IndexType.FUNCTIONAL, "P.ID",
-        "/portfolios1 P, P.positions.values POS");
+        SEPARATOR + "portfolios1 P, P.positions.values POS");
     Index shortIdIndex = qs.createIndex("shortIdIndex", IndexType.FUNCTIONAL, "P.shortID",
-        "/portfolios1 P, P.positions.values POS");
+        SEPARATOR + "portfolios1 P, P.positions.values POS");
 
     String queryString =
-        "SELECT * FROM /portfolios1 P WHERE P.ID > 9 AND P.ID < 21 AND P.shortID = 2 LIMIT 5";
+        "SELECT * FROM " + SEPARATOR
+            + "portfolios1 P WHERE P.ID > 9 AND P.ID < 21 AND P.shortID = 2 LIMIT 5";
     query = qs.newQuery(queryString);
 
     assertNotNull(idIndex);
@@ -1476,9 +1520,10 @@ public class LimitClauseJUnitTest {
     QueryObserver old = QueryObserverHolder.setInstance(observer);
 
     // Create Index on ID
-    Index idIndex = qs.createIndex("idIndex", "P.ID", "/portfolios1 P");
+    Index idIndex = qs.createIndex("idIndex", "P.ID", SEPARATOR + "portfolios1 P");
 
-    String queryString = "SELECT * FROM /portfolios1 P WHERE P.ID = 10 AND P.shortID = 2 LIMIT 5";
+    String queryString =
+        "SELECT * FROM " + SEPARATOR + "portfolios1 P WHERE P.ID = 10 AND P.shortID = 2 LIMIT 5";
     query = qs.newQuery(queryString);
 
     assertNotNull(idIndex);
@@ -1537,11 +1582,12 @@ public class LimitClauseJUnitTest {
     // QueryObserver old = QueryObserverHolder.setInstance(observer);
 
     // Create Index on ID
-    Index idIndex = qs.createIndex("idIndex", "P.ID", "/portfolios1 P");
-    Index shortIdIndex = qs.createIndex("shortIdIndex", "P.shortID", "/portfolios1 P");
+    Index idIndex = qs.createIndex("idIndex", "P.ID", SEPARATOR + "portfolios1 P");
+    Index shortIdIndex = qs.createIndex("shortIdIndex", "P.shortID", SEPARATOR + "portfolios1 P");
 
     String queryString =
-        "<trace>SELECT * FROM /portfolios1 P WHERE P.ID = 10 AND P.shortID = 2 LIMIT 5";
+        "<trace>SELECT * FROM " + SEPARATOR
+            + "portfolios1 P WHERE P.ID = 10 AND P.shortID = 2 LIMIT 5";
     query = qs.newQuery(queryString);
 
     assertNotNull(idIndex);
@@ -1577,10 +1623,12 @@ public class LimitClauseJUnitTest {
     QueryObserver old = QueryObserverHolder.setInstance(observer);
 
     // Create Index on ID
-    Index idIndex = qs.createIndex("idIndex", "P.ID", "/portfolios1 P, P.positions.values POS");
-    Index shortIdIndex = qs.createIndex("shortIdIndex", "P.shortID", "/portfolios1 P");
+    Index idIndex =
+        qs.createIndex("idIndex", "P.ID", SEPARATOR + "portfolios1 P, P.positions.values POS");
+    Index shortIdIndex = qs.createIndex("shortIdIndex", "P.shortID", SEPARATOR + "portfolios1 P");
 
-    String queryString = "SELECT * FROM /portfolios1 P WHERE P.ID = 10 AND P.shortID = 2 LIMIT 5";
+    String queryString =
+        "SELECT * FROM " + SEPARATOR + "portfolios1 P WHERE P.ID = 10 AND P.shortID = 2 LIMIT 5";
     query = qs.newQuery(queryString);
 
     assertNotNull(idIndex);
@@ -1617,11 +1665,12 @@ public class LimitClauseJUnitTest {
     QueryObserver old = QueryObserverHolder.setInstance(observer);
 
     // Create Index on ID
-    Index idIndex = qs.createIndex("idIndex", "P.ID", "/portfolios1 P");
-    Index shortIdIndex = qs.createIndex("shortIdIndex", "P.shortID", "/portfolios1 P");
+    Index idIndex = qs.createIndex("idIndex", "P.ID", SEPARATOR + "portfolios1 P");
+    Index shortIdIndex = qs.createIndex("shortIdIndex", "P.shortID", SEPARATOR + "portfolios1 P");
 
     String queryString =
-        "SELECT * FROM /portfolios1 P WHERE P.ID > 9 AND P.ID < 20 AND P.shortID > 1 AND P.shortID < 3 LIMIT 5";
+        "SELECT * FROM " + SEPARATOR
+            + "portfolios1 P WHERE P.ID > 9 AND P.ID < 20 AND P.shortID > 1 AND P.shortID < 3 LIMIT 5";
     query = qs.newQuery(queryString);
 
     assertNotNull(idIndex);
@@ -1656,10 +1705,11 @@ public class LimitClauseJUnitTest {
     QueryObserver old = QueryObserverHolder.setInstance(observer);
 
     // Create Index on ID
-    Index idIndex = qs.createIndex("idIndex", "P.ID", "/portfolios1 P");
+    Index idIndex = qs.createIndex("idIndex", "P.ID", SEPARATOR + "portfolios1 P");
 
     String queryString =
-        "SELECT * FROM /portfolios1 P WHERE P.ID > 9 AND P.ID < 20 AND P.shortID > 1 AND P.shortID < 3 LIMIT 5";
+        "SELECT * FROM " + SEPARATOR
+            + "portfolios1 P WHERE P.ID > 9 AND P.ID < 20 AND P.shortID > 1 AND P.shortID < 3 LIMIT 5";
     query = qs.newQuery(queryString);
 
     assertNotNull(idIndex);
@@ -1694,10 +1744,11 @@ public class LimitClauseJUnitTest {
     QueryObserver old = QueryObserverHolder.setInstance(observer);
 
     // Create Index on ID
-    Index idIndex = qs.createIndex("idIndex", "P.ID", "/portfolios1 P");
+    Index idIndex = qs.createIndex("idIndex", "P.ID", SEPARATOR + "portfolios1 P");
 
     String queryString =
-        "SELECT * FROM /portfolios1 P WHERE P.ID = 10 AND P.shortID > 1 AND P.shortID < 3 LIMIT 5";
+        "SELECT * FROM " + SEPARATOR
+            + "portfolios1 P WHERE P.ID = 10 AND P.shortID > 1 AND P.shortID < 3 LIMIT 5";
     query = qs.newQuery(queryString);
 
     assertNotNull(idIndex);
@@ -1733,11 +1784,12 @@ public class LimitClauseJUnitTest {
     QueryObserver old = QueryObserverHolder.setInstance(observer);
 
     // Create Index on ID
-    Index idIndex = qs.createIndex("idIndex", "P.ID", "/portfolios1 P");
-    Index shortIdIndex = qs.createIndex("shortIdIndex", "P.shortID", "/portfolios1 P");
+    Index idIndex = qs.createIndex("idIndex", "P.ID", SEPARATOR + "portfolios1 P");
+    Index shortIdIndex = qs.createIndex("shortIdIndex", "P.shortID", SEPARATOR + "portfolios1 P");
 
     String queryString =
-        "SELECT * FROM /portfolios1 P WHERE P.ID > 9 AND P.ID < 20 AND P.shortID = 2 LIMIT 5";
+        "SELECT * FROM " + SEPARATOR
+            + "portfolios1 P WHERE P.ID > 9 AND P.ID < 20 AND P.shortID = 2 LIMIT 5";
     query = qs.newQuery(queryString);
 
     assertNotNull(idIndex);
