@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query.internal.aggregate;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.cache.query.internal.aggregate.AbstractAggregator.downCast;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.assertj.core.api.Assertions.assertThat;
@@ -63,83 +64,91 @@ public class AvgIntegrationTest extends AggregateFunctionQueryBaseIntegrationTes
     }
 
     // Simple Queries
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName + " p",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName + " p",
         downCast(supplierOne.get().mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName + " p WHERE p.ID > 0",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName + " p WHERE p.ID > 0",
         downCast(supplierOne.get().filter(p -> p.getID() > 0).mapToInt(Portfolio::getID).average()
             .orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName + " p WHERE p.ID > 50",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName + " p WHERE p.ID > 50",
         downCast(supplierOne.get().filter(p -> p.getID() > 50).mapToInt(Portfolio::getID).average()
             .orElse(Double.NaN)));
     queries.put(
-        "SELECT AVG(p.ID) FROM /" + firstRegionName + " p WHERE p.ID > 0 OR p.status='active'",
+        "SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
+            + " p WHERE p.ID > 0 OR p.status='active'",
         downCast(supplierOne.get().filter(p -> p.getID() > 0 || p.isActive())
             .mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
     queries.put(
-        "SELECT AVG(p.ID) FROM /" + firstRegionName + " p WHERE p.ID > 0 OR p.status LIKE 'ina%'",
+        "SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
+            + " p WHERE p.ID > 0 OR p.status LIKE 'ina%'",
         downCast(supplierOne.get().filter(p -> p.getID() > 0 || p.status.startsWith("ina"))
             .mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName + " p WHERE p.ID IN SET(1, 2, 3, 4, 5)",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
+        + " p WHERE p.ID IN SET(1, 2, 3, 4, 5)",
         downCast(supplierOne.get().filter(p -> Arrays.asList(1, 2, 3, 4, 5).contains(p.getID()))
             .mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName + " p WHERE NOT (p.ID > 5)",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName + " p WHERE NOT (p.ID > 5)",
         downCast(supplierOne.get().filter(p -> p.getID() <= 5).mapToInt(Portfolio::getID).average()
             .orElse(Double.NaN)));
 
     // Distinct Queries
-    queries.put("SELECT AVG(DISTINCT p.ID) FROM /" + firstRegionName + " p WHERE p.ID > 0",
+    queries.put(
+        "SELECT AVG(DISTINCT p.ID) FROM " + SEPARATOR + firstRegionName + " p WHERE p.ID > 0",
         downCast(
             supplierOne.get().filter(p -> p.getID() > 0).filter(distinctByKey(Portfolio::getID))
                 .mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(DISTINCT p.shortID) FROM /" + firstRegionName + " p WHERE p.ID > 0",
+    queries.put(
+        "SELECT AVG(DISTINCT p.shortID) FROM " + SEPARATOR + firstRegionName + " p WHERE p.ID > 0",
         downCast(supplierOne.get().filter(p -> p.getID() > 0).filter(distinctByKey(p -> p.shortID))
             .mapToInt(p -> p.shortID).average().orElse(Double.NaN)));
 
     // StructSet queries.
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND pos.secId = 'IBM'",
         downCast(supplierOne.get().filter(p -> p.getID() > 0 && p.getPositions().containsKey("IBM"))
             .mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID < 100 AND pos.secId = 'IBM'",
         downCast(
             supplierOne.get().filter(p -> p.getID() < 100 && p.getPositions().containsKey("IBM"))
                 .mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT DISTINCT AVG(p.ID) FROM /" + firstRegionName
+    queries.put("SELECT DISTINCT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND pos.secId = 'IBM'",
         downCast(supplierOne.get().filter(p -> p.getID() > 0 && p.getPositions().containsKey("IBM"))
             .distinct().mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND p.status = 'active' AND pos.secId = 'IBM'",
         downCast(supplierOne.get()
             .filter(p -> p.getID() > 0 && p.isActive() && p.getPositions().containsKey("IBM"))
             .mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
 
     // Aggregate used as as WHERE condition within inner query.
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName
-        + " p WHERE p.ID IN (SELECT MIN(o.ID) FROM /" + firstRegionName + " o)",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
+        + " p WHERE p.ID IN (SELECT MIN(o.ID) FROM " + SEPARATOR + firstRegionName + " o)",
         downCast(supplierOne.get()
             .filter(p -> p.getID() == supplierOne.get().mapToInt(Portfolio::getID).min().orElse(-1))
             .mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName
-        + " p WHERE p.ID = ELEMENT(SELECT MAX(o.ID) FROM /" + firstRegionName + " o)",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
+        + " p WHERE p.ID = ELEMENT(SELECT MAX(o.ID) FROM " + SEPARATOR + firstRegionName + " o)",
         downCast(supplierOne.get()
             .filter(p -> p.getID() == supplierOne.get().mapToInt(Portfolio::getID).max().orElse(-1))
             .mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
 
     // Equi Join Queries
-    equiJoinQueries.put("SELECT AVG(p.ID) from /" + firstRegionName + " p, /" + secondRegionName
+    equiJoinQueries.put("SELECT AVG(p.ID) from " + SEPARATOR + firstRegionName + " p, " + SEPARATOR
+        + secondRegionName
         + " e WHERE p.ID = e.ID AND p.ID > 0",
         downCast(supplierOne.get().filter(p -> regionTwoLocalCopy.containsKey(p.getID()))
             .filter(p -> p.getID() > 0).mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
-    equiJoinQueries.put("SELECT AVG(p.ID) from /" + firstRegionName + " p, /" + secondRegionName
+    equiJoinQueries.put("SELECT AVG(p.ID) from " + SEPARATOR + firstRegionName + " p, " + SEPARATOR
+        + secondRegionName
         + " e WHERE p.ID = e.ID AND p.ID > 20 AND e.ID > 40",
         downCast(supplierOne.get()
             .filter(p -> supplierTwo.get().filter(e -> e.getID() > 40)
                 .collect(Collectors.toMap(Portfolio::getID, Function.identity()))
                 .containsKey(p.getID()))
             .filter(p -> p.getID() > 20).mapToInt(Portfolio::getID).average().orElse(Double.NaN)));
-    equiJoinQueries.put("SELECT AVG(p.ID) from /" + firstRegionName + " p, /" + secondRegionName
+    equiJoinQueries.put("SELECT AVG(p.ID) from " + SEPARATOR + firstRegionName + " p, " + SEPARATOR
+        + secondRegionName
         + " e WHERE p.ID = e.ID AND p.ID > 0 AND p.status = 'active'",
         downCast(supplierOne.get().filter(p -> regionTwoLocalCopy.containsKey(p.getID()))
             .filter(p -> p.getID() > 0 && p.isActive()).mapToInt(Portfolio::getID).average()
@@ -165,79 +174,86 @@ public class AvgIntegrationTest extends AggregateFunctionQueryBaseIntegrationTes
     }
 
     // Simple Queries
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName + " p",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName + " p",
         downCast(supplierOne.get().mapToInt(PortfolioPdx::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName + " p WHERE p.ID > 0",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName + " p WHERE p.ID > 0",
         downCast(supplierOne.get().filter(p -> p.getID() > 0).mapToInt(PortfolioPdx::getID)
             .average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName + " p WHERE p.ID > 50",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName + " p WHERE p.ID > 50",
         downCast(supplierOne.get().filter(p -> p.getID() > 50).mapToInt(PortfolioPdx::getID)
             .average().orElse(Double.NaN)));
     queries.put(
-        "SELECT AVG(p.ID) FROM /" + firstRegionName + " p WHERE p.ID > 0 OR p.status='active'",
+        "SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
+            + " p WHERE p.ID > 0 OR p.status='active'",
         downCast(supplierOne.get().filter(p -> p.getID() > 0 || p.isActive())
             .mapToInt(PortfolioPdx::getID).average().orElse(Double.NaN)));
     queries.put(
-        "SELECT AVG(p.ID) FROM /" + firstRegionName + " p WHERE p.ID > 0 OR p.status LIKE 'ina%'",
+        "SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
+            + " p WHERE p.ID > 0 OR p.status LIKE 'ina%'",
         downCast(supplierOne.get().filter(p -> p.getID() > 0 || p.status.startsWith("ina"))
             .mapToInt(PortfolioPdx::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName + " p WHERE p.ID IN SET(1, 2, 3, 4, 5)",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
+        + " p WHERE p.ID IN SET(1, 2, 3, 4, 5)",
         downCast(supplierOne.get().filter(p -> Arrays.asList(1, 2, 3, 4, 5).contains(p.getID()))
             .mapToInt(PortfolioPdx::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName + " p WHERE NOT (p.ID > 5)",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName + " p WHERE NOT (p.ID > 5)",
         downCast(supplierOne.get().filter(p -> p.getID() <= 5).mapToInt(PortfolioPdx::getID)
             .average().orElse(Double.NaN)));
 
     // Distinct Queries
-    queries.put("SELECT AVG(DISTINCT p.ID) FROM /" + firstRegionName + " p WHERE p.ID > 0",
+    queries.put(
+        "SELECT AVG(DISTINCT p.ID) FROM " + SEPARATOR + firstRegionName + " p WHERE p.ID > 0",
         downCast(
             supplierOne.get().filter(p -> p.getID() > 0).filter(distinctByKey(PortfolioPdx::getID))
                 .mapToInt(PortfolioPdx::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(DISTINCT p.shortID) FROM /" + firstRegionName + " p WHERE p.ID > 0",
+    queries.put(
+        "SELECT AVG(DISTINCT p.shortID) FROM " + SEPARATOR + firstRegionName + " p WHERE p.ID > 0",
         downCast(supplierOne.get().filter(p -> p.getID() > 0).filter(distinctByKey(p -> p.shortID))
             .mapToInt(p -> p.shortID).average().orElse(Double.NaN)));
 
     // StructSet queries.
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND pos.secId = 'IBM'",
         downCast(supplierOne.get().filter(p -> p.getID() > 0 && p.getPositions().containsKey("IBM"))
             .mapToInt(PortfolioPdx::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID < 100 AND pos.secId = 'IBM'",
         downCast(
             supplierOne.get().filter(p -> p.getID() < 100 && p.getPositions().containsKey("IBM"))
                 .mapToInt(PortfolioPdx::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT DISTINCT AVG(p.ID) FROM /" + firstRegionName
+    queries.put("SELECT DISTINCT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND pos.secId = 'IBM'",
         downCast(supplierOne.get().filter(p -> p.getID() > 0 && p.getPositions().containsKey("IBM"))
             .distinct().mapToInt(PortfolioPdx::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND p.status = 'active' AND pos.secId = 'IBM'",
         downCast(supplierOne.get()
             .filter(p -> p.getID() > 0 && p.isActive() && p.getPositions().containsKey("IBM"))
             .mapToInt(PortfolioPdx::getID).average().orElse(Double.NaN)));
 
     // Aggregate used as as WHERE condition within inner query.
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName
-        + " p WHERE p.ID IN (SELECT MIN(o.ID) FROM /" + firstRegionName + " o)",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
+        + " p WHERE p.ID IN (SELECT MIN(o.ID) FROM " + SEPARATOR + firstRegionName + " o)",
         downCast(supplierOne.get()
             .filter(
                 p -> p.getID() == supplierOne.get().mapToInt(PortfolioPdx::getID).min().orElse(-1))
             .mapToInt(PortfolioPdx::getID).average().orElse(Double.NaN)));
-    queries.put("SELECT AVG(p.ID) FROM /" + firstRegionName
-        + " p WHERE p.ID = ELEMENT(SELECT MAX(o.ID) FROM /" + firstRegionName + " o)",
+    queries.put("SELECT AVG(p.ID) FROM " + SEPARATOR + firstRegionName
+        + " p WHERE p.ID = ELEMENT(SELECT MAX(o.ID) FROM " + SEPARATOR + firstRegionName + " o)",
         downCast(supplierOne.get()
             .filter(
                 p -> p.getID() == supplierOne.get().mapToInt(PortfolioPdx::getID).max().orElse(-1))
             .mapToInt(PortfolioPdx::getID).average().orElse(Double.NaN)));
 
     // Equi Join Queries
-    equiJoinQueries.put("SELECT AVG(p.ID) from /" + firstRegionName + " p, /" + secondRegionName
+    equiJoinQueries.put("SELECT AVG(p.ID) from " + SEPARATOR + firstRegionName + " p, " + SEPARATOR
+        + secondRegionName
         + " e WHERE p.ID = e.ID AND p.ID > 0",
         downCast(supplierOne.get().filter(p -> regionTwoLocalCopy.containsKey(p.getID()))
             .filter(p -> p.getID() > 0).mapToInt(PortfolioPdx::getID).average()
             .orElse(Double.NaN)));
-    equiJoinQueries.put("SELECT AVG(p.ID) from /" + firstRegionName + " p, /" + secondRegionName
+    equiJoinQueries.put("SELECT AVG(p.ID) from " + SEPARATOR + firstRegionName + " p, " + SEPARATOR
+        + secondRegionName
         + " e WHERE p.ID = e.ID AND p.ID > 20 AND e.ID > 40",
         downCast(supplierOne.get()
             .filter(p -> supplierTwo.get().filter(e -> e.getID() > 40)
@@ -245,7 +261,8 @@ public class AvgIntegrationTest extends AggregateFunctionQueryBaseIntegrationTes
                 .containsKey(p.getID()))
             .filter(p -> p.getID() > 20).mapToInt(PortfolioPdx::getID).average()
             .orElse(Double.NaN)));
-    equiJoinQueries.put("SELECT AVG(p.ID) from /" + firstRegionName + " p, /" + secondRegionName
+    equiJoinQueries.put("SELECT AVG(p.ID) from " + SEPARATOR + firstRegionName + " p, " + SEPARATOR
+        + secondRegionName
         + " e WHERE p.ID = e.ID AND p.ID > 0 AND p.status = 'active'",
         downCast(supplierOne.get().filter(p -> regionTwoLocalCopy.containsKey(p.getID()))
             .filter(p -> p.getID() > 0 && p.isActive()).mapToInt(PortfolioPdx::getID).average()
@@ -294,10 +311,10 @@ public class AvgIntegrationTest extends AggregateFunctionQueryBaseIntegrationTes
     parameterizedSetUp(usePdx);
     createRegion(firstRegionName, regionShortcut);
     QueryService queryService = server.getCache().getQueryService();
-    queryService.createIndex("sampleIndex-1", "p.ID", "/" + firstRegionName + " p");
-    queryService.createIndex("sampleIndex-2", "p.status", "/" + firstRegionName + " p");
+    queryService.createIndex("sampleIndex-1", "p.ID", SEPARATOR + firstRegionName + " p");
+    queryService.createIndex("sampleIndex-2", "p.status", SEPARATOR + firstRegionName + " p");
     queryService.createIndex("sampleIndex-3", "pos.secId",
-        "/" + firstRegionName + " p, p.positions.values pos");
+        SEPARATOR + firstRegionName + " p, p.positions.values pos");
     await().untilAsserted(() -> assertThat(queryService.getIndexes().size()).isEqualTo(3));
     populateRegion(firstRegionName, regionOneLocalCopy);
 
@@ -342,10 +359,10 @@ public class AvgIntegrationTest extends AggregateFunctionQueryBaseIntegrationTes
     createRegion(firstRegionName, regionShortcut);
     createRegion(secondRegionName, regionShortcut);
     QueryService queryService = server.getCache().getQueryService();
-    queryService.createIndex("sampleIndex-1", "p.ID", "/" + firstRegionName + " p");
-    queryService.createIndex("sampleIndex-2", "p.status", "/" + firstRegionName + " p");
-    queryService.createIndex("sampleIndex-3", "e.ID", "/" + secondRegionName + " e");
-    queryService.createIndex("sampleIndex-4", "e.status", "/" + secondRegionName + " e");
+    queryService.createIndex("sampleIndex-1", "p.ID", SEPARATOR + firstRegionName + " p");
+    queryService.createIndex("sampleIndex-2", "p.status", SEPARATOR + firstRegionName + " p");
+    queryService.createIndex("sampleIndex-3", "e.ID", SEPARATOR + secondRegionName + " e");
+    queryService.createIndex("sampleIndex-4", "e.status", SEPARATOR + secondRegionName + " e");
     await().untilAsserted(() -> assertThat(queryService.getIndexes().size()).isEqualTo(4));
     populateRegion(firstRegionName, regionOneLocalCopy);
     populateRegion(secondRegionName, regionTwoLocalCopy);
