@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query.internal.aggregate;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.assertj.core.api.Assertions.assertThat;
 
@@ -63,47 +64,49 @@ public class MinIntegrationTest extends AggregateFunctionQueryBaseIntegrationTes
     }
 
     // Simple Queries
-    queries.put("SELECT MIN(ID) FROM /" + firstRegionName,
+    queries.put("SELECT MIN(ID) FROM " + SEPARATOR + firstRegionName,
         supplierOne.get().mapToInt(Portfolio::getID).min().orElse(-1));
-    queries.put("SELECT MIN(ID) FROM /" + firstRegionName + " WHERE ID > 0",
+    queries.put("SELECT MIN(ID) FROM " + SEPARATOR + firstRegionName + " WHERE ID > 0",
         supplierOne.get().filter(p -> p.getID() > 0).mapToInt(Portfolio::getID).min().orElse(-1));
-    queries.put("SELECT MIN(ID) FROM /" + firstRegionName + " WHERE ID > 0 LIMIT 50",
+    queries.put("SELECT MIN(ID) FROM " + SEPARATOR + firstRegionName + " WHERE ID > 0 LIMIT 50",
         supplierOne.get().filter(p -> p.getID() > 0).mapToInt(Portfolio::getID).min().orElse(-1));
-    queries.put("SELECT MIN(p.getType()) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.getType()) FROM " + SEPARATOR + firstRegionName
         + " p WHERE p.ID > 0 OR p.status='active'",
         supplierOne.get().filter(p -> p.getID() > 0 || p.isActive())
             .min(Comparator.comparing(Portfolio::getType)).map(Portfolio::getType).orElse(""));
-    queries.put("SELECT MIN(p.getType()) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.getType()) FROM " + SEPARATOR + firstRegionName
         + " p WHERE p.ID > 0 OR p.status LIKE 'ina%'",
         supplierOne.get().filter(p -> p.getID() > 0 || p.status.startsWith("ina"))
             .min(Comparator.comparing(Portfolio::getType)).map(Portfolio::getType).orElse(""));
     queries.put(
-        "SELECT MIN(p.shortID) FROM /" + firstRegionName + " p WHERE p.ID IN SET(1, 2, 3, 4, 5)",
+        "SELECT MIN(p.shortID) FROM " + SEPARATOR + firstRegionName
+            + " p WHERE p.ID IN SET(1, 2, 3, 4, 5)",
         supplierOne.get().filter(p -> Arrays.asList(1, 2, 3, 4, 5).contains(p.getID()))
             .min(Comparator.comparing(p -> p.shortID)).map(p -> p.shortID).orElse((short) -1));
-    queries.put("SELECT MIN(p.shortID) FROM /" + firstRegionName + " p WHERE NOT (p.ID > 5)",
+    queries.put(
+        "SELECT MIN(p.shortID) FROM " + SEPARATOR + firstRegionName + " p WHERE NOT (p.ID > 5)",
         supplierOne.get().filter(p -> p.getID() <= 5).min(Comparator.comparing(p -> p.shortID))
             .map(p -> p.shortID).orElse((short) -1));
 
     // StructSet queries.
-    queries.put("SELECT MIN(p.ID) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.ID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND pos.secId = 'IBM'",
         supplierOne.get().filter(p -> p.getID() > 0 && p.getPositions().containsKey("IBM"))
             .mapToInt(Portfolio::getID).min().orElse(-1));
-    queries.put("SELECT MIN(p.getType()) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.getType()) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND pos.secId = 'IBM' LIMIT 5",
         supplierOne.get().filter(p -> p.getID() > 0 && p.getPositions().containsKey("IBM"))
             .min(Comparator.comparing(Portfolio::getType)).map(Portfolio::getType).orElse(""));
-    queries.put("SELECT MIN(p.status) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.status) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND pos.secId = 'IBM'",
         supplierOne.get().filter(p -> p.getID() > 0 && p.getPositions().containsKey("IBM"))
             .min(Comparator.comparing(p -> p.status)).map(p -> p.status).orElse(""));
-    queries.put("SELECT MIN(p.shortID) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.shortID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND p.status = 'active' AND pos.secId = 'IBM'",
         supplierOne.get()
             .filter(p -> p.getID() > 0 && p.isActive() && p.getPositions().containsKey("IBM"))
             .min(Comparator.comparing(p -> p.shortID)).map(p -> p.shortID).orElse((short) -1));
-    queries.put("SELECT MIN(p.shortID) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.shortID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 OR p.status IN SET ('active', 'inactive') OR pos.secId = 'IBM' LIMIT 50",
         supplierOne.get()
             .filter(p -> p.getID() > 0 || p.isActive() || !p.isActive()
@@ -111,36 +114,40 @@ public class MinIntegrationTest extends AggregateFunctionQueryBaseIntegrationTes
             .min(Comparator.comparing(p -> p.shortID)).map(p -> p.shortID).orElse((short) -1));
 
     // Aggregate used as as WHERE condition within inner query.
-    queries.put("SELECT MIN(p.shortID) FROM /" + firstRegionName
-        + " p WHERE p.ID IN (SELECT MIN(o.ID) FROM /" + firstRegionName + " o)",
+    queries.put("SELECT MIN(p.shortID) FROM " + SEPARATOR + firstRegionName
+        + " p WHERE p.ID IN (SELECT MIN(o.ID) FROM " + SEPARATOR + firstRegionName + " o)",
         supplierOne.get()
             .filter(p -> p.getID() == supplierOne.get().mapToInt(Portfolio::getID).min().orElse(-1))
             .min(Comparator.comparing(p -> p.shortID)).map(p -> p.shortID).orElse((short) -1));
-    queries.put("SELECT MIN(p.shortID) FROM /" + firstRegionName
-        + " p WHERE p.ID = ELEMENT(SELECT MAX(o.ID) FROM /" + firstRegionName + " o)",
+    queries.put("SELECT MIN(p.shortID) FROM " + SEPARATOR + firstRegionName
+        + " p WHERE p.ID = ELEMENT(SELECT MAX(o.ID) FROM " + SEPARATOR + firstRegionName + " o)",
         supplierOne.get()
             .filter(p -> p.getID() == supplierOne.get().mapToInt(Portfolio::getID).max().orElse(-1))
             .min(Comparator.comparing(p -> p.shortID)).map(p -> p.shortID).orElse((short) -1));
 
     // Equi Join Queries
-    equiJoinQueries.put("SELECT MIN(p.shortID) from /" + firstRegionName + " p, /"
-        + secondRegionName + " e WHERE p.ID = e.ID AND p.ID > 0",
-        supplierOne.get().filter(p -> regionTwoLocalCopy.containsKey(p.getID()))
-            .filter(p -> p.getID() > 0).min(Comparator.comparing(p -> p.shortID))
-            .map(p -> p.shortID).orElse((short) -1));
-    equiJoinQueries.put("SELECT MIN(p.shortID) from /" + firstRegionName + " p, /"
-        + secondRegionName + " e WHERE p.ID = e.ID AND p.ID > 20 AND e.ID > 40",
-        supplierOne.get()
-            .filter(p -> supplierTwo.get().filter(e -> e.getID() > 40)
-                .collect(Collectors.toMap(Portfolio::getID, Function.identity()))
-                .containsKey(p.getID()))
-            .filter(p -> p.getID() > 20).min(Comparator.comparing(p -> p.shortID))
-            .map(p -> p.shortID).orElse((short) -1));
-    equiJoinQueries.put("SELECT MIN(p.shortID) from /" + firstRegionName + " p, /"
-        + secondRegionName + " e WHERE p.ID = e.ID AND p.ID > 0 AND p.status = 'active'",
-        supplierOne.get().filter(p -> regionTwoLocalCopy.containsKey(p.getID()))
-            .filter(p -> p.getID() > 0 && p.isActive()).min(Comparator.comparing(p -> p.shortID))
-            .map(p -> p.shortID).orElse((short) -1));
+    equiJoinQueries
+        .put("SELECT MIN(p.shortID) from " + SEPARATOR + firstRegionName + " p, " + SEPARATOR
+            + secondRegionName + " e WHERE p.ID = e.ID AND p.ID > 0",
+            supplierOne.get().filter(p -> regionTwoLocalCopy.containsKey(p.getID()))
+                .filter(p -> p.getID() > 0).min(Comparator.comparing(p -> p.shortID))
+                .map(p -> p.shortID).orElse((short) -1));
+    equiJoinQueries
+        .put("SELECT MIN(p.shortID) from " + SEPARATOR + firstRegionName + " p, " + SEPARATOR
+            + secondRegionName + " e WHERE p.ID = e.ID AND p.ID > 20 AND e.ID > 40",
+            supplierOne.get()
+                .filter(p -> supplierTwo.get().filter(e -> e.getID() > 40)
+                    .collect(Collectors.toMap(Portfolio::getID, Function.identity()))
+                    .containsKey(p.getID()))
+                .filter(p -> p.getID() > 20).min(Comparator.comparing(p -> p.shortID))
+                .map(p -> p.shortID).orElse((short) -1));
+    equiJoinQueries
+        .put("SELECT MIN(p.shortID) from " + SEPARATOR + firstRegionName + " p, " + SEPARATOR
+            + secondRegionName + " e WHERE p.ID = e.ID AND p.ID > 0 AND p.status = 'active'",
+            supplierOne.get().filter(p -> regionTwoLocalCopy.containsKey(p.getID()))
+                .filter(p -> p.getID() > 0 && p.isActive())
+                .min(Comparator.comparing(p -> p.shortID))
+                .map(p -> p.shortID).orElse((short) -1));
   }
 
   public void prepareStructuresWithPdx() {
@@ -162,52 +169,54 @@ public class MinIntegrationTest extends AggregateFunctionQueryBaseIntegrationTes
     }
 
     // Simple Queries
-    queries.put("SELECT MIN(ID) FROM /" + firstRegionName,
+    queries.put("SELECT MIN(ID) FROM " + SEPARATOR + firstRegionName,
         supplierOne.get().mapToInt(PortfolioPdx::getID).min().orElse(-1));
-    queries.put("SELECT MIN(ID) FROM /" + firstRegionName + " WHERE ID > 0",
+    queries.put("SELECT MIN(ID) FROM " + SEPARATOR + firstRegionName + " WHERE ID > 0",
         supplierOne.get().filter(p -> p.getID() > 0).mapToInt(PortfolioPdx::getID).min()
             .orElse(-1));
-    queries.put("SELECT MIN(ID) FROM /" + firstRegionName + " WHERE ID > 0 LIMIT 50",
+    queries.put("SELECT MIN(ID) FROM " + SEPARATOR + firstRegionName + " WHERE ID > 0 LIMIT 50",
         supplierOne.get().filter(p -> p.getID() > 0).mapToInt(PortfolioPdx::getID).min()
             .orElse(-1));
-    queries.put("SELECT MIN(p.getType()) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.getType()) FROM " + SEPARATOR + firstRegionName
         + " p WHERE p.ID > 0 OR p.status='active'",
         supplierOne.get().filter(p -> p.getID() > 0 || p.isActive())
             .min(Comparator.comparing(PortfolioPdx::getType)).map(PortfolioPdx::getType)
             .orElse(""));
-    queries.put("SELECT MIN(p.getType()) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.getType()) FROM " + SEPARATOR + firstRegionName
         + " p WHERE p.ID > 0 OR p.status LIKE 'ina%'",
         supplierOne.get().filter(p -> p.getID() > 0 || p.status.startsWith("ina"))
             .min(Comparator.comparing(PortfolioPdx::getType)).map(PortfolioPdx::getType)
             .orElse(""));
     queries.put(
-        "SELECT MIN(p.shortID) FROM /" + firstRegionName + " p WHERE p.ID IN SET(1, 2, 3, 4, 5)",
+        "SELECT MIN(p.shortID) FROM " + SEPARATOR + firstRegionName
+            + " p WHERE p.ID IN SET(1, 2, 3, 4, 5)",
         supplierOne.get().filter(p -> Arrays.asList(1, 2, 3, 4, 5).contains(p.getID()))
             .min(Comparator.comparing(p -> p.shortID)).map(p -> p.shortID).orElse((short) -1));
-    queries.put("SELECT MIN(p.shortID) FROM /" + firstRegionName + " p WHERE NOT (p.ID > 5)",
+    queries.put(
+        "SELECT MIN(p.shortID) FROM " + SEPARATOR + firstRegionName + " p WHERE NOT (p.ID > 5)",
         supplierOne.get().filter(p -> p.getID() <= 5).min(Comparator.comparing(p -> p.shortID))
             .map(p -> p.shortID).orElse((short) -1));
 
     // StructSet queries.
-    queries.put("SELECT MIN(p.ID) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.ID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND pos.secId = 'IBM'",
         supplierOne.get().filter(p -> p.getID() > 0 && p.getPositions().containsKey("IBM"))
             .mapToInt(PortfolioPdx::getID).min().orElse(-1));
-    queries.put("SELECT MIN(p.getType()) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.getType()) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND pos.secId = 'IBM' LIMIT 5",
         supplierOne.get().filter(p -> p.getID() > 0 && p.getPositions().containsKey("IBM"))
             .min(Comparator.comparing(PortfolioPdx::getType)).map(PortfolioPdx::getType)
             .orElse(""));
-    queries.put("SELECT MIN(p.status) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.status) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND pos.secId = 'IBM'",
         supplierOne.get().filter(p -> p.getID() > 0 && p.getPositions().containsKey("IBM"))
             .min(Comparator.comparing(p -> p.status)).map(p -> p.status).orElse(""));
-    queries.put("SELECT MIN(p.shortID) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.shortID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 AND p.status = 'active' AND pos.secId = 'IBM'",
         supplierOne.get()
             .filter(p -> p.getID() > 0 && p.isActive() && p.getPositions().containsKey("IBM"))
             .min(Comparator.comparing(p -> p.shortID)).map(p -> p.shortID).orElse((short) -1));
-    queries.put("SELECT MIN(p.shortID) FROM /" + firstRegionName
+    queries.put("SELECT MIN(p.shortID) FROM " + SEPARATOR + firstRegionName
         + " p, p.positions.values pos WHERE p.ID > 0 OR p.status IN SET ('active', 'inactive') OR pos.secId = 'IBM' LIMIT 50",
         supplierOne.get()
             .filter(p -> p.getID() > 0 || p.isActive() || !p.isActive()
@@ -215,14 +224,14 @@ public class MinIntegrationTest extends AggregateFunctionQueryBaseIntegrationTes
             .min(Comparator.comparing(p -> p.shortID)).map(p -> p.shortID).orElse((short) -1));
 
     // Aggregate used as as WHERE condition within inner query.
-    queries.put("SELECT MIN(p.shortID) FROM /" + firstRegionName
-        + " p WHERE p.ID IN (SELECT MIN(o.ID) FROM /" + firstRegionName + " o)",
+    queries.put("SELECT MIN(p.shortID) FROM " + SEPARATOR + firstRegionName
+        + " p WHERE p.ID IN (SELECT MIN(o.ID) FROM " + SEPARATOR + firstRegionName + " o)",
         supplierOne.get()
             .filter(
                 p -> p.getID() == supplierOne.get().mapToInt(PortfolioPdx::getID).min().orElse(-1))
             .min(Comparator.comparing(p -> p.shortID)).map(p -> p.shortID).orElse((short) -1));
-    queries.put("SELECT MIN(p.shortID) FROM /" + firstRegionName
-        + " p WHERE p.ID = ELEMENT(SELECT MAX(o.ID) FROM /" + firstRegionName + " o)",
+    queries.put("SELECT MIN(p.shortID) FROM " + SEPARATOR + firstRegionName
+        + " p WHERE p.ID = ELEMENT(SELECT MAX(o.ID) FROM " + SEPARATOR + firstRegionName + " o)",
         supplierOne.get()
             .filter(
                 p -> p.getID() == supplierOne.get().mapToInt(PortfolioPdx::getID).max().orElse(-1))
@@ -230,24 +239,28 @@ public class MinIntegrationTest extends AggregateFunctionQueryBaseIntegrationTes
 
 
     // Equi Join Queries
-    equiJoinQueries.put("SELECT MIN(p.shortID) from /" + firstRegionName + " p, /"
-        + secondRegionName + " e WHERE p.ID = e.ID AND p.ID > 0",
-        supplierOne.get().filter(p -> regionTwoLocalCopy.containsKey(p.getID()))
-            .filter(p -> p.getID() > 0).min(Comparator.comparing(p -> p.shortID))
-            .map(p -> p.shortID).orElse((short) -1));
-    equiJoinQueries.put("SELECT MIN(p.shortID) from /" + firstRegionName + " p, /"
-        + secondRegionName + " e WHERE p.ID = e.ID AND p.ID > 20 AND e.ID > 40",
-        supplierOne.get()
-            .filter(p -> supplierTwo.get().filter(e -> e.getID() > 40)
-                .collect(Collectors.toMap(PortfolioPdx::getID, Function.identity()))
-                .containsKey(p.getID()))
-            .filter(p -> p.getID() > 20).min(Comparator.comparing(p -> p.shortID))
-            .map(p -> p.shortID).orElse((short) -1));
-    equiJoinQueries.put("SELECT MIN(p.shortID) from /" + firstRegionName + " p, /"
-        + secondRegionName + " e WHERE p.ID = e.ID AND p.ID > 0 AND p.status = 'active'",
-        supplierOne.get().filter(p -> regionTwoLocalCopy.containsKey(p.getID()))
-            .filter(p -> p.getID() > 0 && p.isActive()).min(Comparator.comparing(p -> p.shortID))
-            .map(p -> p.shortID).orElse((short) -1));
+    equiJoinQueries
+        .put("SELECT MIN(p.shortID) from " + SEPARATOR + firstRegionName + " p, " + SEPARATOR
+            + secondRegionName + " e WHERE p.ID = e.ID AND p.ID > 0",
+            supplierOne.get().filter(p -> regionTwoLocalCopy.containsKey(p.getID()))
+                .filter(p -> p.getID() > 0).min(Comparator.comparing(p -> p.shortID))
+                .map(p -> p.shortID).orElse((short) -1));
+    equiJoinQueries
+        .put("SELECT MIN(p.shortID) from " + SEPARATOR + firstRegionName + " p, " + SEPARATOR
+            + secondRegionName + " e WHERE p.ID = e.ID AND p.ID > 20 AND e.ID > 40",
+            supplierOne.get()
+                .filter(p -> supplierTwo.get().filter(e -> e.getID() > 40)
+                    .collect(Collectors.toMap(PortfolioPdx::getID, Function.identity()))
+                    .containsKey(p.getID()))
+                .filter(p -> p.getID() > 20).min(Comparator.comparing(p -> p.shortID))
+                .map(p -> p.shortID).orElse((short) -1));
+    equiJoinQueries
+        .put("SELECT MIN(p.shortID) from " + SEPARATOR + firstRegionName + " p, " + SEPARATOR
+            + secondRegionName + " e WHERE p.ID = e.ID AND p.ID > 0 AND p.status = 'active'",
+            supplierOne.get().filter(p -> regionTwoLocalCopy.containsKey(p.getID()))
+                .filter(p -> p.getID() > 0 && p.isActive())
+                .min(Comparator.comparing(p -> p.shortID))
+                .map(p -> p.shortID).orElse((short) -1));
   }
 
   public void parameterizedSetUp(boolean usePdx) {
@@ -292,10 +305,10 @@ public class MinIntegrationTest extends AggregateFunctionQueryBaseIntegrationTes
     parameterizedSetUp(usePdx);
     createRegion(firstRegionName, regionShortcut);
     QueryService queryService = server.getCache().getQueryService();
-    queryService.createIndex("sampleIndex-1", "p.ID", "/" + firstRegionName + " p");
-    queryService.createIndex("sampleIndex-2", "p.status", "/" + firstRegionName + " p");
+    queryService.createIndex("sampleIndex-1", "p.ID", SEPARATOR + firstRegionName + " p");
+    queryService.createIndex("sampleIndex-2", "p.status", SEPARATOR + firstRegionName + " p");
     queryService.createIndex("sampleIndex-3", "pos.secId",
-        "/" + firstRegionName + " p, p.positions.values pos");
+        SEPARATOR + firstRegionName + " p, p.positions.values pos");
     await().untilAsserted(() -> assertThat(queryService.getIndexes().size()).isEqualTo(3));
     populateRegion(firstRegionName, regionOneLocalCopy);
 
@@ -340,10 +353,10 @@ public class MinIntegrationTest extends AggregateFunctionQueryBaseIntegrationTes
     createRegion(firstRegionName, regionShortcut);
     createRegion(secondRegionName, regionShortcut);
     QueryService queryService = server.getCache().getQueryService();
-    queryService.createIndex("sampleIndex-1", "p.ID", "/" + firstRegionName + " p");
-    queryService.createIndex("sampleIndex-2", "p.status", "/" + firstRegionName + " p");
-    queryService.createIndex("sampleIndex-3", "e.ID", "/" + secondRegionName + " e");
-    queryService.createIndex("sampleIndex-4", "e.status", "/" + secondRegionName + " e");
+    queryService.createIndex("sampleIndex-1", "p.ID", SEPARATOR + firstRegionName + " p");
+    queryService.createIndex("sampleIndex-2", "p.status", SEPARATOR + firstRegionName + " p");
+    queryService.createIndex("sampleIndex-3", "e.ID", SEPARATOR + secondRegionName + " e");
+    queryService.createIndex("sampleIndex-4", "e.status", SEPARATOR + secondRegionName + " e");
     await().untilAsserted(() -> assertThat(queryService.getIndexes().size()).isEqualTo(4));
     populateRegion(firstRegionName, regionOneLocalCopy);
     populateRegion(secondRegionName, regionTwoLocalCopy);
