@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query.internal.index;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
@@ -65,12 +66,12 @@ public class CompactRangeIndexJUnitTest {
   @Test
   public void testCompactRangeIndex() throws Exception {
     System.setProperty("index_elemarray_threshold", "3");
-    index = utils.createIndex("type", "\"type\"", "/exampleRegion");
+    index = utils.createIndex("type", "\"type\"", SEPARATOR + "exampleRegion");
     putValues(9);
     isUsingIndexElemArray("type1");
     putValues(10);
     isUsingConcurrentHashSet("type1");
-    utils.removeIndex("type", "/exampleRegion");
+    utils.removeIndex("type", SEPARATOR + "exampleRegion");
     executeQueryWithAndWithoutIndex(4);
     putOffsetValues(2);
     executeQueryWithCount();
@@ -85,7 +86,7 @@ public class CompactRangeIndexJUnitTest {
    */
   @Test
   public void testNullKeyCompactRangeIndex() throws Exception {
-    index = utils.createIndex("indexName", "status", "/exampleRegion");
+    index = utils.createIndex("indexName", "status", SEPARATOR + "exampleRegion");
     Region region = utils.getCache().getRegion("exampleRegion");
 
     // create objects
@@ -98,7 +99,7 @@ public class CompactRangeIndexJUnitTest {
     // execute query and check result size
     QueryService qs = utils.getCache().getQueryService();
     SelectResults results = (SelectResults) qs
-        .newQuery("Select * from /exampleRegion r where r.status = null").execute();
+        .newQuery("Select * from " + SEPARATOR + "exampleRegion r where r.status = null").execute();
     assertEquals("Null matched Results expected", numObjects, results.size());
   }
 
@@ -107,7 +108,7 @@ public class CompactRangeIndexJUnitTest {
    */
   @Test
   public void testNullMapKeyCompactRangeIndex() throws Exception {
-    index = utils.createIndex("indexName", "positions[*]", "/exampleRegion");
+    index = utils.createIndex("indexName", "positions[*]", SEPARATOR + "exampleRegion");
     Region region = utils.getCache().getRegion("exampleRegion");
 
     // create objects
@@ -121,7 +122,9 @@ public class CompactRangeIndexJUnitTest {
     // execute query and check result size
     QueryService qs = utils.getCache().getQueryService();
     SelectResults results = (SelectResults) qs
-        .newQuery("Select * from /exampleRegion r where r.position[null] = something").execute();
+        .newQuery(
+            "Select * from " + SEPARATOR + "exampleRegion r where r.position[null] = something")
+        .execute();
     assertEquals("Null matched Results expected", numObjects, results.size());
   }
 
@@ -140,11 +143,13 @@ public class CompactRangeIndexJUnitTest {
       p.getPositions().put(null, "something");
       region.put("KEY-" + i, p);
     }
-    index = utils.createIndex("indexName", "positions[*]", "/exampleRegion");
+    index = utils.createIndex("indexName", "positions[*]", SEPARATOR + "exampleRegion");
     // execute query and check result size
     QueryService qs = utils.getCache().getQueryService();
     SelectResults results = (SelectResults) qs
-        .newQuery("Select * from /exampleRegion r where r.position[null] = something").execute();
+        .newQuery(
+            "Select * from " + SEPARATOR + "exampleRegion r where r.position[null] = something")
+        .execute();
     assertEquals("Null matched Results expected", numObjects, results.size());
   }
 
@@ -156,8 +161,8 @@ public class CompactRangeIndexJUnitTest {
   @Test
   public void testCompactRangeIndexMemoryIndexStoreMaintenance() throws Exception {
     try {
-      index = utils.createIndex("compact range index", "p.status", "/exampleRegion p");
-      final Region r = utils.getCache().getRegion("/exampleRegion");
+      index = utils.createIndex("compact range index", "p.status", SEPARATOR + "exampleRegion p");
+      final Region r = utils.getCache().getRegion(SEPARATOR + "exampleRegion");
       Portfolio p0 = new Portfolio(0);
       p0.status = "active";
       final Portfolio p1 = new Portfolio(1);
@@ -188,12 +193,14 @@ public class CompactRangeIndexJUnitTest {
       threadsDone.await(90, TimeUnit.SECONDS);
       QueryService qs = utils.getCache().getQueryService();
       SelectResults results = (SelectResults) qs
-          .newQuery("Select * from /exampleRegion r where r.status='active'").execute();
+          .newQuery("Select * from " + SEPARATOR + "exampleRegion r where r.status='active'")
+          .execute();
       // the remove should have happened
       assertEquals(1, results.size());
 
       results = (SelectResults) qs
-          .newQuery("Select * from /exampleRegion r where r.status!='inactive'").execute();
+          .newQuery("Select * from " + SEPARATOR + "exampleRegion r where r.status!='inactive'")
+          .execute();
       assertEquals(1, results.size());
 
       CompactRangeIndex cindex = (CompactRangeIndex) index;
@@ -219,8 +226,8 @@ public class CompactRangeIndexJUnitTest {
   public void testMemoryIndexStoreMaintenanceTransitionFromElemArrayToTokenToConcurrentHashSet()
       throws Exception {
     try {
-      index = utils.createIndex("compact range index", "p.status", "/exampleRegion p");
-      final Region r = utils.getCache().getRegion("/exampleRegion");
+      index = utils.createIndex("compact range index", "p.status", SEPARATOR + "exampleRegion p");
+      final Region r = utils.getCache().getRegion(SEPARATOR + "exampleRegion");
       Portfolio p0 = new Portfolio(0);
       p0.status = "active";
       Portfolio p1 = new Portfolio(1);
@@ -258,12 +265,14 @@ public class CompactRangeIndexJUnitTest {
       threadsDone.await(90, TimeUnit.SECONDS);
       QueryService qs = utils.getCache().getQueryService();
       SelectResults results = (SelectResults) qs
-          .newQuery("Select * from /exampleRegion r where r.status='active'").execute();
+          .newQuery("Select * from " + SEPARATOR + "exampleRegion r where r.status='active'")
+          .execute();
       // the remove should have happened
       assertEquals(3, results.size());
 
       results = (SelectResults) qs
-          .newQuery("Select * from /exampleRegion r where r.status!='inactive'").execute();
+          .newQuery("Select * from " + SEPARATOR + "exampleRegion r where r.status!='inactive'")
+          .execute();
       assertEquals(3, results.size());
 
       CompactRangeIndex cindex = (CompactRangeIndex) index;
@@ -283,18 +292,20 @@ public class CompactRangeIndexJUnitTest {
 
   @Test
   public void testInvalidTokens() throws Exception {
-    final Region r = utils.getCache().getRegion("/exampleRegion");
+    final Region r = utils.getCache().getRegion(SEPARATOR + "exampleRegion");
     r.put("0", new Portfolio(0));
     r.invalidate("0");
-    index = utils.createIndex("compact range index", "p.status", "/exampleRegion p");
+    index = utils.createIndex("compact range index", "p.status", SEPARATOR + "exampleRegion p");
     QueryService qs = utils.getCache().getQueryService();
     SelectResults results = (SelectResults) qs
-        .newQuery("Select * from /exampleRegion r where r.status='active'").execute();
+        .newQuery("Select * from " + SEPARATOR + "exampleRegion r where r.status='active'")
+        .execute();
     // the remove should have happened
     assertEquals(0, results.size());
 
     results = (SelectResults) qs
-        .newQuery("Select * from /exampleRegion r where r.status!='inactive'").execute();
+        .newQuery("Select * from " + SEPARATOR + "exampleRegion r where r.status!='inactive'")
+        .execute();
     assertEquals(0, results.size());
 
     CompactRangeIndex cindex = (CompactRangeIndex) index;
@@ -313,7 +324,8 @@ public class CompactRangeIndexJUnitTest {
       throws Exception {
     try {
       CompactRangeIndex.TEST_ALWAYS_UPDATE_IN_PROGRESS = true;
-      index = utils.createIndex("indexName", "getP1().getSharesOutstanding()", "/exampleRegion");
+      index = utils.createIndex("indexName", "getP1().getSharesOutstanding()",
+          SEPARATOR + "exampleRegion");
       Region region = utils.getCache().getRegion("exampleRegion");
 
       // create objects
@@ -327,7 +339,8 @@ public class CompactRangeIndexJUnitTest {
       QueryService qs = utils.getCache().getQueryService();
       SelectResults results = (SelectResults) qs
           .newQuery(
-              "<trace>SELECT DISTINCT e.key FROM /exampleRegion AS e WHERE e.ID = 1 AND e.getP1().getSharesOutstanding() >= -1 AND e.getP1().getSharesOutstanding() <= 1000 LIMIT 10 ")
+              "<trace>SELECT DISTINCT e.key FROM " + SEPARATOR
+                  + "exampleRegion AS e WHERE e.ID = 1 AND e.getP1().getSharesOutstanding() >= -1 AND e.getP1().getSharesOutstanding() <= 1000 LIMIT 10 ")
           .execute();
     } finally {
       CompactRangeIndex.TEST_ALWAYS_UPDATE_IN_PROGRESS = false;
@@ -491,13 +504,13 @@ public class CompactRangeIndexJUnitTest {
     } catch (Exception e) {
       fail("Query execution failed. : " + e);
     }
-    index = utils.createIndex("type", "\"type\"", "/exampleRegion");
+    index = utils.createIndex("type", "\"type\"", SEPARATOR + "exampleRegion");
     try {
       executeSimpleQuery(expectedResults);
     } catch (Exception e) {
       fail("Query execution failed. : " + e);
     }
-    utils.removeIndex("type", "/exampleRegion");
+    utils.removeIndex("type", SEPARATOR + "exampleRegion");
   }
 
   private int executeSimpleQuery(int expResults) throws Exception {
