@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query.partitioned;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 
@@ -101,7 +102,7 @@ public class PRIndexStatisticsJUnitTest {
   public void testStatsForRangeIndex() throws Exception {
     createAndPopulateRegion();
     keyIndex1 = (IndexProtocol) qs.createIndex("multiKeyIndex1", IndexType.FUNCTIONAL, "pos.secId",
-        "/portfolio p, p.positions.values pos");
+        SEPARATOR + "portfolio p, p.positions.values pos");
 
     assertTrue(keyIndex1 instanceof PartitionedIndex);
 
@@ -122,7 +123,8 @@ public class PRIndexStatisticsJUnitTest {
     assertEquals(400, keyIndex1Stats.getNumUpdates());
 
     // IndexUsed stats test
-    String queryStr = "select * from /portfolio p, p.positions.values pos where pos.secId = 'YHOO'";
+    String queryStr = "select * from " + SEPARATOR
+        + "portfolio p, p.positions.values pos where pos.secId = 'YHOO'";
     Query query = qs.newQuery(queryStr);
 
     for (int i = 0; i < 50; i++) {
@@ -170,7 +172,8 @@ public class PRIndexStatisticsJUnitTest {
   public void testStatsForCompactRangeIndex() throws Exception {
     createAndPopulateRegion();
     keyIndex2 =
-        (IndexProtocol) qs.createIndex("multiKeyIndex2", IndexType.FUNCTIONAL, "ID", "/portfolio ");
+        (IndexProtocol) qs.createIndex("multiKeyIndex2", IndexType.FUNCTIONAL, "ID",
+            SEPARATOR + "portfolio ");
 
     assertTrue(keyIndex2 instanceof PartitionedIndex);
 
@@ -191,7 +194,7 @@ public class PRIndexStatisticsJUnitTest {
     assertEquals(200, keyIndex1Stats.getNumUpdates());
 
     // IndexUsed stats test
-    String queryStr = "select * from /portfolio where ID > 0";
+    String queryStr = "select * from " + SEPARATOR + "portfolio where ID > 0";
     Query query = qs.newQuery(queryStr);
 
     for (int i = 0; i < 50; i++) {
@@ -239,7 +242,7 @@ public class PRIndexStatisticsJUnitTest {
   public void testStatsForCompactMapRangeIndex() throws Exception {
     createAndPopulateRegion();
     keyIndex3 = (IndexProtocol) qs.createIndex("multiKeyIndex3", IndexType.FUNCTIONAL,
-        "positions['DELL', 'YHOO']", "/portfolio p");
+        "positions['DELL', 'YHOO']", SEPARATOR + "portfolio p");
 
     assertTrue(keyIndex3 instanceof PartitionedIndex);
 
@@ -262,7 +265,8 @@ public class PRIndexStatisticsJUnitTest {
     assertEquals(200, keyIndexStats.getNumUpdates());
 
     String queryStr =
-        "select * from /portfolio where positions['DELL'] != NULL OR positions['YHOO'] != NULL";
+        "select * from " + SEPARATOR
+            + "portfolio where positions['DELL'] != NULL OR positions['YHOO'] != NULL";
     Query query = qs.newQuery(queryStr);
 
     for (int i = 0; i < 50; i++) {
@@ -311,7 +315,7 @@ public class PRIndexStatisticsJUnitTest {
     IndexManager.TEST_RANGEINDEX_ONLY = true;
     createAndPopulateRegion();
     keyIndex3 = (IndexProtocol) qs.createIndex("multiKeyIndex3", IndexType.FUNCTIONAL,
-        "positions['DELL', 'YHOO']", "/portfolio");
+        "positions['DELL', 'YHOO']", SEPARATOR + "portfolio");
 
     assertTrue(keyIndex3 instanceof PartitionedIndex);
 
@@ -336,7 +340,8 @@ public class PRIndexStatisticsJUnitTest {
     assertEquals(200, keyIndexStats.getNumUpdates());
 
     String queryStr =
-        "select * from /portfolio where positions['DELL'] != NULL OR positions['YHOO'] != NULL";
+        "select * from " + SEPARATOR
+            + "portfolio where positions['DELL'] != NULL OR positions['YHOO'] != NULL";
     Query query = qs.newQuery(queryStr);
 
     for (int i = 0; i < 50; i++) {
@@ -388,7 +393,7 @@ public class PRIndexStatisticsJUnitTest {
     assertEquals(0, region.size());
 
     keyIndex1 = (IndexProtocol) qs.createIndex("multiKeyIndex4", IndexType.FUNCTIONAL, "pos.secId",
-        "/portfolio p, p.positions.values pos");
+        SEPARATOR + "portfolio p, p.positions.values pos");
 
     // Recreate all entries in the region
     for (int i = 0; i < 100; i++) {
@@ -414,7 +419,8 @@ public class PRIndexStatisticsJUnitTest {
     assertEquals(400, keyIndex1Stats.getNumUpdates());
 
     // IndexUsed stats test
-    String queryStr = "select * from /portfolio p, p.positions.values pos where pos.secId = 'YHOO'";
+    String queryStr = "select * from " + SEPARATOR
+        + "portfolio p, p.positions.values pos where pos.secId = 'YHOO'";
     Query query = qs.newQuery(queryStr);
 
     for (int i = 0; i < 50; i++) {
@@ -465,7 +471,8 @@ public class PRIndexStatisticsJUnitTest {
     assertEquals(0, region.size());
 
     keyIndex2 =
-        (IndexProtocol) qs.createIndex("multiKeyIndex5", IndexType.FUNCTIONAL, "ID", "/portfolio ");
+        (IndexProtocol) qs.createIndex("multiKeyIndex5", IndexType.FUNCTIONAL, "ID",
+            SEPARATOR + "portfolio ");
 
     // Recreate all entries in the region
     for (int i = 0; i < 100; i++) {
@@ -491,7 +498,7 @@ public class PRIndexStatisticsJUnitTest {
     assertEquals(200, keyIndex1Stats.getNumUpdates());
 
     // IndexUsed stats test
-    String queryStr = "select * from /portfolio where ID > 0";
+    String queryStr = "select * from " + SEPARATOR + "portfolio where ID > 0";
     Query query = qs.newQuery(queryStr);
 
     for (int i = 0; i < 50; i++) {
@@ -541,7 +548,7 @@ public class PRIndexStatisticsJUnitTest {
     assertEquals(0, region.size());
 
     keyIndex3 = (IndexProtocol) qs.createIndex("multiKeyIndex6", IndexType.FUNCTIONAL,
-        "positions['DELL', 'YHOO']", "/portfolio");
+        "positions['DELL', 'YHOO']", SEPARATOR + "portfolio");
 
     // Recreate all entries in the region
     Position.cnt = 0;
@@ -570,7 +577,8 @@ public class PRIndexStatisticsJUnitTest {
     assertEquals(200, keyIndexStats.getNumUpdates());
 
     String queryStr =
-        "select * from /portfolio where positions['DELL'] != NULL OR positions['YHOO'] != NULL";
+        "select * from " + SEPARATOR
+            + "portfolio where positions['DELL'] != NULL OR positions['YHOO'] != NULL";
     Query query = qs.newQuery(queryStr);
 
     for (int i = 0; i < 50; i++) {
@@ -622,7 +630,7 @@ public class PRIndexStatisticsJUnitTest {
     assertEquals(0, region.size());
 
     keyIndex3 = (IndexProtocol) qs.createIndex("multiKeyIndex6", IndexType.FUNCTIONAL,
-        "positions['DELL', 'YHOO']", "/portfolio");
+        "positions['DELL', 'YHOO']", SEPARATOR + "portfolio");
 
     // Recreate all entries in the region
     Position.cnt = 0;
@@ -651,7 +659,8 @@ public class PRIndexStatisticsJUnitTest {
     assertEquals(200, keyIndexStats.getNumUpdates());
 
     String queryStr =
-        "select * from /portfolio where positions['DELL'] != NULL OR positions['YHOO'] != NULL";
+        "select * from " + SEPARATOR
+            + "portfolio where positions['DELL'] != NULL OR positions['YHOO'] != NULL";
     Query query = qs.newQuery(queryStr);
 
     for (int i = 0; i < 50; i++) {
