@@ -19,6 +19,7 @@
  */
 package org.apache.geode.internal.jta.functional;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
@@ -81,7 +82,7 @@ public class CacheJUnitTest {
     assertNotNull(this.cache);
 
     this.currRegion = this.cache.getRegion("root");
-    assertTrue(this.currRegion.getFullPath().equals("/root"));
+    assertTrue(this.currRegion.getFullPath().equals(SEPARATOR + "root"));
   }
 
   @After
@@ -249,7 +250,8 @@ public class CacheJUnitTest {
       jtaObj.getRegionFromCache("region1");
 
       String current_fullpath = jtaObj.currRegion.getFullPath();
-      assertEquals("failed retrieving current region fullpath", "/" + DEFAULT_RGN + "/region1",
+      assertEquals("failed retrieving current region fullpath",
+          SEPARATOR + DEFAULT_RGN + SEPARATOR + "region1",
           current_fullpath);
 
       jtaObj.put("key1", "value1");
@@ -259,7 +261,8 @@ public class CacheJUnitTest {
       assertEquals("get failed for corresponding put", "\"value1\"", tok);
 
       current_fullpath = jtaObj.currRegion.getFullPath();
-      assertEquals("failed retrieving current region fullpath", "/" + DEFAULT_RGN + "/region1",
+      assertEquals("failed retrieving current region fullpath",
+          SEPARATOR + DEFAULT_RGN + SEPARATOR + "region1",
           current_fullpath);
 
       DataSource da = (DataSource) ctx.lookup("java:/XAPooledDataSource");
@@ -280,7 +283,7 @@ public class CacheJUnitTest {
 
       current_fullpath = jtaObj.currRegion.getFullPath();
       assertEquals("failed retrieving current region fullpath after txn commit",
-          "/" + DEFAULT_RGN + "/region1", current_fullpath);
+          SEPARATOR + DEFAULT_RGN + SEPARATOR + "region1", current_fullpath);
 
       int ifAnyRows = jtaObj.getRows(this.tblName);
       assertEquals("rows retrieved is:" + ifAnyRows, 1, ifAnyRows);
@@ -349,7 +352,7 @@ public class CacheJUnitTest {
       String current_fullpath = jtaObj.currRegion.getFullPath();
       assertEquals(
           "failed retrieving current region fullpath after doing getRegionFromCache(region1)",
-          "/" + DEFAULT_RGN + "/region1", current_fullpath);
+          SEPARATOR + DEFAULT_RGN + SEPARATOR + "region1", current_fullpath);
 
       jtaObj.put("key1", "test");
       ta.begin();
@@ -360,7 +363,8 @@ public class CacheJUnitTest {
       assertEquals("get value do not match with the put", "\"value1\"", tok);
 
       current_fullpath = jtaObj.currRegion.getFullPath();
-      assertEquals("failed retrieving current region fullpath", "/" + DEFAULT_RGN + "/region1",
+      assertEquals("failed retrieving current region fullpath",
+          SEPARATOR + DEFAULT_RGN + SEPARATOR + "region1",
           current_fullpath);
 
       DataSource da = (DataSource) ctx.lookup("java:/XAPooledDataSource");
@@ -380,7 +384,7 @@ public class CacheJUnitTest {
 
       current_fullpath = jtaObj.currRegion.getFullPath();
       assertEquals("failed retirieving current region fullpath after txn rollback",
-          "/" + DEFAULT_RGN + "/region1", current_fullpath);
+          SEPARATOR + DEFAULT_RGN + SEPARATOR + "region1", current_fullpath);
 
       int ifAnyRows = jtaObj.getRows(this.tblName);
       assertEquals("rows retrieved is: " + ifAnyRows, 0, ifAnyRows);
@@ -452,7 +456,8 @@ public class CacheJUnitTest {
       // now current region should point to region1, as done from within
       // getRegionFromCache method...
       String current_fullpath = jtaObj.currRegion.getFullPath();
-      assertEquals("failed retirieving current fullpath", "/" + DEFAULT_RGN + "/region1",
+      assertEquals("failed retirieving current fullpath",
+          SEPARATOR + DEFAULT_RGN + SEPARATOR + "region1",
           current_fullpath);
 
       jtaObj.put("key1", "test");
@@ -466,7 +471,7 @@ public class CacheJUnitTest {
 
       current_fullpath = jtaObj.currRegion.getFullPath();
       assertEquals("failed retrieving current fullpath, current fullpath: " + current_fullpath,
-          "/" + DEFAULT_RGN + "/region1", current_fullpath);
+          SEPARATOR + DEFAULT_RGN + SEPARATOR + "region1", current_fullpath);
 
       DataSource da = (DataSource) ctx.lookup("java:/XAPooledDataSource");
 
@@ -517,7 +522,7 @@ public class CacheJUnitTest {
         String current_fullpath = jtaObj.currRegion.getFullPath();
         assertEquals(
             "failed retrieving current fullpath after rollback, fullpath is: " + current_fullpath,
-            "/" + DEFAULT_RGN + "/region1", current_fullpath);
+            SEPARATOR + DEFAULT_RGN + SEPARATOR + "region1", current_fullpath);
 
         // after jdbc rollback, cache value in region1 for key1 must vanish...
         String str1 = null;
@@ -579,7 +584,8 @@ public class CacheJUnitTest {
       // now current region should point to region1, as done from within
       // getRegionFromCache method...
       String current_fullpath = jtaObj.currRegion.getFullPath();
-      assertEquals("failed retrieving the current region fullpath", "/" + DEFAULT_RGN + "/region1",
+      assertEquals("failed retrieving the current region fullpath",
+          SEPARATOR + DEFAULT_RGN + SEPARATOR + "region1",
           current_fullpath);
 
       jtaObj.put("key1", "value1");
@@ -590,7 +596,8 @@ public class CacheJUnitTest {
       assertEquals("get value mismatch with put", "\"value1\"", tok);
 
       current_fullpath = jtaObj.currRegion.getFullPath();
-      assertEquals("failed retrieving current region fullpath", "/" + DEFAULT_RGN + "/region1",
+      assertEquals("failed retrieving current region fullpath",
+          SEPARATOR + DEFAULT_RGN + SEPARATOR + "region1",
           current_fullpath);
 
       DataSource da = (DataSource) ctx.lookup("java:/XAPooledDataSource");
@@ -603,7 +610,7 @@ public class CacheJUnitTest {
 
       current_fullpath = jtaObj.currRegion.getFullPath();
       assertEquals("failed retrieving current region fullpath after txn commit, fullpath is: "
-          + current_region, "/" + DEFAULT_RGN + "/region1", current_fullpath);
+          + current_region, SEPARATOR + DEFAULT_RGN + SEPARATOR + "region1", current_fullpath);
 
       str = jtaObj.get("key1");
       tok = jtaObj.parseGetValue(str);
