@@ -36,6 +36,7 @@ import org.apache.logging.log4j.Logger;
 import org.apache.geode.ToDataException;
 import org.apache.geode.annotations.Immutable;
 import org.apache.geode.cache.client.NoAvailableLocatorsException;
+import org.apache.geode.cache.client.SocketFactory;
 import org.apache.geode.cache.client.internal.PoolImpl.PoolTask;
 import org.apache.geode.cache.client.internal.locator.ClientConnectionRequest;
 import org.apache.geode.cache.client.internal.locator.ClientConnectionResponse;
@@ -49,7 +50,7 @@ import org.apache.geode.cache.client.internal.locator.QueueConnectionResponse;
 import org.apache.geode.cache.client.internal.locator.ServerLocationRequest;
 import org.apache.geode.cache.client.internal.locator.ServerLocationResponse;
 import org.apache.geode.distributed.internal.ServerLocation;
-import org.apache.geode.distributed.internal.tcpserver.LocatorAddress;
+import org.apache.geode.distributed.internal.tcpserver.HostAndPort;
 import org.apache.geode.distributed.internal.tcpserver.TcpClient;
 import org.apache.geode.internal.InternalDataSerializer;
 import org.apache.geode.internal.cache.tier.sockets.ClientProxyMembershipID;
@@ -73,26 +74,31 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
   @Immutable
   private static final LocatorListRequest LOCATOR_LIST_REQUEST = new LocatorListRequest();
 
+  /**
+   * A Comparator used to sort a list of locator addresses. This should not be
+   * used in other ways as it can return zero when two addresses aren't actually equal.
+   */
   @Immutable
-  private static final Comparator<LocatorAddress> SOCKET_ADDRESS_COMPARATOR =
+  private static final Comparator<HostAndPort> SOCKET_ADDRESS_COMPARATOR =
       (address, otherAddress) -> {
         InetSocketAddress inetSocketAddress = address.getSocketInetAddress();
         InetSocketAddress otherInetSocketAddress = otherAddress.getSocketInetAddress();
         // shouldn't happen, but if it does we'll say they're the same.
-        if (inetSocketAddress.getAddress() == null
-            || otherInetSocketAddress.getAddress() == null) {
+        if (inetSocketAddress.getHostString() == null
+            || otherInetSocketAddress.getHostString() == null) {
           return 0;
         }
 
-        int result = inetSocketAddress.getAddress().getCanonicalHostName()
-            .compareTo(otherInetSocketAddress.getAddress().getCanonicalHostName());
+        int result = inetSocketAddress.getHostString()
+            .compareTo(otherInetSocketAddress.getHostString());
         if (result != 0) {
           return result;
         } else {
           return inetSocketAddress.getPort() - otherInetSocketAddress.getPort();
         }
       };
-  private final List<LocatorAddress> initialLocators;
+  private final List<HostAndPort> initialLocators;
+
   private final String serverGroup;
   private AtomicReference<LocatorList> locators = new AtomicReference<>();
   private AtomicReference<LocatorList> onlineLocators = new AtomicReference<>();
@@ -107,8 +113,9 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
    */
   private final Map<InetSocketAddress, Exception> locatorState = new HashMap<>();
 
-  public AutoConnectionSourceImpl(List<LocatorAddress> contacts, String serverGroup,
-      int handshakeTimeout) {
+  public AutoConnectionSourceImpl(List<HostAndPort> contacts, String serverGroup,
+      int handshakeTimeout,
+      SocketFactory socketFactory) {
     this.locators.set(new LocatorList(new ArrayList<>(contacts)));
     this.onlineLocators.set(new LocatorList(Collections.emptyList()));
     this.initialLocators = Collections.unmodifiableList(this.locators.get().getLocatorAddresses());
@@ -117,7 +124,8 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
     this.tcpClient = new TcpClient(SocketCreatorFactory
         .getSocketCreatorForComponent(SecurableCommunicationChannel.LOCATOR),
         InternalDataSerializer.getDSFIDSerializer().getObjectSerializer(),
-        InternalDataSerializer.getDSFIDSerializer().getObjectDeserializer());
+        InternalDataSerializer.getDSFIDSerializer().getObjectDeserializer(),
+        socketFactory::createSocket);
   }
 
   @Override
@@ -194,24 +202,24 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
   }
 
 
-  private ServerLocationResponse queryOneLocator(LocatorAddress locator,
+  private ServerLocationResponse queryOneLocator(HostAndPort locator,
       ServerLocationRequest request) {
     return queryOneLocatorUsingConnection(locator, request, tcpClient);
   }
 
 
-  ServerLocationResponse queryOneLocatorUsingConnection(LocatorAddress locator,
+  ServerLocationResponse queryOneLocatorUsingConnection(HostAndPort locator,
       ServerLocationRequest request,
       TcpClient locatorConnection) {
     Object returnObj = null;
     try {
       pool.getStats().incLocatorRequests();
-      returnObj = locatorConnection.requestToServer(locator.getSocketInetAddressNoLookup(), request,
+      returnObj = locatorConnection.requestToServer(locator, request,
           connectionTimeout, true);
       ServerLocationResponse response = (ServerLocationResponse) returnObj;
       pool.getStats().incLocatorResponses();
       if (response != null) {
-        reportLiveLocator(locator.getSocketInetAddressNoLookup());
+        reportLiveLocator(locator.getSocketInetAddress());
       }
       return response;
     } catch (IOException | ToDataException ioe) {
@@ -219,8 +227,7 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
         logger.warn("Encountered ToDataException when communicating with a locator.  "
             + "This is expected if the locator is shutting down.", ioe);
       }
-      reportDeadLocator(locator.getSocketInetAddressNoLookup(), ioe);
-      updateLocatorInLocatorList(locator);
+      reportDeadLocator(locator.getSocketInetAddress(), ioe);
       return null;
     } catch (ClassNotFoundException e) {
       logger.warn("Received exception from locator {}", locator, e);
@@ -229,52 +236,18 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
       if (logger.isDebugEnabled()) {
         logger.debug("Received odd response object from the locator: {}", returnObj);
       }
-      reportDeadLocator(locator.getSocketInetAddressNoLookup(), e);
+      reportDeadLocator(locator.getSocketInetAddress(), e);
       return null;
     }
   }
 
-  /**
-   * If connecting to the locator fails with an IOException, this may be because the locator's IP
-   * has changed. Add the locator back to the list of locators using host address rather than IP.
-   * This will cause another DNS lookup, hopefully finding the locator.
-   *
-   */
-  protected void updateLocatorInLocatorList(LocatorAddress locator) {
-    if (locator.getSocketInetAddressNoLookup().getHostName() != null && !locator.isIpString()) {
-      LocatorList locatorList = locators.get();
-      List<LocatorAddress> newLocatorsList = new ArrayList<>();
-
-      for (LocatorAddress tloc : locatorList.getLocatorAddresses()) {
-        if (tloc.equals(locator)) {
-          InetSocketAddress changeLoc = new InetSocketAddress(locator.getHostName(),
-              locator.getSocketInetAddressNoLookup().getPort());
-          LocatorAddress hostAddress = new LocatorAddress(changeLoc, locator.getHostName());
-          newLocatorsList.add(hostAddress);
-        } else {
-          newLocatorsList.add(tloc);
-        }
-      }
-
-      logger.debug("updateLocatorInLocatorList locator list from: {} to {}",
-          locatorList.getLocators(), newLocatorsList);
-
-      LocatorList newLocatorList = new LocatorList(newLocatorsList);
-      locators.set(newLocatorList);
-    }
-  }
-
-  protected List<InetSocketAddress> getCurrentLocators() {
-    return locators.get().getLocators();
-  }
-
   private ServerLocationResponse queryLocators(ServerLocationRequest request) {
     Iterator controllerItr = locators.get().iterator();
     ServerLocationResponse response;
 
     final boolean isDebugEnabled = logger.isDebugEnabled();
     do {
-      LocatorAddress hostAddress = (LocatorAddress) controllerItr.next();
+      HostAndPort hostAddress = (HostAndPort) controllerItr.next();
       if (isDebugEnabled) {
         logger.debug("Sending query to locator {}: {}", hostAddress, request);
       }
@@ -294,13 +267,13 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
     isBalanced = response.isBalanced();
     List<ServerLocation> locatorResponse = response.getLocators();
 
-    List<LocatorAddress> newLocatorAddresses = new ArrayList<>(locatorResponse.size());
-    List<LocatorAddress> newOnlineLocators = new ArrayList<>(locatorResponse.size());
+    List<HostAndPort> newLocatorAddresses = new ArrayList<>(locatorResponse.size());
+    List<HostAndPort> newOnlineLocators = new ArrayList<>(locatorResponse.size());
+
+    Set<HostAndPort> badLocators = new HashSet<>(initialLocators);
 
-    Set<LocatorAddress> badLocators = new HashSet<>(initialLocators);
     for (ServerLocation locator : locatorResponse) {
-      InetSocketAddress address = new InetSocketAddress(locator.getHostName(), locator.getPort());
-      LocatorAddress hostAddress = new LocatorAddress(address, locator.getHostName());
+      HostAndPort hostAddress = new HostAndPort(locator.getHostName(), locator.getPort());
       newLocatorAddresses.add(hostAddress);
       newOnlineLocators.add(hostAddress);
       badLocators.remove(hostAddress);
@@ -339,10 +312,10 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
    * This method will add bad locator only when locator with hostname and port is not already in
    * list.
    */
-  protected void addbadLocators(List<LocatorAddress> newLocators, Set<LocatorAddress> badLocators) {
-    for (LocatorAddress badloc : badLocators) {
+  protected void addbadLocators(List<HostAndPort> newLocators, Set<HostAndPort> badLocators) {
+    for (HostAndPort badloc : badLocators) {
       boolean addIt = true;
-      for (LocatorAddress goodloc : newLocators) {
+      for (HostAndPort goodloc : newLocators) {
         boolean isSameHost = badloc.getHostName().equals(goodloc.getHostName());
         if (isSameHost && badloc.getPort() == goodloc.getPort()) {
           // ip has been changed so don't add this in current
@@ -408,23 +381,23 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
    * A list of locators, which remembers the last known good locator.
    */
   private static class LocatorList {
-    protected final List<LocatorAddress> locators;
+    protected final List<HostAndPort> locators;
     AtomicInteger currentLocatorIndex = new AtomicInteger();
 
-    LocatorList(List<LocatorAddress> locators) {
+    LocatorList(List<HostAndPort> locators) {
       locators.sort(SOCKET_ADDRESS_COMPARATOR);
       this.locators = Collections.unmodifiableList(locators);
     }
 
     public List<InetSocketAddress> getLocators() {
       List<InetSocketAddress> locs = new ArrayList<>();
-      for (LocatorAddress la : locators) {
+      for (HostAndPort la : locators) {
         locs.add(la.getSocketInetAddress());
       }
       return locs;
     }
 
-    List<LocatorAddress> getLocatorAddresses() {
+    List<HostAndPort> getLocatorAddresses() {
       return locators;
     }
 
@@ -432,7 +405,7 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
       return locators.size();
     }
 
-    public Iterator<LocatorAddress> iterator() {
+    public Iterator<HostAndPort> iterator() {
       return new LocatorIterator();
     }
 
@@ -447,7 +420,7 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
      * controller.
      *
      */
-    protected class LocatorIterator implements Iterator<LocatorAddress> {
+    protected class LocatorIterator implements Iterator<HostAndPort> {
       private int startLocator = currentLocatorIndex.get();
       private int locatorNum = 0;
 
@@ -457,12 +430,12 @@ public class AutoConnectionSourceImpl implements ConnectionSource {
       }
 
       @Override
-      public LocatorAddress next() {
+      public HostAndPort next() {
         if (!hasNext()) {
           return null;
         } else {
           int index = (locatorNum + startLocator) % locators.size();
-          LocatorAddress nextLocator = locators.get(index);
+          HostAndPort nextLocator = locators.get(index);
           currentLocatorIndex.set(index);
           locatorNum++;
           return nextLocator;
