@@ -14,6 +14,8 @@
  */
 package org.apache.geode.cache.client.internal;
 
+import static org.apache.geode.util.internal.UncheckedUtils.uncheckedCast;
+
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
@@ -197,12 +199,12 @@ public class ClientMetadataService {
     }
   }
 
-  public Map<ServerLocation, HashSet> getServerToFilterMap(final Collection routingKeys,
+  public Map<ServerLocation, Set> getServerToFilterMap(final Collection routingKeys,
       final Region region, boolean primaryMembersNeeded) {
     return getServerToFilterMap(routingKeys, region, primaryMembersNeeded, false);
   }
 
-  public Map<ServerLocation, HashSet> getServerToFilterMap(final Collection routingKeys,
+  public Map<ServerLocation, Set> getServerToFilterMap(final Collection routingKeys,
       final Region region, boolean primaryMembersNeeded, boolean bucketsAsFilter) {
     final String regionFullPath = region.getFullPath();
     ClientPartitionAdvisor prAdvisor = this.getClientPartitionAdvisor(regionFullPath);
@@ -210,11 +212,11 @@ public class ClientMetadataService {
       scheduleGetPRMetaData((InternalRegion) region, false);
       return null;
     }
-    HashMap<Integer, HashSet> bucketToKeysMap =
+    Map<Integer, Set> bucketToKeysMap =
         groupByBucketOnClientSide(region, prAdvisor, routingKeys, bucketsAsFilter);
 
-    HashMap<ServerLocation, HashSet> serverToKeysMap = new HashMap<ServerLocation, HashSet>();
-    HashMap<ServerLocation, HashSet<Integer>> serverToBuckets =
+    Map<ServerLocation, Set> serverToKeysMap = new HashMap<>();
+    Map<ServerLocation, Set<Integer>> serverToBuckets =
         groupByServerToBuckets(prAdvisor, bucketToKeysMap.keySet(), primaryMembersNeeded, region);
 
     if (serverToBuckets == null) {
@@ -228,11 +230,11 @@ public class ClientMetadataService {
 
     for (Map.Entry entry : serverToBuckets.entrySet()) {
       ServerLocation server = (ServerLocation) entry.getKey();
-      HashSet<Integer> buckets = (HashSet) entry.getValue();
+      Set<Integer> buckets = uncheckedCast(entry.getValue());
       for (Integer bucket : buckets) {
         // use LinkedHashSet to maintain the order of keys
         // the keys will be iterated several times
-        LinkedHashSet keys = (LinkedHashSet) serverToKeysMap.get(server);
+        Set keys = serverToKeysMap.get(server);
         if (keys == null) {
           keys = new LinkedHashSet();
         }
@@ -247,7 +249,7 @@ public class ClientMetadataService {
     return serverToKeysMap;
   }
 
-  public HashMap<ServerLocation, HashSet<Integer>> groupByServerToAllBuckets(Region region,
+  public Map<ServerLocation, Set<Integer>> groupByServerToAllBuckets(Region region,
       boolean primaryOnly) {
     final String regionFullPath = region.getFullPath();
     ClientPartitionAdvisor prAdvisor = this.getClientPartitionAdvisor(regionFullPath);
@@ -256,7 +258,7 @@ public class ClientMetadataService {
       return null;
     }
     int totalNumberOfBuckets = prAdvisor.getTotalNumBuckets();
-    HashSet<Integer> allBucketIds = new HashSet<Integer>();
+    Set<Integer> allBucketIds = new HashSet<Integer>();
     for (int i = 0; i < totalNumberOfBuckets; i++) {
       allBucketIds.add(i);
     }
@@ -267,12 +269,11 @@ public class ClientMetadataService {
    * This function should make a map of server to buckets it is hosting. If for some bucket servers
    * are not available due to mismatch in metadata it should fill up a random server for it.
    */
-  private HashMap<ServerLocation, HashSet<Integer>> groupByServerToBuckets(
+  private Map<ServerLocation, Set<Integer>> groupByServerToBuckets(
       ClientPartitionAdvisor prAdvisor, Set<Integer> bucketSet, boolean primaryOnly,
       Region region) {
     if (primaryOnly) {
-      HashMap<ServerLocation, HashSet<Integer>> serverToBucketsMap =
-          new HashMap<ServerLocation, HashSet<Integer>>();
+      Map<ServerLocation, Set<Integer>> serverToBucketsMap = new HashMap<>();
       for (Integer bucketId : bucketSet) {
         ServerLocation server = prAdvisor.advisePrimaryServerLocation(bucketId);
         if (server == null) {
@@ -284,9 +285,9 @@ public class ClientMetadataService {
               prAdvisor.adviseServerLocations(bucketId));
           return null;
         }
-        HashSet<Integer> buckets = serverToBucketsMap.get(server);
+        Set<Integer> buckets = serverToBucketsMap.get(server);
         if (buckets == null) {
-          buckets = new HashSet<Integer>(); // faster if this was an ArrayList
+          buckets = new HashSet<>(); // faster if this was an ArrayList
           serverToBucketsMap.put(server, buckets);
         }
         buckets.add(bucketId);
@@ -303,17 +304,15 @@ public class ClientMetadataService {
   }
 
 
-  private HashMap<ServerLocation, HashSet<Integer>> pruneNodes(ClientPartitionAdvisor prAdvisor,
+  private Map<ServerLocation, Set<Integer>> pruneNodes(ClientPartitionAdvisor prAdvisor,
       Set<Integer> buckets) {
 
     final boolean isDebugEnabled = logger.isDebugEnabled();
     if (isDebugEnabled) {
       logger.debug("ClientMetadataService: The buckets to be pruned are: {}", buckets);
     }
-    HashMap<ServerLocation, HashSet<Integer>> serverToBucketsMap =
-        new HashMap<ServerLocation, HashSet<Integer>>();
-    HashMap<ServerLocation, HashSet<Integer>> prunedServerToBucketsMap =
-        new HashMap<ServerLocation, HashSet<Integer>>();
+    Map<ServerLocation, Set<Integer>> serverToBucketsMap = new HashMap<>();
+    Map<ServerLocation, Set<Integer>> prunedServerToBucketsMap = new HashMap<>();
 
     for (Integer bucketId : buckets) {
       List<BucketServerLocation66> serversList = prAdvisor.adviseServerLocations(bucketId);
@@ -335,11 +334,11 @@ public class ClientMetadataService {
 
       for (ServerLocation server : serversList) {
         if (serverToBucketsMap.get(server) == null) {
-          HashSet<Integer> bucketSet = new HashSet<Integer>();
+          Set<Integer> bucketSet = new HashSet<>();
           bucketSet.add(bucketId);
           serverToBucketsMap.put(server, bucketSet);
         } else {
-          HashSet<Integer> bucketSet = serverToBucketsMap.get(server);
+          Set<Integer> bucketSet = serverToBucketsMap.get(server);
           bucketSet.add(bucketId);
           serverToBucketsMap.put(server, bucketSet);
         }
@@ -357,13 +356,13 @@ public class ClientMetadataService {
       randomFirstServer =
           (ServerLocation) serverToBucketsMap.keySet().toArray()[rand.nextInt(size)];
     }
-    HashSet<Integer> bucketSet = serverToBucketsMap.get(randomFirstServer);
+    Set<Integer> bucketSet = serverToBucketsMap.get(randomFirstServer);
     if (isDebugEnabled) {
       logger.debug(
           "ClientMetadataService: Adding the server : {} which is random and buckets {} to prunedMap",
           randomFirstServer, bucketSet);
     }
-    HashSet<Integer> currentBucketSet = new HashSet<Integer>(bucketSet);
+    Set<Integer> currentBucketSet = new HashSet<>(bucketSet);
     prunedServerToBucketsMap.put(randomFirstServer, bucketSet);
     serverToBucketsMap.remove(randomFirstServer);
 
@@ -373,7 +372,7 @@ public class ClientMetadataService {
         break;
       }
 
-      HashSet<Integer> bucketSet2 = serverToBucketsMap.get(server);
+      Set<Integer> bucketSet2 = serverToBucketsMap.get(server);
       bucketSet2.removeAll(currentBucketSet);
       if (bucketSet2.isEmpty()) {
         serverToBucketsMap.remove(server);
@@ -398,14 +397,14 @@ public class ClientMetadataService {
   }
 
 
-  private ServerLocation findNextServer(Set<Map.Entry<ServerLocation, HashSet<Integer>>> entrySet,
-      HashSet<Integer> currentBucketSet) {
+  private ServerLocation findNextServer(Set<Map.Entry<ServerLocation, Set<Integer>>> entrySet,
+      Set<Integer> currentBucketSet) {
 
     ServerLocation server = null;
     int max = -1;
-    ArrayList<ServerLocation> nodesOfEqualSize = new ArrayList<ServerLocation>();
-    for (Map.Entry<ServerLocation, HashSet<Integer>> entry : entrySet) {
-      HashSet<Integer> buckets = new HashSet<Integer>(entry.getValue());
+    List<ServerLocation> nodesOfEqualSize = new ArrayList<>();
+    for (Map.Entry<ServerLocation, Set<Integer>> entry : entrySet) {
+      Set<Integer> buckets = new HashSet<>(entry.getValue());
       buckets.removeAll(currentBucketSet);
 
       if (max < buckets.size()) {
@@ -426,17 +425,17 @@ public class ClientMetadataService {
     return null;
   }
 
-  private HashMap<Integer, HashSet> groupByBucketOnClientSide(Region region,
+  private Map<Integer, Set> groupByBucketOnClientSide(Region region,
       ClientPartitionAdvisor prAdvisor, Collection routingKeys, boolean bucketsAsFilter) {
 
-    HashMap<Integer, HashSet> bucketToKeysMap = new HashMap();
+    Map<Integer, Set> bucketToKeysMap = new HashMap<>();
     int totalNumberOfBuckets = prAdvisor.getTotalNumBuckets();
     Iterator i = routingKeys.iterator();
     while (i.hasNext()) {
       Object key = i.next();
       int bucketId = bucketsAsFilter ? ((Integer) key).intValue()
           : extractBucketID(region, prAdvisor, totalNumberOfBuckets, key);
-      HashSet bucketKeys = bucketToKeysMap.get(bucketId);
+      Set bucketKeys = bucketToKeysMap.get(bucketId);
       if (bucketKeys == null) {
         bucketKeys = new HashSet(); // faster if this was an ArrayList
         bucketToKeysMap.put(bucketId, bucketKeys);
@@ -757,7 +756,7 @@ public class ClientMetadataService {
   }
 
   private void addClientPartitionAdvisor(String regionFullPath, ClientPartitionAdvisor advisor) {
-    if (this.cache.isClosed() || this.clientPRAdvisors == null) {
+    if (this.cache.isClosed()) {
       return;
     }
     try {
@@ -779,7 +778,7 @@ public class ClientMetadataService {
   }
 
   public ClientPartitionAdvisor getClientPartitionAdvisor(String regionFullPath) {
-    if (this.cache.isClosed() || this.clientPRAdvisors == null) {
+    if (this.cache.isClosed()) {
       return null;
     }
     ClientPartitionAdvisor prAdvisor = null;
@@ -792,15 +791,14 @@ public class ClientMetadataService {
   }
 
   public Set<ClientPartitionAdvisor> getColocatedClientPartitionAdvisor(String regionFullPath) {
-    if (this.cache.isClosed() || this.clientPRAdvisors == null
-        || this.colocatedPRAdvisors == null) {
+    if (this.cache.isClosed()) {
       return null;
     }
     return this.colocatedPRAdvisors.get(regionFullPath);
   }
 
   private Set<String> getAllRegionFullPaths() {
-    if (this.cache.isClosed() || this.clientPRAdvisors == null) {
+    if (this.cache.isClosed()) {
       return null;
     }
     Set<String> keys = null;
@@ -817,14 +815,17 @@ public class ClientMetadataService {
     this.colocatedPRAdvisors.clear();
   }
 
+  @VisibleForTesting
   public boolean isRefreshMetadataTestOnly() {
     return isMetadataRefreshed_TEST_ONLY;
   }
 
+  @VisibleForTesting
   public void satisfyRefreshMetadata_TEST_ONLY(boolean isRefreshMetadataTestOnly) {
     isMetadataRefreshed_TEST_ONLY = isRefreshMetadataTestOnly;
   }
 
+  @VisibleForTesting
   public Map<String, ClientPartitionAdvisor> getClientPRMetadata_TEST_ONLY() {
     return clientPRAdvisors;
   }
@@ -846,6 +847,7 @@ public class ClientMetadataService {
   }
 
   /** For Testing */
+  @VisibleForTesting
   public int getRefreshTaskCount_TEST_ONLY() {
     synchronized (fetchTaskCountLock) {
       return refreshTaskCount;
@@ -853,6 +855,7 @@ public class ClientMetadataService {
   }
 
   /** for testing */
+  @VisibleForTesting
   public long getTotalRefreshTaskCount_TEST_ONLY() {
     synchronized (fetchTaskCountLock) {
       return totalRefreshTaskCount;
