@@ -49,6 +49,7 @@ import org.apache.geode.cache.client.internal.pooling.ConnectionManager;
 import org.apache.geode.cache.execute.FunctionException;
 import org.apache.geode.cache.execute.FunctionInvocationTargetException;
 import org.apache.geode.distributed.internal.ServerLocation;
+import org.apache.geode.distributed.internal.ServerLocationAndMemberId;
 import org.apache.geode.internal.cache.PoolManagerImpl;
 import org.apache.geode.internal.cache.PutAllPartialResultException;
 import org.apache.geode.internal.cache.execute.InternalFunctionInvocationTargetException;
@@ -314,7 +315,9 @@ public class OpExecutorImpl implements ExecutablePool {
       if (queueManager != null) {
         // see if our QueueManager has a connection to this server that we can send
         // the ping on.
-        Endpoint ep = endpointManager.getEndpointMap().get(p_server);
+        ServerLocationAndMemberId slAndMId = new ServerLocationAndMemberId(p_server,
+            ((PingOp.PingOpImpl) op).getServerID().getUniqueId());
+        Endpoint ep = endpointManager.getEndpointMap().get(slAndMId);
         if (ep != null) {
           QueueConnections qcs = queueManager.getAllConnectionsNoWait();
           conn = qcs.getConnection(ep);
