@@ -15,6 +15,7 @@
 package org.apache.geode.cache.client.internal.pooling;
 
 import java.util.Deque;
+import java.util.Objects;
 import java.util.concurrent.ConcurrentLinkedDeque;
 import java.util.function.Predicate;
 
@@ -150,6 +151,11 @@ public class AvailableConnectionManager {
       return false;
     }
 
+    @Override
+    public int hashCode() {
+      return Objects.hash(predicate, connectionThatMatched);
+    }
+
     public Connection getConnectionThatMatched() {
       return this.connectionThatMatched;
     }
