@@ -34,6 +34,7 @@ import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
 import org.w3c.dom.Element;
 
 import org.apache.geode.annotations.Experimental;
+import org.apache.geode.cache.Region;
 import org.apache.geode.internal.config.VersionAdapter;
 import org.apache.geode.lang.Identifiable;
 
@@ -160,6 +161,7 @@ import org.apache.geode.lang.Identifiable;
  *                 &lt;attribute name="alert-threshold" type="{http://www.w3.org/2001/XMLSchema}string" />
  *                 &lt;attribute name="dispatcher-threads" type="{http://www.w3.org/2001/XMLSchema}string" />
  *                 &lt;attribute name="order-policy" type="{http://www.w3.org/2001/XMLSchema}string" />
+ *                 &lt;attribute name="group-transaction-events" type="{http://www.w3.org/2001/XMLSchema}boolean" />
  *               &lt;/restriction>
  *             &lt;/complexContent>
  *           &lt;/complexType>
@@ -328,7 +330,11 @@ public class CacheConfig {
   @XmlJavaTypeAdapter(VersionAdapter.class)
   protected String version;
 
-  public static final String SEPARATOR = "/";
+  /**
+   * @deprecated Please use {@link Region#SEPARATOR}
+   */
+  @Deprecated
+  public static final String SEPARATOR = Region.SEPARATOR;
 
   public CacheConfig() {}
 
@@ -1027,12 +1033,12 @@ public class CacheConfig {
 
   // this supports looking for sub regions
   public RegionConfig findRegionConfiguration(String regionPath) {
-    if (regionPath.startsWith(SEPARATOR)) {
+    if (regionPath.startsWith(Region.SEPARATOR)) {
       regionPath = regionPath.substring(1);
     }
     List<RegionConfig> regions = getRegions();
     RegionConfig found = null;
-    for (String regionToken : regionPath.split(SEPARATOR)) {
+    for (String regionToken : regionPath.split(Region.SEPARATOR)) {
       found = Identifiable.find(regions, regionToken);
       // couldn't find one of the sub regions, break out of the loop
       if (found == null) {
@@ -2595,6 +2601,7 @@ public class CacheConfig {
    *       &lt;attribute name="alert-threshold" type="{http://www.w3.org/2001/XMLSchema}string" />
    *       &lt;attribute name="dispatcher-threads" type="{http://www.w3.org/2001/XMLSchema}string" />
    *       &lt;attribute name="order-policy" type="{http://www.w3.org/2001/XMLSchema}string" />
+   *       &lt;attribute name="group-transaction-events" type="{http://www.w3.org/2001/XMLSchema}boolean" />
    *     &lt;/restriction>
    *   &lt;/complexContent>
    * &lt;/complexType>
@@ -2647,6 +2654,10 @@ public class CacheConfig {
     protected String dispatcherThreads;
     @XmlAttribute(name = "order-policy")
     protected String orderPolicy;
+    @XmlAttribute(name = "group-transaction-events")
+    protected Boolean groupTransactionEvents;
+    @XmlAttribute(name = "enforce-threads-connect-same-receiver")
+    protected Boolean enforceThreadsConnectSameReceiver;
 
     /**
      * Gets the value of the gatewayEventFilters property.
@@ -2774,6 +2785,15 @@ public class CacheConfig {
       this.remoteDistributedSystemId = value;
     }
 
+    public Boolean mustGroupTransactionEvents() {
+      return groupTransactionEvents;
+    }
+
+
+    public void setGroupTransactionEvents(Boolean value) {
+      this.groupTransactionEvents = value;
+    }
+
     /**
      * Gets the value of the parallel property.
      *
@@ -3082,6 +3102,27 @@ public class CacheConfig {
       this.orderPolicy = value;
     }
 
+    /**
+     * Sets the value of the enforceThreadsConnectSameReceiver property.
+     *
+     * allowed object is
+     * {@link Boolean }
+     *
+     */
+    public void setEnforceThreadsConnectSameReceiver(Boolean value) {
+      this.enforceThreadsConnectSameReceiver = value;
+    }
+
+    /**
+     * Gets the value of the enforceThreadsConnectSameReceiver property.
+     *
+     * possible object is
+     * {@link Boolean }
+     *
+     */
+    public Boolean getEnforceThreadsConnectSameReceiver() {
+      return this.enforceThreadsConnectSameReceiver;
+    }
   }
 
 }
