@@ -60,14 +60,16 @@ import org.apache.geode.cache.Cache;
 import org.apache.geode.cache.client.internal.locator.LocatorStatusRequest;
 import org.apache.geode.cache.client.internal.locator.LocatorStatusResponse;
 import org.apache.geode.distributed.internal.InternalLocator;
+import org.apache.geode.distributed.internal.tcpserver.HostAndPort;
 import org.apache.geode.distributed.internal.tcpserver.TcpClient;
 import org.apache.geode.distributed.internal.tcpserver.TcpSocketCreator;
+import org.apache.geode.distributed.internal.tcpserver.TcpSocketFactory;
 import org.apache.geode.internal.DistributionLocator;
 import org.apache.geode.internal.GemFireVersion;
 import org.apache.geode.internal.InternalDataSerializer;
-import org.apache.geode.internal.admin.SSLConfig;
 import org.apache.geode.internal.inet.LocalHostUtil;
 import org.apache.geode.internal.lang.ObjectUtils;
+import org.apache.geode.internal.net.SSLConfig;
 import org.apache.geode.internal.net.SSLConfigurationFactory;
 import org.apache.geode.internal.net.SocketCreator;
 import org.apache.geode.internal.process.ConnectionFailedException;
@@ -322,9 +324,11 @@ public class LocatorLauncher extends AbstractLauncher<String> {
       final TcpSocketCreator socketCreator = new SocketCreator(sslConfig);
       final TcpClient client = new TcpClient(socketCreator,
           InternalDataSerializer.getDSFIDSerializer().getObjectSerializer(),
-          InternalDataSerializer.getDSFIDSerializer().getObjectDeserializer());
+          InternalDataSerializer.getDSFIDSerializer().getObjectDeserializer(),
+          TcpSocketFactory.DEFAULT);
 
-      return (LocatorStatusResponse) client.requestToServer(bindAddress, port,
+      return (LocatorStatusResponse) client.requestToServer(
+          new HostAndPort(bindAddress == null ? null : bindAddress.getCanonicalHostName(), port),
           new LocatorStatusRequest(), timeout, true);
     } catch (ClassNotFoundException e) {
       throw new RuntimeException(e);
@@ -448,9 +452,7 @@ public class LocatorLauncher extends AbstractLauncher<String> {
         return getBindAddress().getCanonicalHostName();
       }
 
-      InetAddress localhost = LocalHostUtil.getLocalHost();
-
-      return localhost.getCanonicalHostName();
+      return LocalHostUtil.getCanonicalLocalHostName();
     } catch (UnknownHostException handled) {
       // Returning localhost/127.0.0.1 implies the bindAddress was null and no IP address for
       // localhost could be found
@@ -661,7 +663,7 @@ public class LocatorLauncher extends AbstractLauncher<String> {
 
   /**
    * Starts a Locator running on the specified port and bind address, as determined by getPort and
-   * getBindAddress respectively, defaulting to 10334 and 'localhost' if not specified, with both
+   * getSocketAddress respectively, defaulting to 10334 and 'localhost' if not specified, with both
    * peer and server location enabled.
    *
    * 'start' is an asynchronous invocation of the Locator. As such, this method makes no guarantees
