@@ -80,7 +80,7 @@ import org.apache.geode.internal.inet.LocalHostUtil;
 import org.apache.geode.internal.logging.log4j.LogMarker;
 import org.apache.geode.internal.monitoring.ThreadsMonitoring;
 import org.apache.geode.internal.sequencelog.MembershipLogger;
-import org.apache.geode.internal.serialization.Version;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.internal.tcp.ConnectionTable;
 import org.apache.geode.internal.tcp.ReenteredConnectException;
 import org.apache.geode.logging.internal.OSProcess;
@@ -1384,19 +1384,22 @@ public class ClusterDistributionManager implements DistributionManager {
 
   /**
    * This stalls waiting for the current membership view (as seen by the membership manager) to be
-   * acknowledged by all membership listeners
+   * acknowledged by all membership listeners.
    */
+  @SuppressWarnings("lgtm[java/constant-comparison]")
   void waitForViewInstallation(long id) throws InterruptedException {
     if (id <= membershipViewIdAcknowledged) {
       return;
     }
     synchronized (membershipViewIdGuard) {
+      // The LGTM alert for this line is suppressed as it fails to take into account the value of
+      // membershipViewIdAcknowledged being modified by another thread
       while (membershipViewIdAcknowledged < id && !stopper.isCancelInProgress()) {
         if (logger.isDebugEnabled()) {
           logger.debug("waiting for view {}.  Current DM view processed by all listeners is {}", id,
               membershipViewIdAcknowledged);
         }
-        membershipViewIdGuard.wait();
+        membershipViewIdGuard.wait(100);
       }
     }
   }
@@ -1546,14 +1549,14 @@ public class ClusterDistributionManager implements DistributionManager {
 
   @Override
   public void retainMembersWithSameOrNewerVersion(Collection<InternalDistributedMember> members,
-      Version version) {
-    members.removeIf(id -> id.getVersionOrdinalObject().compareTo(version) < 0);
+      KnownVersion version) {
+    members.removeIf(id -> id.getVersion().compareTo(version) < 0);
   }
 
   @Override
   public void removeMembersWithSameOrNewerVersion(Collection<InternalDistributedMember> members,
-      Version version) {
-    members.removeIf(id -> id.getVersionOrdinalObject().compareTo(version) >= 0);
+      KnownVersion version) {
+    members.removeIf(id -> id.getVersion().compareTo(version) >= 0);
   }
 
   @Override
