@@ -34,8 +34,8 @@ import org.apache.geode.distributed.internal.membership.InternalDistributedMembe
 import org.apache.geode.internal.Assert;
 import org.apache.geode.internal.cache.versions.ConcurrentCacheModificationException;
 import org.apache.geode.internal.serialization.DSFIDNotFoundException;
-import org.apache.geode.internal.serialization.UnsupportedSerializationVersionException;
 import org.apache.geode.internal.serialization.Version;
+import org.apache.geode.internal.serialization.Versioning;
 import org.apache.geode.internal.util.Breadcrumbs;
 import org.apache.geode.internal.util.concurrent.StoppableCountDownLatch;
 import org.apache.geode.logging.internal.log4j.api.LogService;
@@ -472,18 +472,10 @@ public class ReplyProcessor21 implements MembershipListener {
    */
   protected synchronized void processException(DistributionMessage msg, DSFIDNotFoundException ex) {
     final short versionOrdinal = ex.getProductVersionOrdinal();
-    String versionStr = null;
-    try {
-      Version version = Version.fromOrdinal(versionOrdinal);
-      versionStr = version.toString();
-    } catch (UnsupportedSerializationVersionException e) {
-    }
-    if (versionStr == null) {
-      versionStr = "Ordinal=" + versionOrdinal;
-    }
+    final Version anyVersion = Versioning.getVersion(versionOrdinal);
     logger.fatal(String.format(
         "Exception received due to missing DSFID %s on remote node %s running version %s.",
-        new Object[] {ex.getUnknownDSFID(), msg.getSender(), versionStr}), ex);
+        new Object[] {ex.getUnknownDSFID(), msg.getSender(), anyVersion}), ex);
   }
 
   @Override
