@@ -56,11 +56,6 @@ public class VersionDescription {
    */
   public static final String SOURCE_REPOSITORY = "Source-Repository";
 
-  /**
-   * Constant for the build date Resource Property entry
-   */
-  public static final String BUILD_DATE = "Build-Date";
-
   /**
    * Constant for the build id Resource Property entry
    */
@@ -175,12 +170,6 @@ public class VersionDescription {
               SOURCE_REPOSITORY, RESOURCE_NAME));
     }
 
-    if (props.get(BUILD_DATE) == null) {
-      return Optional
-          .of(String.format("<Missing property %s from resource org/apache/geode/internal/%s>",
-              BUILD_DATE, RESOURCE_NAME));
-    }
-
     if (props.get(BUILD_ID) == null) {
       return Optional
           .of(String.format("<Missing property %s from resource org/apache/geode/internal/%s>",
