@@ -543,7 +543,7 @@ public class BucketAdvisor extends CacheDistributionAdvisor {
    * @see #adviseProfileUpdate()
    */
   @Override
-  public boolean putProfile(Profile profile, boolean forceProfile) {
+  public synchronized boolean putProfile(Profile profile, boolean forceProfile) {
     assert profile instanceof BucketProfile;
     BucketProfile bp = (BucketProfile) profile;
 
@@ -2305,7 +2305,7 @@ public class BucketAdvisor extends CacheDistributionAdvisor {
    */
   public static class ServerBucketProfile extends BucketProfile {
 
-    public Set<BucketServerLocation66> bucketServerLocations;
+    private Set<BucketServerLocation66> bucketServerLocations;
 
     private int bucketId;
 
