@@ -28,6 +28,7 @@ import java.util.concurrent.LinkedBlockingDeque;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.AtomicReference;
+import java.util.function.Predicate;
 
 import org.apache.logging.log4j.Logger;
 
@@ -250,11 +251,11 @@ public class BucketRegionQueue extends AbstractBucketRegionQueue {
   @Override
   public boolean virtualPut(EntryEventImpl event, boolean ifNew, boolean ifOld,
       Object expectedOldValue, boolean requireOldValue, long lastModified,
-      boolean overwriteDestroyed, boolean invokeCallbacks, boolean throwConcurrentModificaiton)
+      boolean overwriteDestroyed, boolean invokeCallbacks, boolean throwConcurrentModification)
       throws TimeoutException, CacheWriterException {
     try {
       boolean success = super.virtualPut(event, ifNew, ifOld, expectedOldValue, requireOldValue,
-          lastModified, overwriteDestroyed, invokeCallbacks, throwConcurrentModificaiton);
+          lastModified, overwriteDestroyed, invokeCallbacks, throwConcurrentModification);
 
       if (success) {
         if (getPartitionedRegion().getColocatedWith() == null) {
@@ -448,6 +449,36 @@ public class BucketRegionQueue extends AbstractBucketRegionQueue {
     }
   }
 
+  /**
+   * This method returns a list of objects that fulfill the matchingPredicate.
+   * If a matching object also fulfills the endPredicate then the method
+   * stops looking for more matching objects.
+   */
+  public List<Object> getElementsMatching(Predicate matchingPredicate, Predicate endPredicate) {
+    getInitializationLock().readLock().lock();
+    try {
+      if (this.getPartitionedRegion().isDestroyed()) {
+        throw new BucketRegionQueueUnavailableException();
+      }
+      List<Object> elementsMatching = new ArrayList<Object>();
+      Iterator<Object> it = this.eventSeqNumDeque.iterator();
+      while (it.hasNext()) {
+        Object key = it.next();
+        Object object = optimalGet(key);
+        if (matchingPredicate.test(object)) {
+          elementsMatching.add(object);
+          this.eventSeqNumDeque.remove(key);
+          if (endPredicate.test(object)) {
+            break;
+          }
+        }
+      }
+      return elementsMatching;
+    } finally {
+      getInitializationLock().readLock().unlock();
+    }
+  }
+
   @Override
   protected void addToEventQueue(Object key, boolean didPut, EntryEventImpl event) {
     if (didPut) {
