@@ -34,8 +34,8 @@ import org.apache.geode.internal.InternalDataSerializer;
 import org.apache.geode.internal.ObjToByteArraySerializer;
 import org.apache.geode.internal.VersionedDataSerializable;
 import org.apache.geode.internal.serialization.ByteArrayDataInput;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.internal.serialization.StaticSerialization;
-import org.apache.geode.internal.serialization.Version;
 
 /**
  * This class is used to hold the information about the servers and their Filters (CQs and Interest
@@ -49,7 +49,8 @@ public class FilterRoutingInfo implements VersionedDataSerializable {
       Boolean.getBoolean("optimized-cq-serialization");
 
   @Immutable
-  private static final Version[] serializationVersions = new Version[] {Version.GFE_71};
+  private static final KnownVersion[] serializationVersions =
+      new KnownVersion[] {KnownVersion.GFE_71};
 
   /** Set to true if any peer members has any filters. */
   private boolean memberWithFilterInfoExists = false;
@@ -248,7 +249,7 @@ public class FilterRoutingInfo implements VersionedDataSerializable {
   }
 
   @Override
-  public Version[] getSerializationVersions() {
+  public KnownVersion[] getSerializationVersions() {
     return serializationVersions;
   }
 
@@ -320,7 +321,7 @@ public class FilterRoutingInfo implements VersionedDataSerializable {
     private transient byte[] myData;
 
     /** version of creator of myData, needed for deserialization */
-    private transient Version myDataVersion;
+    private transient KnownVersion myDataVersion;
 
     /** Clients that are interested in the event and want values */
     private Set interestedClients;
@@ -361,10 +362,11 @@ public class FilterRoutingInfo implements VersionedDataSerializable {
     }
 
     @Immutable
-    private static final Version[] serializationVersions = new Version[] {Version.GFE_80};
+    private static final KnownVersion[] serializationVersions =
+        new KnownVersion[] {KnownVersion.GFE_80};
 
     @Override
-    public Version[] getSerializationVersions() {
+    public KnownVersion[] getSerializationVersions() {
       return serializationVersions;
     }
 
@@ -485,9 +487,7 @@ public class FilterRoutingInfo implements VersionedDataSerializable {
      * routing, so there is no need to deserialize the routings for other members
      */
     private void deserialize() {
-      try {
-        ByteArrayDataInput dis =
-            new ByteArrayDataInput(myData, myDataVersion);
+      try (ByteArrayDataInput dis = new ByteArrayDataInput(myData, myDataVersion)) {
         boolean hasCQs = dis.readBoolean();
         if (hasCQs) {
           int numEntries = InternalDataSerializer.readArrayLength(dis);
