@@ -1215,6 +1215,16 @@ public class InternalCacheForClientAccess implements InternalCache {
     return delegate.getInternalQueryService();
   }
 
+  @Override
+  public void lockDiskStore(String diskStoreName) {
+
+  }
+
+  @Override
+  public void unlockDiskStore(String diskStoreName) {
+
+  }
+
   @Override
   public JSONFormatter getJsonFormatter() {
     return delegate.getJsonFormatter();
