@@ -1881,10 +1881,16 @@ public class SearchLoadAndWriteProcessor implements MembershipListener {
       boolean authoritative = false;
       VersionTag versionTag = null;
 
+      InternalCache cache = dm.getExistingCache();
+
       final InitializationLevel oldLevel =
           LocalRegion.setThreadInitLevelRequirement(BEFORE_INITIAL_IMAGE);
+      LocalRegion region = (LocalRegion) cache.getRegion(this.regionName);
+      CachePerfStats stats =
+          region == null ? cache.getCachePerfStats() : region.getRegionPerfStats();
+      long startHandlingTime = stats.startHandlingNetsearch();
+      boolean handlingSuccess = false;
       try {
-        LocalRegion region = (LocalRegion) dm.getExistingCache().getRegion(this.regionName);
         if (region != null) {
           setClearCountReference(region);
           try {
@@ -1898,7 +1904,7 @@ public class SearchLoadAndWriteProcessor implements MembershipListener {
                   versionTag = versionStamp.asVersionTag();
                 }
                 Object eov = region.getNoLRU(this.key, false, true, true); // OFFHEAP: incrc, copy
-                                                                           // bytes, decrc
+                // bytes, decrc
                 if (eov != null) {
                   if (eov == Token.INVALID || eov == Token.LOCAL_INVALID) {
                     // nothing?
@@ -1931,6 +1937,7 @@ public class SearchLoadAndWriteProcessor implements MembershipListener {
                         ebvLen = ebv.length;
                       }
                     }
+                    handlingSuccess = true;
                   } else {
                     requestorTimedOut = true;
                   }
@@ -1968,6 +1975,7 @@ public class SearchLoadAndWriteProcessor implements MembershipListener {
         replyWithNull(dm);
       } finally {
         LocalRegion.setThreadInitLevelRequirement(oldLevel);
+        stats.endHandlingNetsearch(startHandlingTime, handlingSuccess);
       }
     }
 
