@@ -27,6 +27,7 @@ import java.util.IdentityHashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.ServiceConfigurationError;
 import java.util.Set;
 
 import org.apache.logging.log4j.Logger;
@@ -73,9 +74,9 @@ import org.apache.geode.internal.cache.versions.VersionSource;
 import org.apache.geode.internal.cache.versions.VersionTag;
 import org.apache.geode.internal.offheap.annotations.Released;
 import org.apache.geode.internal.serialization.DeserializationContext;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.internal.serialization.SerializationContext;
 import org.apache.geode.internal.serialization.StaticSerialization;
-import org.apache.geode.internal.serialization.Version;
 import org.apache.geode.logging.internal.executors.LoggingThread;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 
@@ -137,7 +138,7 @@ public class TXCommitMessage extends PooledDistributionMessage
    * Version of the client that this TXCommitMessage is being sent to. Used for backwards
    * compatibility
    */
-  private transient Version clientVersion;
+  private transient KnownVersion clientVersion;
 
   /**
    * A token to be put in TXManagerImpl#failoverMap to represent a CommitConflictException while
@@ -726,19 +727,32 @@ public class TXCommitMessage extends PooledDistributionMessage
     firePendingCallbacks(pendingCallbacks);
   }
 
-  private void firePendingCallbacks(List<EntryEventImpl> callbacks) {
-    Iterator<EntryEventImpl> ci = callbacks.iterator();
-    while (ci.hasNext()) {
-      EntryEventImpl ee = ci.next();
+  void firePendingCallbacks(List<EntryEventImpl> callbacks) {
+    boolean isConfigError = false;
+    EntryEventImpl lastTransactionEvent = null;
+    try {
+      lastTransactionEvent = getLastTransactionEvent(callbacks);
+    } catch (ServiceConfigurationError ex) {
+      logger.error(ex.getMessage());
+      isConfigError = true;
+    }
+
+    for (EntryEventImpl ee : callbacks) {
+      boolean isLastTransactionEvent = TXLastEventInTransactionUtils
+          .isLastTransactionEvent(isConfigError, lastTransactionEvent, ee);
       try {
         if (ee.getOperation().isDestroy()) {
-          ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_DESTROY, ee, true);
+          ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_DESTROY, ee, true,
+              isLastTransactionEvent);
         } else if (ee.getOperation().isInvalidate()) {
-          ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_INVALIDATE, ee, true);
+          ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_INVALIDATE, ee, true,
+              isLastTransactionEvent);
         } else if (ee.getOperation().isCreate()) {
-          ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_CREATE, ee, true);
+          ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_CREATE, ee, true,
+              isLastTransactionEvent);
         } else {
-          ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_UPDATE, ee, true);
+          ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_UPDATE, ee, true,
+              isLastTransactionEvent);
         }
       } finally {
         ee.release();
@@ -746,6 +760,11 @@ public class TXCommitMessage extends PooledDistributionMessage
     }
   }
 
+  EntryEventImpl getLastTransactionEvent(List<EntryEventImpl> callbacks) {
+    return TXLastEventInTransactionUtils.getLastTransactionEventInGroupedTxForWANSender(callbacks,
+        dm.getCache());
+  }
+
   protected void processCacheRuntimeException(CacheRuntimeException problem) {
     if (problem instanceof RegionDestroyedException) { // catch RegionDestroyedException
       addProcessingException(problem);
@@ -938,8 +957,8 @@ public class TXCommitMessage extends PooledDistributionMessage
     return hasFlagsField(StaticSerialization.getVersionForDataStream(in));
   }
 
-  private boolean hasFlagsField(final Version version) {
-    return version.compareTo(Version.GEODE_1_7_0) >= 0;
+  private boolean hasFlagsField(final KnownVersion version) {
+    return version.isNotOlderThan(KnownVersion.GEODE_1_7_0);
   }
 
   private boolean useShadowKey() {
@@ -1488,7 +1507,8 @@ public class TXCommitMessage extends PooledDistributionMessage
         out.writeBoolean(largeModCount);
 
         final boolean sendVersionTags =
-            this.msg.clientVersion == null || Version.GFE_70.compareTo(this.msg.clientVersion) <= 0;
+            this.msg.clientVersion == null
+                || KnownVersion.GFE_70.compareTo(this.msg.clientVersion) <= 0;
         if (sendVersionTags) {
           VersionSource member = this.memberId;
           if (member == null) {
@@ -1521,7 +1541,7 @@ public class TXCommitMessage extends PooledDistributionMessage
         this.preserializedBuffer.rewind();
         this.preserializedBuffer.sendTo(out);
       } else if (this.refCount > 1) {
-        Version v = StaticSerialization.getVersionForDataStream(out);
+        KnownVersion v = StaticSerialization.getVersionForDataStream(out);
         HeapDataOutputStream hdos = new HeapDataOutputStream(1024, v);
         basicToData(hdos, context, useShadowKey);
         this.preserializedBuffer = hdos;
@@ -2402,11 +2422,11 @@ public class TXCommitMessage extends PooledDistributionMessage
     disableListeners = true;
   }
 
-  public Version getClientVersion() {
+  public KnownVersion getClientVersion() {
     return clientVersion;
   }
 
-  public void setClientVersion(Version clientVersion) {
+  public void setClientVersion(KnownVersion clientVersion) {
     this.clientVersion = clientVersion;
   }
 
