@@ -23,6 +23,7 @@ import java.util.IdentityHashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.ServiceConfigurationError;
 import java.util.Set;
 import java.util.concurrent.Executor;
 import java.util.concurrent.locks.ReentrantLock;
@@ -145,7 +146,9 @@ public class TXState implements TXStateInterface {
   /** keeps track of events, so as not to re-apply events */
   protected Set<EventID> seenEvents = new HashSet<EventID>();
   /** keeps track of results of txPutEntry */
-  private Map<EventID, Boolean> seenResults = new HashMap<EventID, Boolean>();
+  private Map<EventID, Boolean> seenResults = new HashMap<>();
+  /** keeps track of TransactionDataRebalancedException during txPutEntry */
+  private Map<EventID, TransactionDataRebalancedException> eventExceptions = new HashMap<>();
 
   @Immutable
   static final TXEntryState ENTRY_EXISTS = new TXEntryState();
@@ -192,19 +195,34 @@ public class TXState implements TXStateInterface {
     }
   }
 
-  private void recordEventAndResult(EntryEventImpl event, boolean result) {
+  void recordEventAndResult(EntryEventImpl event, boolean result) {
     recordEvent(event);
     if (event.getEventId() != null) {
       this.seenResults.put(event.getEventId(), result);
     }
   }
 
-  private boolean getRecordedResult(EntryEventImpl event) {
+  boolean getRecordedResult(EntryEventImpl event) {
     assert event != null;
     assert this.seenResults.containsKey(event.getEventId());
     return this.seenResults.get(event.getEventId());
   }
 
+  void recordEventException(EntryEventImpl event,
+      TransactionDataRebalancedException exception) {
+    if (event.getEventId() != null) {
+      eventExceptions.put(event.getEventId(), exception);
+    }
+  }
+
+  boolean getRecordedResultOrException(EntryEventImpl event) {
+    boolean result = getRecordedResult(event);
+    if (!result && eventExceptions.containsKey(event.getEventId())) {
+      throw eventExceptions.get(event.getEventId());
+    }
+    return result;
+  }
+
   @Override
   public String toString() {
     StringBuilder builder = new StringBuilder();
@@ -224,15 +242,31 @@ public class TXState implements TXStateInterface {
   }
 
   public void firePendingCallbacks() {
+    boolean isConfigError = false;
+    EntryEventImpl lastTransactionEvent = null;
+    try {
+      lastTransactionEvent = TXLastEventInTransactionUtils
+          .getLastTransactionEventInGroupedTxForWANSender(getPendingCallbacks(), getCache());
+    } catch (ServiceConfigurationError ex) {
+      logger.error(ex.getMessage());
+      isConfigError = true;
+    }
+
     for (EntryEventImpl ee : getPendingCallbacks()) {
+      boolean isLastTransactionEvent = TXLastEventInTransactionUtils
+          .isLastTransactionEvent(isConfigError, lastTransactionEvent, ee);
       if (ee.getOperation().isDestroy()) {
-        ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_DESTROY, ee, true);
+        ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_DESTROY, ee, true,
+            isLastTransactionEvent);
       } else if (ee.getOperation().isInvalidate()) {
-        ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_INVALIDATE, ee, true);
+        ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_INVALIDATE, ee, true,
+            isLastTransactionEvent);
       } else if (ee.getOperation().isCreate()) {
-        ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_CREATE, ee, true);
+        ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_CREATE, ee, true,
+            isLastTransactionEvent);
       } else {
-        ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_UPDATE, ee, true);
+        ee.getRegion().invokeTXCallbacks(EnumListenerEvent.AFTER_UPDATE, ee, true,
+            isLastTransactionEvent);
       }
     }
   }
@@ -1381,14 +1415,14 @@ public class TXState implements TXStateInterface {
     }
 
     if (hasSeenEvent(event)) {
-      return getRecordedResult(event);
+      return getRecordedResultOrException(event);
     }
 
     // if requireOldValue then oldValue gets set in event
     // (even if ifNew and entry exists)
     // !!!:ezoerner:20080813 need to handle ifOld for transactional on
     // PRs when PRs become transactional
-    TXEntryState tx = null;
+    TXEntryState tx;
     boolean result = false;
     try {
       tx = txWriteEntry(region, event, ifNew, requireOldValue, expectedOldValue);
@@ -1399,6 +1433,10 @@ public class TXState implements TXStateInterface {
       }
     } catch (EntryNotFoundException e) {
       result = false;
+    } catch (TransactionDataRebalancedException e) {
+      result = false;
+      recordEventException(event, e);
+      throw e;
     } finally {
       recordEventAndResult(event, result);
     }
