@@ -477,7 +477,7 @@ public class TombstoneService {
     }
   }
 
-  private static class ReplicateTombstoneSweeper extends TombstoneSweeper {
+  protected static class ReplicateTombstoneSweeper extends TombstoneSweeper {
     /**
      * Used to execute batch gc message execution in the background.
      */
@@ -565,7 +565,8 @@ public class TombstoneService {
     }
 
     /** expire a batch of tombstones */
-    private void expireBatch() {
+
+    protected void expireBatch() {
       // fix for bug #46087 - OOME due to too many GC threads
       if (this.batchExpirationInProgress) {
         // incorrect return due to race between this and waiting-pool GC thread is okay
@@ -600,6 +601,9 @@ public class TombstoneService {
           synchronized (expiredTombstonesLock) {
             for (Tombstone t : expiredTombstones) {
               DistributedRegion tr = (DistributedRegion) t.region;
+              if (!tr.isInitialized()) {
+                continue;
+              }
               tr.getVersionVector().recordGCVersion(t.getMemberID(), t.getRegionVersion());
               if (!reapedKeys.containsKey(tr)) {
                 reapedKeys.put(tr, Collections.emptySet());
@@ -625,15 +629,17 @@ public class TombstoneService {
             // for PR buckets we have to keep track of the keys removed because clients have
             // them all lumped in a single non-PR region
             DistributedRegion tr = (DistributedRegion) t.region;
-            boolean tombstoneWasStillInRegionMap =
-                tr.getRegionMap().removeTombstone(t.entry, t, false, true);
-            if (tombstoneWasStillInRegionMap && hasToTrackKeysForClients(tr)) {
-              Set<Object> keys = reapedKeys.get(tr);
-              if (keys.isEmpty()) {
-                keys = new HashSet<Object>();
-                reapedKeys.put(tr, keys);
+            if (reapedKeys.containsKey(tr)) {
+              boolean tombstoneWasStillInRegionMap =
+                  tr.getRegionMap().removeTombstone(t.entry, t, false, true);
+              if (tombstoneWasStillInRegionMap && hasToTrackKeysForClients(tr)) {
+                Set<Object> keys = reapedKeys.get(tr);
+                if (keys.isEmpty()) {
+                  keys = new HashSet<Object>();
+                  reapedKeys.put(tr, keys);
+                }
+                keys.add(t.entry.getKey());
               }
-              keys.add(t.entry.getKey());
             }
             return true;
           });
