@@ -36,6 +36,7 @@ import org.apache.logging.log4j.Logger;
 
 import org.apache.geode.CancelCriterion;
 import org.apache.geode.InternalGemFireError;
+import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.annotations.internal.MutableForTesting;
 import org.apache.geode.cache.Cache;
 import org.apache.geode.cache.Region;
@@ -130,7 +131,7 @@ public class InternalResourceManager implements ResourceManager {
     // Create a new executor that other classes may use for handling resource
     // related tasks
     this.scheduledExecutor = LoggingExecutors
-        .newScheduledThreadPool("ResourceManagerRecoveryThread ", MAX_RESOURCE_MANAGER_EXE_THREADS);
+        .newScheduledThreadPool(MAX_RESOURCE_MANAGER_EXE_THREADS, "ResourceManagerRecoveryThread ");
 
     // Initialize the load probe
     try {
@@ -143,10 +144,10 @@ public class InternalResourceManager implements ResourceManager {
     // Create a new executor the resource manager and the monitors it creates
     // can use to handle dispatching of notifications.
     this.notifyExecutor =
-        CoreLoggingExecutors.newSerialThreadPoolWithFeedStatistics("Notification Handler",
+        CoreLoggingExecutors.newSerialThreadPoolWithFeedStatistics(0,
+            this.stats.getResourceEventQueueStatHelper(), "Notification Handler",
             thread -> thread.setPriority(Thread.MAX_PRIORITY), null,
-            this.stats.getResourceEventPoolStatHelper(), getThreadMonitorObj(),
-            0, this.stats.getResourceEventQueueStatHelper());
+            this.stats.getResourceEventPoolStatHelper(), getThreadMonitorObj());
 
     // Create the monitors
     Map<ResourceType, ResourceMonitor> tempMonitors = new HashMap<>();
@@ -638,7 +639,9 @@ public class InternalResourceManager implements ResourceManager {
    */
   public void addStartupTask(CompletableFuture<Void> startupTask) {
     Objects.requireNonNull(startupTask);
-    startupTasks.add(startupTask);
+    synchronized (startupTasks) {
+      startupTasks.add(startupTask);
+    }
   }
 
   /**
@@ -648,8 +651,15 @@ public class InternalResourceManager implements ResourceManager {
    * @return a CompletableFuture that completes when all of the startup tasks complete
    */
   public CompletableFuture<Void> allOfStartupTasks() {
-    CompletableFuture[] completableFutures = startupTasks.toArray(new CompletableFuture[0]);
-    startupTasks.clear();
-    return CompletableFuture.allOf(completableFutures);
+    synchronized (startupTasks) {
+      CompletableFuture[] completableFutures = startupTasks.toArray(new CompletableFuture[0]);
+      startupTasks.clear();
+      return CompletableFuture.allOf(completableFutures);
+    }
+  }
+
+  @VisibleForTesting
+  Collection<CompletableFuture<Void>> getStartupTasks() {
+    return startupTasks;
   }
 }
