@@ -14,6 +14,8 @@
  */
 package org.apache.geode.internal.cache.ha;
 
+import static org.apache.geode.util.internal.UncheckedUtils.uncheckedCast;
+
 import java.io.DataInput;
 import java.io.DataOutput;
 import java.io.IOException;
@@ -62,7 +64,7 @@ public class QueueRemovalMessage extends PooledDistributionMessage {
    * Set the message list
    */
   void setMessagesList(List messages) {
-    this.messagesList = messages;
+    this.messagesList = uncheckedCast(messages);
   }
 
   /**
@@ -96,6 +98,10 @@ public class QueueRemovalMessage extends PooledDistributionMessage {
       boolean succeed = processRegionQueue(iterator, regionName, size, hrq);
       if (!succeed) {
         return;
+      } else {
+        if (hrq != null) {
+          hrq.synchronizeQueueWithPrimary(getSender(), cache);
+        }
       }
     }
   }
