@@ -14,6 +14,8 @@
  */
 package org.apache.geode.internal.cache.tier.sockets;
 
+import static java.util.concurrent.TimeUnit.MILLISECONDS;
+import static java.util.concurrent.TimeUnit.SECONDS;
 import static org.apache.geode.distributed.ConfigurationProperties.SECURITY_CLIENT_ACCESSOR_PP;
 import static org.apache.geode.internal.cache.tier.CommunicationMode.ClientToServerForQueue;
 import static org.apache.geode.internal.cache.tier.sockets.Handshake.REPLY_REFUSED;
@@ -52,7 +54,6 @@ import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.RejectedExecutionException;
-import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.function.Supplier;
 
@@ -92,9 +93,10 @@ import org.apache.geode.internal.cache.wan.GatewayReceiverStats;
 import org.apache.geode.internal.inet.LocalHostUtil;
 import org.apache.geode.internal.logging.CoreLoggingExecutors;
 import org.apache.geode.internal.monitoring.ThreadsMonitoring;
+import org.apache.geode.internal.net.SocketCloser;
 import org.apache.geode.internal.net.SocketCreator;
 import org.apache.geode.internal.security.SecurityService;
-import org.apache.geode.internal.serialization.Version;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.internal.statistics.StatisticsClock;
 import org.apache.geode.internal.statistics.StatisticsClockFactory;
 import org.apache.geode.internal.tcp.ConnectionTable;
@@ -121,6 +123,7 @@ public class AcceptorImpl implements Acceptor, Runnable {
   private final CacheServerStats stats;
   private final int maxConnections;
   private final int maxThreads;
+  private final int maximumTimeBetweenPings;
 
   private final ExecutorService pool;
   /**
@@ -347,6 +350,8 @@ public class AcceptorImpl implements Acceptor, Runnable {
 
   private final ServerConnectionFactory serverConnectionFactory;
 
+  private final SocketCloser socketCloser = new SocketCloser();
+
   /**
    * Constructs an AcceptorImpl for use within a CacheServer.
    *
@@ -635,6 +640,7 @@ public class AcceptorImpl implements Acceptor, Runnable {
     this.socketBufferSize = socketBufferSize;
 
     // Create the singleton ClientHealthMonitor
+    this.maximumTimeBetweenPings = maximumTimeBetweenPings;
     healthMonitor = clientHealthMonitorProvider.get(internalCache, maximumTimeBetweenPings,
         clientNotifier.getStats());
 
@@ -656,8 +662,9 @@ public class AcceptorImpl implements Acceptor, Runnable {
         "Handshaker " + serverSock.getInetAddress() + ":" + localPort + " Thread ";
     try {
       logger.warn("Handshaker max Pool size: " + HANDSHAKE_POOL_SIZE);
-      return CoreLoggingExecutors.newThreadPoolWithSynchronousFeedThatHandlesRejection(threadName,
-          thread -> getStats().incAcceptThreadsCreated(), null, 1, HANDSHAKE_POOL_SIZE, 60);
+      return CoreLoggingExecutors.newThreadPoolWithSynchronousFeedThatHandlesRejection(1,
+          HANDSHAKE_POOL_SIZE, 60, SECONDS, threadName,
+          thread -> getStats().incAcceptThreadsCreated(), null);
     } catch (IllegalArgumentException poolInitException) {
       stats.close();
       serverSock.close();
@@ -668,6 +675,7 @@ public class AcceptorImpl implements Acceptor, Runnable {
 
   private ExecutorService initializeClientQueueInitializerThreadPool() {
     return CoreLoggingExecutors.newThreadPoolWithSynchronousFeed(
+        CLIENT_QUEUE_INITIALIZATION_POOL_SIZE, 60000, MILLISECONDS,
         "Client Queue Initialization Thread ",
         command -> {
           try {
@@ -675,8 +683,8 @@ public class AcceptorImpl implements Acceptor, Runnable {
           } catch (CancelException e) {
             logger.debug("Client Queue Initialization was canceled.", e);
           }
-        }, CLIENT_QUEUE_INITIALIZATION_POOL_SIZE, getStats().getCnxPoolHelper(), 60000,
-        getThreadMonitorObj());
+        },
+        getStats().getCnxPoolHelper(), getThreadMonitorObj());
   }
 
   private ExecutorService initializeServerConnectionThreadPool() throws IOException {
@@ -693,13 +701,12 @@ public class AcceptorImpl implements Acceptor, Runnable {
     try {
       String threadName = "ServerConnection on port " + localPort + " Thread ";
       if (isSelector()) {
-        return CoreLoggingExecutors.newThreadPoolWithUnlimitedFeed(threadName, threadInitializer,
-            commandWrapper, maxThreads,
-            getStats().getCnxPoolHelper(), Integer.MAX_VALUE, getThreadMonitorObj());
+        return CoreLoggingExecutors.newThreadPoolWithUnlimitedFeed(maxThreads, Integer.MAX_VALUE,
+            MILLISECONDS, threadName, threadInitializer, commandWrapper,
+            getStats().getCnxPoolHelper(), getThreadMonitorObj());
       }
-      return CoreLoggingExecutors.newThreadPoolWithSynchronousFeed(threadName, threadInitializer,
-          commandWrapper,
-          MINIMUM_MAX_CONNECTIONS, maxConnections, 0L);
+      return CoreLoggingExecutors.newThreadPoolWithSynchronousFeed(MINIMUM_MAX_CONNECTIONS,
+          maxConnections, 0L, SECONDS, threadName, threadInitializer, commandWrapper);
     } catch (IllegalArgumentException poolInitException) {
       stats.close();
       serverSock.close();
@@ -1510,35 +1517,36 @@ public class AcceptorImpl implements Acceptor, Runnable {
 
   @Override
   public void refuseHandshake(OutputStream out, String message, byte exception) throws IOException {
-    HeapDataOutputStream hdos = new HeapDataOutputStream(32, Version.CURRENT);
-    DataOutputStream dos = new DataOutputStream(hdos);
-    // Write refused reply
-    dos.writeByte(exception);
+    try (HeapDataOutputStream hdos = new HeapDataOutputStream(32, KnownVersion.CURRENT)) {
+      DataOutputStream dos = new DataOutputStream(hdos);
+      // Write refused reply
+      dos.writeByte(exception);
 
-    // write dummy endpointType
-    dos.writeByte(0);
-    // write dummy queueSize
-    dos.writeInt(0);
+      // write dummy endpointType
+      dos.writeByte(0);
+      // write dummy queueSize
+      dos.writeInt(0);
 
-    // Write the server's member
-    DistributedMember member = InternalDistributedSystem.getAnyInstance().getDistributedMember();
-    HeapDataOutputStream memberDos = new HeapDataOutputStream(Version.CURRENT);
-    DataSerializer.writeObject(member, memberDos);
-    DataSerializer.writeByteArray(memberDos.toByteArray(), dos);
-    memberDos.close();
+      // Write the server's member
+      DistributedMember member = InternalDistributedSystem.getAnyInstance().getDistributedMember();
+      HeapDataOutputStream memberDos = new HeapDataOutputStream(KnownVersion.CURRENT);
+      DataSerializer.writeObject(member, memberDos);
+      DataSerializer.writeByteArray(memberDos.toByteArray(), dos);
+      memberDos.close();
 
-    // Write the refusal message
-    if (message == null) {
-      message = "";
+      // Write the refusal message
+      if (message == null) {
+        message = "";
+      }
+      dos.writeUTF(message);
+
+      // Write dummy delta-propagation property value. This will never be read at
+      // receiver because the exception byte above will cause the receiver code
+      // throw an exception before the below byte could be read.
+      dos.writeBoolean(Boolean.TRUE);
+
+      out.write(hdos.toByteArray());
     }
-    dos.writeUTF(message);
-
-    // Write dummy delta-propagation property value. This will never be read at
-    // receiver because the exception byte above will cause the receiver code
-    // throw an exception before the below byte could be read.
-    dos.writeBoolean(Boolean.TRUE);
-
-    out.write(hdos.toByteArray());
     out.flush();
   }
 
@@ -1683,7 +1691,7 @@ public class AcceptorImpl implements Acceptor, Runnable {
   private void shutdownPools() {
     pool.shutdown();
     try {
-      if (!pool.awaitTermination(PoolImpl.SHUTDOWN_TIMEOUT, TimeUnit.MILLISECONDS)) {
+      if (!pool.awaitTermination(PoolImpl.SHUTDOWN_TIMEOUT, MILLISECONDS)) {
         logger.warn("Timeout waiting for background tasks to complete.");
         pool.shutdownNow();
       }
@@ -1702,6 +1710,7 @@ public class AcceptorImpl implements Acceptor, Runnable {
       for (ServerConnection serverConnection : snap) {
         serverConnection.cleanup();
       }
+      socketCloser.close();
     }
   }
 
@@ -1862,6 +1871,16 @@ public class AcceptorImpl implements Acceptor, Runnable {
     releaseCommBuffer(Message.setTLCommBuffer(null));
   }
 
+  @Override
+  public int getMaximumTimeBetweenPings() {
+    return maximumTimeBetweenPings;
+  }
+
+  @Override
+  public SocketCloser getSocketCloser() {
+    return socketCloser;
+  }
+
   private static class ClientQueueInitializerTask implements Runnable {
     private final Socket socket;
     private final boolean isPrimaryServerToClient;
