@@ -79,7 +79,7 @@ import org.apache.geode.internal.logging.LogWriterImpl;
 import org.apache.geode.internal.logging.log4j.LogMarker;
 import org.apache.geode.internal.security.AuthorizeRequestPP;
 import org.apache.geode.internal.security.SecurityService;
-import org.apache.geode.internal.serialization.Version;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.internal.statistics.StatisticsClock;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.security.AccessControl;
@@ -242,7 +242,7 @@ public class CacheClientProxy implements ClientSession {
   /**
    * The version of the client
    */
-  private Version clientVersion;
+  private KnownVersion clientVersion;
 
   /**
    * A map of region name as key and integer as its value. Basically, it stores the names of the
@@ -313,7 +313,7 @@ public class CacheClientProxy implements ClientSession {
    */
   protected CacheClientProxy(CacheClientNotifier ccn, Socket socket,
       ClientProxyMembershipID proxyID, boolean isPrimary, byte clientConflation,
-      Version clientVersion, long acceptorId, boolean notifyBySubscription,
+      KnownVersion clientVersion, long acceptorId, boolean notifyBySubscription,
       SecurityService securityService, Subject subject, StatisticsClock statisticsClock)
       throws CacheException {
     this(ccn.getCache(), ccn, socket, proxyID, isPrimary, clientConflation, clientVersion,
@@ -326,7 +326,7 @@ public class CacheClientProxy implements ClientSession {
   @VisibleForTesting
   protected CacheClientProxy(InternalCache cache, CacheClientNotifier ccn, Socket socket,
       ClientProxyMembershipID proxyID, boolean isPrimary, byte clientConflation,
-      Version clientVersion, long acceptorId, boolean notifyBySubscription,
+      KnownVersion clientVersion, long acceptorId, boolean notifyBySubscription,
       SecurityService securityService, Subject subject, StatisticsClock statisticsClock,
       StatisticsFactory statisticsFactory,
       CacheClientProxyStatsFactory cacheClientProxyStatsFactory,
@@ -358,7 +358,7 @@ public class CacheClientProxy implements ClientSession {
     initializeClientAuths();
   }
 
-  Version getClientVersion() {
+  KnownVersion getClientVersion() {
     return clientVersion;
   }
 
@@ -408,7 +408,7 @@ public class CacheClientProxy implements ClientSession {
   }
 
   private void initializeTransientFields(Socket socket, ClientProxyMembershipID pid, boolean ip,
-      byte cc, Version vers) {
+      byte cc, KnownVersion vers) {
     this._socket = socket;
     this.proxyID = pid;
     this.connected = true;
@@ -957,7 +957,9 @@ public class CacheClientProxy implements ClientSession {
     String remoteHostAddress = this._remoteHostAddress;
     if (this._socketClosed.compareAndSet(false, true) && remoteHostAddress != null) {
       // Only one thread is expected to close the socket
-      this._cacheClientNotifier.getSocketCloser().asyncClose(this._socket, remoteHostAddress, null);
+      this._cacheClientNotifier.getSocketCloser().asyncClose(this._socket, remoteHostAddress,
+          () -> {
+          });
       getCacheClientNotifier().getAcceptorStats().decCurrentQueueConnections();
       return true;
     }
@@ -1174,7 +1176,7 @@ public class CacheClientProxy implements ClientSession {
     // If the client is not 7.0.1 or greater and the key of interest is a list,
     // then create an individual message for each entry in the list since the
     // client doesn't support a ClientInterestMessageImpl containing a list.
-    if (Version.GFE_701.compareTo(this.clientVersion) > 0
+    if (KnownVersion.GFE_701.compareTo(this.clientVersion) > 0
         && message.getKeyOfInterest() instanceof List) {
       for (Iterator i = ((List) message.getKeyOfInterest()).iterator(); i.hasNext();) {
         this._messageDispatcher.enqueueMessage(
@@ -1830,7 +1832,7 @@ public class CacheClientProxy implements ClientSession {
    * @param ip whether this proxy represents the primary
    */
   protected void reinitialize(Socket socket, ClientProxyMembershipID proxyId, Cache cache,
-      boolean ip, byte cc, Version ver) {
+      boolean ip, byte cc, KnownVersion ver) {
     // Re-initialize transient fields
     initializeTransientFields(socket, proxyId, ip, cc, ver);
     getCacheClientNotifier().getAcceptorStats().incCurrentQueueConnections();
@@ -1878,7 +1880,7 @@ public class CacheClientProxy implements ClientSession {
     return this._messageDispatcher._messageQueue.getRegion();
   }
 
-  public Version getVersion() {
+  public KnownVersion getVersion() {
     return this.clientVersion;
   }
 
