@@ -17,6 +17,7 @@ package org.apache.geode.internal.cache.tier.sockets;
 import static org.apache.geode.distributed.ConfigurationProperties.SECURITY_CLIENT_ACCESSOR;
 import static org.apache.geode.distributed.ConfigurationProperties.SECURITY_CLIENT_ACCESSOR_PP;
 import static org.apache.geode.distributed.ConfigurationProperties.SECURITY_CLIENT_AUTHENTICATOR;
+import static org.apache.geode.internal.monitoring.ThreadsMonitoring.Mode.ServerConnectionExecutor;
 
 import java.io.EOFException;
 import java.io.IOException;
@@ -65,11 +66,13 @@ import org.apache.geode.internal.cache.tier.MessageType;
 import org.apache.geode.internal.cache.tier.ServerSideHandshake;
 import org.apache.geode.internal.cache.tier.sockets.command.Default;
 import org.apache.geode.internal.logging.InternalLogWriter;
+import org.apache.geode.internal.monitoring.ThreadsMonitoring;
+import org.apache.geode.internal.monitoring.executor.AbstractExecutor;
 import org.apache.geode.internal.security.AuthorizeRequest;
 import org.apache.geode.internal.security.AuthorizeRequestPP;
 import org.apache.geode.internal.security.SecurityService;
 import org.apache.geode.internal.serialization.ByteArrayDataInput;
-import org.apache.geode.internal.serialization.Version;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.internal.util.Breadcrumbs;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.security.AuthenticationFailedException;
@@ -105,7 +108,7 @@ public abstract class ServerConnection implements Runnable {
   public static boolean allowInternalMessagesWithoutCredentials =
       !Boolean.getBoolean(DISALLOW_INTERNAL_MESSAGES_WITHOUT_CREDENTIALS_NAME);
 
-  private Map commands;
+  private Map<Integer, Command> commands;
 
   protected final SecurityService securityService;
 
@@ -122,6 +125,16 @@ public abstract class ServerConnection implements Runnable {
 
   private final ProcessingMessageTimer processingMessageTimer = new ProcessingMessageTimer();
 
+  private final ThreadsMonitoring threadMonitoring;
+  /**
+   * The threadMonitorExecutor for this server connection.
+   * This will be null if acceptor is a selector.
+   * When a selector is used, the thread pool that is used to process client requests
+   * will automatically register with the thread monitor the thread that is processing
+   * the request. So no need to create a threadMonitorExecutor.
+   */
+  private AbstractExecutor threadMonitorExecutor;
+
   public static ByteBuffer allocateCommBuffer(int size, Socket sock) {
     // I expect that size will almost always be the same value
     if (sock.getChannel() == null) {
@@ -170,20 +183,20 @@ public abstract class ServerConnection implements Runnable {
 
   // IMPORTANT: if new messages are added change setHandshake to initialize them
   // to the correct Version for serializing to the client
-  private Message requestMessage = new Message(2, Version.CURRENT);
-  private final Message replyMessage = new Message(1, Version.CURRENT);
-  private final Message responseMessage = new Message(1, Version.CURRENT);
-  private final Message errorMessage = new Message(1, Version.CURRENT);
+  private Message requestMessage = new Message(2, KnownVersion.CURRENT);
+  private final Message replyMessage = new Message(1, KnownVersion.CURRENT);
+  private final Message responseMessage = new Message(1, KnownVersion.CURRENT);
+  private final Message errorMessage = new Message(1, KnownVersion.CURRENT);
 
   // IMPORTANT: if new messages are added change setHandshake to initialize them
   // to the correct Version for serializing to the client
-  private final ChunkedMessage queryResponseMessage = new ChunkedMessage(2, Version.CURRENT);
-  private final ChunkedMessage chunkedResponseMessage = new ChunkedMessage(1, Version.CURRENT);
+  private final ChunkedMessage queryResponseMessage = new ChunkedMessage(2, KnownVersion.CURRENT);
+  private final ChunkedMessage chunkedResponseMessage = new ChunkedMessage(1, KnownVersion.CURRENT);
   private final ChunkedMessage executeFunctionResponseMessage =
-      new ChunkedMessage(1, Version.CURRENT);
+      new ChunkedMessage(1, KnownVersion.CURRENT);
   private final ChunkedMessage registerInterestResponseMessage =
-      new ChunkedMessage(1, Version.CURRENT);
-  private final ChunkedMessage keySetResponseMessage = new ChunkedMessage(1, Version.CURRENT);
+      new ChunkedMessage(1, KnownVersion.CURRENT);
+  private final ChunkedMessage keySetResponseMessage = new ChunkedMessage(1, KnownVersion.CURRENT);
 
   @Deprecated
   private final InternalLogWriter logWriter;
@@ -304,6 +317,7 @@ public abstract class ServerConnection implements Runnable {
         logger.debug("While creating server connection", e);
       }
     }
+    threadMonitoring = getCache().getInternalDistributedSystem().getDM().getThreadMonitoring();
   }
 
   public Acceptor getAcceptor() {
@@ -362,8 +376,7 @@ public abstract class ServerConnection implements Runnable {
 
         setHandshake(readHandshake);
         setProxyId(readHandshake.getMembershipId());
-        if (readHandshake.getVersion().compareTo(Version.GFE_65) < 0
-            || getCommunicationMode().isWAN()) {
+        if (getCommunicationMode().isWAN()) {
           try {
             setAuthAttributes();
 
@@ -443,7 +456,7 @@ public abstract class ServerConnection implements Runnable {
     }
   }
 
-  protected Map getCommands() {
+  protected Map<Integer, Command> getCommands() {
     return commands;
   }
 
@@ -469,7 +482,7 @@ public abstract class ServerConnection implements Runnable {
 
   public void setHandshake(ServerSideHandshake handshake) {
     this.handshake = handshake;
-    Version v = handshake.getVersion();
+    KnownVersion v = handshake.getVersion();
 
     replyMessage.setVersion(v);
     requestMessage.setVersion(v);
@@ -487,7 +500,7 @@ public abstract class ServerConnection implements Runnable {
     this.requestMessage = requestMessage;
   }
 
-  public Version getClientVersion() {
+  public KnownVersion getClientVersion() {
     return handshake.getVersion();
   }
 
@@ -634,7 +647,7 @@ public abstract class ServerConnection implements Runnable {
         chmRegistered = true;
       }
       if (registerClient) {
-        chm.registerClient(proxyId);
+        chm.registerClient(proxyId, acceptor.getMaximumTimeBetweenPings());
       }
       serverConnectionCollection = chm.addConnection(proxyId, this);
       acceptor.getConnectionListener().connectionOpened(registerClient, communicationMode);
@@ -779,6 +792,7 @@ public abstract class ServerConnection implements Runnable {
     }
 
     ThreadState threadState = null;
+    resumeThreadMonitoring();
     try {
       if (message != null) {
         // Since this thread is not interrupted when the cache server is shutdown, test again after
@@ -840,7 +854,7 @@ public abstract class ServerConnection implements Runnable {
           } else {
             logger.warn(
                 "Failed to bind the subject of uniqueId {} for message {} with {} : Possible re-authentication required",
-                uniqueId, messageType, this.getName());
+                uniqueId, messageType, getName());
             throw new AuthenticationRequiredException("Failed to find the authenticated user.");
           }
         }
@@ -848,6 +862,7 @@ public abstract class ServerConnection implements Runnable {
         command.execute(message, this, securityService);
       }
     } finally {
+      suspendThreadMonitoring();
       // Keep track of the fact that a message is no longer being
       // processed.
       serverConnectionCollection.connectionsProcessing.decrementAndGet();
@@ -859,6 +874,18 @@ public abstract class ServerConnection implements Runnable {
     }
   }
 
+  private void suspendThreadMonitoring() {
+    if (threadMonitorExecutor != null) {
+      threadMonitorExecutor.suspendMonitoring();
+    }
+  }
+
+  private void resumeThreadMonitoring() {
+    if (threadMonitorExecutor != null) {
+      threadMonitorExecutor.resumeMonitoring();
+    }
+  }
+
   private final Object terminationLock = new Object();
   private boolean terminated;
 
@@ -986,13 +1013,19 @@ public abstract class ServerConnection implements Runnable {
   }
 
   void initializeCommands() {
-    // The commands are cached here, but are just referencing the ones
-    // stored in the CommandInitializer
-    commands = CommandInitializer.getCommands(this);
+    // The commands are cached here, but are just referencing the ones stored in the
+    // CommandInitializer
+    KnownVersion clientVersion = getClientVersion();
+    // WAN uses KnownVersion.CURRENT, but that might not have a command table, so we look
+    // for one that does
+    if (!clientVersion.hasClientServerProtocolChange()) {
+      clientVersion = clientVersion.getClientServerProtocolVersion();
+    }
+    commands = CommandInitializer.getDefaultInstance().get(clientVersion);
   }
 
   private Command getCommand(Integer messageType) {
-    return (Command) commands.get(messageType);
+    return commands.get(messageType);
   }
 
   public void removeUserAuth(Message message, boolean keepAlive) {
@@ -1070,8 +1103,10 @@ public abstract class ServerConnection implements Runnable {
 
       credBytes = handshake.getEncryptor().decryptBytes(credBytes);
 
-      ByteArrayDataInput dinp = new ByteArrayDataInput(credBytes);
-      Properties credentials = DataSerializer.readProperties(dinp);
+      Properties credentials;
+      try (ByteArrayDataInput dinp = new ByteArrayDataInput(credBytes)) {
+        credentials = DataSerializer.readProperties(dinp);
+      }
 
       // When here, security is enforced on server, if login returns a subject, then it's the newly
       // integrated security, otherwise, do it the old way.
@@ -1125,7 +1160,6 @@ public abstract class ServerConnection implements Runnable {
   public Part updateAndGetSecurityPart() {
     // need to take care all message types here
     if (AcceptorImpl.isAuthenticationRequired()
-        && handshake.getVersion().compareTo(Version.GFE_65) >= 0
         && !communicationMode.isWAN() && !requestMessage.getAndResetIsMetaRegion()
         && !isInternalMessage(requestMessage, allowInternalMessagesWithoutCredentials)) {
       setSecurityPart();
@@ -1206,6 +1240,9 @@ public abstract class ServerConnection implements Runnable {
         }
       }
     } else {
+      threadMonitorExecutor = threadMonitoring.createAbstractExecutor(ServerConnectionExecutor);
+      suspendThreadMonitoring();
+      threadMonitoring.register(threadMonitorExecutor);
       try {
         while (processMessages && !crHelper.isShutdown()) {
           try {
@@ -1218,6 +1255,7 @@ public abstract class ServerConnection implements Runnable {
           }
         }
       } finally {
+        threadMonitoring.unregister(threadMonitorExecutor);
         try {
           unsetRequestSpecificTimeout();
           handleTermination();
@@ -1412,11 +1450,22 @@ public abstract class ServerConnection implements Runnable {
       getAcceptor().decClientServerConnectionCount();
     }
 
-    try {
-      theSocket.close();
-    } catch (Exception ignored) {
+    if (!theSocket.isClosed()) {
+      // Here we direct closing of sockets to one of two executors. Use of an executor
+      // keeps us from causing an explosion of new threads when a server is shut down.
+      // Background threads are used in case the close() operation on the socket hangs.
+      final String closerName =
+          communicationMode.isWAN() ? "WANSocketCloser" : "CacheServerSocketCloser";
+      acceptor.getSocketCloser().asyncClose(theSocket, closerName, () -> {
+      },
+          () -> cleanupAfterSocketClose());
+      return true;
     }
+    cleanupAfterSocketClose();
+    return true;
+  }
 
+  protected void cleanupAfterSocketClose() {
     try {
       if (postAuthzRequest != null) {
         postAuthzRequest.close();
@@ -1437,7 +1486,6 @@ public abstract class ServerConnection implements Runnable {
     }
     releaseCommBuffer();
     processMessages = false;
-    return true;
   }
 
   private void releaseCommBuffer() {
@@ -1652,7 +1700,8 @@ public abstract class ServerConnection implements Runnable {
 
   private byte[] encryptId(long id) throws Exception {
     // deserialize this using handshake keys
-    try (HeapDataOutputStream heapDataOutputStream = new HeapDataOutputStream(Version.CURRENT)) {
+    try (HeapDataOutputStream heapDataOutputStream =
+        new HeapDataOutputStream(KnownVersion.CURRENT)) {
 
       heapDataOutputStream.writeLong(id);
 
@@ -1663,7 +1712,7 @@ public abstract class ServerConnection implements Runnable {
   public long getUniqueId() {
     long uniqueId;
 
-    if (handshake.getVersion().isPre65() || communicationMode.isWAN()) {
+    if (communicationMode.isWAN()) {
       uniqueId = userAuthId;
     } else if (requestMessage.isSecureMode()) {
       uniqueId = messageIdExtractor.getUniqueIdFromMessage(requestMessage,
@@ -1696,7 +1745,7 @@ public abstract class ServerConnection implements Runnable {
       if (isTerminated()) {
         throw new IOException("Server connection is terminated.");
       }
-      logger.debug("Unexpected exception {}", npe);
+      logger.debug("Unexpected exception {}", npe.toString());
     }
     if (uaa == null) {
       throw new AuthenticationRequiredException("User authorization attributes not found.");
