@@ -22,6 +22,7 @@ import java.util.Collection;
 import java.util.List;
 
 import org.apache.logging.log4j.Logger;
+import org.jetbrains.annotations.NotNull;
 
 import org.apache.geode.CancelException;
 import org.apache.geode.DataSerializer;
@@ -203,12 +204,7 @@ public abstract class RemoteOperationMessage extends DistributionMessage
     long startTime = 0;
     try {
       if (checkCacheClosing(cache) || checkDSClosing(dm)) {
-        String message = getCacheClosedMessage(dm);
-        if (cache == null) {
-          thr = new CacheClosedException(message);
-        } else {
-          thr = cache.getCacheClosedException(message);
-        }
+        thr = cache.getCacheClosedException(getCacheClosedMessage(dm));
         return;
       }
       r = getRegionByPath(cache);
@@ -300,6 +296,7 @@ public abstract class RemoteOperationMessage extends DistributionMessage
     }
   }
 
+  @NotNull
   private String getCacheClosedMessage(ClusterDistributionManager dm) {
     return "Remote cache is closed: " + dm.getId();
   }
