@@ -124,6 +124,8 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
 
   protected boolean isParallel;
 
+  protected boolean groupTransactionEvents;
+
   protected boolean isForInternalUse;
 
   protected boolean isDiskSynchronous;
@@ -169,6 +171,8 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
 
   private ServerLocation serverLocation;
 
+  private String expectedReceiverUniqueId = "";
+
   protected Object queuedEventsSync = new Object();
 
   protected volatile boolean enqueuedAllTempQueueEvents = false;
@@ -235,6 +239,8 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
 
   private final StatisticsClock statisticsClock;
 
+  protected boolean enforceThreadsConnectSameReceiver;
+
   protected AbstractGatewaySender() {
     statisticsClock = disabledClock();
   }
@@ -254,6 +260,7 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
     this.alertThreshold = attrs.getAlertThreshold();
     this.manualStart = attrs.isManualStart();
     this.isParallel = attrs.isParallel();
+    this.groupTransactionEvents = attrs.mustGroupTransactionEvents();
     this.isForInternalUse = attrs.isForInternalUse();
     this.diskStoreName = attrs.getDiskStoreName();
     this.remoteDSId = attrs.getRemoteDSId();
@@ -272,6 +279,7 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
     this.maxMemoryPerDispatcherQueue = this.queueMemory / this.dispatcherThreads;
     this.serialNumber = DistributionAdvisor.createSerialNumber();
     this.isMetaQueue = attrs.isMetaQueue();
+    this.enforceThreadsConnectSameReceiver = attrs.getEnforceThreadsConnectSameReceiver();
     if (!(this.cache instanceof CacheCreation)) {
       this.myDSId = this.cache.getInternalDistributedSystem().getDistributionManager()
           .getDistributedSystemId();
@@ -496,6 +504,11 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
     return this.eventIdIndex;
   }
 
+  @Override
+  public boolean getEnforceThreadsConnectSameReceiver() {
+    return this.enforceThreadsConnectSameReceiver;
+  }
+
   @Override
   public boolean equals(Object obj) {
     if (obj == null) {
@@ -545,6 +558,11 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
     return this.isParallel;
   }
 
+  @Override
+  public boolean mustGroupTransactionEvents() {
+    return this.groupTransactionEvents;
+  }
+
   public boolean isForInternalUse() {
     return this.isForInternalUse;
   }
@@ -552,6 +570,9 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
   @Override
   public abstract void start();
 
+  @Override
+  public abstract void startWithCleanQueue();
+
   @Override
   public abstract void stop();
 
@@ -927,6 +948,11 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
 
   public void distribute(EnumListenerEvent operation, EntryEventImpl event,
       List<Integer> allRemoteDSIds) {
+    distribute(operation, event, allRemoteDSIds, false);
+  }
+
+  public void distribute(EnumListenerEvent operation, EntryEventImpl event,
+      List<Integer> allRemoteDSIds, boolean isLastEventInTransaction) {
 
     final boolean isDebugEnabled = logger.isDebugEnabled();
 
@@ -1018,10 +1044,7 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
       // If this gateway is not running, return
       if (!isRunning()) {
         if (this.isPrimary()) {
-          tmpDroppedEvents.add(clonedEvent);
-          if (isDebugEnabled) {
-            logger.debug("add to tmpDroppedEvents for evnet {}", clonedEvent);
-          }
+          recordDroppedEvent(clonedEvent);
         }
         if (isDebugEnabled) {
           logger.debug("Returning back without putting into the gateway sender queue:" + event);
@@ -1055,8 +1078,8 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
           if (isDebugEnabled) {
             logger.debug("Returning back without putting into the gateway sender queue:" + event);
           }
-          if (this.eventProcessor != null) {
-            this.eventProcessor.registerEventDroppedInPrimaryQueue(event);
+          if (this.isPrimary()) {
+            recordDroppedEvent(clonedEvent);
           }
           return;
         }
@@ -1077,7 +1100,7 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
           // Get substitution value to enqueue if necessary
           Object substituteValue = getSubstituteValue(clonedEvent, operation);
 
-          ev.enqueueEvent(operation, clonedEvent, substituteValue);
+          ev.enqueueEvent(operation, clonedEvent, substituteValue, isLastEventInTransaction);
         } catch (CancelException e) {
           logger.debug("caught cancel exception", e);
           throw e;
@@ -1102,6 +1125,17 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
     }
   }
 
+  private void recordDroppedEvent(EntryEventImpl event) {
+    if (this.eventProcessor != null) {
+      this.eventProcessor.registerEventDroppedInPrimaryQueue(event);
+    } else {
+      tmpDroppedEvents.add(event);
+      if (logger.isDebugEnabled()) {
+        logger.debug("added to tmpDroppedEvents event: {}", event);
+      }
+    }
+  }
+
   @VisibleForTesting
   int getTmpDroppedEventSize() {
     return tmpDroppedEvents.size();
@@ -1122,7 +1156,7 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
   public void enqueueTempEvents() {
     if (this.eventProcessor != null) {// Fix for defect #47308
       // process tmpDroppedEvents
-      EntryEventImpl droppedEvent = null;
+      EntryEventImpl droppedEvent;
       while ((droppedEvent = tmpDroppedEvents.poll()) != null) {
         this.eventProcessor.registerEventDroppedInPrimaryQueue(droppedEvent);
       }
@@ -1405,6 +1439,14 @@ public abstract class AbstractGatewaySender implements InternalGatewaySender, Di
     }
   }
 
+  public void setExpectedReceiverUniqueId(String expectedReceiverUniqueId) {
+    this.expectedReceiverUniqueId = expectedReceiverUniqueId;
+  }
+
+  public String getExpectedReceiverUniqueId() {
+    return this.expectedReceiverUniqueId;
+  }
+
   /**
    * Has a reference to a GatewayEventImpl and has a timeout value.
    */
