@@ -14,7 +14,9 @@
  */
 package org.apache.geode.internal.cache.wan.parallel;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.cache.wan.GatewaySender.DEFAULT_BATCH_SIZE;
+import static org.apache.geode.cache.wan.GatewaySender.GET_TRANSACTION_EVENTS_FROM_QUEUE_RETRIES;
 import static org.apache.geode.internal.cache.LocalRegion.InitializationLevel.BEFORE_INITIAL_IMAGE;
 
 import java.util.ArrayList;
@@ -33,12 +35,14 @@ import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.TimeUnit;
+import java.util.function.Predicate;
 
 import it.unimi.dsi.fastutil.objects.ObjectOpenHashSet;
 import org.apache.logging.log4j.Logger;
 
 import org.apache.geode.CancelException;
 import org.apache.geode.SystemFailure;
+import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.annotations.internal.MutableForTesting;
 import org.apache.geode.cache.AttributesMutator;
 import org.apache.geode.cache.Cache;
@@ -53,6 +57,7 @@ import org.apache.geode.cache.Region;
 import org.apache.geode.cache.RegionAttributes;
 import org.apache.geode.cache.RegionDestroyedException;
 import org.apache.geode.cache.RegionShortcut;
+import org.apache.geode.cache.TransactionId;
 import org.apache.geode.cache.asyncqueue.internal.AsyncEventQueueImpl;
 import org.apache.geode.distributed.internal.DistributionManager;
 import org.apache.geode.distributed.internal.InternalDistributedSystem;
@@ -98,7 +103,7 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
   protected final Map<String, PartitionedRegion> userRegionNameToShadowPRMap =
       new ConcurrentHashMap<>();
   private static final String SHADOW_BUCKET_PATH_PREFIX =
-      Region.SEPARATOR + PartitionedRegionHelper.PR_ROOT_REGION_NAME + Region.SEPARATOR;
+      SEPARATOR + PartitionedRegionHelper.PR_ROOT_REGION_NAME + SEPARATOR;
 
   // <PartitionedRegion, Map<Integer, List<Object>>>
   private final Map regionToDispatchedKeysMap = new ConcurrentHashMap();
@@ -108,6 +113,16 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
   protected final StoppableReentrantLock queueEmptyLock;
   private volatile boolean isQueueEmpty = true;
 
+  private final boolean cleanQueues;
+
+  @VisibleForTesting
+  boolean getCleanQueues() {
+    return cleanQueues;
+  }
+
+
+  private final boolean asyncEvent;
+
   /**
    * False signal is fine on this condition. As processor will loop again and find out if it was a
    * false signal. However, make sure that whatever scenario can cause an entry to be peeked shoudld
@@ -189,12 +204,11 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
 
     @Override
     public void run() {
-      PartitionedRegion prQ = null;
       GatewaySenderEventImpl event = (GatewaySenderEventImpl) conflatableObject;
+      String regionPath =
+          ColocationHelper.getLeaderRegion((PartitionedRegion) event.getRegion()).getFullPath();
+      PartitionedRegion prQ = userRegionNameToShadowPRMap.get(regionPath);
       try {
-        String regionPath =
-            ColocationHelper.getLeaderRegion((PartitionedRegion) event.getRegion()).getFullPath();
-        prQ = userRegionNameToShadowPRMap.get(regionPath);
         destroyEventFromQueue(prQ, bucketId, previousTailKeyTobeRemoved);
       } catch (EntryNotFoundException e) {
         if (logger.isDebugEnabled()) {
@@ -217,7 +231,7 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
         // ClassNotFoundException
         try {
           deserializedObject = EntryEventImpl.deserialize(serializedBytesCast);
-        } catch (Exception e) {
+        } catch (Exception ignore) {
         }
       }
       return deserializedObject;
@@ -231,20 +245,28 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
   private MetaRegionFactory metaRegionFactory;
 
   public ParallelGatewaySenderQueue(AbstractGatewaySender sender, Set<Region> userRegions, int idx,
-      int nDispatcher) {
-    this(sender, userRegions, idx, nDispatcher, new MetaRegionFactory());
+      int nDispatcher, boolean cleanQueues) {
+    this(sender, userRegions, idx, nDispatcher, new MetaRegionFactory(), cleanQueues);
   }
 
   ParallelGatewaySenderQueue(AbstractGatewaySender sender, Set<Region> userRegions, int idx,
-      int nDispatcher, MetaRegionFactory metaRegionFactory) {
+      int nDispatcher, MetaRegionFactory metaRegionFactory, boolean cleanQueues) {
 
     this.metaRegionFactory = metaRegionFactory;
 
+    this.cleanQueues = cleanQueues;
+
     this.index = idx;
     this.nDispatcher = nDispatcher;
     this.stats = sender.getStatistics();
     this.sender = sender;
 
+    if (this.sender.getId().contains(AsyncEventQueueImpl.ASYNC_EVENT_QUEUE_PREFIX)) {
+      this.asyncEvent = true;
+    } else {
+      this.asyncEvent = false;
+    }
+
     List<Region> listOfRegions = new ArrayList<Region>(userRegions);
     Collections.sort(listOfRegions, new Comparator<Region>() {
       @Override
@@ -256,20 +278,22 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
     for (Region userRegion : listOfRegions) {
       if (userRegion instanceof PartitionedRegion) {
         addShadowPartitionedRegionForUserPR((PartitionedRegion) userRegion);
+        if (index == 0 && getRegion(userRegion.getFullPath()) != null) {
+          this.stats.incQueueSize(getRegion(userRegion.getFullPath()).getLocalSize());
+        }
       } else {
         // Fix for Bug#51491. Once decided to support this configuration we have call
         // addShadowPartitionedRegionForUserRR
-        if (this.sender.getId().contains(AsyncEventQueueImpl.ASYNC_EVENT_QUEUE_PREFIX)) {
-          throw new AsyncEventQueueConfigurationException(
-              String.format(
-                  "Parallel Async Event Queue %s can not be used with replicated region %s",
-                  new Object[] {
-                      AsyncEventQueueImpl.getAsyncEventQueueIdFromSenderId(this.sender.getId()),
-                      userRegion.getFullPath()}));
+
+        if (this.asyncEvent) {
+          throw new AsyncEventQueueConfigurationException(String.format(
+              "Parallel Async Event Queue %s can not be used with replicated region %s",
+              AsyncEventQueueImpl.getAsyncEventQueueIdFromSenderId(this.sender.getId()),
+              userRegion.getFullPath()));
         }
         throw new GatewaySenderConfigurationException(
-            String.format("Parallel gateway sender %s can not be used with replicated region %s",
-                new Object[] {this.sender.getId(), userRegion.getFullPath()}));
+            String.format("Parallel Gateway Sender %s can not be used with replicated region %s",
+                this.sender.getId(), userRegion.getFullPath()));
       }
     }
 
@@ -419,9 +443,15 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
   }
 
   public void addShadowPartitionedRegionForUserPR(PartitionedRegion userPR) {
+    addShadowPartitionedRegionForUserPR(userPR, null);
+  }
+
+  public void addShadowPartitionedRegionForUserPR(PartitionedRegion userPR,
+      PartitionedRegion childPR) {
     if (logger.isDebugEnabled()) {
-      logger.debug("{} addShadowPartitionedRegionForUserPR: Attempting to create queue region: {}",
-          this, userPR.getDisplayName());
+      logger.debug(
+          "{} addShadowPartitionedRegionForUserPR: Attempting to create queue region: {}; child region: {}",
+          this, userPR.getDisplayName(), childPR == null ? "null" : childPR.getDisplayName());
     }
     this.sender.getLifeCycleLock().writeLock().lock();
 
@@ -437,7 +467,7 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
         // though, internally, colocate the GatewaySender's shadowPR with the leader PR in
         // colocation chain
         if (!this.userRegionNameToShadowPRMap.containsKey(leaderRegionName)) {
-          addShadowPartitionedRegionForUserPR(ColocationHelper.getLeaderRegion(userPR));
+          addShadowPartitionedRegionForUserPR(ColocationHelper.getLeaderRegion(userPR), userPR);
         }
         return;
       }
@@ -446,7 +476,8 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
         return;
       }
 
-      if (userPR.getDataPolicy().withPersistence() && !sender.isPersistenceEnabled()) {
+      if ((childPR == null ? userPR : childPR).getDataPolicy().withPersistence()
+          && !sender.isPersistenceEnabled()) {
         throw new GatewaySenderException(
             String.format(
                 "Non persistent gateway sender %s can not be attached to persistent region %s",
@@ -458,6 +489,13 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
 
       final String prQName = sender.getId() + QSTRING + convertPathToName(userPR.getFullPath());
       prQ = (PartitionedRegion) cache.getRegion(prQName);
+
+      if ((prQ != null) && (this.index == 0) && this.cleanQueues) {
+        cleanOverflowStats(cache);
+        prQ.destroyRegion(null);
+        prQ = null;
+      }
+
       if (prQ == null) {
         RegionShortcut regionShortcut;
         if (sender.isPersistenceEnabled() && !isAccessor) {
@@ -515,6 +553,9 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
         prQ = (PartitionedRegion) fact.create(prQName);
         // at this point we should be able to assert prQ == meta;
 
+        if (prQ == null) {
+          return;
+        }
         // TODO This should not be set on the PR but on the GatewaySender
         prQ.enableConflation(sender.isBatchConflationEnabled());
         if (isAccessor) {
@@ -524,12 +565,15 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
         // Add the overflow statistics to the mbean
         addOverflowStatisticsToMBean(cache, prQ);
 
-        // Wait for buckets to be recovered.
-        prQ.shadowPRWaitForBucketRecovery();
+        if (!this.cleanQueues) {
+          // Wait for buckets to be recovered.
+          prQ.shadowPRWaitForBucketRecovery();
+        }
 
         if (logger.isDebugEnabled()) {
           logger.debug("{}: Created queue region: {}", this, prQ);
         }
+
       } else {
         if (isAccessor) {
           return; // return from here if accessor node
@@ -540,6 +584,7 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
         {
           handleShadowPRExistsScenario(cache, prQ);
         }
+
       }
 
     } finally {
@@ -563,7 +608,7 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
   private void addOverflowStatisticsToMBean(Cache cache, PartitionedRegion prQ) {
     // Get the appropriate mbean and add the eviction and disk region stats to it
     ManagementService service = ManagementService.getManagementService(cache);
-    if (this.sender.getId().contains(AsyncEventQueueImpl.ASYNC_EVENT_QUEUE_PREFIX)) {
+    if (this.asyncEvent) {
       AsyncEventQueueMBean bean = (AsyncEventQueueMBean) service.getLocalAsyncEventQueueMXBean(
           AsyncEventQueueImpl.getAsyncEventQueueIdFromSenderId(this.sender.getId()));
 
@@ -588,6 +633,19 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
     }
   }
 
+  private void cleanOverflowStats(Cache cache) {
+    ManagementService service = ManagementService.getManagementService(cache);
+    if (!this.asyncEvent) {
+      GatewaySenderMBean bean =
+          (GatewaySenderMBean) service.getLocalGatewaySenderMXBean(this.sender.getId());
+      if (bean != null) {
+        bean.getBridge().clearOverflowStatistics();
+      }
+    }
+
+  }
+
+
   /**
    * This will be case when the sender is started again after stop operation.
    */
@@ -597,12 +655,6 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
       logger.debug("{}: No need to create the region as the region has been retrieved: {}", this,
           prQ);
     }
-    // now, clean up the shadowPR's buckets on this node (primary as well as
-    // secondary) for a fresh start
-    Set<BucketRegion> localBucketRegions = prQ.getDataStore().getAllLocalBucketRegions();
-    for (BucketRegion bucketRegion : localBucketRegions) {
-      bucketRegion.clear();
-    }
   }
 
   protected void afterRegionAdd(PartitionedRegion userPR) {
@@ -616,7 +668,7 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
   private void initializeConflationThreadPool() {
     int poolSize = Runtime.getRuntime().availableProcessors();
     conflationExecutor =
-        LoggingExecutors.newFixedThreadPool("WAN Queue Conflation Thread", true, poolSize);
+        LoggingExecutors.newFixedThreadPool(poolSize, "WAN Queue Conflation Thread", true);
   }
 
   /**
@@ -1232,7 +1284,7 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
     // Add peeked events
     addPeekedEvents(batch, batchSize == BATCH_BASED_ON_TIME_ONLY ? DEFAULT_BATCH_SIZE : batchSize);
 
-    int bId = -1;
+    int bId;
     while (batchSize == BATCH_BASED_ON_TIME_ONLY || batch.size() < batchSize) {
       if (areLocalBucketQueueRegionsPresent() && ((bId = getRandomPrimaryBucket(prQ)) != -1)) {
         GatewaySenderEventImpl object = (GatewaySenderEventImpl) peekAhead(prQ, bId);
@@ -1255,60 +1307,135 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
           peekedEvents.add(object);
 
         } else {
-          // If time to wait is -1 (don't wait) or time interval has elapsed
-          long currentTime = System.currentTimeMillis();
-          if (isDebugEnabled) {
-            logger.debug("{}: Peeked object was null. Peek current time: {}", this, currentTime);
-          }
-          if (timeToWait == -1 || (end <= currentTime)) {
-            if (isDebugEnabled) {
-              logger.debug("{}: Peeked object was null.. Peek breaking", this);
-            }
+          if (stopPeekingDueToTime(timeToWait, end)) {
             break;
           }
           if (isDebugEnabled) {
             logger.debug("{}: Peeked object was null. Peek continuing", this);
           }
-          continue;
         }
       } else {
-        // If time to wait is -1 (don't wait) or time interval has elapsed
-        long currentTime = System.currentTimeMillis();
-        if (isDebugEnabled) {
-          logger.debug("{}: Peek current time: {}", this, currentTime);
-        }
-        if (timeToWait == -1 || (end <= currentTime)) {
-          if (isDebugEnabled) {
-            logger.debug("{}: Peek breaking", this);
-          }
+        if (stopPeekingDueToTime(timeToWait, end)) {
           break;
         }
         if (isDebugEnabled) {
           logger.debug("{}: Peek continuing", this);
         }
         // Sleep a bit before trying again.
+        long currentTime = System.currentTimeMillis();
         try {
-          Thread.sleep(getTimeToSleep(end - currentTime));
+          Thread.sleep(calculateTimeToSleep(end - currentTime));
         } catch (InterruptedException e) {
           Thread.currentThread().interrupt();
           break;
         }
-        continue;
       }
     }
+
+    if (batch.size() > 0) {
+      peekEventsFromIncompleteTransactions(batch, prQ);
+    }
+
+
     if (isDebugEnabled) {
       logger.debug("{}: Peeked a batch of {} entries. The size of the queue is {}. localSize is {}",
           this, batch.size(), size(), localSize());
     }
+
     if (batch.size() == 0) {
       blockProcessorThreadIfRequired();
     }
     return batch;
   }
 
-  private long getTimeToSleep(long timeToWait) {
+  private boolean stopPeekingDueToTime(int timeToWait, long end) {
+    final boolean isDebugEnabled = logger.isDebugEnabled();
+    // If time to wait is -1 (don't wait) or time interval has elapsed
+    long currentTime = System.currentTimeMillis();
+    if (isDebugEnabled) {
+      logger.debug("{}: Peek current time: {}", this, currentTime);
+    }
+    if (timeToWait == -1 || (end <= currentTime)) {
+      if (isDebugEnabled) {
+        logger.debug("{}: Peek breaking", this);
+      }
+      return true;
+    }
+    return false;
+  }
+
+  protected boolean mustGroupTransactionEvents() {
+    return sender.mustGroupTransactionEvents();
+  }
+
+  private void peekEventsFromIncompleteTransactions(List<GatewaySenderEventImpl> batch,
+      PartitionedRegion prQ) {
+    if (!mustGroupTransactionEvents()) {
+      return;
+    }
+
+    Map<TransactionId, Integer> incompleteTransactionIdsInBatch =
+        getIncompleteTransactionsInBatch(batch);
+    if (incompleteTransactionIdsInBatch.size() == 0) {
+      return;
+    }
+
+    boolean batchHasIncompleteTransactions = false;
+    for (Map.Entry<TransactionId, Integer> pendingTransaction : incompleteTransactionIdsInBatch
+        .entrySet()) {
+      TransactionId transactionId = pendingTransaction.getKey();
+      int bucketId = pendingTransaction.getValue();
+      boolean areAllEventsForTransactionInBatch = false;
+      int retries = 0;
+      while (!areAllEventsForTransactionInBatch
+          && retries++ < GET_TRANSACTION_EVENTS_FROM_QUEUE_RETRIES) {
+        List<Object> events = peekEventsWithTransactionId(prQ, bucketId, transactionId);
+        for (Object object : events) {
+          GatewaySenderEventImpl event = (GatewaySenderEventImpl) object;
+          batch.add(event);
+          peekedEvents.add(event);
+          areAllEventsForTransactionInBatch = event.isLastEventInTransaction();
+
+          if (logger.isDebugEnabled()) {
+            logger.debug(
+                "Peeking extra event: {}, bucketId: {}, isLastEventInTransaction: {}, batch size: {}",
+                event.getKey(), bucketId, event.isLastEventInTransaction(), batch.size());
+          }
+        }
+      }
+      if (!areAllEventsForTransactionInBatch) {
+        batchHasIncompleteTransactions = true;
+        logger.warn("Not able to retrieve all events for transaction {} after {} tries",
+            transactionId, retries);
+      }
+    }
+    if (batchHasIncompleteTransactions) {
+      stats.incBatchesWithIncompleteTransactions();
+    }
+  }
+
+  private Map<TransactionId, Integer> getIncompleteTransactionsInBatch(
+      List<GatewaySenderEventImpl> batch) {
+    Map<TransactionId, Integer> incompleteTransactionsInBatch = new HashMap<>();
+    for (GatewaySenderEventImpl event : batch) {
+      if (event.getTransactionId() != null) {
+        if (event.isLastEventInTransaction()) {
+          incompleteTransactionsInBatch.remove(event.getTransactionId());
+        } else {
+          incompleteTransactionsInBatch.put(event.getTransactionId(), event.getBucketId());
+        }
+      }
+    }
+    return incompleteTransactionsInBatch;
+  }
+
+  @VisibleForTesting
+  static long calculateTimeToSleep(long timeToWait) {
+    if (timeToWait <= 0) {
+      return 0;
+    }
     // Get the minimum of 50 and 5% of the time to wait (which by default is 1000 ms)
-    long timeToSleep = Math.min(50l, ((long) (timeToWait * 0.05)));
+    long timeToSleep = Math.min(50L, ((long) (timeToWait * 0.05)));
 
     // If it is 0, then try 50% of the time to wait
     if (timeToSleep == 0) {
@@ -1328,16 +1455,19 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
 
       // Remove all entries from peekedEvents for buckets that are not longer primary
       // This will prevent repeatedly trying to dispatch non-primary events
-      for (Iterator<GatewaySenderEventImpl> iterator = peekedEvents.iterator(); iterator
-          .hasNext();) {
-        GatewaySenderEventImpl event = iterator.next();
-        final int bucketId = event.getBucketId();
-        final PartitionedRegion region = (PartitionedRegion) event.getRegion();
-        if (!region.getRegionAdvisor().isPrimaryForBucket(bucketId)) {
-          iterator.remove();
-          BucketRegionQueue brq = getBucketRegionQueueByBucketId(getRandomShadowPR(), bucketId);
-          if (brq != null) {
-            brq.pushKeyIntoQueue(event.getShadowKey());
+      Object[] helpArray = peekedEvents.toArray();
+      if (helpArray.length > 0) {
+
+        for (int i = helpArray.length - 1; i >= 0; i--) {
+          GatewaySenderEventImpl event = (GatewaySenderEventImpl) helpArray[i];
+          final int bucketId = event.getBucketId();
+          final PartitionedRegion region = (PartitionedRegion) event.getRegion();
+          if (!region.getRegionAdvisor().isPrimaryForBucket(bucketId)) {
+            peekedEvents.remove(event);
+            BucketRegionQueue brq = getBucketRegionQueueByBucketId(getRandomShadowPR(), bucketId);
+            if (brq != null) {
+              brq.pushKeyIntoQueue(event.getShadowKey());
+            }
           }
         }
       }
@@ -1356,6 +1486,8 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
         // The peekedEvents queue is > batch size. This means that the previous batch size was
         // reduced due to MessageTooLargeException. Create a batch from the peekedEventsProcessing
         // queue.
+        // This could also be a normal case in which the batch included extra events to make
+        // sure that events for each transaction were sent in the same batch.
         this.peekedEventsProcessing.addAll(this.peekedEvents);
         this.peekedEventsProcessingInProgress = true;
         addPreviouslyPeekedEvents(batch, batchSize);
@@ -1372,8 +1504,19 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
   }
 
   private void addPreviouslyPeekedEvents(List<GatewaySenderEventImpl> batch, int batchSize) {
-    for (int i = 0; i < batchSize; i++) {
-      batch.add(this.peekedEventsProcessing.remove());
+    Set<TransactionId> incompleteTransactionsInBatch = new HashSet<>();
+    for (int i = 0; i < batchSize || incompleteTransactionsInBatch.size() != 0; i++) {
+      GatewaySenderEventImpl event = this.peekedEventsProcessing.remove();
+      batch.add(event);
+      if (mustGroupTransactionEvents()) {
+        if (event.getTransactionId() != null) {
+          if (event.isLastEventInTransaction()) {
+            incompleteTransactionsInBatch.remove(event.getTransactionId());
+          } else {
+            incompleteTransactionsInBatch.add(event.getTransactionId());
+          }
+        }
+      }
       if (this.peekedEventsProcessing.isEmpty()) {
         this.resetLastPeeked = false;
         this.peekedEventsProcessingInProgress = false;
@@ -1432,13 +1575,44 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
                    // finished with peeked object.
   }
 
+  protected List<Object> peekEventsWithTransactionId(PartitionedRegion prQ, int bucketId,
+      TransactionId transactionId) throws CacheException {
+    List<Object> objects;
+    BucketRegionQueue brq = getBucketRegionQueueByBucketId(prQ, bucketId);
+
+    try {
+      Predicate<GatewaySenderEventImpl> hasTransactionIdPredicate =
+          getHasTransactionIdPredicate(transactionId);
+      Predicate<GatewaySenderEventImpl> isLastEventInTransactionPredicate =
+          getIsLastEventInTransactionPredicate();
+      objects =
+          brq.getElementsMatching(hasTransactionIdPredicate, isLastEventInTransactionPredicate);
+    } catch (BucketRegionQueueUnavailableException e) {
+      // BucketRegionQueue unavailable. Can be due to the BucketRegionQueue being destroyed.
+      return Collections.emptyList();
+    }
+
+    return objects; // OFFHEAP: ok since callers are careful to do destroys on region queue after
+    // finished with peeked objects.
+  }
+
+  @VisibleForTesting
+  public static Predicate<GatewaySenderEventImpl> getIsLastEventInTransactionPredicate() {
+    return x -> x.isLastEventInTransaction();
+  }
+
+  @VisibleForTesting
+  public static Predicate<GatewaySenderEventImpl> getHasTransactionIdPredicate(
+      TransactionId transactionId) {
+    return x -> transactionId.equals(x.getTransactionId());
+  }
+
   protected BucketRegionQueue getBucketRegionQueueByBucketId(final PartitionedRegion prQ,
       final int bucketId) {
     return (BucketRegionQueue) prQ.getDataStore().getLocalBucketById(bucketId);
   }
 
   public String displayContent() {
-    int size = 0;
     StringBuffer sb = new StringBuffer();
     for (PartitionedRegion prQ : this.userRegionNameToShadowPRMap.values()) {
       if (prQ != null && prQ.getDataStore() != null) {
@@ -1460,7 +1634,7 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
   public int localSize(boolean includeSecondary) {
     int size = 0;
     for (PartitionedRegion prQ : this.userRegionNameToShadowPRMap.values()) {
-      if (prQ != null && prQ.getDataStore() != null) {
+      if (prQ.getDataStore() != null) {
         if (includeSecondary) {
           size += prQ.getDataStore().getSizeOfLocalBuckets();
         } else {
@@ -1591,7 +1765,27 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
 
   @Override
   public void close() {
-    // Because of bug 49060 do not close the regions of a parallel queue
+    if (resetLastPeeked) {
+      returnToQueuePreviouslyPeekedEvents();
+      resetLastPeeked = false;
+    }
+  }
+
+  private void returnToQueuePreviouslyPeekedEvents() {
+    Object[] helpArray = peekedEvents.toArray();
+    peekedEvents.clear();
+    if (helpArray.length == 0) {
+      return;
+    }
+
+    for (int i = helpArray.length - 1; i >= 0; i--) {
+      GatewaySenderEventImpl event = (GatewaySenderEventImpl) helpArray[i];
+      final int bucketId = event.getBucketId();
+      BucketRegionQueue brq = getBucketRegionQueueByBucketId(getRandomShadowPR(), bucketId);
+      if (brq != null) {
+        brq.pushKeyIntoQueue(event.getShadowKey());
+      }
+    }
   }
 
   /**
@@ -1624,8 +1818,6 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
 
     private final InternalCache cache;
 
-    private final ParallelGatewaySenderQueue parallelQueue;
-
     /**
      * Constructor : Creates and initializes the thread
      */
@@ -1633,7 +1825,6 @@ public class ParallelGatewaySenderQueue implements RegionQueue {
       super("BatchRemovalThread for GatewaySender_" + queue.sender.getId() + "_" + queue.index);
       this.setDaemon(true);
       this.cache = c;
-      this.parallelQueue = queue;
     }
 
     private boolean checkCancelled() {
