@@ -144,7 +144,7 @@ public class BatchDestroyOperation extends DistributedCacheOperation {
           }
           if (ep != null) {
             // if sender is being shutdown, the ep could be null
-            boolean removed = ep.basicHandlePrimaryDestroy(ev.getEventId());
+            boolean removed = ep.basicHandlePrimaryDestroy(ev.getEventId(), true);
             if (removed) {
               if (isDebugEnabled) {
                 logger.debug("Removed a dropped event {} from unprocessedEvents.",
