@@ -66,11 +66,11 @@ public class ConcurrentSerialGatewaySenderEventProcessor
   private final Set<RegionQueue> queues;
 
   public ConcurrentSerialGatewaySenderEventProcessor(AbstractGatewaySender sender,
-      ThreadsMonitoring tMonitoring) {
+      ThreadsMonitoring tMonitoring, boolean cleanQueues) {
     super("Event Processor for GatewaySender_" + sender.getId(), sender, tMonitoring);
     this.sender = sender;
 
-    initializeMessageQueue(sender.getId());
+    initializeMessageQueue(sender.getId(), cleanQueues);
     queues = new HashSet<RegionQueue>();
     for (SerialGatewaySenderEventProcessor processor : processors) {
       queues.add(processor.getQueue());
@@ -87,10 +87,11 @@ public class ConcurrentSerialGatewaySenderEventProcessor
   }
 
   @Override
-  protected void initializeMessageQueue(String id) {
+  protected void initializeMessageQueue(String id, boolean cleanQueues) {
     for (int i = 0; i < sender.getDispatcherThreads(); i++) {
       processors.add(
-          new SerialGatewaySenderEventProcessor(this.sender, id + "." + i, getThreadMonitorObj()));
+          new SerialGatewaySenderEventProcessor(this.sender, id + "." + i, getThreadMonitorObj(),
+              cleanQueues));
       if (logger.isDebugEnabled()) {
         logger.debug("Created the SerialGatewayEventProcessor_{}->{}", i, processors.get(i));
       }
@@ -110,11 +111,17 @@ public class ConcurrentSerialGatewaySenderEventProcessor
   @Override
   public void enqueueEvent(EnumListenerEvent operation, EntryEvent event, Object substituteValue)
       throws IOException, CacheException {
+    enqueueEvent(operation, event, substituteValue, false);
+
+  }
+
+  @Override
+  public void enqueueEvent(EnumListenerEvent operation, EntryEvent event, Object substituteValue,
+      boolean isLastEventInTransaction) throws IOException, CacheException {
     // Get the appropriate index into the gateways
     int index = Math.abs(getHashCode(((EntryEventImpl) event)) % this.processors.size());
     // Distribute the event to the gateway
-    enqueueEvent(operation, event, substituteValue, index);
-
+    enqueueEvent(operation, event, substituteValue, index, isLastEventInTransaction);
   }
 
   public void setModifiedEventId(EntryEventImpl clonedEvent, int index) {
@@ -147,7 +154,7 @@ public class ConcurrentSerialGatewaySenderEventProcessor
   }
 
   public void enqueueEvent(EnumListenerEvent operation, EntryEvent event, Object substituteValue,
-      int index) throws CacheException, IOException {
+      int index, boolean isLastEventInTransaction) throws CacheException, IOException {
     // Get the appropriate gateway
     SerialGatewaySenderEventProcessor serialProcessor = this.processors.get(index);
 
@@ -159,7 +166,8 @@ public class ConcurrentSerialGatewaySenderEventProcessor
       EntryEventImpl clonedEvent = new EntryEventImpl((EntryEventImpl) event);
       try {
         setModifiedEventId(clonedEvent, index);
-        serialProcessor.enqueueEvent(operation, clonedEvent, substituteValue);
+        serialProcessor.enqueueEvent(operation, clonedEvent, substituteValue,
+            isLastEventInTransaction);
       } finally {
         clonedEvent.release();
       }
@@ -171,12 +179,27 @@ public class ConcurrentSerialGatewaySenderEventProcessor
 
   @Override
   public void run() {
-    for (int i = 0; i < this.processors.size(); i++) {
-      if (logger.isDebugEnabled()) {
+    boolean isDebugEnabled = logger.isDebugEnabled();
+    if (this.sender.getEnforceThreadsConnectSameReceiver()) {
+      this.processors.get(0).start();
+      waitForRunningStatus(this.processors.get(0));
+      String receiverUniqueId = this.processors.get(0).getExpectedReceiverUniqueId();
+      if (isDebugEnabled) {
+        logger.debug("First dispatcher is connected to " + receiverUniqueId);
+      }
+      for (int j = 1; j < this.processors.size(); j++) {
+        this.processors.get(j).setExpectedReceiverUniqueId(receiverUniqueId);
+      }
+    }
+
+    for (int i = this.sender.getEnforceThreadsConnectSameReceiver() ? 1 : 0; i < this.processors
+        .size(); i++) {
+      if (isDebugEnabled) {
         logger.debug("Starting the serialProcessor {}", i);
       }
       this.processors.get(i).start();
     }
+
     try {
       waitForRunningStatus();
     } catch (GatewaySenderException e) {
@@ -197,7 +220,7 @@ public class ConcurrentSerialGatewaySenderEventProcessor
       try {
         serialProcessor.join();
       } catch (InterruptedException e) {
-        if (logger.isDebugEnabled()) {
+        if (isDebugEnabled) {
           logger.debug("Got InterruptedException while waiting for child threads to finish.");
           Thread.currentThread().interrupt();
         }
@@ -211,24 +234,28 @@ public class ConcurrentSerialGatewaySenderEventProcessor
     throw new UnsupportedOperationException();
   }
 
-  private void waitForRunningStatus() {
-    for (SerialGatewaySenderEventProcessor serialProcessor : this.processors) {
-      synchronized (serialProcessor.getRunningStateLock()) {
-        while (serialProcessor.getException() == null && serialProcessor.isStopped()) {
-          try {
-            serialProcessor.getRunningStateLock().wait();
-          } catch (InterruptedException e) {
-            Thread.currentThread().interrupt();
-          }
-        }
-        Exception ex = serialProcessor.getException();
-        if (ex != null) {
-          throw new GatewaySenderException(
-              String.format("Could not start a gateway sender %s because of exception %s",
-                  new Object[] {this.sender.getId(), ex.getMessage()}),
-              ex.getCause());
+  private void waitForRunningStatus(SerialGatewaySenderEventProcessor serialProcessor) {
+    synchronized (serialProcessor.getRunningStateLock()) {
+      while (serialProcessor.getException() == null && serialProcessor.isStopped()) {
+        try {
+          serialProcessor.getRunningStateLock().wait();
+        } catch (InterruptedException e) {
+          Thread.currentThread().interrupt();
         }
       }
+      Exception ex = serialProcessor.getException();
+      if (ex != null) {
+        throw new GatewaySenderException(
+            String.format("Could not start a gateway sender %s because of exception %s",
+                new Object[] {this.sender.getId(), ex.getMessage()}),
+            ex.getCause());
+      }
+    }
+  }
+
+  private void waitForRunningStatus() {
+    for (SerialGatewaySenderEventProcessor serialProcessor : this.processors) {
+      waitForRunningStatus(serialProcessor);
     }
   }
 
@@ -284,8 +311,8 @@ public class ConcurrentSerialGatewaySenderEventProcessor
     }
 
     ExecutorService stopperService = LoggingExecutors.newFixedThreadPool(
-        "ConcurrentSerialGatewaySenderEventProcessor Stopper Thread",
-        true, processors.size());
+        processors.size(), "ConcurrentSerialGatewaySenderEventProcessor Stopper Thread",
+        true);
     try {
       List<Future<Boolean>> futures = stopperService.invokeAll(stopperCallables);
       for (Future<Boolean> f : futures) {
