@@ -15,22 +15,27 @@
 package org.apache.geode.internal.cache.wan.serial;
 
 import static org.apache.geode.cache.wan.GatewaySender.DEFAULT_BATCH_SIZE;
+import static org.apache.geode.cache.wan.GatewaySender.GET_TRANSACTION_EVENTS_FROM_QUEUE_RETRIES;
 
 import java.util.ArrayList;
 import java.util.Deque;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.LinkedBlockingDeque;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.AtomicReference;
+import java.util.function.Predicate;
 
 import org.apache.logging.log4j.Logger;
 
 import org.apache.geode.CancelException;
 import org.apache.geode.SystemFailure;
 import org.apache.geode.annotations.Immutable;
+import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.cache.AttributesMutator;
 import org.apache.geode.cache.Cache;
 import org.apache.geode.cache.CacheException;
@@ -47,6 +52,7 @@ import org.apache.geode.cache.RegionDestroyedException;
 import org.apache.geode.cache.RegionShortcut;
 import org.apache.geode.cache.Scope;
 import org.apache.geode.cache.TimeoutException;
+import org.apache.geode.cache.TransactionId;
 import org.apache.geode.cache.asyncqueue.AsyncEvent;
 import org.apache.geode.cache.asyncqueue.internal.AsyncEventQueueImpl;
 import org.apache.geode.distributed.internal.InternalDistributedSystem;
@@ -97,8 +103,27 @@ public class SerialGatewaySenderQueue implements RegionQueue {
    */
   private final AtomicLong tailKey = new AtomicLong();
 
+  /**
+   * Last key peeked from the queue excluding the keys peeked
+   * to complete transactions when group-transaction-events is enabled.
+   */
+  private final AtomicLong lastPeekedId = new AtomicLong(-1);
+
   private final Deque<Long> peekedIds = new LinkedBlockingDeque<Long>();
 
+  /**
+   * Contains the set of peekedIds that were peeked to complete a transaction
+   * inside a batch when groupTransactionEvents is set.
+   */
+  private final Set<Long> extraPeekedIds = ConcurrentHashMap.newKeySet();
+
+  /**
+   * Contains the set of peekedIds that were peeked to complete a transaction
+   * inside a batch when groupTransactionEvents is set and that have
+   * been sent in a batch but have not yet been removed.
+   */
+  private final Set<Long> extraPeekedIdsSentNotRemoved = ConcurrentHashMap.newKeySet();
+
   /**
    * The name of the <code>Region</code> backing this queue
    */
@@ -134,6 +159,8 @@ public class SerialGatewaySenderQueue implements RegionQueue {
    */
   private boolean enablePersistence;
 
+  private final boolean cleanQueues;
+
   /**
    * Whether write to disk is synchronous.
    */
@@ -171,11 +198,20 @@ public class SerialGatewaySenderQueue implements RegionQueue {
 
   private AbstractGatewaySender sender = null;
 
+  private MetaRegionFactory metaRegionFactory;
+
   public SerialGatewaySenderQueue(AbstractGatewaySender abstractSender, String regionName,
-      CacheListener listener) {
+      CacheListener listener, boolean cleanQueues) {
+    this(abstractSender, regionName, listener, cleanQueues, new MetaRegionFactory());
+  }
+
+  public SerialGatewaySenderQueue(AbstractGatewaySender abstractSender, String regionName,
+      CacheListener listener, boolean cleanQueues, MetaRegionFactory metaRegionFactory) {
     // The queue starts out with headKey and tailKey equal to -1 to force
     // them to be initialized from the region.
     this.regionName = regionName;
+    this.cleanQueues = cleanQueues;
+    this.metaRegionFactory = metaRegionFactory;
     this.headKey = -1;
     this.tailKey.set(-1);
     this.indexes = new HashMap<String, Map<Object, Long>>();
@@ -269,13 +305,16 @@ public class SerialGatewaySenderQueue implements RegionQueue {
    */
   @Override
   public synchronized void remove() throws CacheException {
-    if (this.peekedIds.isEmpty()) {
+    if (peekedIds.isEmpty()) {
       return;
     }
-    Long key = this.peekedIds.remove();
+    Long key = peekedIds.remove();
+    boolean isExtraPeeked = extraPeekedIds.remove(key);
     try {
       // Increment the head key
-      updateHeadKey(key.longValue());
+      if (!isExtraPeeked) {
+        updateHeadKey(key.longValue());
+      }
       removeIndex(key);
       // Remove the entry at that key with a callback arg signifying it is
       // a WAN queue so that AbstractRegionEntry.destroy can get the value
@@ -295,7 +334,26 @@ public class SerialGatewaySenderQueue implements RegionQueue {
     }
 
     boolean wasEmpty = this.lastDispatchedKey == this.lastDestroyedKey;
-    this.lastDispatchedKey = key;
+    if (!isExtraPeeked) {
+      this.lastDispatchedKey = key;
+      // Remove also the extraPeekedIds right after this one so that
+      // they do not stay in the secondary's queue forever
+      long tmpKey = key;
+      while (extraPeekedIdsSentNotRemoved.contains(tmpKey = inc(tmpKey))) {
+        extraPeekedIdsSentNotRemoved.remove(tmpKey);
+        this.lastDispatchedKey = tmpKey;
+        updateHeadKey(tmpKey);
+      }
+    } else {
+      extraPeekedIdsSentNotRemoved.add(key);
+      // Remove if previous key was already dispatched so that it does
+      // not stay in the secondary's queue forever
+      long tmpKey = dec(key);
+      if (this.lastDispatchedKey == tmpKey) {
+        this.lastDispatchedKey = key;
+        updateHeadKey(key);
+      }
+    }
     if (wasEmpty) {
       synchronized (this) {
         notifyAll();
@@ -327,23 +385,23 @@ public class SerialGatewaySenderQueue implements RegionQueue {
 
   @Override
   public Object peek() throws CacheException {
-    Object object = peekAhead();
+    KeyAndEventPair object = peekAhead();
     if (logger.isTraceEnabled()) {
       logger.trace("{}: Peeked {} -> {}", this, peekedIds, object);
     }
 
-    return object;
+    return object.event;
     // OFFHEAP returned object only used to see if queue is empty
     // so no need to worry about off-heap refCount.
   }
 
   @Override
-  public List<AsyncEvent> peek(int size) throws CacheException {
+  public List<AsyncEvent<?, ?>> peek(int size) throws CacheException {
     return peek(size, -1);
   }
 
   @Override
-  public List<AsyncEvent> peek(int size, int timeToWait) throws CacheException {
+  public List<AsyncEvent<?, ?>> peek(int size, int timeToWait) throws CacheException {
     final boolean isTraceEnabled = logger.isTraceEnabled();
 
     long start = System.currentTimeMillis();
@@ -352,12 +410,16 @@ public class SerialGatewaySenderQueue implements RegionQueue {
       logger.trace("{}: Peek start time={} end time={} time to wait={}", this, start, end,
           timeToWait);
     }
-    List<AsyncEvent> batch =
-        new ArrayList<AsyncEvent>(size == BATCH_BASED_ON_TIME_ONLY ? DEFAULT_BATCH_SIZE : size);
+
+    List<AsyncEvent<?, ?>> batch =
+        new ArrayList<>(size == BATCH_BASED_ON_TIME_ONLY ? DEFAULT_BATCH_SIZE : size);
+    long lastKey = -1;
     while (size == BATCH_BASED_ON_TIME_ONLY || batch.size() < size) {
-      AsyncEvent object = peekAhead();
+      KeyAndEventPair pair = peekAhead();
       // Conflate here
-      if (object != null) {
+      if (pair != null) {
+        AsyncEvent<?, ?> object = pair.event;
+        lastKey = pair.key;
         batch.add(object);
       } else {
         // If time to wait is -1 (don't wait) or time interval has elapsed
@@ -385,6 +447,10 @@ public class SerialGatewaySenderQueue implements RegionQueue {
         continue;
       }
     }
+    if (batch.size() > 0) {
+      peekEventsFromIncompleteTransactions(batch, lastKey);
+    }
+
     if (isTraceEnabled) {
       logger.trace("{}: Peeked a batch of {} entries", this, batch.size());
     }
@@ -393,6 +459,71 @@ public class SerialGatewaySenderQueue implements RegionQueue {
     // so no need to worry about off-heap refCount.
   }
 
+  private void peekEventsFromIncompleteTransactions(List<AsyncEvent<?, ?>> batch, long lastKey) {
+    if (!mustGroupTransactionEvents()) {
+      return;
+    }
+
+    Set<TransactionId> incompleteTransactionIdsInBatch = getIncompleteTransactionsInBatch(batch);
+    if (incompleteTransactionIdsInBatch.size() == 0) {
+      return;
+    }
+
+    boolean batchHasIncompleteTransactions = true;
+    for (TransactionId transactionId : incompleteTransactionIdsInBatch) {
+      boolean areAllEventsForTransactionInBatch = false;
+      int retries = 0;
+      long lastKeyForTransaction = lastKey;
+      while (!areAllEventsForTransactionInBatch
+          && retries++ < GET_TRANSACTION_EVENTS_FROM_QUEUE_RETRIES) {
+        EventsAndLastKey eventsAndKey =
+            peekEventsWithTransactionId(transactionId, lastKeyForTransaction);
+
+        for (Object object : eventsAndKey.events) {
+          GatewaySenderEventImpl event = (GatewaySenderEventImpl) object;
+          batch.add(event);
+          areAllEventsForTransactionInBatch = event.isLastEventInTransaction();
+
+          if (logger.isDebugEnabled()) {
+            logger.debug(
+                "Peeking extra event: {}, isLastEventInTransaction: {}, batch size: {}",
+                event.getKey(), event.isLastEventInTransaction(), batch.size());
+          }
+        }
+        lastKeyForTransaction = eventsAndKey.lastKey;
+      }
+      if (!areAllEventsForTransactionInBatch) {
+        batchHasIncompleteTransactions = true;
+        logger.warn("Not able to retrieve all events for transaction {} after {} tries",
+            transactionId, retries);
+      }
+    }
+    if (batchHasIncompleteTransactions) {
+      stats.incBatchesWithIncompleteTransactions();
+    }
+  }
+
+  protected boolean mustGroupTransactionEvents() {
+    return sender.mustGroupTransactionEvents();
+  }
+
+  private Set<TransactionId> getIncompleteTransactionsInBatch(List<AsyncEvent<?, ?>> batch) {
+    Set<TransactionId> incompleteTransactionsInBatch = new HashSet<>();
+    for (Object object : batch) {
+      if (object instanceof GatewaySenderEventImpl) {
+        GatewaySenderEventImpl event = (GatewaySenderEventImpl) object;
+        if (event.getTransactionId() != null) {
+          if (event.isLastEventInTransaction()) {
+            incompleteTransactionsInBatch.remove(event.getTransactionId());
+          } else {
+            incompleteTransactionsInBatch.add(event.getTransactionId());
+          }
+        }
+      }
+    }
+    return incompleteTransactionsInBatch;
+  }
+
   @Override
   public String toString() {
     return "SerialGatewaySender queue :" + this.regionName;
@@ -416,9 +547,9 @@ public class SerialGatewaySenderQueue implements RegionQueue {
   public void removeCacheListener() {
     AttributesMutator mutator = this.region.getAttributesMutator();
     CacheListener[] listeners = this.region.getAttributes().getCacheListeners();
-    for (int i = 0; i < listeners.length; i++) {
-      if (listeners[i] instanceof SerialSecondaryGatewayListener) {
-        mutator.removeCacheListener(listeners[i]);
+    for (CacheListener listener : listeners) {
+      if (listener instanceof SerialSecondaryGatewayListener) {
+        mutator.removeCacheListener(listener);
         break;
       }
     }
@@ -449,7 +580,7 @@ public class SerialGatewaySenderQueue implements RegionQueue {
       synchronized (this) {
         Map<Object, Long> latestIndexesForRegion = this.indexes.get(rName);
         if (latestIndexesForRegion == null) {
-          latestIndexesForRegion = new HashMap<Object, Long>();
+          latestIndexesForRegion = new HashMap<>();
           this.indexes.put(rName, latestIndexesForRegion);
         }
 
@@ -520,7 +651,7 @@ public class SerialGatewaySenderQueue implements RegionQueue {
     Object o = null;
     try {
       o = lr.getValueInVMOrDiskWithoutFaultIn(k);
-      if (o != null && o instanceof CachedDeserializable) {
+      if (o instanceof CachedDeserializable) {
         o = ((CachedDeserializable) o).getDeserializedValue(lr, lr.getRegionEntry(k));
       }
     } catch (EntryNotFoundException ok) {
@@ -585,11 +716,20 @@ public class SerialGatewaySenderQueue implements RegionQueue {
     return val;
   }
 
+  private long dec(long value) {
+    long val = value - 1;
+    val = val == -1 ? MAXIMUM_KEY - 1 : val;
+    return val;
+  }
+
+
   /**
    * Clear the list of peeked keys. The next peek will start again at the head key.
    */
   public void resetLastPeeked() {
-    this.peekedIds.clear();
+    peekedIds.clear();
+    extraPeekedIds.clear();
+    lastPeekedId.set(-1);
   }
 
   /**
@@ -598,14 +738,10 @@ public class SerialGatewaySenderQueue implements RegionQueue {
    */
   private Long getCurrentKey() {
     long currentKey;
-    if (this.peekedIds.isEmpty()) {
+    if (lastPeekedId.get() == -1) {
       currentKey = getHeadKey();
     } else {
-      Long lastPeek = this.peekedIds.peekLast();
-      if (lastPeek == null) {
-        return null;
-      }
-      currentKey = lastPeek.longValue() + 1;
+      currentKey = inc(lastPeekedId.get());
     }
     return currentKey;
   }
@@ -627,7 +763,19 @@ public class SerialGatewaySenderQueue implements RegionQueue {
     return object;
   }
 
-  private AsyncEvent peekAhead() throws CacheException {
+  @VisibleForTesting
+  static class KeyAndEventPair {
+    public final long key;
+    public final AsyncEvent event;
+
+    KeyAndEventPair(Long key, AsyncEvent event) {
+      this.key = key;
+      this.event = event;
+    }
+  }
+
+  @VisibleForTesting
+  public KeyAndEventPair peekAhead() throws CacheException {
     AsyncEvent object = null;
     Long currentKey = getCurrentKey();
     if (currentKey == null) {
@@ -648,13 +796,21 @@ public class SerialGatewaySenderQueue implements RegionQueue {
     // Note: getting the serialized form here (if it has overflowed to disk)
     // does not save anything since GatewayBatchOp needs to GatewayEventImpl
     // in object form.
-    while (before(currentKey, getTailKey())
-        && (null == (object = getObjectInSerialSenderQueue(currentKey)))) {
+    while (before(currentKey, getTailKey())) {
+      if (!extraPeekedIds.contains(currentKey)) {
+        object = getObjectInSerialSenderQueue(currentKey);
+        if (object != null) {
+          break;
+        }
+      }
       if (logger.isTraceEnabled()) {
         logger.trace("{}: Trying head key + offset: {}", this, currentKey);
       }
       currentKey = inc(currentKey);
-      if (this.stats != null) {
+      // When mustGroupTransactionEvents is true, conflation cannot be enabled.
+      // Therefore, if we reach here, it would not be due to a conflated event
+      // but rather to an extra peeked event already sent.
+      if (!mustGroupTransactionEvents() && this.stats != null) {
         this.stats.incEventsNotQueuedConflated();
       }
     }
@@ -662,10 +818,63 @@ public class SerialGatewaySenderQueue implements RegionQueue {
     if (logger.isDebugEnabled()) {
       logger.debug("{}: Peeked {}->{}", this, currentKey, object);
     }
+
     if (object != null) {
-      this.peekedIds.add(currentKey);
+      peekedIds.add(currentKey);
+      lastPeekedId.set(currentKey);
+      return new KeyAndEventPair(currentKey, object);
     }
-    return object;
+    return null;
+  }
+
+  private EventsAndLastKey peekEventsWithTransactionId(TransactionId transactionId, long lastKey) {
+    Predicate<GatewaySenderEventImpl> hasTransactionIdPredicate =
+        x -> transactionId.equals(x.getTransactionId());
+    Predicate<GatewaySenderEventImpl> isLastEventInTransactionPredicate =
+        x -> x.isLastEventInTransaction();
+
+    return getElementsMatching(hasTransactionIdPredicate, isLastEventInTransactionPredicate,
+        lastKey);
+  }
+
+  static class EventsAndLastKey {
+    public final List<Object> events;
+    public final long lastKey;
+
+    EventsAndLastKey(List<Object> events, long lastKey) {
+      this.events = events;
+      this.lastKey = lastKey;
+    }
+  }
+
+  EventsAndLastKey getElementsMatching(Predicate condition, Predicate stopCondition, long lastKey) {
+    Object object;
+    List elementsMatching = new ArrayList<>();
+
+    long currentKey = lastKey;
+
+    while ((currentKey = inc(currentKey)) != getTailKey()) {
+      if (extraPeekedIds.contains(currentKey)) {
+        continue;
+      }
+      object = optimalGet(currentKey);
+      if (object == null) {
+        continue;
+      }
+
+      if (condition.test(object)) {
+        elementsMatching.add(object);
+        peekedIds.add(currentKey);
+        extraPeekedIds.add(currentKey);
+        lastKey = currentKey;
+
+        if (stopCondition.test(object)) {
+          break;
+        }
+      }
+    }
+
+    return new EventsAndLastKey(elementsMatching, lastKey);
   }
 
   /**
@@ -863,8 +1072,7 @@ public class SerialGatewaySenderQueue implements RegionQueue {
       final RegionAttributes<Long, AsyncEvent> ra = factory.getCreateAttributes();
       try {
         SerialGatewaySenderQueueMetaRegion meta =
-            new SerialGatewaySenderQueueMetaRegion(this.regionName, ra, null, gemCache, sender,
-                sender.getStatisticsClock());
+            metaRegionFactory.newMetaRegion(gemCache, this.regionName, ra, sender);
         factory
             .setInternalMetaRegion(meta)
             .setDestroyLockFlag(true)
@@ -876,6 +1084,7 @@ public class SerialGatewaySenderQueue implements RegionQueue {
         region = factory.create(regionName);
         // Add overflow statistics to the mbean
         addOverflowStatisticsToMBean(gemCache, sender);
+
         if (logger.isDebugEnabled()) {
           logger.debug("{}: Created queue region: {}", this, this.region);
         }
@@ -885,12 +1094,17 @@ public class SerialGatewaySenderQueue implements RegionQueue {
             e);
       }
     } else {
-      throw new IllegalStateException(
-          "Queue region " + this.regionName + " already exists.");
+      if (listener != null) {
+        addCacheListener(listener);
+      }
+    }
+    if ((this.region != null) && this.cleanQueues) {
+      this.region.clear();
     }
   }
 
-  private void addOverflowStatisticsToMBean(Cache cache, AbstractGatewaySender sender) {
+  @VisibleForTesting
+  protected void addOverflowStatisticsToMBean(Cache cache, AbstractGatewaySender sender) {
     // Get the appropriate mbean and add the overflow stats to it
     LocalRegion lr = (LocalRegion) this.region;
     ManagementService service = ManagementService.getManagementService(cache);
@@ -941,6 +1155,7 @@ public class SerialGatewaySenderQueue implements RegionQueue {
       } catch (RegionDestroyedException e) {
       }
     }
+
   }
 
   private class BatchRemovalThread extends Thread {
@@ -1205,6 +1420,18 @@ public class SerialGatewaySenderQueue implements RegionQueue {
     }
   }
 
+  static class MetaRegionFactory {
+    SerialGatewaySenderQueueMetaRegion newMetaRegion(InternalCache cache,
+        final String regionName,
+        final RegionAttributes ra,
+        AbstractGatewaySender sender) {
+      SerialGatewaySenderQueueMetaRegion meta =
+          new SerialGatewaySenderQueueMetaRegion(regionName, ra, null, cache, sender,
+              sender.getStatisticsClock());
+      return meta;
+    }
+  }
+
   public String displayContent() {
     return this.region.keySet().toString();
   }
