@@ -15,6 +15,7 @@
 package org.apache.geode.internal.cache.xmlcache;
 
 import static java.lang.String.format;
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.internal.logging.LogWriterFactory.toSecurityLogWriter;
 import static org.apache.geode.internal.statistics.StatisticsClockFactory.disabledClock;
 import static org.apache.geode.logging.internal.spi.LogWriterLevel.ALL;
@@ -39,6 +40,7 @@ import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.Executor;
 import java.util.concurrent.TimeUnit;
+import java.util.stream.Stream;
 
 import javax.naming.Context;
 import javax.transaction.TransactionManager;
@@ -160,6 +162,7 @@ import org.apache.geode.internal.cache.wan.AbstractGatewaySender;
 import org.apache.geode.internal.cache.wan.InternalGatewaySenderFactory;
 import org.apache.geode.internal.cache.wan.WANServiceProvider;
 import org.apache.geode.internal.jndi.JNDIInvoker;
+import org.apache.geode.internal.lang.SystemPropertyHelper;
 import org.apache.geode.internal.logging.InternalLogWriter;
 import org.apache.geode.internal.logging.LocalLogWriter;
 import org.apache.geode.internal.offheap.MemoryAllocator;
@@ -189,6 +192,10 @@ public class CacheCreation implements InternalCache {
   @Immutable
   private static final RegionAttributes defaults = new AttributesFactory().create();
 
+  @Immutable
+  private static final Optional<Boolean> parallelDiskStoreRecovery = SystemPropertyHelper
+      .getProductBooleanProperty(SystemPropertyHelper.PARALLEL_DISK_STORE_RECOVERY);
+
   /**
    * Store the current CacheCreation that is doing a create. Used from PoolManager to defer to
    * CacheCreation as a manager of pools.
@@ -521,12 +528,7 @@ public class CacheCreation implements InternalCache {
 
     cache.initializePdxRegistry();
 
-    for (DiskStore diskStore : diskStores.values()) {
-      DiskStoreAttributesCreation creation = (DiskStoreAttributesCreation) diskStore;
-      if (creation != pdxRegDSC) {
-        createDiskStore(creation, cache);
-      }
-    }
+    createDiskStores(cache, pdxRegDSC);
 
     if (hasDynamicRegionFactory()) {
       DynamicRegionFactory.get().open(getDynamicRegionFactoryConfig());
@@ -635,6 +637,21 @@ public class CacheCreation implements InternalCache {
     extensionPoint.fireCreate(cache);
   }
 
+  private void createDiskStores(InternalCache cache, DiskStoreAttributesCreation pdxRegDSC) {
+    Stream<DiskStore> diskStoreStream;
+    if (parallelDiskStoreRecovery.orElse(true)) {
+      diskStoreStream = diskStores.values().parallelStream();
+    } else {
+      diskStoreStream = diskStores.values().stream();
+    }
+    diskStoreStream.forEach(diskStore -> {
+      DiskStoreAttributesCreation creation = (DiskStoreAttributesCreation) diskStore;
+      if (creation != pdxRegDSC) {
+        createDiskStore(creation, cache);
+      }
+    });
+  }
+
   public void initializeDeclarablesMap(InternalCache cache) {
     for (DeclarableAndProperties struct : declarablePropertiesList) {
       Declarable declarable = struct.getDeclarable();
@@ -1088,6 +1105,16 @@ public class CacheCreation implements InternalCache {
     return queryService;
   }
 
+  @Override
+  public void lockDiskStore(String diskStoreName) {
+
+  }
+
+  @Override
+  public void unlockDiskStore(String diskStoreName) {
+
+  }
+
   public QueryConfigurationServiceCreation getQueryConfigurationServiceCreation() {
     return queryConfigurationServiceCreation;
   }
@@ -1161,8 +1188,9 @@ public class CacheCreation implements InternalCache {
 
   @Override
   public Region getRegion(String path) {
-    if (path.contains("/")) {
-      throw new UnsupportedOperationException("Region path '" + path + "' contains '/'");
+    if (path.contains(SEPARATOR)) {
+      throw new UnsupportedOperationException(
+          "Region path '" + path + "' contains '" + SEPARATOR + "'");
     }
     return roots.get(path);
   }
