@@ -113,10 +113,10 @@ public class RegionCreation implements Region, Extensible<Region<?, ?>> {
   public RegionCreation(CacheCreation cache, RegionCreation parent, String name, String refid) {
     this.cache = cache;
     if (parent != null) {
-      this.fullPath = parent.getFullPath() + SEPARATOR + name;
+      this.fullPath = parent.getFullPath() + Region.SEPARATOR + name;
 
     } else {
-      this.fullPath = SEPARATOR + name;
+      this.fullPath = Region.SEPARATOR + name;
     }
     this.name = name;
     this.refid = refid;
