@@ -489,7 +489,7 @@ public class ArchiveSplitter implements StatArchiveFormat {
     }
 
     @Override
-    public void reset() throws IOException {
+    public synchronized void reset() throws IOException {
       idx = 0;
       super.reset();
     }
