@@ -123,13 +123,15 @@ public class LinuxProcFsStatistics {
     if (pid == 0) {
       return;
     }
-    InputStreamReader isr = null;
-    BufferedReader br = null;
+
     try {
       File file = new File("/proc/" + pid + "/stat");
-      isr = new InputStreamReader(new FileInputStream(file));
-      br = new BufferedReader(isr, 2048);
-      String line = br.readLine();
+      String line;
+      try (FileInputStream fileInputStream = new FileInputStream(file);
+          InputStreamReader isr = new InputStreamReader(fileInputStream);
+          BufferedReader br = new BufferedReader(isr, 2048)) {
+        line = br.readLine();
+      }
       if (line == null) {
         return;
       }
@@ -150,12 +152,6 @@ public class LinuxProcFsStatistics {
       // as they are.
     } finally {
       tokenizer.releaseResources();
-      if (br != null) {
-        try {
-          br.close();
-        } catch (IOException ignore) {
-        }
-      }
     }
   }
 
@@ -166,12 +162,11 @@ public class LinuxProcFsStatistics {
     }
     stats.setLong(LinuxSystemStats.processesLONG, getProcessCount());
     stats.setLong(LinuxSystemStats.cpusLONG, sys_cpus);
-    InputStreamReader isr = null;
-    BufferedReader br = null;
-    try {
-      isr = new InputStreamReader(new FileInputStream("/proc/stat"));
-      br = new BufferedReader(isr);
-      String line = null;
+    try (FileInputStream fileInputStream = new FileInputStream("/proc/stat");
+        InputStreamReader isr = new InputStreamReader(fileInputStream);
+        BufferedReader br = new BufferedReader(isr)) {
+
+      String line;
       while ((line = br.readLine()) != null) {
         try {
           if (line.startsWith(CPU_TOKEN)) {
@@ -212,14 +207,7 @@ public class LinuxProcFsStatistics {
           // just do not update what ever entry had the problem
         }
       }
-    } catch (IOException ioe) {
-    } finally {
-      if (br != null) {
-        try {
-          br.close();
-        } catch (IOException ignore) {
-        }
-      }
+    } catch (IOException ignore) {
     }
     getLoadAvg(stats);
     getMemInfo(stats);
@@ -235,11 +223,9 @@ public class LinuxProcFsStatistics {
   // Example of /proc/loadavg
   // 0.00 0.00 0.07 1/218 7907
   private static void getLoadAvg(LocalStatisticsImpl stats) {
-    InputStreamReader isr = null;
-    BufferedReader br = null;
-    try {
-      isr = new InputStreamReader(new FileInputStream("/proc/loadavg"));
-      br = new BufferedReader(isr, 512);
+    try (FileInputStream fileInputStream = new FileInputStream("/proc/loadavg");
+        InputStreamReader isr = new InputStreamReader(fileInputStream);
+        BufferedReader br = new BufferedReader(isr, 512)) {
       String line = br.readLine();
       if (line == null) {
         return;
@@ -248,16 +234,9 @@ public class LinuxProcFsStatistics {
       stats.setDouble(LinuxSystemStats.loadAverage1DOUBLE, tokenizer.nextTokenAsDouble());
       stats.setDouble(LinuxSystemStats.loadAverage5DOUBLE, tokenizer.nextTokenAsDouble());
       stats.setDouble(LinuxSystemStats.loadAverage15DOUBLE, tokenizer.nextTokenAsDouble());
-    } catch (NoSuchElementException nsee) {
-    } catch (IOException ioe) {
+    } catch (NoSuchElementException | IOException ignore) {
     } finally {
       tokenizer.releaseResources();
-      if (br != null) {
-        try {
-          br.close();
-        } catch (IOException ignore) {
-        }
-      }
     }
   }
 
@@ -268,27 +247,24 @@ public class LinuxProcFsStatistics {
    * @return the available memory in bytes
    */
   public static long getAvailableMemory(Logger logger) {
-    try {
-      BufferedReader br =
-          new BufferedReader(new InputStreamReader(new FileInputStream("/proc/meminfo")));
-      try {
-        long free = 0;
-        Pattern p = Pattern.compile("(.*)?:\\s+(\\d+)( kB)?");
+    long free = 0;
+    Pattern p = Pattern.compile("(.*)?:\\s+(\\d+)( kB)?");
 
-        String line;
-        while ((line = br.readLine()) != null) {
-          Matcher m = p.matcher(line);
-          if (m.matches() && ("MemFree".equals(m.group(1)) || "Cached".equals(m.group(1)))) {
-            free += Long.parseLong(m.group(2));
-          }
+    try (FileInputStream fileInputStream = new FileInputStream("/proc/meminfo");
+        InputStreamReader inputStreamReader = new InputStreamReader(fileInputStream);
+        BufferedReader br = new BufferedReader(inputStreamReader)) {
+
+      String line;
+      while ((line = br.readLine()) != null) {
+        Matcher m = p.matcher(line);
+        if (m.matches() && ("MemFree".equals(m.group(1)) || "Cached".equals(m.group(1)))) {
+          free += Long.parseLong(m.group(2));
         }
-
-        // convert to bytes
-        return 1024 * free;
-
-      } finally {
-        br.close();
       }
+
+      // convert to bytes
+      return 1024 * free;
+
     } catch (IOException e) {
       logger.warn("Error determining free memory", e);
       return Long.MAX_VALUE;
@@ -300,11 +276,9 @@ public class LinuxProcFsStatistics {
   // Mem: 4118380544 3816050688 302329856 0 109404160 3060326400
   // Swap: 4194881536 127942656 4066938880
   private static void getMemInfo(LocalStatisticsImpl stats) {
-    InputStreamReader isr = null;
-    BufferedReader br = null;
-    try {
-      isr = new InputStreamReader(new FileInputStream("/proc/meminfo"));
-      br = new BufferedReader(isr);
+    try (FileInputStream fileInputStream = new FileInputStream("/proc/meminfo");
+        InputStreamReader isr = new InputStreamReader(fileInputStream);
+        BufferedReader br = new BufferedReader(isr)) {
       // Assume all values read in are in kB, convert to MB
       String line = null;
       while ((line = br.readLine()) != null) {
@@ -352,15 +326,9 @@ public class LinuxProcFsStatistics {
           // ignore and let that stat not to be updated this time
         }
       }
-    } catch (IOException ioe) {
+    } catch (IOException ignore) {
     } finally {
       tokenizer.releaseResources();
-      if (br != null) {
-        try {
-          br.close();
-        } catch (IOException ignore) {
-        }
-      }
     }
   }
 
@@ -413,9 +381,9 @@ public class LinuxProcFsStatistics {
       }
 
       if (!soMaxConnProcessed) {
-        try (InputStreamReader soMaxConnIsr =
-            new InputStreamReader(new FileInputStream("/proc/sys/net/core/somaxconn"))) {
-          BufferedReader br2 = new BufferedReader(soMaxConnIsr);
+        try (FileInputStream fileInputStream2 = new FileInputStream("/proc/sys/net/core/somaxconn");
+            InputStreamReader soMaxConnIsr = new InputStreamReader(fileInputStream2);
+            BufferedReader br2 = new BufferedReader(soMaxConnIsr)) {
           line = br2.readLine();
           tokenizer.setString(line);
           soMaxConn = tokenizer.nextTokenAsInt();
@@ -439,11 +407,9 @@ public class LinuxProcFsStatistics {
    */
 
   private static void getNetStats(LocalStatisticsImpl stats) {
-    InputStreamReader isr = null;
-    BufferedReader br = null;
-    try {
-      isr = new InputStreamReader(new FileInputStream("/proc/net/dev"));
-      br = new BufferedReader(isr);
+    try (FileInputStream fileInputStream = new FileInputStream("/proc/net/dev");
+        InputStreamReader isr = new InputStreamReader(fileInputStream);
+        BufferedReader br = new BufferedReader(isr)) {
       br.readLine(); // Discard header info
       br.readLine(); // Discard header info
       long lo_recv_packets = 0, lo_recv_bytes = 0;
@@ -454,7 +420,7 @@ public class LinuxProcFsStatistics {
       String line = null;
       while ((line = br.readLine()) != null) {
         int index = line.indexOf(":");
-        boolean isloopback = (line.indexOf("lo:") != -1);
+        boolean isloopback = (line.contains("lo:"));
         tokenizer.setString(line.substring(index + 1).trim());
         long recv_bytes = tokenizer.nextTokenAsLong();
         long recv_packets = tokenizer.nextTokenAsLong();
@@ -500,16 +466,9 @@ public class LinuxProcFsStatistics {
       stats.setLong(LinuxSystemStats.xmitErrorsLONG, other_xmit_errs);
       stats.setLong(LinuxSystemStats.xmitDropsLONG, other_xmit_drop);
       stats.setLong(LinuxSystemStats.xmitCollisionsLONG, other_xmit_colls);
-    } catch (NoSuchElementException nsee) {
-    } catch (IOException ioe) {
+    } catch (NoSuchElementException | IOException ignore) {
     } finally {
       tokenizer.releaseResources();
-      if (br != null) {
-        try {
-          br.close();
-        } catch (IOException ignore) {
-        }
-      }
     }
   }
 
@@ -627,10 +586,7 @@ public class LinuxProcFsStatistics {
       stats.setLong(LinuxSystemStats.iosInProgressLONG, iosInProgress);
       stats.setLong(LinuxSystemStats.timeIosInProgressLONG, timeIosInProgress);
       stats.setLong(LinuxSystemStats.ioTimeLONG, ioTime);
-    } catch (NoSuchElementException nsee) {
-      // org.apache.geode.distributed.internal.InternalDistributedSystem.getAnyInstance().getLogger().fine("unexpected
-      // NoSuchElementException line=" + line, nsee);
-    } catch (IOException ioe) {
+    } catch (NoSuchElementException | IOException ignore) {
     } finally {
       tokenizer.releaseResources();
       if (br != null) {
@@ -639,6 +595,12 @@ public class LinuxProcFsStatistics {
         } catch (IOException ignore) {
         }
       }
+      if (isr != null) {
+        try {
+          isr.close();
+        } catch (IOException ignore) {
+        }
+      }
     }
   }
 
@@ -650,11 +612,9 @@ public class LinuxProcFsStatistics {
   // pswpout 14495
   private static void getVmStats(LocalStatisticsImpl stats) {
     assert hasProcVmStat != false : "getVmStats called when hasVmStat was false";
-    InputStreamReader isr = null;
-    BufferedReader br = null;
-    try {
-      isr = new InputStreamReader(new FileInputStream("/proc/vmstat"));
-      br = new BufferedReader(isr);
+    try (FileInputStream fileInputStream = new FileInputStream("/proc/vmstat");
+        InputStreamReader isr = new InputStreamReader(fileInputStream);
+        BufferedReader br = new BufferedReader(isr)) {
       String line = null;
       while ((line = br.readLine()) != null) {
         if (line.startsWith(PGPGIN)) {
@@ -671,15 +631,7 @@ public class LinuxProcFsStatistics {
               SpaceTokenizer.parseAsLong(line.substring(PSWPOUT.length())));
         }
       }
-    } catch (NoSuchElementException nsee) {
-    } catch (IOException ioe) {
-    } finally {
-      if (br != null) {
-        try {
-          br.close();
-        } catch (IOException ignore) {
-        }
-      }
+    } catch (NoSuchElementException | IOException ignore) {
     }
   }
 
