@@ -1274,6 +1274,13 @@ public class DistributedSystemBridge {
     return senderMonitor.getGatewaySenderEventsQueuedRate();
   }
 
+  /**
+   * @return total batches distributed
+   */
+  public int getGatewaySenderTotalBatchesDistributed() {
+    return senderMonitor.getGatewaySenderTotalBatchesDistributed();
+  }
+
   /**
    * @return total batches redistributed
    */
@@ -1281,6 +1288,13 @@ public class DistributedSystemBridge {
     return senderMonitor.getGatewaySenderTotalBatchesRedistributed();
   }
 
+  /**
+   * @return total batches with incomplete transactions
+   */
+  public int getGatewaySenderTotalBatchesWithIncompleteTransactions() {
+    return senderMonitor.getGatewaySenderTotalBatchesWithIncompleteTransactions();
+  }
+
   /**
    * @return total number of events conflated
    */
