@@ -40,6 +40,7 @@ import static org.apache.geode.management.JMXNotificationType.GATEWAY_SENDER_STO
 import static org.apache.geode.management.JMXNotificationType.LOCATOR_STARTED;
 import static org.apache.geode.management.JMXNotificationType.LOCK_SERVICE_CLOSED;
 import static org.apache.geode.management.JMXNotificationType.LOCK_SERVICE_CREATED;
+import static org.apache.geode.management.JMXNotificationType.MANAGER_STARTED;
 import static org.apache.geode.management.JMXNotificationType.REGION_CLOSED;
 import static org.apache.geode.management.JMXNotificationType.REGION_CREATED;
 import static org.apache.geode.management.JMXNotificationType.SYSTEM_ALERT;
@@ -71,6 +72,7 @@ import static org.apache.geode.management.internal.ManagementConstants.GATEWAY_S
 import static org.apache.geode.management.internal.ManagementConstants.LOCATOR_STARTED_PREFIX;
 import static org.apache.geode.management.internal.ManagementConstants.LOCK_SERVICE_CLOSED_PREFIX;
 import static org.apache.geode.management.internal.ManagementConstants.LOCK_SERVICE_CREATED_PREFIX;
+import static org.apache.geode.management.internal.ManagementConstants.MANAGER_STARTED_PREFIX;
 import static org.apache.geode.management.internal.ManagementConstants.REGION_CLOSED_PREFIX;
 import static org.apache.geode.management.internal.ManagementConstants.REGION_CREATED_PREFIX;
 
@@ -343,7 +345,12 @@ public class ManagementAdapter {
     ManagerMBeanBridge managerMBeanBridge = new ManagerMBeanBridge(service);
     ManagerMXBean managerMXBean = new ManagerMBean(managerMBeanBridge);
 
-    service.registerInternalMBean(managerMXBean, objectName);
+    ObjectName federatedName = service.registerInternalMBean(managerMXBean, objectName);
+    service.federate(federatedName, ManagerMXBean.class, true);
+
+    Notification notification = new Notification(MANAGER_STARTED, memberSource,
+        SequenceNumber.next(), System.currentTimeMillis(), MANAGER_STARTED_PREFIX);
+    memberLevelNotificationEmitter.sendNotification(notification);
   }
 
   /**
