@@ -14,6 +14,8 @@
  */
 package org.apache.geode.management.internal.operation;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
+
 import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -24,6 +26,7 @@ import java.util.List;
 import java.util.Set;
 
 import org.apache.commons.collections.CollectionUtils;
+import org.jetbrains.annotations.NotNull;
 
 import org.apache.geode.annotations.Experimental;
 import org.apache.geode.annotations.VisibleForTesting;
@@ -37,7 +40,7 @@ import org.apache.geode.cache.execute.Function;
 import org.apache.geode.distributed.DistributedMember;
 import org.apache.geode.distributed.internal.membership.InternalDistributedMember;
 import org.apache.geode.internal.cache.InternalCache;
-import org.apache.geode.internal.serialization.Version;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.management.DistributedRegionMXBean;
 import org.apache.geode.management.ManagementService;
 import org.apache.geode.management.internal.MBeanJMXAdapter;
@@ -105,7 +108,7 @@ public class RebalanceOperationPerformer
       boolean simulate)
       throws InterruptedException {
     // To be removed after region Name specification with "/" is fixed
-    regionName = regionName.startsWith("/") ? regionName : ("/" + regionName);
+    regionName = regionName.startsWith(SEPARATOR) ? regionName : (SEPARATOR + regionName);
     Region region = cache.getRegion(regionName);
 
     if (region == null) {
@@ -159,7 +162,7 @@ public class RebalanceOperationPerformer
 
       // translate to the return type we want
       RebalanceRegionResultImpl result = new RebalanceRegionResultImpl();
-      result.setRegionName(regionName.replace("/", ""));
+      result.setRegionName(regionName.replace(SEPARATOR, ""));
       result.setBucketCreateBytes(results.getTotalBucketCreateBytes());
       result.setBucketCreateTimeInMilliseconds(results.getTotalBucketCreateTime());
       result.setBucketCreatesCompleted(results.getTotalBucketCreatesCompleted());
@@ -221,12 +224,12 @@ public class RebalanceOperationPerformer
         for (String aListExcludedRegion : listExcludedRegion) {
           // this is needed since region name may start with / or without it
           String excludedRegion = aListExcludedRegion.trim();
-          if (regionName.startsWith("/") && !excludedRegion.startsWith("/")) {
-            excludedRegion = "/" + excludedRegion;
+          if (regionName.startsWith(SEPARATOR) && !excludedRegion.startsWith(SEPARATOR)) {
+            excludedRegion = SEPARATOR + excludedRegion;
           }
 
-          if (excludedRegion.startsWith("/") && !regionName.startsWith("/")) {
-            regionName = "/" + regionName;
+          if (excludedRegion.startsWith(SEPARATOR) && !regionName.startsWith(SEPARATOR)) {
+            regionName = SEPARATOR + regionName;
           }
 
           if (excludedRegion.equals(regionName)) {
@@ -241,8 +244,8 @@ public class RebalanceOperationPerformer
         continue;
       }
 
-      if (!regionName.startsWith("/")) {
-        regionName = Region.SEPARATOR + regionName;
+      if (!regionName.startsWith(SEPARATOR)) {
+        regionName = SEPARATOR + regionName;
       }
       // remove this prefix /
       DistributedRegionMXBean bean = managementService.getDistributedRegionMXBean(regionName);
@@ -445,10 +448,11 @@ public class RebalanceOperationPerformer
     return rebalanceResult;
   }
 
+  @NotNull
   private Function getRebalanceFunction(InternalDistributedMember dsMember) {
     Function rebalanceFunction;
-    if (dsMember.getVersionObject()
-        .isOlderThan(Version.GEODE_1_12_0)) {
+    if (dsMember.getVersion()
+        .isOlderThan(KnownVersion.GEODE_1_12_0)) {
       rebalanceFunction =
           new org.apache.geode.management.internal.cli.functions.RebalanceFunction();
     } else {
@@ -470,10 +474,10 @@ public class RebalanceOperationPerformer
     result.setTimeInMilliseconds(Long.parseLong(rstList.get(8)));
     if (rstList.size() < 11) {
       result.setNumOfMembers(-1);
-      result.setRegionName(rstList.get(9).replace("/", ""));
+      result.setRegionName(rstList.get(9).replace(SEPARATOR, ""));
     } else {
       result.setNumOfMembers(Integer.parseInt(rstList.get(9)));
-      result.setRegionName(rstList.get(10).replace("/", ""));
+      result.setRegionName(rstList.get(10).replace(SEPARATOR, ""));
     }
 
 
