@@ -19,6 +19,7 @@
  */
 package org.apache.geode.cache.query;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
@@ -86,52 +87,78 @@ public class BaseLineAndCompareQueryPerfJUnitTest {
 
   String queries[] = {
       // Query 1
-      "SELECT DISTINCT * FROM /Countries c, c.states s, s.districts d,"
+      "SELECT DISTINCT * FROM " + SEPARATOR + "Countries c, c.states s, s.districts d,"
           + " d.villages v, d.cities ct WHERE v.name = 'MAHARASHTRA_VILLAGE1'",
       // Query 2
-      "SELECT DISTINCT * FROM /Countries c, c.states s, s.districts d, d.villages v,"
+      "SELECT DISTINCT * FROM " + SEPARATOR
+          + "Countries c, c.states s, s.districts d, d.villages v,"
           + " d.cities ct WHERE v.name='MAHARASHTRA_VILLAGE1' AND ct.name = 'PUNE'",
       // Query 3
-      "SELECT DISTINCT * FROM /Countries c, c.states s, s.districts d, d.villages v, "
+      "SELECT DISTINCT * FROM " + SEPARATOR
+          + "Countries c, c.states s, s.districts d, d.villages v, "
           + "d.cities ct WHERE ct.name = 'PUNE' AND s.name = 'MAHARASHTRA'",
       // Query 4a & 4b
-      "SELECT DISTINCT * FROM /Countries c WHERE c.name = 'INDIA'",
-      "SELECT DISTINCT * FROM /Countries c, c.states s, s.districts d, d.cities ct, d.villages v WHERE c.name = 'INDIA'",
+      "SELECT DISTINCT * FROM " + SEPARATOR + "Countries c WHERE c.name = 'INDIA'",
+      "SELECT DISTINCT * FROM " + SEPARATOR
+          + "Countries c, c.states s, s.districts d, d.cities ct, d.villages v WHERE c.name = 'INDIA'",
       // Query 5
-      "SELECT DISTINCT * FROM /Countries c, c.states s, s.districts d WHERE d.name = 'PUNEDIST' AND s.name = 'GUJARAT'",
+      "SELECT DISTINCT * FROM " + SEPARATOR
+          + "Countries c, c.states s, s.districts d WHERE d.name = 'PUNEDIST' AND s.name = 'GUJARAT'",
       // Query 6
-      "SELECT DISTINCT * FROM /Countries c, c.states s, s.districts d, d.cities ct WHERE ct.name = 'MUMBAI'",
+      "SELECT DISTINCT * FROM " + SEPARATOR
+          + "Countries c, c.states s, s.districts d, d.cities ct WHERE ct.name = 'MUMBAI'",
       // Query 7
-      "SELECT DISTINCT c.name, s.name, d.name, ct.name FROM /Countries c, c.states s, s.districts d, d.cities ct WHERE ct.name = 'MUMBAI' OR ct.name = 'CHENNAI'",
+      "SELECT DISTINCT c.name, s.name, d.name, ct.name FROM " + SEPARATOR
+          + "Countries c, c.states s, s.districts d, d.cities ct WHERE ct.name = 'MUMBAI' OR ct.name = 'CHENNAI'",
       // Query 8
-      "SELECT DISTINCT c.name, s.name FROM /Countries c, c.states s, s.districts d, d.cities ct WHERE ct.name = 'MUMBAI' AND s.name = 'GUJARAT'",
+      "SELECT DISTINCT c.name, s.name FROM " + SEPARATOR
+          + "Countries c, c.states s, s.districts d, d.cities ct WHERE ct.name = 'MUMBAI' AND s.name = 'GUJARAT'",
 
       //// following are multiregion queries
       // Query 9
-      "SELECT DISTINCT * FROM /Countries1 c1, c1.states s1, s1.districts d1, d1.villages v1, d1.cities ct1, /Countries2 c2, c2.states s2, s2.districts d2, d2.villages v2, d2.cities ct2 WHERE v1.name = 'MAHARASHTRA_VILLAGE1' AND ct2.name = 'MUMBAI' ",
+      "SELECT DISTINCT * FROM " + SEPARATOR
+          + "Countries1 c1, c1.states s1, s1.districts d1, d1.villages v1, d1.cities ct1, "
+          + SEPARATOR
+          + "Countries2 c2, c2.states s2, s2.districts d2, d2.villages v2, d2.cities ct2 WHERE v1.name = 'MAHARASHTRA_VILLAGE1' AND ct2.name = 'MUMBAI' ",
       // Query 10
       // "SELECT DISTINCT * FROM /Countries1 c1, c1.states s1, s1.districts d1, d1.villages v1,
       // d1.cities ct1, /Countries2 c2, c2.states s2, s2.districts d2, d2.villages v2, d2.cities
       // ct2, /Countries3 c3, c3.states s3, s3.districts d3, d3.villages v3, d3.cities ct3 WHERE
       // v1.name='MAHARASHTRA_VILLAGE1' AND ct3.name = 'PUNE'",
       // Query 11
-      "SELECT DISTINCT * FROM /Countries1 c1, /Countries2 c2 WHERE c1.name = 'INDIA' AND c2.name = 'ISRAEL'",
+      "SELECT DISTINCT * FROM " + SEPARATOR + "Countries1 c1, " + SEPARATOR
+          + "Countries2 c2 WHERE c1.name = 'INDIA' AND c2.name = 'ISRAEL'",
       // Query 12
-      "SELECT DISTINCT * FROM /Countries1 c1, c1.states s1, s1.districts d1, d1.cities ct1, d1.villages v1, /Countries2 c2, c2.states s2, s2.districts d2, d2.cities ct2, d2.villages v2 WHERE c1.name = 'INDIA' AND c2.name = 'ISRAEL'",
+      "SELECT DISTINCT * FROM " + SEPARATOR
+          + "Countries1 c1, c1.states s1, s1.districts d1, d1.cities ct1, d1.villages v1, "
+          + SEPARATOR
+          + "Countries2 c2, c2.states s2, s2.districts d2, d2.cities ct2, d2.villages v2 WHERE c1.name = 'INDIA' AND c2.name = 'ISRAEL'",
       // Query 13
-      "SELECT DISTINCT * FROM /Countries1 c1, c1.states s1, s1.districts d1, /Countries2 c2, c2.states s2, s2.districts d2, /Countries3 c3, c3.states s3, s3.districts d3 WHERE d3.name = 'PUNEDIST' AND s2.name = 'GUJARAT'",
+      "SELECT DISTINCT * FROM " + SEPARATOR + "Countries1 c1, c1.states s1, s1.districts d1, "
+          + SEPARATOR + "Countries2 c2, c2.states s2, s2.districts d2, " + SEPARATOR
+          + "Countries3 c3, c3.states s3, s3.districts d3 WHERE d3.name = 'PUNEDIST' AND s2.name = 'GUJARAT'",
       // Query 14
-      "SELECT DISTINCT c1.name, s1.name, d2.name, ct2.name FROM /Countries1 c1, c1.states s1, s1.districts d1, d1.cities ct1, /Countries2 c2, c2.states s2, s2.districts d2, d2.cities ct2 WHERE ct1.name = 'MUMBAI' OR ct2.name = 'CHENNAI'",
+      "SELECT DISTINCT c1.name, s1.name, d2.name, ct2.name FROM " + SEPARATOR
+          + "Countries1 c1, c1.states s1, s1.districts d1, d1.cities ct1, " + SEPARATOR
+          + "Countries2 c2, c2.states s2, s2.districts d2, d2.cities ct2 WHERE ct1.name = 'MUMBAI' OR ct2.name = 'CHENNAI'",
       // Query 15
-      "SELECT DISTINCT c1.name, s1.name, ct1.name FROM /Countries1 c1, c1.states s1, (SELECT DISTINCT * FROM /Countries2 c2, c2.states s2, s2.districts d2, d2.cities ct2 WHERE s2.name = 'PUNJAB') itr1, s1.districts d1, d1.cities ct1 WHERE ct1.name = 'CHANDIGARH'",
+      "SELECT DISTINCT c1.name, s1.name, ct1.name FROM " + SEPARATOR
+          + "Countries1 c1, c1.states s1, (SELECT DISTINCT * FROM " + SEPARATOR
+          + "Countries2 c2, c2.states s2, s2.districts d2, d2.cities ct2 WHERE s2.name = 'PUNJAB') itr1, s1.districts d1, d1.cities ct1 WHERE ct1.name = 'CHANDIGARH'",
       // Query 16
-      "SELECT DISTINCT c1.name, s1.name, ct1.name FROM /Countries1 c1, c1.states s1, s1.districts d1, d1.cities ct1 WHERE ct1.name = element (SELECT DISTINCT ct3.name FROM /Countries3 c3, c3.states s3, s3.districts d3, d3.cities ct3 WHERE s3.name = 'MAHARASHTRA' AND ct3.name = 'PUNE')",
+      "SELECT DISTINCT c1.name, s1.name, ct1.name FROM " + SEPARATOR
+          + "Countries1 c1, c1.states s1, s1.districts d1, d1.cities ct1 WHERE ct1.name = element (SELECT DISTINCT ct3.name FROM "
+          + SEPARATOR
+          + "Countries3 c3, c3.states s3, s3.districts d3, d3.cities ct3 WHERE s3.name = 'MAHARASHTRA' AND ct3.name = 'PUNE')",
       // Query 17
-      "SELECT DISTINCT c1.name, s1.name, ct1.name FROM /Countries1 c1, c1.states s1, s1.districts d1, d1.cities ct1, d1.getVillages() v1 WHERE v1.getName() = 'PUNJAB_VILLAGE1'",
+      "SELECT DISTINCT c1.name, s1.name, ct1.name FROM " + SEPARATOR
+          + "Countries1 c1, c1.states s1, s1.districts d1, d1.cities ct1, d1.getVillages() v1 WHERE v1.getName() = 'PUNJAB_VILLAGE1'",
       // Query 18
-      "SELECT DISTINCT s.name, s.getDistricts(), ct.getName() FROM /Countries1 c, c.getStates() s, s.getDistricts() d, d.getCities() ct WHERE ct.getName() = 'PUNE' OR ct.name = 'CHANDIGARH' OR s.getName() = 'GUJARAT'",
+      "SELECT DISTINCT s.name, s.getDistricts(), ct.getName() FROM " + SEPARATOR
+          + "Countries1 c, c.getStates() s, s.getDistricts() d, d.getCities() ct WHERE ct.getName() = 'PUNE' OR ct.name = 'CHANDIGARH' OR s.getName() = 'GUJARAT'",
       // Query 19
-      "SELECT DISTINCT d.getName(), d.getCities(), d.getVillages() FROM /Countries3 c, c.states s, s.districts d WHERE d.name = 'MUMBAIDIST'"
+      "SELECT DISTINCT d.getName(), d.getCities(), d.getVillages() FROM " + SEPARATOR
+          + "Countries3 c, c.states s, s.districts d WHERE d.name = 'MUMBAIDIST'"
 
       // Query 9a & 9b
       // "SELECT DISTINCT c.name, s.name, ct.name FROM /Countries c, c.states s, (SELECT DISTINCT *
@@ -267,7 +294,8 @@ public class BaseLineAndCompareQueryPerfJUnitTest {
       for (int i = 0; i < 25000; ++i) {
         region.create(new Integer(i + 1), new Portfolio(i));
       }
-      String queryStr = "select  * from /Portfolio pf where pf.getID  > 10000 and pf.getID < 12000";
+      String queryStr = "select  * from " + SEPARATOR
+          + "Portfolio pf where pf.getID  > 10000 and pf.getID < 12000";
 
       SelectResults r[][] = new SelectResults[1][2];
       QueryService qs = CacheUtils.getQueryService();
@@ -291,7 +319,7 @@ public class BaseLineAndCompareQueryPerfJUnitTest {
       r[0][0] = sr;
       t1 = ((float) (time)) / numTimesToRun;
       CacheUtils.log("AVG time taken without Index =" + t1);
-      qs.createIndex("ID", IndexType.FUNCTIONAL, "pf.getID", "/Portfolio pf");
+      qs.createIndex("ID", IndexType.FUNCTIONAL, "pf.getID", SEPARATOR + "Portfolio pf");
       for (int i = 0; i < 5; ++i) {
         qry.execute();
       }
@@ -377,36 +405,36 @@ public class BaseLineAndCompareQueryPerfJUnitTest {
     // c.states s,
     // s.districts d, d.cities ct, d.villages v");
     qs.createIndex("cityName", IndexType.FUNCTIONAL, "ct.name",
-        "/Countries c, c.states s, s.districts d, d.cities ct, d.villages v");//
+        SEPARATOR + "Countries c, c.states s, s.districts d, d.cities ct, d.villages v");//
     qs.createIndex("districtName", IndexType.FUNCTIONAL, "d.name",
-        "/Countries c, c.states s, s.districts d, d.cities ct, d.villages v");
+        SEPARATOR + "Countries c, c.states s, s.districts d, d.cities ct, d.villages v");
     qs.createIndex("stateName", IndexType.FUNCTIONAL, "s.name",
-        "/Countries c, c.states s, s.districts d, d.cities ct, d.villages v");
+        SEPARATOR + "Countries c, c.states s, s.districts d, d.cities ct, d.villages v");
     qs.createIndex("countryName", IndexType.FUNCTIONAL, "c.name",
-        "/Countries c, c.states s, s.districts d, d.cities ct, d.villages v");
+        SEPARATOR + "Countries c, c.states s, s.districts d, d.cities ct, d.villages v");
 
     /* Indices on region1 */
     qs.createIndex("villageName1", IndexType.FUNCTIONAL, "v.name",
-        "/Countries1 c, c.states s, s.districts d, d.cities ct, d.villages v");
+        SEPARATOR + "Countries1 c, c.states s, s.districts d, d.cities ct, d.villages v");
     qs.createIndex("cityName1", IndexType.FUNCTIONAL, "ct.name",
-        "/Countries1 c, c.states s, s.districts d, d.cities ct, d.villages v");
+        SEPARATOR + "Countries1 c, c.states s, s.districts d, d.cities ct, d.villages v");
     qs.createIndex("countryNameA", IndexType.FUNCTIONAL, "c.name",
-        "/Countries1 c, c.states s, s.districts d, d.cities ct, d.villages v");
-    qs.createIndex("countryNameB", IndexType.FUNCTIONAL, "c.name", "/Countries1 c");
+        SEPARATOR + "Countries1 c, c.states s, s.districts d, d.cities ct, d.villages v");
+    qs.createIndex("countryNameB", IndexType.FUNCTIONAL, "c.name", SEPARATOR + "Countries1 c");
 
     /* Indices on region2 */
     qs.createIndex("stateName2", IndexType.FUNCTIONAL, "s.name",
-        "/Countries2 c, c.states s, s.districts d, d.cities ct, d.villages v");
+        SEPARATOR + "Countries2 c, c.states s, s.districts d, d.cities ct, d.villages v");
     qs.createIndex("cityName2", IndexType.FUNCTIONAL, "ct.name",
-        "/Countries2 c, c.states s, s.districts d, d.cities ct, d.villages v");
+        SEPARATOR + "Countries2 c, c.states s, s.districts d, d.cities ct, d.villages v");
 
     /* Indices on region3 */
     qs.createIndex("districtName3", IndexType.FUNCTIONAL, "d.name",
-        "/Countries3 c, c.states s, s.districts d, d.cities ct, d.villages v");
+        SEPARATOR + "Countries3 c, c.states s, s.districts d, d.cities ct, d.villages v");
     qs.createIndex("villageName3", IndexType.FUNCTIONAL, "v.name",
-        "/Countries3 c, c.states s, s.districts d, d.cities ct, d.villages v");
+        SEPARATOR + "Countries3 c, c.states s, s.districts d, d.cities ct, d.villages v");
     qs.createIndex("cityName3", IndexType.FUNCTIONAL, "ct.name",
-        "/Countries3 c, c.states s, s.districts d, d.cities ct, d.villages v");
+        SEPARATOR + "Countries3 c, c.states s, s.districts d, d.cities ct, d.villages v");
 
     CacheUtils.log("Indices are created");
 
