@@ -14,6 +14,7 @@
  */
 package org.apache.geode.internal.cache.rollingupgrade;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.apache.geode.test.dunit.Assert.assertEquals;
 import static org.apache.geode.test.dunit.Assert.assertFalse;
@@ -347,7 +348,8 @@ public abstract class RollingUpgrade2DUnitTestBase extends JUnit4DistributedTest
 
       putDataSerializableAndVerify(currentServer1, regionName, 0, 100, currentServer2, oldServer,
           oldServerAndLocator);
-      query("Select * from /" + regionName + " p where p.timeout > 0L", 99, currentServer1,
+      query("Select * from " + SEPARATOR + regionName + " p where p.timeout > 0L", 99,
+          currentServer1,
           currentServer2, oldServer, oldServerAndLocator);
 
     } finally {
@@ -410,9 +412,9 @@ public abstract class RollingUpgrade2DUnitTestBase extends JUnit4DistributedTest
       putDataSerializableAndVerify(currentServer1, regionName, 0, 100, currentServer2, oldServer,
           oldServerAndLocator);
       if (createMultiIndexes) {
-        doCreateIndexes("/" + regionName, currentServer1);
+        doCreateIndexes(SEPARATOR + regionName, currentServer1);
       } else {
-        doCreateIndex("/" + regionName, oldServer);
+        doCreateIndex(SEPARATOR + regionName, oldServer);
       }
     } finally {
       invokeRunnableInVMs(invokeCloseCache(), currentServer1, currentServer2, oldServer,
@@ -1071,7 +1073,7 @@ public abstract class RollingUpgrade2DUnitTestBase extends JUnit4DistributedTest
   private static void assertVersion(GemFireCache cache, short ordinal) {
     DistributedSystem system = cache.getDistributedSystem();
     int thisOrdinal =
-        ((InternalDistributedMember) system.getDistributedMember()).getVersionOrdinalObject()
+        ((InternalDistributedMember) system.getDistributedMember()).getVersion()
             .ordinal();
     if (ordinal != thisOrdinal) {
       throw new Error(
