@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.query.cq.dunit;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.fail;
 
@@ -54,7 +55,7 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
 
   protected CqQueryUsingPoolDUnitTest cqDUnitTest = new CqQueryUsingPoolDUnitTest();
 
-  private final String selStr = "SELECT * FROM /root/regionA";
+  private final String selStr = "SELECT * FROM " + SEPARATOR + "root" + SEPARATOR + "regionA";
 
   /** Supported queries */
   public final String[] condition = new String[] {/* 0 */ " p WHERE p.ID > 3",
@@ -92,10 +93,12 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
 
   /** Unsupported queries */
   public final String[] condition2 =
-      new String[] {/* 0 */ " p1, /root/regionB p2 WHERE p1.status = p2.status",
+      new String[] {/* 0 */ " p1, " + SEPARATOR + "root" + SEPARATOR
+          + "regionB p2 WHERE p1.status = p2.status",
           /* 1 */ " p, p.positions.values p1 WHERE p1.secId = 'IBM'",
           /* 2 */ " p, p.positions.values AS pos WHERE pos.secId != '1'",
-          /* 3 */ " p WHERE p.ID in (SELECT p1.ID FROM /root/regionA p1 WHERE p1.ID > 3)",
+          /* 3 */ " p WHERE p.ID in (SELECT p1.ID FROM " + SEPARATOR + "root" + SEPARATOR
+              + "regionA p1 WHERE p1.ID > 3)",
           /* 4 */ ".entries entry WHERE entry.key = '1'",
           /* 5 */ ".entries entry WHERE entry.value.ID > '3'",
           /* 6 */ ".values p WHERE p.ID > '3' and p.status = 'active'",
@@ -198,10 +201,12 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     cqDUnitTest.createClient(client, port, host0);
 
     // Create index.
-    cqDUnitTest.createFunctionalIndex(server, "IdIndex", "p.ID", "/root/regionA p");
-    cqDUnitTest.createFunctionalIndex(server, "statusIndex", "p.status", "/root/regionA p");
+    cqDUnitTest.createFunctionalIndex(server, "IdIndex", "p.ID",
+        SEPARATOR + "root" + SEPARATOR + "regionA p");
+    cqDUnitTest.createFunctionalIndex(server, "statusIndex", "p.status",
+        SEPARATOR + "root" + SEPARATOR + "regionA p");
     cqDUnitTest.createFunctionalIndex(server, "portfolioIdIndex", "p.position1.portfolioId",
-        "/root/regionA p");
+        SEPARATOR + "root" + SEPARATOR + "regionA p");
 
     // Put 5 entries into the region.
     cqDUnitTest.createValues(server, "regionA", 5);
@@ -250,10 +255,12 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
       }
     });
 
-    cqDUnitTest.createFunctionalIndex(server, "IdIndex", "p.ID", "/root/regionA p");
-    cqDUnitTest.createFunctionalIndex(server, "statusIndex", "p.status", "/root/regionA p");
+    cqDUnitTest.createFunctionalIndex(server, "IdIndex", "p.ID",
+        SEPARATOR + "root" + SEPARATOR + "regionA p");
+    cqDUnitTest.createFunctionalIndex(server, "statusIndex", "p.status",
+        SEPARATOR + "root" + SEPARATOR + "regionA p");
     cqDUnitTest.createFunctionalIndex(server, "portfolioIdIndex", "p.position1.portfolioId",
-        "/root/regionA p");
+        SEPARATOR + "root" + SEPARATOR + "regionA p");
 
     // Put 5 entries into the region.
     cqDUnitTest.createValues(server, "regionA", 5);
@@ -360,10 +367,12 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     cqDUnitTest.createClient(client, port, host0);
 
     // Create index.
-    cqDUnitTest.createFunctionalIndex(server1, "IdIndex", "p.ID", "/root/regionA p");
-    cqDUnitTest.createFunctionalIndex(server1, "statusIndex", "p.status", "/root/regionA p");
+    cqDUnitTest.createFunctionalIndex(server1, "IdIndex", "p.ID",
+        SEPARATOR + "root" + SEPARATOR + "regionA p");
+    cqDUnitTest.createFunctionalIndex(server1, "statusIndex", "p.status",
+        SEPARATOR + "root" + SEPARATOR + "regionA p");
     cqDUnitTest.createFunctionalIndex(server1, "portfolioIdIndex", "p.position1.portfolioId",
-        "/root/regionA p");
+        SEPARATOR + "root" + SEPARATOR + "regionA p");
 
     // Put 5 entries into the region.
     cqDUnitTest.createValues(server1, "regionA", 5);
@@ -423,10 +432,12 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
       }
     });
 
-    cqDUnitTest.createFunctionalIndex(server1, "IdIndex", "p.ID", "/root/regionA p");
-    cqDUnitTest.createFunctionalIndex(server1, "statusIndex", "p.status", "/root/regionA p");
+    cqDUnitTest.createFunctionalIndex(server1, "IdIndex", "p.ID",
+        SEPARATOR + "root" + SEPARATOR + "regionA p");
+    cqDUnitTest.createFunctionalIndex(server1, "statusIndex", "p.status",
+        SEPARATOR + "root" + SEPARATOR + "regionA p");
     cqDUnitTest.createFunctionalIndex(server1, "portfolioIdIndex", "p.position1.portfolioId",
-        "/root/regionA p");
+        SEPARATOR + "root" + SEPARATOR + "regionA p");
 
     // Put 5 entries into the region.
     cqDUnitTest.createValues(server1, "regionA", 5);
@@ -493,7 +504,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     server.invoke(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         for (int i = 1; i <= numObjects; i++) {
           Portfolio p = new Portfolio(i);
           region.put("" + i, p);
@@ -505,7 +517,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     server.invokeAsync(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         // Update (totalObjects - 1) entries.
         for (int i = 1; i < totalObjects; i++) {
           // Destroy entries.
@@ -544,7 +557,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
         }
 
         // Wait till all the region update is performed.
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         while (true) {
           if (region.get("" + totalObjects) == null) {
             try {
@@ -622,7 +636,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     server.invoke(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         for (int i = 1; i <= numObjects; i++) {
           Portfolio p = new Portfolio(i);
           region.put("" + i, p);
@@ -634,7 +649,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     server.invokeAsync(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         // Update (totalObjects - 1) entries.
         for (int i = 1; i < totalObjects; i++) {
           // Destroy entries.
@@ -674,7 +690,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
         }
 
         // Wait till all the region update is performed.
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         while (true) {
           if (region.get("" + totalObjects) == null) {
             try {
@@ -748,7 +765,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     server1.invoke(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         for (int i = 1; i <= numObjects; i++) {
           Portfolio p = new Portfolio(i);
           region.put("" + i, p);
@@ -762,7 +780,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     server2.invoke(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         // Update (totalObjects - 1) entries.
         for (int i = 1; i < totalObjects; i++) {
           // Destroy entries.
@@ -848,7 +867,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     server1.invoke(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         for (int i = 1; i <= numObjects; i++) {
           Portfolio p = new Portfolio(i);
           region.put("" + i, p);
@@ -860,7 +880,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     server2.invoke(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         for (int i = 1; i <= numObjects; i++) {
           Portfolio p = new Portfolio(i);
           region.put("" + i, p);
@@ -872,7 +893,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     server2.invoke(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         for (int i = 1; i <= numObjects; i++) {
           Portfolio p = new Portfolio(i);
           region.destroy("" + i);
@@ -967,7 +989,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     server1.invoke(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         for (int i = 1; i <= numObjects; i++) {
           Portfolio p = new Portfolio(i);
           region.put("" + i, p);
@@ -979,7 +1002,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
     server1.invokeAsync(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         // Update (totalObjects - 1) entries.
         for (int i = 1; i < totalObjects; i++) {
           // Destroy entries.
@@ -1018,7 +1042,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
         }
 
         // Wait till all the region update is performed.
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         while (true) {
           if (region.get("" + totalObjects) == null) {
             try {
@@ -1076,7 +1101,8 @@ public class CqResultSetUsingPoolDUnitTest extends JUnit4CacheTestCase {
         }
 
         // Wait till all the region update is performed.
-        Region region = getCache().getRegion("/root/" + cqDUnitTest.regions[0]);
+        Region region =
+            getCache().getRegion(SEPARATOR + "root" + SEPARATOR + cqDUnitTest.regions[0]);
         while (true) {
           if (region.get("" + totalObjects) == null) {
             try {
