@@ -85,38 +85,44 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
 
   public final String[] cqs = new String[] {
       // 0 - Test for ">"
-      "SELECT ALL * FROM /root/" + regions[0] + " p where p.ID > 0",
+      "SELECT ALL * FROM " + SEPARATOR + "root" + SEPARATOR + regions[0] + " p where p.ID > 0",
 
       // 1 - Test for "=" and "and".
-      "SELECT ALL * FROM /root/" + regions[0] + " p where p.ID = 2 and p.status='active'",
+      "SELECT ALL * FROM " + SEPARATOR + "root" + SEPARATOR + regions[0]
+          + " p where p.ID = 2 and p.status='active'",
 
       // 2 - Test for "<" and "and".
-      "SELECT ALL * FROM /root/" + regions[1] + " p where p.ID < 5 and p.status='active'",
+      "SELECT ALL * FROM " + SEPARATOR + "root" + SEPARATOR + regions[1]
+          + " p where p.ID < 5 and p.status='active'",
 
       // FOLLOWING CQS ARE NOT TESTED WITH VALUES; THEY ARE USED TO TEST PARSING LOGIC WITHIN CQ.
       // 3
-      "SELECT * FROM /root/" + regions[0] + " ;",
+      "SELECT * FROM " + SEPARATOR + "root" + SEPARATOR + regions[0] + " ;",
       // 4
-      "SELECT ALL * FROM /root/" + regions[0],
+      "SELECT ALL * FROM " + SEPARATOR + "root" + SEPARATOR + regions[0],
       // 5
-      "import org.apache.geode.cache.\"query\".data.Portfolio; " + "SELECT ALL * FROM /root/"
+      "import org.apache.geode.cache.\"query\".data.Portfolio; " + "SELECT ALL * FROM " + SEPARATOR
+          + "root" + SEPARATOR
           + regions[0] + " TYPE Portfolio",
       // 6
-      "import org.apache.geode.cache.\"query\".data.Portfolio; " + "SELECT ALL * FROM /root/"
+      "import org.apache.geode.cache.\"query\".data.Portfolio; " + "SELECT ALL * FROM " + SEPARATOR
+          + "root" + SEPARATOR
           + regions[0] + " p TYPE Portfolio",
       // 7
-      "SELECT ALL * FROM /root/" + regions[1] + " p where p.ID < 5 and p.status='active';",
+      "SELECT ALL * FROM " + SEPARATOR + "root" + SEPARATOR + regions[1]
+          + " p where p.ID < 5 and p.status='active';",
       // 8
-      "SELECT ALL * FROM /root/" + regions[0] + "  ;",
+      "SELECT ALL * FROM " + SEPARATOR + "root" + SEPARATOR + regions[0] + "  ;",
       // 9
-      "SELECT ALL * FROM /root/" + regions[0] + " p where p.description = NULL",
+      "SELECT ALL * FROM " + SEPARATOR + "root" + SEPARATOR + regions[0]
+          + " p where p.description = NULL",
 
       // 10
-      "SELECT ALL * FROM /root/" + regions[1] + " p where p.ID > 0",};
+      "SELECT ALL * FROM " + SEPARATOR + "root" + SEPARATOR + regions[1] + " p where p.ID > 0",};
 
   public final String[] cqsWithoutRoot = new String[] {
       // 0 - Test for ">"
-      "SELECT ALL * FROM /" + regions[0] + " p where p.ID > 0"};
+      "SELECT ALL * FROM " + SEPARATOR + regions[0] + " p where p.ID > 0"};
 
   private static int bridgeServerPort;
 
@@ -1061,7 +1067,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
     server1.invoke(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + regions[0]);
+        Region region = getCache().getRegion(SEPARATOR + "root" + SEPARATOR + regions[0]);
         for (int i = 1; i <= numObjects; i++) {
           Portfolio p = new Portfolio(i);
           region.put("" + i, p);
@@ -1073,7 +1079,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
     server1.invokeAsync(new CacheSerializableRunnable("Update Region") {
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/root/" + regions[0]);
+        Region region = getCache().getRegion(SEPARATOR + "root" + SEPARATOR + regions[0]);
         for (int i = numObjects + 1; i <= totalObjects; i++) {
           Portfolio p = new Portfolio(i);
           region.put("" + i, p);
@@ -1182,7 +1188,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
 
       @Override
       public void run2() throws CacheException {
-        Region region = getCache().getRegion("/" + regions[0]);
+        Region region = getCache().getRegion(SEPARATOR + regions[0]);
         for (int i = 1; i <= numObjects; i++) {
           getCache().getLogger().fine("### DOING PUT with key: " + ("KEY-" + i));
           Portfolio p = new Portfolio(i);
@@ -1196,7 +1202,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
       @Override
       public void run2() throws CacheException {
         // Check for region destroyed event from server.
-        Region localRegion = getCache().getRegion("/" + regions[0]);
+        Region localRegion = getCache().getRegion(SEPARATOR + regions[0]);
         assertNotNull(localRegion);
 
         CqQueryTestListener cqListener = (CqQueryTestListener) getCache().getQueryService()
@@ -1212,7 +1218,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
       @Override
       public void run2() throws CacheException {
         // Check for region destroyed event from server.
-        Region localRegion = getCache().getRegion("/" + regions[0]);
+        Region localRegion = getCache().getRegion(SEPARATOR + regions[0]);
         assertNotNull(localRegion);
 
         localRegion.destroyRegion();
@@ -1224,7 +1230,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
       @Override
       public void run2() throws CacheException {
         // Check for region destroyed event from server.
-        Region localRegion = getCache().getRegion("/" + regions[0]);
+        Region localRegion = getCache().getRegion(SEPARATOR + regions[0]);
         // IF NULL - GOOD
         // ELSE - get listener and wait for destroyed.
         if (localRegion != null) {
@@ -1240,7 +1246,7 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
           assertNull(
               "Region is still available on client1 even after performing destroyRegion from client2 on server."
                   + "Client1 must have received destroyRegion message from server with CQ parts in it.",
-              getCache().getRegion("/" + regions[0]));
+              getCache().getRegion(SEPARATOR + regions[0]));
         }
       }
     });
@@ -1474,7 +1480,8 @@ public class PartitionedRegionCqQueryDUnitTest extends JUnit4CacheTestCase {
   }
 
   private static int getCqCountFromRegionProfile() {
-    LocalRegion region1 = (LocalRegion) CacheFactory.getAnyInstance().getRegion("/root/regionA");
+    LocalRegion region1 = (LocalRegion) CacheFactory.getAnyInstance()
+        .getRegion(SEPARATOR + "root" + SEPARATOR + "regionA");
     return region1.getFilterProfile().getCqCount();
   }
 
