@@ -14,9 +14,11 @@
  */
 package org.apache.geode.internal.cache;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
 import static org.apache.geode.internal.Assert.fail;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.apache.geode.test.dunit.Host.getHost;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
@@ -62,7 +64,6 @@ import org.apache.geode.cache.util.CqListenerAdapter;
 import org.apache.geode.compression.Compressor;
 import org.apache.geode.compression.SnappyCompressor;
 import org.apache.geode.distributed.DistributedSystem;
-import org.apache.geode.internal.AvailablePort;
 import org.apache.geode.internal.cache.tier.sockets.CacheClientNotifier;
 import org.apache.geode.internal.cache.tier.sockets.CacheClientProxy;
 import org.apache.geode.internal.cache.tier.sockets.ConflationDUnitTestHelper;
@@ -86,7 +87,7 @@ public class PRDeltaPropagationDUnitTest extends DistributedTestCase {
   private static final String LAST_KEY = "LAST_KEY";
   private static final String REGION_NAME = "PRDeltaPropagationDUnitTest_Region";
   private static final String CQ =
-      "SELECT * FROM " + Region.SEPARATOR + REGION_NAME + " p where p.intVar < 9";
+      "SELECT * FROM " + SEPARATOR + REGION_NAME + " p where p.intVar < 9";
 
   private static Cache cache = null;
   private static Region deltaPR = null;
@@ -785,7 +786,7 @@ public class PRDeltaPropagationDUnitTest extends DistributedTestCase {
     CacheServer server1 = cache.addCacheServer();
     assertNotNull(server1);
 
-    int port = AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET);
+    int port = getRandomAvailableTCPPort();
     server1.setPort(port);
     server1.start();
     assertTrue(server1.isRunning());
@@ -831,7 +832,7 @@ public class PRDeltaPropagationDUnitTest extends DistributedTestCase {
     }
 
     CacheServer server = cache.addCacheServer();
-    int port = AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET);
+    int port = getRandomAvailableTCPPort();
     server.setPort(port);
     // ensures updates to be sent instead of invalidations
     server.setNotifyBySubscription(true);
