@@ -14,10 +14,10 @@
  */
 package org.apache.geode.internal.cache.ha;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
-import static org.apache.geode.internal.AvailablePort.SOCKET;
-import static org.apache.geode.internal.AvailablePort.getRandomAvailablePort;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.apache.geode.test.dunit.Assert.assertEquals;
 import static org.apache.geode.test.dunit.Assert.assertNotNull;
 import static org.apache.geode.test.dunit.Assert.assertTrue;
@@ -219,7 +219,7 @@ public class HADispatcherDUnitTest extends JUnit4DistributedTestCase {
     vm.invoke(new CacheSerializableRunnable("putFromClient") {
       @Override
       public void run2() throws CacheException {
-        Region region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+        Region region = cache.getRegion(SEPARATOR + REGION_NAME);
         assertNotNull(region);
         region.put(key, value);
       }
@@ -231,7 +231,7 @@ public class HADispatcherDUnitTest extends JUnit4DistributedTestCase {
     vm.invoke(new CacheSerializableRunnable("checkFromClient") {
       @Override
       public void run2() throws CacheException {
-        Region region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+        Region region = cache.getRegion(SEPARATOR + REGION_NAME);
         assertNotNull(region);
         cache.getLogger().fine("starting the wait");
         synchronized (dummyObj) {
@@ -311,7 +311,7 @@ public class HADispatcherDUnitTest extends JUnit4DistributedTestCase {
     cache.createRegion(REGION_NAME, attrs);
     CacheServerImpl server = (CacheServerImpl) cache.addCacheServer();
     assertNotNull(server);
-    int port = getRandomAvailablePort(SOCKET);
+    int port = getRandomAvailableTCPPort();
     server.setPort(port);
     server.setNotifyBySubscription(true);
     server.start();
@@ -336,7 +336,7 @@ public class HADispatcherDUnitTest extends JUnit4DistributedTestCase {
     }
     RegionAttributes attrs = factory.create();
     cache.createRegion(REGION_NAME, attrs);
-    Region region = cache.getRegion(Region.SEPARATOR + REGION_NAME);
+    Region region = cache.getRegion(SEPARATOR + REGION_NAME);
     assertNotNull(region);
 
     {
@@ -395,7 +395,7 @@ public class HADispatcherDUnitTest extends JUnit4DistributedTestCase {
     CqAttributes cqa = cqf.create();
 
     String cqName = "CQForHARegionQueueTest";
-    String queryStr = "Select * from " + Region.SEPARATOR + REGION_NAME;
+    String queryStr = "Select * from " + SEPARATOR + REGION_NAME;
 
     // Create CQ.
     CqQuery cq1 = cqService.newCq(cqName, queryStr, cqa);
