@@ -14,9 +14,11 @@
  */
 package org.apache.geode.internal.cache.tier.sockets;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.DELTA_PROPAGATION;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.assertj.core.api.Assertions.assertThat;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
@@ -54,7 +56,6 @@ import org.apache.geode.cache.server.CacheServer;
 import org.apache.geode.cache.util.CacheListenerAdapter;
 import org.apache.geode.cache.util.CqListenerAdapter;
 import org.apache.geode.distributed.DistributedSystem;
-import org.apache.geode.internal.AvailablePort;
 import org.apache.geode.internal.cache.CacheServerImpl;
 import org.apache.geode.internal.cache.LocalRegion;
 import org.apache.geode.internal.cache.TestObjectWithIdentifier;
@@ -118,10 +119,10 @@ public class ClientToServerDeltaDUnitTest extends JUnit4DistributedTestCase {
 
   public static String DELTA_KEY = "DELTA_KEY";
 
-  private static final String[] CQs = new String[] {"select * from /" + REGION_NAME,
-      "select * from /" + REGION_NAME + " where intVar = 0",
-      "select * from /" + REGION_NAME + " where intVar > 0",
-      "select * from /" + REGION_NAME + " where intVar < 0"};
+  private static final String[] CQs = new String[] {"select * from " + SEPARATOR + REGION_NAME,
+      "select * from " + SEPARATOR + REGION_NAME + " where intVar = 0",
+      "select * from " + SEPARATOR + REGION_NAME + " where intVar > 0",
+      "select * from " + SEPARATOR + REGION_NAME + " where intVar < 0"};
 
   public static String LAST_KEY = "LAST_KEY";
 
@@ -665,7 +666,7 @@ public class ClientToServerDeltaDUnitTest extends JUnit4DistributedTestCase {
     }
 
     CacheServer server = cache.addCacheServer();
-    int port = AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET);
+    int port = getRandomAvailableTCPPort();
     server.setPort(port);
     // ensures updates to be sent instead of invalidations
     server.setNotifyBySubscription(true);
