@@ -17,7 +17,7 @@ package org.apache.geode.internal.cache.tier.sockets;
 import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
-import static org.apache.geode.internal.cache.tier.sockets.DeltaToRegionRelationCQRegistrationDUnitTest.getClientProxy;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPort;
 import static org.apache.geode.test.dunit.Assert.assertEquals;
 import static org.apache.geode.test.dunit.Assert.assertFalse;
 import static org.apache.geode.test.dunit.Assert.assertNotNull;
@@ -34,7 +34,6 @@ import org.apache.geode.cache.AttributesFactory;
 import org.apache.geode.cache.Cache;
 import org.apache.geode.cache.CacheFactory;
 import org.apache.geode.cache.DataPolicy;
-import org.apache.geode.cache.Region;
 import org.apache.geode.cache.RegionAttributes;
 import org.apache.geode.cache.Scope;
 import org.apache.geode.cache.client.Pool;
@@ -46,7 +45,6 @@ import org.apache.geode.cache.query.CqQuery;
 import org.apache.geode.cache.query.QueryService;
 import org.apache.geode.cache.server.CacheServer;
 import org.apache.geode.distributed.DistributedSystem;
-import org.apache.geode.internal.AvailablePort;
 import org.apache.geode.internal.cache.CacheServerImpl;
 import org.apache.geode.test.awaitility.GeodeAwaitility;
 import org.apache.geode.test.dunit.Host;
@@ -95,22 +93,22 @@ public class DeltaToRegionRelationCQRegistrationDUnitTest extends JUnit4Distribu
   /*
    * cq 1
    */
-  private static final String CQ1 = "SELECT * FROM " + Region.SEPARATOR + REGION_NAME1;
+  private static final String CQ1 = "SELECT * FROM " + SEPARATOR + REGION_NAME1;
 
   /*
    * cq 2
    */
-  private static final String CQ2 = "SELECT * FROM " + Region.SEPARATOR + REGION_NAME2;
+  private static final String CQ2 = "SELECT * FROM " + SEPARATOR + REGION_NAME2;
 
   /*
    * cq 3
    */
-  private static final String CQ3 = "SELECT ALL * FROM " + Region.SEPARATOR + REGION_NAME1;
+  private static final String CQ3 = "SELECT ALL * FROM " + SEPARATOR + REGION_NAME1;
 
   /*
    * cq 4
    */
-  private static final String CQ4 = "SELECT ALL * FROM " + Region.SEPARATOR + REGION_NAME2;
+  private static final String CQ4 = "SELECT ALL * FROM " + SEPARATOR + REGION_NAME2;
 
   private static final String cqName1 = "cqNameFirst";
   private static final String cqName2 = "cqNameSecond";
@@ -483,7 +481,7 @@ public class DeltaToRegionRelationCQRegistrationDUnitTest extends JUnit4Distribu
     cache.createRegion(REGION_NAME2, attrs);
 
     CacheServer server = cache.addCacheServer();
-    int port = AvailablePort.getRandomAvailablePort(AvailablePort.SOCKET);
+    int port = getRandomAvailableTCPPort();
     server.setPort(port);
     // ensures updates to be sent instead of invalidations
     server.setNotifyBySubscription(true);
