@@ -60,10 +60,12 @@ import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.PoolFactoryImpl;
 import org.apache.geode.internal.cache.ha.HARegionQueue;
 import org.apache.geode.logging.internal.log4j.api.LogService;
+import org.apache.geode.test.awaitility.GeodeAwaitility;
 import org.apache.geode.test.dunit.IgnoredException;
 import org.apache.geode.test.dunit.NetworkUtils;
 import org.apache.geode.test.dunit.SerializableRunnableIF;
 import org.apache.geode.test.dunit.VM;
+import org.apache.geode.test.dunit.WaitCriterion;
 import org.apache.geode.test.dunit.internal.JUnit4DistributedTestCase;
 
 public class DurableClientTestBase extends JUnit4DistributedTestCase {
@@ -80,9 +82,9 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
   VM publisherClientVM;
   protected String regionName;
   int server1Port;
+  int server2Port;
   String durableClientId;
 
-
   @Override
   public final void postSetUp() throws Exception {
     this.server1VM = VM.getVM(0);
@@ -172,6 +174,32 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
     verifyDurableClientPresence(durableClientTimeout, durableClientId, serverVM, 0);
   }
 
+  void waitForDurableClientPresence(String durableClientId, VM serverVM, final int count) {
+    serverVM.invoke(() -> {
+      if (count > 0) {
+
+        WaitCriterion ev = new WaitCriterion() {
+          @Override
+          public boolean done() {
+            checkNumberOfClientProxies(count);
+            CacheClientProxy proxy = getClientProxy();
+
+            if (proxy != null && durableClientId.equals(proxy.getDurableId())) {
+              return true;
+            }
+            return false;
+          }
+
+          @Override
+          public String description() {
+            return null;
+          }
+        };
+        GeodeAwaitility.await().untilAsserted(ev);
+      }
+    });
+  }
+
   void verifyDurableClientPresence(int durableClientTimeout, String durableClientId,
       VM serverVM, final int count) {
     serverVM.invoke(() -> {
@@ -372,7 +400,7 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
     }
   }
 
-  private CqQuery createCq(String cqName, String cqQuery, boolean durable)
+  CqQuery createCq(String cqName, String cqQuery, boolean durable)
       throws CqException, CqExistsException {
     QueryService qs = CacheServerTestUtil.getCache().getQueryService();
     CqAttributesFactory cqf = new CqAttributesFactory();
@@ -461,7 +489,6 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
     return bridgeServer;
   }
 
-
   Pool getClientPool(String host, int server1Port, int server2Port,
       boolean establishCallbackConnection, int redundancyLevel) {
     PoolFactory pf = PoolManager.createFactory();
@@ -664,16 +691,21 @@ public class DurableClientTestBase extends JUnit4DistributedTestCase {
   void checkCqListenerEvents(VM vm, final String cqName, final int numEvents,
       final int secondsToWait) {
     vm.invoke(() -> {
-      QueryService qs = CacheServerTestUtil.getCache().getQueryService();
-      CqQuery cq = qs.getCq(cqName);
-      // Get the listener and wait for the appropriate number of events
-      CacheServerTestUtil.ControlCqListener listener =
-          (CacheServerTestUtil.ControlCqListener) cq.getCqAttributes().getCqListener();
-      listener.waitWhileNotEnoughEvents(secondsToWait * 1000, numEvents);
-      assertThat(numEvents).isEqualTo(listener.events.size());
+      checkCqListenerEvents(cqName, numEvents, secondsToWait);
     });
   }
 
+  void checkCqListenerEvents(final String cqName, final int numEvents,
+      final int secondsToWait) {
+    QueryService qs = CacheServerTestUtil.getCache().getQueryService();
+    CqQuery cq = qs.getCq(cqName);
+    // Get the listener and wait for the appropriate number of events
+    CacheServerTestUtil.ControlCqListener listener =
+        (CacheServerTestUtil.ControlCqListener) cq.getCqAttributes().getCqListener();
+    listener.waitWhileNotEnoughEvents(secondsToWait * 1000, numEvents);
+    assertThat(numEvents).isEqualTo(listener.events.size());
+  }
+
   void checkListenerEvents(int numberOfEntries, final int sleepMinutes, final int eventType,
       final VM vm) {
     vm.invoke(() -> {
