@@ -1369,7 +1369,8 @@ public class CqServiceImpl implements CqService {
                 // Partitioned Regions. Once this is added remove the check
                 // with PR region.
                 if (cQuery.isCqResultsCacheInitialized()) {
-                  b_cqResults_oldValue = cQuery.isPartOfCqResult(eventKey);
+                  b_cqResults_oldValue =
+                      (cQuery.isPartOfCqResult(eventKey) && !cQuery.isKeyDestroyed(eventKey));
                   // For PR if not found in cache, apply the query on old value.
                   // Also apply if the query was not executed during cq execute
                   if ((cQuery.isPR || !CqServiceImpl.EXECUTE_QUERY_DURING_INIT)
