@@ -17,10 +17,12 @@ package org.apache.geode.cache.client.internal;
 import static org.apache.geode.distributed.ConfigurationProperties.ENABLE_CLUSTER_CONFIGURATION;
 import static org.apache.geode.distributed.ConfigurationProperties.GROUPS;
 import static org.apache.geode.distributed.ConfigurationProperties.HTTP_SERVICE_PORT;
+import static org.apache.geode.distributed.ConfigurationProperties.JMX_MANAGER_PORT;
 import static org.apache.geode.distributed.ConfigurationProperties.LOCATORS;
 import static org.apache.geode.distributed.ConfigurationProperties.LOG_LEVEL;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
 import static org.apache.geode.distributed.ConfigurationProperties.START_LOCATOR;
+import static org.apache.geode.internal.AvailablePortHelper.getRandomAvailableTCPPorts;
 
 import java.io.File;
 import java.io.IOException;
@@ -47,7 +49,6 @@ import org.apache.geode.cache.server.CacheServer;
 import org.apache.geode.cache.server.ServerLoadProbe;
 import org.apache.geode.distributed.DistributedSystem;
 import org.apache.geode.distributed.Locator;
-import org.apache.geode.internal.AvailablePortHelper;
 import org.apache.geode.internal.cache.PoolFactoryImpl;
 import org.apache.geode.test.dunit.Assert;
 import org.apache.geode.test.dunit.Invoke;
@@ -118,13 +119,16 @@ public abstract class LocatorTestBase extends JUnit4DistributedTestCase {
 
   protected int startLocator(final String hostName, final String otherLocators) throws Exception {
     disconnectFromDS();
-    final int httpPort = AvailablePortHelper.getRandomAvailableTCPPort();
+    int[] ports = getRandomAvailableTCPPorts(2);
+    int httpPort = ports[0];
+    int jmxManagerPort = ports[1];
     Properties props = new Properties();
     props.put(MCAST_PORT, String.valueOf(0));
     props.put(LOCATORS, otherLocators);
     props.put(LOG_LEVEL, LogWriterUtils.getDUnitLogLevel());
     props.put(ENABLE_CLUSTER_CONFIGURATION, "false");
     props.put(HTTP_SERVICE_PORT, String.valueOf(httpPort));
+    props.put(JMX_MANAGER_PORT, String.valueOf(jmxManagerPort));
     File logFile = new File("");
     InetAddress bindAddr = null;
     try {
