@@ -14,6 +14,7 @@
  */
 package org.apache.geode.management.internal.cli.commands;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.LOG_LEVEL;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
 import static org.apache.geode.distributed.ConfigurationProperties.NAME;
@@ -50,24 +51,28 @@ public class RegionMembershipMBeanDUnitTestBase {
   private static final String DATA_REGION_NAME = "GemfireDataCommandsTestRegion";
   private static final String DATA_REGION_NAME_VM1 = "GemfireDataCommandsTestRegion_Vm1";
   private static final String DATA_REGION_NAME_VM2 = "GemfireDataCommandsTestRegion_Vm2";
-  private static final String DATA_REGION_NAME_PATH = "/GemfireDataCommandsTestRegion";
-  private static final String DATA_REGION_NAME_VM1_PATH = "/GemfireDataCommandsTestRegion_Vm1";
-  private static final String DATA_REGION_NAME_VM2_PATH = "/GemfireDataCommandsTestRegion_Vm2";
+  private static final String DATA_REGION_NAME_PATH = SEPARATOR + "GemfireDataCommandsTestRegion";
+  private static final String DATA_REGION_NAME_VM1_PATH =
+      SEPARATOR + "GemfireDataCommandsTestRegion_Vm1";
+  private static final String DATA_REGION_NAME_VM2_PATH =
+      SEPARATOR + "GemfireDataCommandsTestRegion_Vm2";
 
   private static final String DATA_PAR_REGION_NAME = "GemfireDataCommandsTestParRegion";
   private static final String DATA_PAR_REGION_NAME_VM1 = "GemfireDataCommandsTestParRegion_Vm1";
   private static final String DATA_PAR_REGION_NAME_VM2 = "GemfireDataCommandsTestParRegion_Vm2";
-  private static final String DATA_PAR_REGION_NAME_PATH = "/GemfireDataCommandsTestParRegion";
+  private static final String DATA_PAR_REGION_NAME_PATH =
+      SEPARATOR + "GemfireDataCommandsTestParRegion";
   private static final String DATA_PAR_REGION_NAME_VM1_PATH =
-      "/GemfireDataCommandsTestParRegion_Vm1";
+      SEPARATOR + "GemfireDataCommandsTestParRegion_Vm1";
   private static final String DATA_PAR_REGION_NAME_VM2_PATH =
-      "/GemfireDataCommandsTestParRegion_Vm2";
+      SEPARATOR + "GemfireDataCommandsTestParRegion_Vm2";
   private static final String DATA_REGION_NAME_CHILD_1 = "ChildRegionRegion1";
   private static final String DATA_REGION_NAME_CHILD_1_PATH =
-      "/GemfireDataCommandsTestRegion/ChildRegionRegion1";
+      SEPARATOR + "GemfireDataCommandsTestRegion" + SEPARATOR + "ChildRegionRegion1";
   private static final String DATA_REGION_NAME_CHILD_1_2 = "ChildRegionRegion12";
   private static final String DATA_REGION_NAME_CHILD_1_2_PATH =
-      "/GemfireDataCommandsTestRegion/ChildRegionRegion1/ChildRegionRegion12";
+      SEPARATOR + "GemfireDataCommandsTestRegion" + SEPARATOR + "ChildRegionRegion1" + SEPARATOR
+          + "ChildRegionRegion12";
 
   private static final String SERIALIZATION_FILTER =
       "org.apache.geode.management.internal.cli.**";
