@@ -40,6 +40,7 @@ import org.apache.geode.internal.net.SocketCreator;
 import org.apache.geode.internal.net.SocketCreatorFactory;
 import org.apache.geode.management.internal.cli.LogWrapper;
 import org.apache.geode.pdx.internal.TypeRegistry;
+import org.apache.geode.test.dunit.DUnitEnv;
 import org.apache.geode.test.dunit.IgnoredException;
 import org.apache.geode.test.dunit.internal.DUnitLauncher;
 import org.apache.geode.test.junit.rules.serializable.SerializableExternalResource;
@@ -113,7 +114,7 @@ import org.apache.geode.util.internal.GeodeGlossary;
  * }
  * </pre>
  */
-@SuppressWarnings("unused")
+@SuppressWarnings({"serial", "unused"})
 public class DistributedRule extends AbstractDistributedRule {
 
   /**
@@ -152,6 +153,14 @@ public class DistributedRule extends AbstractDistributedRule {
     return DUnitLauncher.getDistributedSystemProperties();
   }
 
+  public static int getLocatorPort() {
+    return DUnitEnv.get().getLocatorPort();
+  }
+
+  public static String getLocators() {
+    return "localhost[" + getLocatorPort() + "]";
+  }
+
   /**
    * Builds an instance of DistributedRule.
    */
@@ -196,6 +205,7 @@ public class DistributedRule extends AbstractDistributedRule {
    * <p>
    * Note: {@link CacheRule} handles its own cleanup of Cache and Regions.
    */
+  @SuppressWarnings("serial")
   public static class TearDown extends SerializableExternalResource {
 
     @Override
@@ -208,7 +218,7 @@ public class DistributedRule extends AbstractDistributedRule {
       doTearDown();
     }
 
-    static void doTearDown() {
+    private static void doTearDown() {
       tearDownInVM();
       invokeInEveryVM(() -> {
         tearDownInVM();
