@@ -15,6 +15,7 @@
 
 package org.apache.geode.management.internal.cli.commands;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.lang.Identifiable.find;
 import static org.assertj.core.api.Assertions.assertThat;
 
@@ -138,7 +139,8 @@ public class CreateRegionCommandDUnitTest {
     gfsh.executeAndAssertThat("create region --name=failed --template-region=" + regionName)
         .statusIsError()
         .hasInfoSection().hasOutput()
-        .contains("Multiple types of template region /multipleTemplateRegionTypes exist.");
+        .contains("Multiple types of template region " + SEPARATOR
+            + "multipleTemplateRegionTypes exist.");
   }
 
   @Test
@@ -198,14 +200,14 @@ public class CreateRegionCommandDUnitTest {
     gfsh.executeAndAssertThat("create region --name=" + regionName + " --type=REPLICATE")
         .statusIsSuccess();
     String subRegionName = "subregion";
-    String subRegionPath = regionName + "/" + subRegionName;
+    String subRegionPath = regionName + SEPARATOR + subRegionName;
 
     gfsh.executeAndAssertThat("create region --name=" + subRegionPath +
         " --type=REPLICATE")
         .statusIsSuccess();
 
     String subSubRegionName = "subregion2";
-    String subSubRegionPath = regionName + "/" + subRegionName + "/" + subSubRegionName;
+    String subSubRegionPath = regionName + SEPARATOR + subRegionName + SEPARATOR + subSubRegionName;
     gfsh.executeAndAssertThat("create region --name=" + subSubRegionPath +
         " --type=REPLICATE")
         .statusIsSuccess();
@@ -323,63 +325,68 @@ public class CreateRegionCommandDUnitTest {
 
   @Test
   public void testCreateRegionFromTemplateFailsIfTemplateDoesNotExist() {
-    gfsh.executeAndAssertThat("create region --template-region=/TEMPLATE --name=/TEST"
-        + TestCacheListener.class.getName())
+    gfsh.executeAndAssertThat(
+        "create region --template-region=TEMPLATE --name=TEST"
+            + TestCacheListener.class.getName())
         .statusIsError()
-        .containsOutput("Template region /TEMPLATE does not exist");
+        .containsOutput("Template region " + SEPARATOR + "TEMPLATE does not exist");
   }
 
   @Test
   public void overrideListenerFromTemplate() {
-    gfsh.executeAndAssertThat("create region --name=/TEMPLATE --type=PARTITION_REDUNDANT"
-        + " --cache-listener=" + TestCacheListener.class.getName()).statusIsSuccess();
+    String regionName = testName.getMethodName();
+    gfsh.executeAndAssertThat(
+        "create region --name=" + regionName + " --type=PARTITION_REDUNDANT"
+            + " --cache-listener=" + TestCacheListener.class.getName())
+        .statusIsSuccess();
 
-    gfsh.executeAndAssertThat("create region --name=/COPY --template-region=/TEMPLATE"
-        + " --cache-listener=" + AnotherTestCacheListener.class.getName()).statusIsSuccess();
+    gfsh.executeAndAssertThat(
+        "create region --name=" + regionName + "_COPY --template-region=" + regionName
+            + " --cache-listener=" + AnotherTestCacheListener.class.getName())
+        .statusIsSuccess();
 
     server1.getVM().invoke(() -> {
-      Region<?, ?> copy = ClusterStartupRule.getCache().getRegion("/COPY");
+      Region<?, ?> copy = ClusterStartupRule.getCache().getRegion(regionName + "_COPY");
 
       assertThat(Arrays.stream(copy.getAttributes().getCacheListeners())
           .map(c -> c.getClass().getName()).collect(Collectors.toSet()))
               .containsExactly(AnotherTestCacheListener.class.getName());
     });
-
-    gfsh.executeAndAssertThat("destroy region --name=/COPY").statusIsSuccess();
-    gfsh.executeAndAssertThat("destroy region --name=/TEMPLATE").statusIsSuccess();
   }
 
 
   @Test
   public void cannotSetRegionExpirationForPartitionedTemplate() {
-    gfsh.executeAndAssertThat("create region --name=/TEMPLATE --type=PARTITION")
+    String regionName = testName.getMethodName();
+    gfsh.executeAndAssertThat("create region --name=" + regionName + " --type=PARTITION")
         .statusIsSuccess();
 
     gfsh.executeAndAssertThat(
-        "create region --name=/COPY --template-region=/TEMPLATE --enable-statistics=true --region-idle-time-expiration=1 --region-time-to-live-expiration=1")
+        "create region --name=" + regionName + "_COPY --template-region=" + regionName
+            + " --enable-statistics=true --region-idle-time-expiration=1 --region-time-to-live-expiration=1")
         .statusIsError()
         .containsOutput(
             "ExpirationAction INVALIDATE or LOCAL_INVALIDATE for region is not supported for Partitioned Region");
-
-    gfsh.executeAndAssertThat("destroy region --name=/TEMPLATE").statusIsSuccess();
   }
 
   @Test
   public void cannotCreateTemplateWithInconsistentPersistence() {
-    gfsh.executeAndAssertThat("create region --name=/TEMPLATE --type=PARTITION_PERSISTENT")
+    String regionName = testName.getMethodName();
+    gfsh.executeAndAssertThat(
+        "create region --name=" + regionName + " --type=PARTITION_PERSISTENT")
         .statusIsSuccess();
 
     gfsh.executeAndAssertThat(
-        "create region --name=/COPY --template-region=/TEMPLATE --enable-statistics=true --region-idle-time-expiration=1 --region-time-to-live-expiration=1")
+        "create region --name=" + regionName + "_COPY --template-region=" + regionName
+            + " --enable-statistics=true --region-idle-time-expiration=1 --region-time-to-live-expiration=1")
         .statusIsError()
         .containsOutput(
             "ExpirationAction INVALIDATE or LOCAL_INVALIDATE for region is not supported for Partitioned Region");
-
-    gfsh.executeAndAssertThat("destroy region --name=/TEMPLATE").statusIsSuccess();
   }
 
   @Test
   public void ensureOverridingCallbacksFromTemplateDoNotRequireClassesOnLocator() throws Exception {
+    String regionName = testName.getMethodName();
     final File prJarFile = new File(tmpDir.getRoot(), "myCacheListener.jar");
     new JarBuilder().buildJar(prJarFile, getUniversalClassCode("MyCallback"),
         getUniversalClassCode("MyNewCallback"));
@@ -389,7 +396,7 @@ public class CreateRegionCommandDUnitTest {
     gfsh.executeAndAssertThat(
         String
             .format(
-                "create region --name=/TEMPLATE --type=PARTITION_REDUNDANT "
+                "create region --name=" + regionName + " --type=PARTITION_REDUNDANT "
                     + "--cache-listener=%1$s " + "--cache-loader=%1$s " + "--cache-writer=%1$s "
                     + "--compressor=%1$s " + "--key-constraint=%1$s " + "--value-constraint=%1$s",
                 myCallback))
@@ -397,13 +404,14 @@ public class CreateRegionCommandDUnitTest {
 
     String myNewCallback = "io.pivotal.MyNewCallback";
     gfsh.executeAndAssertThat(String
-        .format("create region --name=/COPY --template-region=/TEMPLATE " + "--cache-listener=%1$s "
+        .format("create region --name=" + regionName + "_COPY --template-region=" + regionName
+            + " --cache-listener=%1$s "
             + "--cache-loader=%1$s " + "--cache-writer=%1$s " + "--compressor=%1$s "
             + "--key-constraint=%1$s " + "--value-constraint=%1$s", myNewCallback))
         .statusIsSuccess();
 
     server1.getVM().invoke(() -> {
-      Region<?, ?> copy = ClusterStartupRule.getCache().getRegion("/COPY");
+      Region<?, ?> copy = ClusterStartupRule.getCache().getRegion(regionName + "_COPY");
 
       assertThat(Arrays.stream(copy.getAttributes().getCacheListeners())
           .map(c -> c.getClass().getName()).collect(Collectors.toSet()))
@@ -422,29 +430,29 @@ public class CreateRegionCommandDUnitTest {
 
       assertThat(copy.getAttributes().getValueConstraint().getName()).isEqualTo(myNewCallback);
     });
-
-    gfsh.executeAndAssertThat("destroy region --name=/COPY").statusIsSuccess();
-    gfsh.executeAndAssertThat("destroy region --name=/TEMPLATE").statusIsSuccess();
   }
 
   @Test
   public void ensureNewCallbacksFromTemplateDoNotRequireClassesOnLocator() throws Exception {
+    String regionName = testName.getMethodName();
     final File prJarFile = new File(tmpDir.getRoot(), "myCacheListener.jar");
     new JarBuilder().buildJar(prJarFile, getUniversalClassCode("MyNewCallback"));
     gfsh.executeAndAssertThat("deploy --jar=" + prJarFile.getAbsolutePath()).statusIsSuccess();
 
-    gfsh.executeAndAssertThat("create region --name=/TEMPLATE --type=PARTITION_REDUNDANT")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + regionName + " --type=PARTITION_REDUNDANT")
         .statusIsSuccess();
 
     String myNewCallback = "io.pivotal.MyNewCallback";
     gfsh.executeAndAssertThat(String
-        .format("create region --name=/COPY --template-region=/TEMPLATE " + "--cache-listener=%1$s "
+        .format("create region --name=" + regionName + "_COPY --template-region=" + regionName
+            + " --cache-listener=%1$s "
             + "--cache-loader=%1$s " + "--cache-writer=%1$s " + "--compressor=%1$s "
             + "--key-constraint=%1$s " + "--value-constraint=%1$s", myNewCallback))
         .statusIsSuccess();
 
     server1.getVM().invoke(() -> {
-      Region<?, ?> copy = ClusterStartupRule.getCache().getRegion("/COPY");
+      Region<?, ?> copy = ClusterStartupRule.getCache().getRegion(regionName + "_COPY");
 
       assertThat(Arrays.stream(copy.getAttributes().getCacheListeners())
           .map(c -> c.getClass().getName()).collect(Collectors.toSet()))
@@ -463,13 +471,11 @@ public class CreateRegionCommandDUnitTest {
 
       assertThat(copy.getAttributes().getValueConstraint().getName()).isEqualTo(myNewCallback);
     });
-
-    gfsh.executeAndAssertThat("destroy region --name=/COPY").statusIsSuccess();
-    gfsh.executeAndAssertThat("destroy region --name=/TEMPLATE").statusIsSuccess();
   }
 
   @Test
   public void ensureOriginalCallbacksFromTemplateDoNotRequireClassesOnLocator() throws Exception {
+    String regionName = testName.getMethodName();
     final File prJarFile = new File(tmpDir.getRoot(), "myCacheListener.jar");
     new JarBuilder().buildJar(prJarFile, getUniversalClassCode("MyCallback"));
     gfsh.executeAndAssertThat("deploy --jar=" + prJarFile.getAbsolutePath()).statusIsSuccess();
@@ -478,17 +484,18 @@ public class CreateRegionCommandDUnitTest {
     gfsh.executeAndAssertThat(
         String
             .format(
-                "create region --name=/TEMPLATE --type=PARTITION_REDUNDANT "
+                "create region --name=" + regionName + " --type=PARTITION_REDUNDANT "
                     + "--cache-listener=%1$s " + "--cache-loader=%1$s " + "--cache-writer=%1$s "
                     + "--compressor=%1$s " + "--key-constraint=%1$s " + "--value-constraint=%1$s",
                 myCallback))
         .statusIsSuccess();
 
-    gfsh.executeAndAssertThat("create region --name=/COPY --template-region=/TEMPLATE")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + regionName + "_COPY --template-region=" + regionName)
         .statusIsSuccess();
 
     server1.getVM().invoke(() -> {
-      Region<?, ?> copy = ClusterStartupRule.getCache().getRegion("/COPY");
+      Region<?, ?> copy = ClusterStartupRule.getCache().getRegion(regionName + "_COPY");
 
       assertThat(Arrays.stream(copy.getAttributes().getCacheListeners())
           .map(c -> c.getClass().getName()).collect(Collectors.toSet()))
@@ -504,9 +511,6 @@ public class CreateRegionCommandDUnitTest {
 
       assertThat(copy.getAttributes().getValueConstraint().getName()).isEqualTo(myCallback);
     });
-
-    gfsh.executeAndAssertThat("destroy region --name=/COPY").statusIsSuccess();
-    gfsh.executeAndAssertThat("destroy region --name=/TEMPLATE").statusIsSuccess();
   }
 
   @Test
@@ -516,16 +520,18 @@ public class CreateRegionCommandDUnitTest {
     gfsh.executeAndAssertThat("create region --type=REPLICATE --group=group1 --name=" + regionName)
         .statusIsSuccess().tableHasRowWithValues("Member", "server-1");
     gfsh.executeAndAssertThat("create region --type=REPLICATE --group=group2 --name=" + regionName)
-        .statusIsError().containsOutput("Region /" + regionName + " already exists on the cluster");
+        .statusIsError()
+        .containsOutput("Region " + SEPARATOR + regionName + " already exists on the cluster");
 
     gfsh.executeAndAssertThat("create region --type=PARTITION --group=group2 --name=" + regionName)
-        .statusIsError().containsOutput("Region /" + regionName + " already exists on the cluster");
+        .statusIsError()
+        .containsOutput("Region " + SEPARATOR + regionName + " already exists on the cluster");
 
     gfsh.executeAndAssertThat(
         "create region --type=REPLICATE_PROXY --group=group2 --name=" + regionName)
         .statusIsSuccess().tableHasRowWithValues("Member", "server-2");
 
-    locator.waitUntilRegionIsReadyOnExactlyThisManyServers("/" + regionName, 2);
+    locator.waitUntilRegionIsReadyOnExactlyThisManyServers(SEPARATOR + regionName, 2);
 
     gfsh.executeAndAssertThat(
         "create region --type=PARTITION_PROXY --group=group2 --name=" + regionName).statusIsError()
@@ -542,10 +548,11 @@ public class CreateRegionCommandDUnitTest {
     gfsh.executeAndAssertThat("create region --type=REPLICATE --group=group2 --name=" + regionName)
         .statusIsSuccess().tableHasRowWithValues("Member", "server-2");
 
-    locator.waitUntilRegionIsReadyOnExactlyThisManyServers("/" + regionName, 2);
+    locator.waitUntilRegionIsReadyOnExactlyThisManyServers(SEPARATOR + regionName, 2);
     // the following two should fail with name check on locator, not on server
     gfsh.executeAndAssertThat("create region --type=PARTITION --group=group2 --name=" + regionName)
-        .statusIsError().containsOutput("Region /" + regionName + " already exists on the cluster");
+        .statusIsError()
+        .containsOutput("Region " + SEPARATOR + regionName + " already exists on the cluster");
     gfsh.executeAndAssertThat(
         "create region --type=PARTITION_PROXY --group=group2 --name=" + regionName).statusIsError()
         .containsOutput("The existing region is not a partitioned region");
@@ -593,10 +600,12 @@ public class CreateRegionCommandDUnitTest {
         .statusIsSuccess().tableHasRowWithValues("Member", "server-1");
     gfsh.executeAndAssertThat("create region --type=REPLICATE --group=group2 --name=" + regionName)
         .statusIsError()
-        .containsOutput("Region /startWithLocalPersistent already exists on the cluster");
+        .containsOutput(
+            "Region " + SEPARATOR + "startWithLocalPersistent already exists on the cluster");
     gfsh.executeAndAssertThat("create region --type=LOCAL --group=group2 --name=" + regionName)
         .statusIsError()
-        .containsOutput("Region /startWithLocalPersistent already exists on the cluster");
+        .containsOutput(
+            "Region " + SEPARATOR + "startWithLocalPersistent already exists on the cluster");
   }
 
   @Test
@@ -663,9 +672,10 @@ public class CreateRegionCommandDUnitTest {
     gfsh.executeAndAssertThat("create region --type=PARTITION --group=group2 --name=" + regionName)
         .statusIsSuccess().tableHasRowWithValues("Member", "server-2");
 
-    locator.waitUntilRegionIsReadyOnExactlyThisManyServers("/" + regionName, 2);
+    locator.waitUntilRegionIsReadyOnExactlyThisManyServers(SEPARATOR + regionName, 2);
     gfsh.executeAndAssertThat("create region --type=PARTITION --group=group2 --name=" + regionName)
-        .statusIsError().containsOutput("Region /" + regionName + " already exists on the cluster");
+        .statusIsError()
+        .containsOutput("Region " + SEPARATOR + regionName + " already exists on the cluster");
     gfsh.executeAndAssertThat(
         "create region --type=REPLICATE_PROXY --group=group2 --name=" + regionName).statusIsError()
         .containsOutput("The existing region is not a replicate region");
@@ -680,13 +690,16 @@ public class CreateRegionCommandDUnitTest {
     gfsh.executeAndAssertThat("create region --type=LOCAL --group=group1 --name=" + regionName)
         .statusIsSuccess();
     gfsh.executeAndAssertThat("create region --type=REPLICATE --name=" + regionName).statusIsError()
-        .containsOutput("Region /startWithLocalRegion already exists on the cluster.");
+        .containsOutput(
+            "Region " + SEPARATOR + "startWithLocalRegion already exists on the cluster.");
     gfsh.executeAndAssertThat("create region --type=PARTITION --group=group2 --name=" + regionName)
         .statusIsError()
-        .containsOutput("Region /startWithLocalRegion already exists on the cluster.");
+        .containsOutput(
+            "Region " + SEPARATOR + "startWithLocalRegion already exists on the cluster.");
     gfsh.executeAndAssertThat(
         "create region --type=PARTITION_PROXY --group=group2 --name=" + regionName).statusIsError()
-        .containsOutput("Region /startWithLocalRegion already exists on the cluster");
+        .containsOutput(
+            "Region " + SEPARATOR + "startWithLocalRegion already exists on the cluster");
   }
 
   @Test
@@ -705,35 +718,39 @@ public class CreateRegionCommandDUnitTest {
     gfsh.executeAndAssertThat("create region"
         + " --name=" + regionName
         + " --type=PARTITION"
-        + " --colocated-with=/nonexistent").statusIsError()
+        + " --colocated-with=" + SEPARATOR + "nonexistent").statusIsError()
         .containsOutput("Specify a valid region path for colocated-with")
         .containsOutput("nonexistent not found");
   }
 
   @Test
   public void cannotColocateWithNonPartitionedRegion() {
-    gfsh.executeAndAssertThat("create region --type=REPLICATE --name=/nonpartitioned")
+    gfsh.executeAndAssertThat(
+        "create region --type=REPLICATE --name=" + SEPARATOR + "nonpartitioned")
         .statusIsSuccess();
 
     String regionName = testName.getMethodName();
     gfsh.executeAndAssertThat("create region"
         + " --name=" + regionName
         + " --type=PARTITION"
-        + " --colocated-with=/nonpartitioned").statusIsError()
-        .containsOutput("\"/nonpartitioned\" is not a Partitioned Region");
+        + " --colocated-with=" + SEPARATOR + "nonpartitioned").statusIsError()
+        .containsOutput("\"" + SEPARATOR + "nonpartitioned\" is not a Partitioned Region");
   }
 
   @Test
   public void cannotCreateSubregionOnNonExistentParentRegion() {
-    gfsh.executeAndAssertThat("create region --type=REPLICATE --name=/nonexistentparent/child")
+    gfsh.executeAndAssertThat("create region --type=REPLICATE --name=" + SEPARATOR
+        + "nonexistentparent" + SEPARATOR + "child")
         .statusIsError()
-        .containsOutput("Parent region for \"/nonexistentparent/child\" does not exist");
+        .containsOutput("Parent region for \"" + SEPARATOR + "nonexistentparent" + SEPARATOR
+            + "child\" does not exist");
   }
 
   @Test
   public void cannotCreateWithNonexistentGatewaySenders() {
     gfsh.executeAndAssertThat(
-        "create region --type=REPLICATE --name=/invalid --gateway-sender-id=nonexistent")
+        "create region --type=REPLICATE --name=" + SEPARATOR
+            + "invalid --gateway-sender-id=nonexistent")
         .statusIsError()
         .containsOutput("There are no GatewaySenders");
   }
