@@ -15,6 +15,7 @@
 
 package org.apache.geode.management.internal.cli.commands;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.internal.lang.SystemUtils.CURRENT_DIRECTORY;
 import static org.assertj.core.api.Assertions.assertThat;
 
@@ -47,6 +48,7 @@ import org.apache.geode.cache.configuration.DiskStoreType;
 import org.apache.geode.distributed.Locator;
 import org.apache.geode.distributed.internal.InternalConfigurationPersistenceService;
 import org.apache.geode.distributed.internal.InternalLocator;
+import org.apache.geode.internal.cache.DiskInitFile;
 import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.SnapshotTestUtil;
 import org.apache.geode.management.internal.cli.result.model.TabularResultModel;
@@ -206,7 +208,7 @@ public class DiskStoreCommandsDUnitTest implements Serializable {
     gfsh.executeAndAssertThat("revoke missing-disk-store --id=" + diskstoreIDs.get(0))
         .statusIsSuccess().containsOutput("Missing disk store successfully revoked");
 
-    locator.waitUntilRegionIsReadyOnExactlyThisManyServers("/" + REGION_1, 1);
+    locator.waitUntilRegionIsReadyOnExactlyThisManyServers(SEPARATOR + REGION_1, 1);
 
     server1.invoke(() -> {
       Cache cache = ClusterStartupRule.getCache();
@@ -499,7 +501,8 @@ public class DiskStoreCommandsDUnitTest implements Serializable {
         String.format(
             "alter disk-store --name=%s --region=INVALID --disk-dirs=%s --compressor=foo.Bar",
             DISKSTORE, diskDirs))
-        .statusIsError().containsOutput("The disk store does not contain a region named: /INVALID");
+        .statusIsError()
+        .containsOutput("The disk store does not contain a region named: " + SEPARATOR + "INVALID");
   }
 
   @Test
@@ -517,6 +520,25 @@ public class DiskStoreCommandsDUnitTest implements Serializable {
     assertThat(Files.exists(nonExistingDiskStorePath)).isFalse();
   }
 
+  @Test
+  @Parameters({"compact offline-disk-store", "describe offline-disk-store",
+      "upgrade offline-disk-store", "validate offline-disk-store",
+      "alter disk-store --region=testRegion --enable-statistics=true"})
+  public void offlineDiskStoreCommandShouldFailWhenDiskStoreFileDoesNotExist(
+      String baseCommand) {
+    Path diskStorePath =
+        Paths.get(tempDir.getRoot().getAbsolutePath());
+    assertThat(Files.exists(diskStorePath)).isTrue();
+    Path diskStoreFilePath =
+        Paths.get(diskStorePath + File.separator + "BACKUPnonExistingDiskStore"
+            + DiskInitFile.IF_FILE_EXT);
+    assertThat(Files.exists(diskStoreFilePath)).isFalse();
+    gfsh.executeAndAssertThat(baseCommand + " --name=nonExistingDiskStore --disk-dirs="
+        + diskStorePath.toAbsolutePath().toString()).statusIsError()
+        .containsOutput("The init file " + diskStoreFilePath + " does not exist.");
+    assertThat(Files.exists(diskStoreFilePath)).isFalse();
+  }
+
   @Test
   @Parameters(method = "getDiskDirNames")
   public void validateDiskStoreDiskDirectoryPath(String diskDirectoryName)
