@@ -22,7 +22,6 @@ import org.junit.Test;
 import org.junit.experimental.categories.Category;
 import org.springframework.shell.core.Completion;
 
-import org.apache.geode.cache.query.IndexType;
 import org.apache.geode.management.internal.i18n.CliStrings;
 import org.apache.geode.test.junit.categories.GfshTest;
 import org.apache.geode.test.junit.rules.GfshParserRule;
@@ -342,7 +341,7 @@ public class GfshParserAutoCompletionIntegrationTest {
   public void testCompleteHelpPartialFirstWord() {
     String buffer = "help st";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
-    assertThat(candidate.getCandidates()).hasSize(17);
+    assertThat(candidate.getCandidates()).hasSize(18);
     assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "art gateway-receiver");
   }
 
@@ -382,7 +381,7 @@ public class GfshParserAutoCompletionIntegrationTest {
     String hintArgument = "data";
     String hintsProvided = gfshParserRule.getCommandManager().obtainHint(hintArgument);
     String[] hintsProvidedArray = hintsProvided.split(lineSeparator());
-    assertThat(hintsProvidedArray.length).isEqualTo(15);
+    assertThat(hintsProvidedArray.length).isEqualTo(17);
     assertThat(hintsProvidedArray[0])
         .isEqualTo("User data as stored in regions of the Geode distributed system.");
   }
@@ -422,10 +421,12 @@ public class GfshParserAutoCompletionIntegrationTest {
   }
 
   @Test
+  @SuppressWarnings("deprecation")
   public void testIndexType() {
     String buffer = "create index --type=";
     CommandCandidate candidate = gfshParserRule.complete(buffer);
-    assertThat(candidate.getCandidates()).hasSize(IndexType.values().length);
+    assertThat(candidate.getCandidates())
+        .hasSize(org.apache.geode.cache.query.IndexType.values().length);
     assertThat(candidate.getFirstCandidate()).isEqualTo(buffer + "hash");
   }
 }
