@@ -15,6 +15,7 @@
 
 package org.apache.geode.management.internal.cli.commands;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.assertj.core.api.Assertions.assertThat;
 
 import java.util.Arrays;
@@ -64,135 +65,162 @@ public class CreateRegionCommandIntegrationTest {
 
   @Test
   public void parentRegionDoesNotExist() {
-    gfsh.executeAndAssertThat(CREATE_REGION + "--name=/A/B").statusIsError()
-        .containsOutput("Parent region for \"/A/B\" does not exist");
+    gfsh.executeAndAssertThat(CREATE_REGION + "--name=" + SEPARATOR + "A" + SEPARATOR + "B")
+        .statusIsError()
+        .containsOutput(
+            "Parent region for \"" + SEPARATOR + "A" + SEPARATOR + "B\" does not exist");
   }
 
   @Test
   public void groupDoesNotExist() {
-    gfsh.executeAndAssertThat(CREATE_REGION + "--name=/FOO --groups=unknown").statusIsError()
+    gfsh.executeAndAssertThat(CREATE_REGION + "--name=" + SEPARATOR + "FOO --groups=unknown")
+        .statusIsError()
         .containsOutput("Group(s) \"unknown\" are invalid");
   }
 
   @Test
   public void templateRegionDoesNotExist() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --template-region=/BAR").statusIsError()
-        .containsOutput("Template region /BAR does not exist");
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "FOO --template-region=" + SEPARATOR + "BAR")
+        .statusIsError()
+        .containsOutput("Template region " + SEPARATOR + "BAR does not exist");
   }
 
   @Test
   public void conflictingPartitionAttributesWithTemplate() {
     gfsh.executeAndAssertThat(
-        "create region --name=/FOO --template-region=REPLICATED --redundant-copies=2")
+        "create region --name=" + SEPARATOR
+            + "FOO --template-region=REPLICATED --redundant-copies=2")
         .statusIsError().containsOutput(
             "can be used only for creating a Partitioned Region");
   }
 
   @Test
   public void conflictingPartitionAttributesWithShortCut() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --type=REPLICATE --redundant-copies=2")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "FOO --type=REPLICATE --redundant-copies=2")
         .statusIsError().containsOutput("can be used only for creating a Partitioned Region");
   }
 
   @Test
   public void colocatedWithRegionDoesNotExist() {
-    gfsh.executeAndAssertThat("create region --type=PARTITION --name=/FOO --colocated-with=/BAR")
+    gfsh.executeAndAssertThat("create region --type=PARTITION --name=" + SEPARATOR
+        + "FOO --colocated-with=" + SEPARATOR + "BAR")
         .statusIsError().containsOutput("Specify a valid region path for colocated-with");
   }
 
   @Test
   public void colocatedWithRegionIsNotPartitioned() {
     gfsh.executeAndAssertThat(
-        "create region --type=PARTITION --name=/FOO --colocated-with=/REPLICATED").statusIsError()
-        .containsOutput("colocated-with \"/REPLICATED\" is not a Partitioned Region");
+        "create region --type=PARTITION --name=" + SEPARATOR + "FOO --colocated-with=" + SEPARATOR
+            + "REPLICATED")
+        .statusIsError()
+        .containsOutput(
+            "colocated-with \"" + SEPARATOR + "REPLICATED\" is not a Partitioned Region");
   }
 
   @Test
   public void negativeLocalMaxMemory() {
-    gfsh.executeAndAssertThat("create region --type=PARTITION --name=/FOO --local-max-memory=-1")
+    gfsh.executeAndAssertThat(
+        "create region --type=PARTITION --name=" + SEPARATOR + "FOO --local-max-memory=-1")
         .statusIsError().containsOutput("PartitionAttributes localMaxMemory must not be negative");
   }
 
   @Test
   public void zeroLocalMaxMemoryIsOK() {
-    gfsh.executeAndAssertThat("create region --type=PARTITION --name=/FOO --local-max-memory=0")
-        .statusIsSuccess().containsOutput("Region \"/FOO\" created");
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat(
+        "create region --type=PARTITION --name=" + SEPARATOR + "FOO --local-max-memory=0")
+        .statusIsSuccess().containsOutput("Region \"" + SEPARATOR + "FOO\" created");
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
   public void negativeTotalMaxMemory() {
-    gfsh.executeAndAssertThat("create region --type=PARTITION --name=/FOO --total-max-memory=-1")
+    gfsh.executeAndAssertThat(
+        "create region --type=PARTITION --name=" + SEPARATOR + "FOO --total-max-memory=-1")
         .statusIsError().containsOutput("Total size of partition region must be > 0");
   }
 
   @Test
   public void zeroTotalMaxMemory() {
-    gfsh.executeAndAssertThat("create region --type=PARTITION --name=/FOO --total-max-memory=0")
+    gfsh.executeAndAssertThat(
+        "create region --type=PARTITION --name=" + SEPARATOR + "FOO --total-max-memory=0")
         .statusIsError().containsOutput("Total size of partition region must be > 0");
   }
 
   @Test
   public void redundantCopies() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --type=PARTITION --redundant-copies=2")
-        .statusIsSuccess().containsOutput("Region \"/FOO\" created");
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "FOO --type=PARTITION --redundant-copies=2")
+        .statusIsSuccess().containsOutput("Region \"" + SEPARATOR + "FOO\" created");
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
   public void tooManyredundantCopies() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --type=PARTITION --redundant-copies=4")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "FOO --type=PARTITION --redundant-copies=4")
         .statusIsError().containsOutput("redundant-copies \"4\" is not valid");
   }
 
   @Test
   public void keyConstraint() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --type=REPLICATE --key-constraint=abc-def")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "FOO --type=REPLICATE --key-constraint=abc-def")
         .statusIsError().containsOutput("Specify a valid class name for key-constraint");
   }
 
   @Test
   public void valueConstraint() {
     gfsh.executeAndAssertThat(
-        "create region --name=/FOO --type=REPLICATE --value-constraint=abc-def").statusIsError()
+        "create region --name=" + SEPARATOR + "FOO --type=REPLICATE --value-constraint=abc-def")
+        .statusIsError()
         .containsOutput("Specify a valid class name for value-constraint");
   }
 
   @Test
   public void ifNotExistsIsIdempotent() {
     gfsh.executeAndAssertThat(
-        "create region --if-not-exists --type=PARTITION --name=/FOO --local-max-memory=0")
-        .statusIsSuccess().containsOutput("Region \"/FOO\" created");
+        "create region --if-not-exists --type=PARTITION --name=" + SEPARATOR
+            + "FOO --local-max-memory=0")
+        .statusIsSuccess().containsOutput("Region \"" + SEPARATOR + "FOO\" created");
 
     gfsh.executeAndAssertThat(
-        "create region --skip-if-exists --type=PARTITION --name=/FOO --local-max-memory=0")
-        .statusIsSuccess().containsOutput("Region /FOO already exists on these members: server.");
+        "create region --skip-if-exists --type=PARTITION --name=" + SEPARATOR
+            + "FOO --local-max-memory=0")
+        .statusIsSuccess()
+        .containsOutput("Region " + SEPARATOR + "FOO already exists on these members: server.");
 
     gfsh.executeAndAssertThat(
-        "create region --if-not-exists --type=PARTITION --name=/FOO --local-max-memory=0")
-        .statusIsSuccess().containsOutput("Region /FOO already exists on these members: server.");
+        "create region --if-not-exists --type=PARTITION --name=" + SEPARATOR
+            + "FOO --local-max-memory=0")
+        .statusIsSuccess()
+        .containsOutput("Region " + SEPARATOR + "FOO already exists on these members: server.");
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
   public void invalidCacheListener() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --type=REPLICATE --cache-listener=abc-def")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "FOO --type=REPLICATE --cache-listener=abc-def")
         .statusIsError().containsOutput(
             "java.lang.IllegalArgumentException: Failed to convert 'abc-def' to type ClassName");
   }
 
   @Test
   public void invalidCacheLoader() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --type=REPLICATE --cache-loader=abc-def")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "FOO --type=REPLICATE --cache-loader=abc-def")
         .statusIsError().containsOutput(
             "java.lang.IllegalArgumentException: Failed to convert 'abc-def' to type ClassName");
   }
 
   @Test
   public void invalidCacheWriter() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --type=REPLICATE --cache-writer=abc-def")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "FOO --type=REPLICATE --cache-writer=abc-def")
         .statusIsError().containsOutput(
             "java.lang.IllegalArgumentException: Failed to convert 'abc-def' to type ClassName");
   }
@@ -200,7 +228,8 @@ public class CreateRegionCommandIntegrationTest {
   @Test
   public void invalidGatewaySenders() {
     gfsh.executeAndAssertThat(
-        "create region --name=/FOO --type=REPLICATE --gateway-sender-id=unknown").statusIsError()
+        "create region --name=" + SEPARATOR + "FOO --type=REPLICATE --gateway-sender-id=unknown")
+        .statusIsError()
         .containsOutput("There are no GatewaySenders defined currently in the system");
   }
 
@@ -209,13 +238,15 @@ public class CreateRegionCommandIntegrationTest {
   @Test
   public void invalidConcurrencyLevel() {
     gfsh.executeAndAssertThat(
-        "create region --name=/FOO --template-region=/REPLICATED --concurrency-level=-1")
+        "create region --name=" + SEPARATOR + "FOO --template-region=" + SEPARATOR
+            + "REPLICATED --concurrency-level=-1")
         .statusIsError().containsOutput("Specify positive integer value for concurrency-level");
   }
 
   @Test
   public void nonPersistentRegionWithdiskStore() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --type=REPLICATE --disk-store=unknown")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "FOO --type=REPLICATE --disk-store=unknown")
         .statusIsError()
         .containsOutput("Only regions with persistence or overflow to disk can specify DiskStore");
   }
@@ -223,8 +254,10 @@ public class CreateRegionCommandIntegrationTest {
   @Test
   public void nonPersistentTemplateWithdiskStore() {
     gfsh.executeAndAssertThat(
-        "create region --name=/FOO --template-region=/REPLICATED --disk-store=unknown")
-        .statusIsError().containsOutput("template-region region \"/REPLICATED\" is not persistent")
+        "create region --name=" + SEPARATOR + "FOO --template-region=" + SEPARATOR
+            + "REPLICATED --disk-store=unknown")
+        .statusIsError()
+        .containsOutput("template-region region \"" + SEPARATOR + "REPLICATED\" is not persistent")
         .containsOutput("Only regions with persistence or overflow to disk can specify DiskStore");
   }
 
@@ -235,11 +268,12 @@ public class CreateRegionCommandIntegrationTest {
             " --compaction-threshold=99 --max-oplog-size=1 --allow-force-compaction=true")
         .statusIsSuccess()
         .doesNotContainOutput("Did not complete waiting");
-    gfsh.executeAndAssertThat("create region --name=/OVERFLOW --type=REPLICATE_OVERFLOW" +
-        " --eviction-action=overflow-to-disk --eviction-entry-count=1000 --disk-store=DISKSTORE")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "OVERFLOW --type=REPLICATE_OVERFLOW" +
+            " --eviction-action=overflow-to-disk --eviction-entry-count=1000 --disk-store=DISKSTORE")
         .statusIsSuccess();
 
-    gfsh.executeAndAssertThat("destroy region --name=/OVERFLOW").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "OVERFLOW").statusIsSuccess();
     gfsh.executeAndAssertThat("destroy disk-store --name=DISKSTORE").statusIsSuccess();
   }
 
@@ -250,11 +284,12 @@ public class CreateRegionCommandIntegrationTest {
             " --compaction-threshold=99 --max-oplog-size=1 --allow-force-compaction=true")
         .statusIsSuccess()
         .doesNotContainOutput("Did not complete waiting");
-    gfsh.executeAndAssertThat("create region --name=/OVERFLOW --type=PARTITION_OVERFLOW" +
-        " --eviction-action=overflow-to-disk --eviction-entry-count=1000 --disk-store=DISKSTORE")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "OVERFLOW --type=PARTITION_OVERFLOW" +
+            " --eviction-action=overflow-to-disk --eviction-entry-count=1000 --disk-store=DISKSTORE")
         .statusIsSuccess();
 
-    gfsh.executeAndAssertThat("destroy region --name=/OVERFLOW").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "OVERFLOW").statusIsSuccess();
     gfsh.executeAndAssertThat("destroy disk-store --name=DISKSTORE").statusIsSuccess();
   }
 
@@ -265,23 +300,26 @@ public class CreateRegionCommandIntegrationTest {
             " --compaction-threshold=99 --max-oplog-size=1 --allow-force-compaction=true")
         .statusIsSuccess()
         .doesNotContainOutput("Did not complete waiting");
-    gfsh.executeAndAssertThat("create region --name=/OVERFLOW --type=PARTITION_OVERFLOW" +
-        " --eviction-action=overflow-to-disk --eviction-entry-count=1000 --disk-store=DISKSTORE")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "OVERFLOW --type=PARTITION_OVERFLOW" +
+            " --eviction-action=overflow-to-disk --eviction-entry-count=1000 --disk-store=DISKSTORE")
         .statusIsSuccess();
 
     gfsh.executeAndAssertThat(
-        "create region --name=/TEMPLATE --template-region=/OVERFLOW --disk-store=DISKSTORE")
+        "create region --name=" + SEPARATOR + "TEMPLATE --template-region=" + SEPARATOR
+            + "OVERFLOW --disk-store=DISKSTORE")
         .statusIsSuccess();
 
-    gfsh.executeAndAssertThat("destroy region --name=/TEMPLATE").statusIsSuccess();
-    gfsh.executeAndAssertThat("destroy region --name=/OVERFLOW").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "TEMPLATE").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "OVERFLOW").statusIsSuccess();
     gfsh.executeAndAssertThat("destroy disk-store --name=DISKSTORE").statusIsSuccess();
   }
 
   @Test
   public void invalidDiskStore() {
     gfsh.executeAndAssertThat(
-        "create region --name=/FOO --type=REPLICATE_PERSISTENT --disk-store=unknown")
+        "create region --name=" + SEPARATOR
+            + "FOO --type=REPLICATE_PERSISTENT --disk-store=unknown")
         .statusIsError()
         .containsOutput("Specify valid disk-store. Unknown Disk Store : \"unknown\"");
   }
@@ -289,23 +327,26 @@ public class CreateRegionCommandIntegrationTest {
   @Test
   public void entryIdleTimeWithoutStatisticsEnabled() {
     gfsh.executeAndAssertThat(
-        "create region --name=/FOO --type=REPLICATE --entry-idle-time-expiration=1").statusIsError()
+        "create region --name=" + SEPARATOR + "FOO --type=REPLICATE --entry-idle-time-expiration=1")
+        .statusIsError()
         .containsOutput("Statistics must be enabled for expiration");
   }
 
   @Test
   public void invalidCompressor() {
     gfsh.executeAndAssertThat(
-        "create region --name=/FOO --type=REPLICATE --compressor=java.lang.String").statusIsError()
+        "create region --name=" + SEPARATOR + "FOO --type=REPLICATE --compressor=java.lang.String")
+        .statusIsError()
         .containsOutput("java.lang.String cannot be cast to ")
         .containsOutput("org.apache.geode.compression.Compressor");
   }
 
   @Test
   public void validateDefaultExpirationAttributes() {
-    gfsh.executeAndAssertThat("create region --name=/A --type=REPLICATE").statusIsSuccess();
+    gfsh.executeAndAssertThat("create region --name=" + SEPARATOR + "A --type=REPLICATE")
+        .statusIsSuccess();
 
-    Region region = server.getCache().getRegion("/A");
+    Region region = server.getCache().getRegion(SEPARATOR + "A");
     RegionAttributes attributes = region.getAttributes();
     ExpirationAttributes entryIdle = attributes.getEntryIdleTimeout();
     ExpirationAttributes entryTTL = attributes.getEntryTimeToLive();
@@ -325,17 +366,17 @@ public class CreateRegionCommandIntegrationTest {
     assertThat(regionTTL.getTimeout()).isEqualTo(0);
     assertThat(regionTTL.getAction()).isEqualTo(ExpirationAction.INVALIDATE);
 
-    gfsh.executeAndAssertThat("destroy region --name=/A").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "A").statusIsSuccess();
   }
 
   @Test
   public void validateNonDefaultBinaryOptions() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --type=REPLICATE"
+    gfsh.executeAndAssertThat("create region --name=" + SEPARATOR + "FOO --type=REPLICATE"
         + " --enable-async-conflation" + " --enable-cloning" + " --enable-concurrency-checks=false"
         + " --enable-multicast" + " --enable-statistics" + " --enable-subscription-conflation"
         + " --enable-synchronous-disk=false").statusIsSuccess();
 
-    Region foo = server.getCache().getRegion("/FOO");
+    Region foo = server.getCache().getRegion(SEPARATOR + "FOO");
 
     assertThat(foo.getAttributes().getEnableAsyncConflation()).isTrue();
     assertThat(foo.getAttributes().getCloningEnabled()).isTrue();
@@ -345,19 +386,22 @@ public class CreateRegionCommandIntegrationTest {
     assertThat(foo.getAttributes().getEnableSubscriptionConflation()).isTrue();
     assertThat(foo.getAttributes().isDiskSynchronous()).isFalse();
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
   public void validateExpirationOptions() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --type=REPLICATE" + " --enable-statistics"
-        + " --entry-idle-time-expiration=3" + " --entry-idle-time-expiration-action=DESTROY"
-        + " --entry-time-to-live-expiration=5" + " --entry-time-to-live-expiration-action=DESTROY"
-        + " --region-idle-time-expiration=7" + " --region-idle-time-expiration-action=DESTROY"
-        + " --region-time-to-live-expiration=11"
-        + " --region-time-to-live-expiration-action=DESTROY").statusIsSuccess();
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "FOO --type=REPLICATE" + " --enable-statistics"
+            + " --entry-idle-time-expiration=3" + " --entry-idle-time-expiration-action=DESTROY"
+            + " --entry-time-to-live-expiration=5"
+            + " --entry-time-to-live-expiration-action=DESTROY"
+            + " --region-idle-time-expiration=7" + " --region-idle-time-expiration-action=DESTROY"
+            + " --region-time-to-live-expiration=11"
+            + " --region-time-to-live-expiration-action=DESTROY")
+        .statusIsSuccess();
 
-    Region<?, ?> foo = server.getCache().getRegion("/FOO");
+    Region<?, ?> foo = server.getCache().getRegion(SEPARATOR + "FOO");
 
     assertThat(foo.getAttributes().getStatisticsEnabled()).isTrue();
     assertThat(foo.getAttributes().getEntryIdleTimeout().getTimeout()).isEqualTo(3);
@@ -373,18 +417,18 @@ public class CreateRegionCommandIntegrationTest {
     assertThat(foo.getAttributes().getRegionTimeToLive().getAction())
         .isEqualTo(ExpirationAction.DESTROY);
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @SuppressWarnings("deprecation")
   @Test
   public void validatePartitionRegionOptions() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --type=PARTITION_REDUNDANT"
+    gfsh.executeAndAssertThat("create region --name=" + SEPARATOR + "FOO --type=PARTITION_REDUNDANT"
         + " --local-max-memory=1001" + " --recovery-delay=7" + " --redundant-copies=1"
         + " --startup-recovery-delay=5" + " --total-max-memory=2001" + " --total-num-buckets=11"
         + " --partition-resolver=" + TestPartitionResolver.class.getName()).statusIsSuccess();
 
-    Region<?, ?> foo = server.getCache().getRegion("/FOO");
+    Region<?, ?> foo = server.getCache().getRegion(SEPARATOR + "FOO");
 
     assertThat(foo.getAttributes().getPartitionAttributes().getLocalMaxMemory()).isEqualTo(1001);
     assertThat(foo.getAttributes().getPartitionAttributes().getRecoveryDelay()).isEqualTo(7);
@@ -396,19 +440,19 @@ public class CreateRegionCommandIntegrationTest {
         foo.getAttributes().getPartitionAttributes().getPartitionResolver().getClass().getName())
             .isEqualTo(TestPartitionResolver.class.getName());
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
   public void validateCallbackOptions() {
     gfsh.executeAndAssertThat(
-        "create region --name=/FOO --type=PARTITION_REDUNDANT --cache-listener="
+        "create region --name=" + SEPARATOR + "FOO --type=PARTITION_REDUNDANT --cache-listener="
             + TestCacheListener.class.getName() + " --cache-loader="
             + TestCacheLoader.class.getName() + " --cache-writer=" + TestCacheWriter.class.getName()
             + " --compressor=" + TestCompressor.class.getName())
         .statusIsSuccess();
 
-    Region<?, ?> foo = server.getCache().getRegion("/FOO");
+    Region<?, ?> foo = server.getCache().getRegion(SEPARATOR + "FOO");
 
     assertThat(Arrays.stream(foo.getAttributes().getCacheListeners())
         .map(c -> c.getClass().getName()).collect(Collectors.toSet()))
@@ -420,39 +464,42 @@ public class CreateRegionCommandIntegrationTest {
     assertThat(foo.getAttributes().getCompressor().getClass().getName())
         .isEqualTo(TestCompressor.class.getName());
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
   public void validateConstraints() {
-    gfsh.executeAndAssertThat("create region --name=/FOO --type=REPLICATE" + " --key-constraint="
-        + TestConstraint.class.getName() + " --value-constraint=" + TestConstraint.class.getName())
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "FOO --type=REPLICATE" + " --key-constraint="
+            + TestConstraint.class.getName() + " --value-constraint="
+            + TestConstraint.class.getName())
         .statusIsSuccess();
 
-    Region<?, ?> foo = server.getCache().getRegion("/FOO");
+    Region<?, ?> foo = server.getCache().getRegion(SEPARATOR + "FOO");
 
     assertThat(foo.getAttributes().getKeyConstraint().getName())
         .isEqualTo(TestConstraint.class.getName());
     assertThat(foo.getAttributes().getValueConstraint().getName())
         .isEqualTo(TestConstraint.class.getName());
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
   public void validateEntryIdleTimeExpiration() {
     gfsh.executeAndAssertThat(
-        "create region --name=/FOO --type=REPLICATE --entry-idle-time-expiration=7 --enable-statistics")
+        "create region --name=" + SEPARATOR
+            + "FOO --type=REPLICATE --entry-idle-time-expiration=7 --enable-statistics")
         .statusIsSuccess();
-    Region<?, ?> template = server.getCache().getRegion("/FOO");
+    Region<?, ?> template = server.getCache().getRegion(SEPARATOR + "FOO");
     assertThat(template.getAttributes().getEntryIdleTimeout().getTimeout()).isEqualTo(7);
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
   public void validateTemplateRegionAttributesForReplicate() {
-    gfsh.executeAndAssertThat("create region --name=/TEMPLATE --type=REPLICATE"
+    gfsh.executeAndAssertThat("create region --name=" + SEPARATOR + "TEMPLATE --type=REPLICATE"
         + " --enable-async-conflation" + " --enable-cloning" + " --enable-concurrency-checks=false"
         + " --enable-multicast" + " --enable-statistics" + " --enable-subscription-conflation"
         + " --enable-synchronous-disk=false" + " --entry-idle-time-expiration=3"
@@ -465,10 +512,11 @@ public class CreateRegionCommandIntegrationTest {
         + TestCompressor.class.getName() + " --key-constraint=" + TestConstraint.class.getName()
         + " --value-constraint=" + TestConstraint.class.getName()).statusIsSuccess();
 
-    gfsh.executeAndAssertThat("create region --name=/COPY --template-region=/TEMPLATE")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "COPY --template-region=" + SEPARATOR + "TEMPLATE")
         .statusIsSuccess();
 
-    Region<?, ?> copy = server.getCache().getRegion("/COPY");
+    Region<?, ?> copy = server.getCache().getRegion(SEPARATOR + "COPY");
 
     assertThat(copy.getAttributes().getStatisticsEnabled()).isTrue();
     assertThat(copy.getAttributes().getEnableAsyncConflation()).isTrue();
@@ -504,29 +552,34 @@ public class CreateRegionCommandIntegrationTest {
     assertThat(copy.getAttributes().getValueConstraint().getName())
         .isEqualTo(TestConstraint.class.getName());
 
-    gfsh.executeAndAssertThat("destroy region --name=/COPY").statusIsSuccess();
-    gfsh.executeAndAssertThat("destroy region --name=/TEMPLATE").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "COPY").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "TEMPLATE").statusIsSuccess();
   }
 
   @Test
   @SuppressWarnings("deprecation")
   public void validateTemplateRegionAttributesForPartitionRedundant() {
-    gfsh.executeAndAssertThat("create region --name=/TEMPLATE --type=PARTITION_REDUNDANT"
-        + " --enable-async-conflation" + " --enable-cloning" + " --enable-concurrency-checks=false"
-        + " --enable-multicast" + " --enable-statistics" + " --enable-subscription-conflation"
-        + " --enable-synchronous-disk=false" + " --cache-listener="
-        + TestCacheListener.class.getName() + " --cache-loader=" + TestCacheLoader.class.getName()
-        + " --cache-writer=" + TestCacheWriter.class.getName() + " --compressor="
-        + TestCompressor.class.getName() + " --key-constraint=" + TestConstraint.class.getName()
-        + " --value-constraint=" + TestConstraint.class.getName() + " --local-max-memory=1001"
-        + " --recovery-delay=7" + " --redundant-copies=1" + " --startup-recovery-delay=5"
-        + " --total-max-memory=2001" + " --total-num-buckets=11" + " --partition-resolver="
-        + TestPartitionResolver.class.getName()).statusIsSuccess();
-
-    gfsh.executeAndAssertThat("create region --name=/COPY --template-region=/TEMPLATE")
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "TEMPLATE --type=PARTITION_REDUNDANT"
+            + " --enable-async-conflation" + " --enable-cloning"
+            + " --enable-concurrency-checks=false"
+            + " --enable-multicast" + " --enable-statistics" + " --enable-subscription-conflation"
+            + " --enable-synchronous-disk=false" + " --cache-listener="
+            + TestCacheListener.class.getName() + " --cache-loader="
+            + TestCacheLoader.class.getName()
+            + " --cache-writer=" + TestCacheWriter.class.getName() + " --compressor="
+            + TestCompressor.class.getName() + " --key-constraint=" + TestConstraint.class.getName()
+            + " --value-constraint=" + TestConstraint.class.getName() + " --local-max-memory=1001"
+            + " --recovery-delay=7" + " --redundant-copies=1" + " --startup-recovery-delay=5"
+            + " --total-max-memory=2001" + " --total-num-buckets=11" + " --partition-resolver="
+            + TestPartitionResolver.class.getName())
         .statusIsSuccess();
 
-    Region<?, ?> copy = server.getCache().getRegion("/COPY");
+    gfsh.executeAndAssertThat(
+        "create region --name=" + SEPARATOR + "COPY --template-region=" + SEPARATOR + "TEMPLATE")
+        .statusIsSuccess();
+
+    Region<?, ?> copy = server.getCache().getRegion(SEPARATOR + "COPY");
 
     assertThat(copy.getAttributes().getStatisticsEnabled()).isTrue();
     assertThat(copy.getAttributes().getEnableAsyncConflation()).isTrue();
@@ -560,14 +613,14 @@ public class CreateRegionCommandIntegrationTest {
         copy.getAttributes().getPartitionAttributes().getPartitionResolver().getClass().getName())
             .isEqualTo(TestPartitionResolver.class.getName());
 
-    gfsh.executeAndAssertThat("destroy region --name=/COPY").statusIsSuccess();
-    gfsh.executeAndAssertThat("destroy region --name=/TEMPLATE").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "COPY").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "TEMPLATE").statusIsSuccess();
   }
 
   @Test
   public void cannotSetRegionExpirationForPartitionedRegion() {
     gfsh.executeAndAssertThat(
-        "create region --enable-statistics=true --name=/FOO --type=PARTITION " +
+        "create region --enable-statistics=true --name=" + SEPARATOR + "FOO --type=PARTITION " +
             "--region-idle-time-expiration=1 --region-time-to-live-expiration=1")
         .statusIsError()
         .containsOutput(
@@ -580,13 +633,13 @@ public class CreateRegionCommandIntegrationTest {
         "create region --name=FOO --type=REPLICATE --eviction-action=local-destroy")
         .statusIsSuccess();
 
-    Region<?, ?> foo = server.getCache().getRegion("/FOO");
+    Region<?, ?> foo = server.getCache().getRegion(SEPARATOR + "FOO");
     assertThat(foo.getAttributes().getEvictionAttributes().getAction())
         .isEqualTo(EvictionAction.LOCAL_DESTROY);
     assertThat(foo.getAttributes().getEvictionAttributes().getAlgorithm())
         .isEqualTo(EvictionAlgorithm.LRU_HEAP);
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
@@ -596,7 +649,7 @@ public class CreateRegionCommandIntegrationTest {
             + TestObjectSizer.class.getName())
         .statusIsSuccess();
 
-    Region<?, ?> foo = server.getCache().getRegion("/FOO");
+    Region<?, ?> foo = server.getCache().getRegion(SEPARATOR + "FOO");
     assertThat(foo.getAttributes().getEvictionAttributes().getAction())
         .isEqualTo(EvictionAction.LOCAL_DESTROY);
     assertThat(foo.getAttributes().getEvictionAttributes().getAlgorithm())
@@ -604,7 +657,7 @@ public class CreateRegionCommandIntegrationTest {
     assertThat(foo.getAttributes().getEvictionAttributes().getObjectSizer().getClass().getName())
         .isEqualTo(TestObjectSizer.class.getName());
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
@@ -614,14 +667,14 @@ public class CreateRegionCommandIntegrationTest {
             "--eviction-action=overflow-to-disk")
         .statusIsSuccess();
 
-    Region<?, ?> foo = server.getCache().getRegion("/FOO");
+    Region<?, ?> foo = server.getCache().getRegion(SEPARATOR + "FOO");
     assertThat(foo.getAttributes().getEvictionAttributes().getAction())
         .isEqualTo(EvictionAction.OVERFLOW_TO_DISK);
     assertThat(foo.getAttributes().getEvictionAttributes().getAlgorithm())
         .isEqualTo(EvictionAlgorithm.LRU_ENTRY);
     assertThat(foo.getAttributes().getEvictionAttributes().getMaximum()).isEqualTo(1001);
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
@@ -631,14 +684,14 @@ public class CreateRegionCommandIntegrationTest {
             "--eviction-action=overflow-to-disk")
         .statusIsSuccess();
 
-    Region<?, ?> foo = server.getCache().getRegion("/FOO");
+    Region<?, ?> foo = server.getCache().getRegion(SEPARATOR + "FOO");
     assertThat(foo.getAttributes().getEvictionAttributes().getAction())
         .isEqualTo(EvictionAction.OVERFLOW_TO_DISK);
     assertThat(foo.getAttributes().getEvictionAttributes().getAlgorithm())
         .isEqualTo(EvictionAlgorithm.LRU_MEMORY);
     assertThat(foo.getAttributes().getEvictionAttributes().getMaximum()).isEqualTo(1001);
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
@@ -649,7 +702,7 @@ public class CreateRegionCommandIntegrationTest {
             + TestObjectSizer.class.getName())
         .statusIsSuccess();
 
-    Region<?, ?> foo = server.getCache().getRegion("/FOO");
+    Region<?, ?> foo = server.getCache().getRegion(SEPARATOR + "FOO");
     EvictionAttributes attrs = foo.getAttributes().getEvictionAttributes();
     assertThat(attrs.getAction()).isEqualTo(EvictionAction.OVERFLOW_TO_DISK);
     assertThat(attrs.getAlgorithm()).isEqualTo(EvictionAlgorithm.LRU_MEMORY);
@@ -657,7 +710,7 @@ public class CreateRegionCommandIntegrationTest {
     assertThat(attrs.getObjectSizer().getClass().getName())
         .isEqualTo(TestObjectSizer.class.getName());
 
-    gfsh.executeAndAssertThat("destroy region --name=/FOO").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "FOO").statusIsSuccess();
   }
 
   @Test
@@ -679,12 +732,14 @@ public class CreateRegionCommandIntegrationTest {
   @Test
   public void createSubRegion() {
     gfsh.executeAndAssertThat("create region --name=region --type=REPLICATE").statusIsSuccess();
-    gfsh.executeAndAssertThat("create region --name=region/region1 --type=REPLICATE")
+    gfsh.executeAndAssertThat(
+        "create region --name=region" + SEPARATOR + "region1 --type=REPLICATE")
         .statusIsSuccess();
 
-    Region<?, ?> subregion = server.getCache().getRegion("/region/region1");
+    Region<?, ?> subregion =
+        server.getCache().getRegion(SEPARATOR + "region" + SEPARATOR + "region1");
     assertThat(subregion).isNotNull();
 
-    gfsh.executeAndAssertThat("destroy region --name=/region").statusIsSuccess();
+    gfsh.executeAndAssertThat("destroy region --name=" + SEPARATOR + "region").statusIsSuccess();
   }
 }
