@@ -37,12 +37,12 @@ import org.springframework.shell.core.annotation.CliOption;
 import org.apache.geode.annotations.Immutable;
 import org.apache.geode.internal.net.SSLConfig;
 import org.apache.geode.internal.net.SSLConfigurationFactory;
+import org.apache.geode.internal.net.SSLUtil;
 import org.apache.geode.internal.security.SecurableCommunicationChannel;
 import org.apache.geode.management.cli.CliMetaData;
 import org.apache.geode.management.cli.ConverterHint;
 import org.apache.geode.management.internal.JmxManagerLocatorRequest;
 import org.apache.geode.management.internal.JmxManagerLocatorResponse;
-import org.apache.geode.management.internal.SSLUtil;
 import org.apache.geode.management.internal.cli.LogWrapper;
 import org.apache.geode.management.internal.cli.converters.ConnectionEndpointConverter;
 import org.apache.geode.management.internal.cli.domain.ConnectToLocatorResult;
@@ -168,26 +168,27 @@ public class ConnectCommand extends OfflineGfshCommand {
       return result;
     }
 
-    // since 1.14, only allow gfsh to connect to cluster that's older than 1.10
     String remoteVersion = null;
-    String gfshVersion = gfsh.getVersion();
+    String remoteGeodeSerializationVersion = null;
     try {
       remoteVersion = invoker.getRemoteVersion();
-      int minorVersion = Integer.parseInt(versionComponent(remoteVersion, VERSION_MINOR));
-      if (versionComponent(remoteVersion, VERSION_MAJOR).equals("1") && minorVersion >= 10 ||
-          versionComponent(remoteVersion, VERSION_MAJOR).equals("9") && minorVersion >= 9) {
-        InfoResultModel versionInfo = result.addInfo("versionInfo");
-        versionInfo.addLine("You are connected to a cluster of version: " + remoteVersion);
-        return result;
-      }
+      remoteGeodeSerializationVersion = getRemoteSerializationVersion(invoker);
     } catch (Exception ex) {
       // if unable to get the remote version, we are certainly talking to
       // a pre-1.5 cluster
       gfsh.logInfo("failed to get the the remote version.", ex);
     }
 
+    String ourSerializationVersion = gfsh.getGeodeSerializationVersion();
+    if (shouldConnect(ourSerializationVersion, remoteVersion, remoteGeodeSerializationVersion)) {
+      InfoResultModel versionInfo = result.addInfo("versionInfo");
+      versionInfo.addLine("You are connected to a cluster of version: " + remoteVersion);
+      return result;
+    }
+
     // will reach here only when remoteVersion is not available or does not match
     invoker.stop();
+    String gfshVersion = gfsh.getVersion();
     if (remoteVersion == null) {
       return ResultModel.createError(
           String.format("Cannot use a %s gfsh client to connect to this cluster.", gfshVersion));
@@ -197,9 +198,56 @@ public class ConnectCommand extends OfflineGfshCommand {
     }
   }
 
-  private static String versionComponent(String version, int component) {
+  private static String getRemoteSerializationVersion(OperationInvoker invoker) {
+    try {
+      return invoker.getRemoteGeodeSerializationVersion();
+    } catch (Exception ignore) {
+      // expected to fail for Geode cluster older than 1.12
+      return null;
+    }
+  }
+
+  /**
+   * because remote serialization version was not exposed until 1.12, but we are compatible back to
+   * 1.10, then any 1.x remote serialization version implies compatibility; otherwise make some
+   * narrow assumptions about product version numbers known to be associated with 1.10/1.11 to fill
+   * the gap.
+   *
+   * It seems reasonable to commit to future compatibility with any future Geode of the same major,
+   * but we should probably draw the line somewhere and not promise that gfsh 1.x will be eternally
+   * compatible with Geode 2.x and later
+   */
+  static boolean shouldConnect(String ourSerializationVersion, String remoteVersion,
+      String remoteSerializationVersion) {
+    // pre 1.5
+    if (remoteVersion == null) {
+      return false;
+    }
+
+    // at least 1.12 (but only promise forward compatibility within same major)
+    if (remoteSerializationVersion != null) {
+      int ourMajor = versionComponent(ourSerializationVersion, VERSION_MAJOR);
+      int remoteMajor = versionComponent(remoteSerializationVersion, VERSION_MAJOR);
+      // assume Geode 2.x will support backward compatibility to 1.x
+      return remoteMajor >= 1 && remoteMajor <= ourMajor;
+    }
+
+    // after 1.5 but before 1.12, use remoteVersion to determine if 1.10 or after
+    int remoteMajorVersion = versionComponent(remoteVersion, VERSION_MAJOR);
+    int remoteMinorVersion = versionComponent(remoteVersion, VERSION_MINOR);
+    return remoteMajorVersion == 9 && remoteMinorVersion == 9 ||
+        remoteMajorVersion == 1 && remoteMinorVersion == 10 ||
+        remoteMajorVersion == 1 && remoteMinorVersion == 11;
+  }
+
+  private static int versionComponent(String version, int component) {
     String[] versionComponents = StringUtils.split(version, '.');
-    return versionComponents.length >= component + 1 ? versionComponents[component] : "";
+    try {
+      return versionComponents.length >= component + 1
+          ? Integer.parseInt(versionComponents[component]) : -1;
+    } catch (Exception invalidFormat) {
+      return -1;
+    }
   }
 
   /**
