@@ -14,6 +14,8 @@
  */
 package org.apache.geode.management.internal.cli.commands;
 
+import static org.apache.geode.management.cli.GfshCommand.EXPERIMENTAL;
+
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
@@ -130,11 +132,13 @@ public class StartServerCommand extends OfflineGfshCommand {
       @CliOption(key = CliStrings.START_SERVER__MEMCACHED_BIND_ADDRESS,
           help = CliStrings.START_SERVER__MEMCACHED_BIND_ADDRESS__HELP) final String memcachedBindAddress,
       @CliOption(key = CliStrings.START_SERVER__REDIS_PORT,
-          help = CliStrings.START_SERVER__REDIS_PORT__HELP) final Integer redisPort,
+          help = EXPERIMENTAL + CliStrings.START_SERVER__REDIS_PORT__HELP) final Integer redisPort,
       @CliOption(key = CliStrings.START_SERVER__REDIS_BIND_ADDRESS,
-          help = CliStrings.START_SERVER__REDIS_BIND_ADDRESS__HELP) final String redisBindAddress,
+          help = EXPERIMENTAL
+              + CliStrings.START_SERVER__REDIS_BIND_ADDRESS__HELP) final String redisBindAddress,
       @CliOption(key = CliStrings.START_SERVER__REDIS_PASSWORD,
-          help = CliStrings.START_SERVER__REDIS_PASSWORD__HELP) final String redisPassword,
+          help = EXPERIMENTAL
+              + CliStrings.START_SERVER__REDIS_PASSWORD__HELP) final String redisPassword,
       @CliOption(key = CliStrings.START_SERVER__MESSAGE__TIME__TO__LIVE,
           help = CliStrings.START_SERVER__MESSAGE__TIME__TO__LIVE__HELP) final Integer messageTimeToLive,
       @CliOption(key = CliStrings.START_SERVER__OFF_HEAP_MEMORY_SIZE,
@@ -301,6 +305,18 @@ public class StartServerCommand extends OfflineGfshCommand {
         ConfigurationProperties.HTTP_SERVICE_PORT, httpServicePort);
     StartMemberUtils.setPropertyIfNotNull(gemfireProperties,
         ConfigurationProperties.HTTP_SERVICE_BIND_ADDRESS, httpServiceBindAddress);
+
+    // if compatible-with-redis-port, compatible-with-redis-bind-address, or
+    // compatible-with-redis-password are specified in the command line, REDIS_ENABLED should be set
+    // to true
+    String stringRedisPort;
+    stringRedisPort = redisPort == null ? "" : redisPort.toString();
+
+    if (StringUtils.isNotBlank(stringRedisPort) || StringUtils.isNotBlank(redisPassword)
+        || StringUtils.isNotBlank(redisBindAddress)) {
+      gemfireProperties.setProperty(ConfigurationProperties.REDIS_ENABLED, "true");
+    }
+
     // if username is specified in the command line, it will overwrite what's set in the
     // properties file
     if (StringUtils.isNotBlank(userName)) {
