@@ -25,6 +25,7 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.PriorityQueue;
 import java.util.Queue;
 import java.util.Set;
@@ -1038,6 +1039,31 @@ public class TestObjectForJSONFormatter implements PdxSerializable {
     return true;
   }
 
+  @Override
+  public int hashCode() {
+    int result = Objects.hash(p_bool, p_byte, p_short, p_int, p_long, p_float, p_double, w_bool,
+        w_byte, w_short, w_int, w_long, w_bigInt, w_float, w_bigDec, w_double, w_string, c_list,
+        c_set, c_queue, c_deque, m_empByCity, day);
+    result = 31 * result + Arrays.hashCode(p_boolArray);
+    result = 31 * result + Arrays.hashCode(p_byteArray);
+    result = 31 * result + Arrays.hashCode(p_shortArray);
+    result = 31 * result + Arrays.hashCode(p_intArray);
+    result = 31 * result + Arrays.hashCode(p_longArray);
+    result = 31 * result + Arrays.hashCode(p_floatArray);
+    result = 31 * result + Arrays.hashCode(p_doubleArray);
+    result = 31 * result + Arrays.hashCode(w_boolArray);
+    result = 31 * result + Arrays.hashCode(w_byteArray);
+    result = 31 * result + Arrays.hashCode(w_shortArray);
+    result = 31 * result + Arrays.hashCode(w_intArray);
+    result = 31 * result + Arrays.hashCode(w_longArray);
+    result = 31 * result + Arrays.hashCode(w_bigIntArray);
+    result = 31 * result + Arrays.hashCode(w_floatArray);
+    result = 31 * result + Arrays.hashCode(w_bigDecArray);
+    result = 31 * result + Arrays.hashCode(w_doubleArray);
+    result = 31 * result + Arrays.hashCode(w_strArray);
+    return result;
+  }
+
   @Override
   public String toString() {
     return "TestObjectForJSONFormatter [p_bool=" + p_bool + ", p_byte=" + p_byte + ", p_short="
