@@ -14,6 +14,7 @@
  */
 package org.apache.geode.cache.lucene;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.cache.lucene.test.LuceneTestUtilities.DEFAULT_FIELD;
 import static org.apache.geode.cache.lucene.test.LuceneTestUtilities.IntRangeQueryProvider;
 import static org.apache.geode.cache.lucene.test.LuceneTestUtilities.verifyQueryKeyAndValues;
@@ -349,7 +350,8 @@ public class LuceneQueriesIntegrationTest extends LuceneIntegrationTest {
           "Should have got the exception because the queue does not exist for the non created index ");
     } catch (Exception ex) {
       assertEquals(ex.getMessage(),
-          "java.lang.IllegalStateException: The AEQ does not exist for the index index2 region /index");
+          "java.lang.IllegalStateException: The AEQ does not exist for the index index2 region "
+              + SEPARATOR + "index");
       assertFalse(result);
     }
   }
