@@ -56,7 +56,7 @@ import org.apache.geode.distributed.internal.DistributionConfig;
 import org.apache.geode.internal.cache.GemFireCacheImpl;
 import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.LocalRegion;
-import org.apache.geode.internal.serialization.Version;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.test.awaitility.GeodeAwaitility;
 import org.apache.geode.test.dunit.DistributedTestUtils;
@@ -136,7 +136,7 @@ public abstract class LuceneSearchWithRollingUpgradeTestBase extends JUnit4Distr
     VM rollClient = Host.getHost(0).getVM(VersionManager.CURRENT_VERSION, oldClient.getId());
     rollClient.invoke(invokeCreateClientCache(getClientSystemProperties(), hostNames, locatorPorts,
         subscriptionEnabled, singleHopEnabled));
-    rollClient.invoke(invokeAssertVersion(Version.CURRENT_ORDINAL));
+    rollClient.invoke(invokeAssertVersion(KnownVersion.CURRENT_ORDINAL));
     return rollClient;
   }
 
@@ -348,7 +348,7 @@ public abstract class LuceneSearchWithRollingUpgradeTestBase extends JUnit4Distr
     VM rollServer = Host.getHost(0).getVM(VersionManager.CURRENT_VERSION, oldServer.getId());
     rollServer.invoke(invokeCreateCache(locatorPorts == null ? getSystemPropertiesPost71()
         : getSystemPropertiesPost71(locatorPorts)));
-    rollServer.invoke(invokeAssertVersion(Version.CURRENT_ORDINAL));
+    rollServer.invoke(invokeAssertVersion(KnownVersion.CURRENT_ORDINAL));
     return rollServer;
   }
 
@@ -718,9 +718,27 @@ public abstract class LuceneSearchWithRollingUpgradeTestBase extends JUnit4Distr
     Method getDistributedMemberMethod = ds.getClass().getMethod("getDistributedMember");
     getDistributedMemberMethod.setAccessible(true);
     Object member = getDistributedMemberMethod.invoke(ds);
-    Method getVersionObjectMethod = member.getClass().getMethod("getVersionObject");
-    getVersionObjectMethod.setAccessible(true);
-    Object thisVersion = getVersionObjectMethod.invoke(member);
+
+    Method getVersionMethod;
+    /*
+     * The method to get the version from an InternalDistributedMember has changed over time:
+     *
+     * 1. getVersionObject()
+     * 2. getVersionOrdinalObject()
+     * 3. getVersion()
+     */
+    try {
+      getVersionMethod = member.getClass().getMethod("getVersion");
+    } catch (final NoSuchMethodException e) {
+      try {
+        getVersionMethod = member.getClass().getMethod("getVersionOrdinalObject");
+      } catch (final NoSuchMethodException e2) {
+        getVersionMethod = member.getClass().getMethod("getVersionObject");
+      }
+    }
+
+    getVersionMethod.setAccessible(true);
+    Object thisVersion = getVersionMethod.invoke(member);
     Method getOrdinalMethod = thisVersion.getClass().getMethod("ordinal");
     getOrdinalMethod.setAccessible(true);
     short thisOrdinal = (Short) getOrdinalMethod.invoke(thisVersion);
