@@ -16,18 +16,22 @@ package org.apache.geode.distributed.internal.membership.gms.membership;
 
 import static org.apache.geode.test.awaitility.GeodeAwaitility.await;
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatNoException;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.hamcrest.core.IsEqual.equalTo;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyBoolean;
 import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.ArgumentMatchers.contains;
 import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Matchers.isA;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.timeout;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
@@ -83,7 +87,7 @@ import org.apache.geode.distributed.internal.membership.gms.messages.ViewAckMess
 import org.apache.geode.distributed.internal.membership.gms.util.MemberIdentifierUtil;
 import org.apache.geode.distributed.internal.tcpserver.HostAndPort;
 import org.apache.geode.distributed.internal.tcpserver.TcpClient;
-import org.apache.geode.internal.serialization.Version;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.test.junit.categories.MembershipTest;
 
 @Category({MembershipTest.class})
@@ -115,11 +119,18 @@ public class GMSJoinLeaveJUnitTest {
 
   public void initMocks(boolean enableNetworkPartition, boolean useTestGMSJoinLeave)
       throws Exception {
+    String locator = "localhost[12345]";
+    initMocks(enableNetworkPartition, useTestGMSJoinLeave, locator, locator);
+  }
+
+  public void initMocks(boolean enableNetworkPartition, boolean useTestGMSJoinLeave,
+      String locators, String startLocator)
+      throws Exception {
     mockConfig = mock(MembershipConfig.class);
     when(mockConfig.isNetworkPartitionDetectionEnabled()).thenReturn(enableNetworkPartition);
     when(mockConfig.getSecurityUDPDHAlgo()).thenReturn("");
-    when(mockConfig.getStartLocator()).thenReturn("localhost[12345]");
-    when(mockConfig.getLocators()).thenReturn("localhost[12345]");
+    when(mockConfig.getStartLocator()).thenReturn(startLocator);
+    when(mockConfig.getLocators()).thenReturn(locators);
     when(mockConfig.getMcastPort()).thenReturn(0);
     when(mockConfig.getMemberTimeout()).thenReturn(2000L);
 
@@ -166,7 +177,7 @@ public class GMSJoinLeaveJUnitTest {
     mockOldMember = services.getMemberFactory().create(
         MemberDataBuilder.newBuilderForLocalHost("localhost")
             .setMembershipPort(8700).build());
-    ((MemberIdentifierImpl) mockOldMember).setVersionObjectForTest(Version.GFE_56);
+    ((MemberIdentifierImpl) mockOldMember).setVersionForTest(KnownVersion.OLDEST);
     locatorClient = mock(TcpClient.class);
 
     if (useTestGMSJoinLeave) {
@@ -257,7 +268,7 @@ public class GMSJoinLeaveJUnitTest {
     // simulate a response being received
     MemberIdentifier sender = mockMembers[2];
     FindCoordinatorResponse resp = new FindCoordinatorResponse(coordinator, sender, null, 0);
-    gmsJoinLeave.processMessage(resp);
+    gmsJoinLeave.processFindCoordinatorResponseMessage(resp);
     // tell GMSJoinLeave that a unit test is running so it won't clear the
     // responses collection
     gmsJoinLeave.unitTesting.add("findCoordinatorFromView");
@@ -273,7 +284,8 @@ public class GMSJoinLeaveJUnitTest {
   public void testProcessJoinMessageRejectOldMemberVersion() throws Exception {
     initMocks();
 
-    gmsJoinLeave.processMessage(new JoinRequestMessage(mockOldMember, mockOldMember, null, -1, 0));
+    gmsJoinLeave.processJoinRequestMessage(
+        new JoinRequestMessage(mockOldMember, mockOldMember, null, -1, 0));
     assertTrue("JoinRequest should not have been added to view request",
         gmsJoinLeave.getViewRequests().size() == 0);
     verify(messenger).send(isA(JoinResponseMessage.class));
@@ -286,7 +298,7 @@ public class GMSJoinLeaveJUnitTest {
     List<MemberIdentifier> members = Arrays.asList(mockMembers);
     GMSMembershipView v = new GMSMembershipView(mockMembers[0], 2, members);
     InstallViewMessage message = getInstallViewMessage(v, null, false);
-    gmsJoinLeave.processMessage(message);
+    gmsJoinLeave.processInstallViewMessage(message);
     verify(manager).forceDisconnect(isA(String.class));
   }
 
@@ -298,7 +310,8 @@ public class GMSJoinLeaveJUnitTest {
         .thenThrow(new SecurityException("we want to fail auth here"));
 
     gmsJoinLeave
-        .processMessage(new JoinRequestMessage(mockMembers[0], mockMembers[0], credentials, -1, 0));
+        .processJoinRequestMessage(
+            new JoinRequestMessage(mockMembers[0], mockMembers[0], credentials, -1, 0));
     assertTrue("JoinRequest should not have been added to view request",
         gmsJoinLeave.getViewRequests().size() == 0);
     verify(messenger).send(isA(JoinResponseMessage.class));
@@ -311,7 +324,8 @@ public class GMSJoinLeaveJUnitTest {
         .thenThrow(new SecurityException("we want to fail auth here"));
 
     gmsJoinLeave
-        .processMessage(new JoinRequestMessage(mockMembers[0], mockMembers[0], null, -1, 0));
+        .processJoinRequestMessage(
+            new JoinRequestMessage(mockMembers[0], mockMembers[0], null, -1, 0));
     assertTrue("JoinRequest should not have been added to view request",
         gmsJoinLeave.getViewRequests().size() == 0);
     verify(messenger).send(isA(JoinResponseMessage.class));
@@ -327,12 +341,12 @@ public class GMSJoinLeaveJUnitTest {
     JoinResponseMessage[] joinResponse = gmsJoinLeave.getJoinResponseMessage();
 
     JoinResponseMessage jrm = new JoinResponseMessage(mockMembers[0], new byte[9], 233);
-    gmsJoinLeave.processMessage(jrm);
+    gmsJoinLeave.processJoinResponseMessage(jrm);
     // this should NOT logs, this is just to inform member succesful joining
     Assert.assertEquals(null, joinResponse[0]);
 
     jrm = new JoinResponseMessage("rejected...", 0);
-    gmsJoinLeave.processMessage(jrm);
+    gmsJoinLeave.processJoinResponseMessage(jrm);
     // this should log..
     Assert.assertEquals(jrm, joinResponse[0]);
   }
@@ -352,12 +366,12 @@ public class GMSJoinLeaveJUnitTest {
       netView.setPublicKey(member, member.toString());
     }
     InstallViewMessage installViewMessage = getInstallViewMessage(netView, credentials, true);
-    gmsJoinLeave.processMessage(installViewMessage);
+    gmsJoinLeave.processInstallViewMessage(installViewMessage);
     verify(messenger).send(isA(ViewAckMessage.class));
 
     // install the view
     installViewMessage = getInstallViewMessage(netView, credentials, false);
-    gmsJoinLeave.processMessage(installViewMessage);
+    gmsJoinLeave.processInstallViewMessage(installViewMessage);
     Assert.assertEquals(netView, gmsJoinLeave.getView());
   }
 
@@ -391,7 +405,7 @@ public class GMSJoinLeaveJUnitTest {
     LeaveRequestMessage msg =
         new LeaveRequestMessage(gmsJoinLeave.getMemberID(), mockMembers[1], "leaving for test");
     msg.setSender(mockMembers[1]);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processLeaveRequestMessage(msg);
     assertTrue(gmsJoinLeave.isMemberLeaving(mockMembers[1]));
   }
 
@@ -447,7 +461,7 @@ public class GMSJoinLeaveJUnitTest {
     // try to install an older view where viewId < currentView.viewId
     GMSMembershipView olderNetView = new GMSMembershipView(mockMembers[0], 0, mbrs);
     InstallViewMessage installViewMessage = getInstallViewMessage(olderNetView, credentials, false);
-    gmsJoinLeave.processMessage(installViewMessage);
+    gmsJoinLeave.processInstallViewMessage(installViewMessage);
     Assert.assertNotEquals(gmsJoinLeave.getView(), olderNetView);
   }
 
@@ -467,7 +481,7 @@ public class GMSJoinLeaveJUnitTest {
     // install the view
     GMSMembershipView netView = new GMSMembershipView(mockMembers[0], viewId, mbrs);
     InstallViewMessage installViewMessage = getInstallViewMessage(netView, credentials, false);
-    gmsJoinLeave.processMessage(installViewMessage);
+    gmsJoinLeave.processInstallViewMessage(installViewMessage);
 
     Assert.assertNotEquals(netView, gmsJoinLeave.getView());
     verify(mockManager).forceDisconnect(isA(String.class));
@@ -481,7 +495,7 @@ public class GMSJoinLeaveJUnitTest {
     // test that a non-member can't remove another member
     RemoveMemberMessage msg = new RemoveMemberMessage(mockMembers[0], mockMembers[1], reason);
     msg.setSender(MemberIdentifierUtil.createMemberID(9000));
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processRemoveMemberMessage(msg);
     assertTrue("RemoveMemberMessage should not have been added to view requests",
         gmsJoinLeave.getViewRequests().size() == 0);
   }
@@ -498,10 +512,10 @@ public class GMSJoinLeaveJUnitTest {
     LeaveRequestMessage msg =
         new LeaveRequestMessage(gmsJoinLeave.getMemberID(), mockMembers[0], reason);
     msg.setSender(mockMembers[0]);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processLeaveRequestMessage(msg);
     msg = new LeaveRequestMessage(gmsJoinLeave.getMemberID(), mockMembers[0], reason);
     msg.setSender(mockMembers[0]);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processLeaveRequestMessage(msg);
 
     waitForViewAndNoRequestsInProgress(7);
 
@@ -524,10 +538,10 @@ public class GMSJoinLeaveJUnitTest {
     RemoveMemberMessage msg =
         new RemoveMemberMessage(gmsJoinLeave.getMemberID(), mockMembers[0], reason);
     msg.setSender(mockMembers[0]);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processRemoveMemberMessage(msg);
     msg = new RemoveMemberMessage(gmsJoinLeave.getMemberID(), mockMembers[0], reason);
     msg.setSender(mockMembers[0]);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processRemoveMemberMessage(msg);
 
     waitForViewAndNoRequestsInProgress(7);
 
@@ -543,7 +557,8 @@ public class GMSJoinLeaveJUnitTest {
   public void testDuplicateJoinRequestDoesNotCauseNewView() throws Exception {
     initMocks();
     when(healthMonitor.checkIfAvailable(isA(MemberIdentifier.class), isA(String.class),
-        isA(Boolean.class))).thenReturn(true);
+        isA(Boolean.class), isA(Boolean.class))).thenReturn(true);
+
     gmsJoinLeave.unitTesting.add("noRandomViewChange");
     prepareAndInstallView(gmsJoinLeaveMemberId,
         createMemberList(gmsJoinLeaveMemberId, mockMembers[0]));
@@ -552,10 +567,10 @@ public class GMSJoinLeaveJUnitTest {
     JoinRequestMessage msg =
         new JoinRequestMessage(gmsJoinLeaveMemberId, mockMembers[2], null, -1, 0);
     msg.setSender(mockMembers[2]);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processJoinRequestMessage(msg);
     msg = new JoinRequestMessage(gmsJoinLeaveMemberId, mockMembers[2], null, -1, 0);
     msg.setSender(mockMembers[2]);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processJoinRequestMessage(msg);
 
     waitForViewAndNoRequestsInProgress(7);
 
@@ -572,7 +587,7 @@ public class GMSJoinLeaveJUnitTest {
     assertTrue("expected member to only be in the view once: " + mockMembers[2] + "; view: " + view,
         occurrences == 1);
     verify(healthMonitor, times(5)).checkIfAvailable(isA(MemberIdentifier.class),
-        isA(String.class), isA(Boolean.class));
+        isA(String.class), isA(Boolean.class), isA(Boolean.class));
   }
 
 
@@ -598,7 +613,7 @@ public class GMSJoinLeaveJUnitTest {
     RemoveMemberMessage msg = new RemoveMemberMessage(gmsJoinLeaveMemberId,
         MemberIdentifierUtil.createMemberID(10000), "removing for test");
     msg.setSender(mockMembers[0]);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processRemoveMemberMessage(msg);
     verify(messenger).send(isA(RemoveMemberMessage.class));
   }
 
@@ -618,13 +633,13 @@ public class GMSJoinLeaveJUnitTest {
         createMemberList(mockMembers[0], previousMemberId, mockMembers[1]));
     InstallViewMessage viewMessage = new InstallViewMessage(view, 0, false);
     viewMessage.setSender(mockMembers[0]);
-    gmsJoinLeave.processMessage(viewMessage);
+    gmsJoinLeave.processInstallViewMessage(viewMessage);
     assertEquals(0, gmsJoinLeaveMemberId.getVmViewId());
     // a RemoveMember message should cause it to force-disconnect
     RemoveMemberMessage msg =
         new RemoveMemberMessage(gmsJoinLeaveMemberId, gmsJoinLeaveMemberId, "removing for test");
     msg.setSender(mockMembers[0]);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processRemoveMemberMessage(msg);
     verify(manager).forceDisconnect("removing for test");
   }
 
@@ -637,7 +652,7 @@ public class GMSJoinLeaveJUnitTest {
     RemoveMemberMessage msg =
         new RemoveMemberMessage(mockMembers[0], gmsJoinLeave.getMemberID(), reason);
     msg.setSender(mockMembers[1]);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processRemoveMemberMessage(msg);
     verify(manager).forceDisconnect(reason);
   }
 
@@ -651,7 +666,7 @@ public class GMSJoinLeaveJUnitTest {
     LeaveRequestMessage msg =
         new LeaveRequestMessage(gmsJoinLeave.getMemberID(), gmsJoinLeave.getMemberID(), reason);
     msg.setSender(mockMembers[1]);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processLeaveRequestMessage(msg);
     verify(manager).forceDisconnect(reason);
   }
 
@@ -664,7 +679,7 @@ public class GMSJoinLeaveJUnitTest {
     LeaveRequestMessage msg =
         new LeaveRequestMessage(gmsJoinLeave.getMemberID(), mockMembers[1], reason);
     msg.setSender(mockMembers[1]);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processLeaveRequestMessage(msg);
     assertTrue("Expected leave request from non-member to be ignored",
         gmsJoinLeave.getViewRequests().isEmpty());
   }
@@ -686,7 +701,7 @@ public class GMSJoinLeaveJUnitTest {
     MemberIdentifier creator = view.getCreator();
     LeaveRequestMessage msg = new LeaveRequestMessage(creator, creator, reason);
     msg.setSender(creator);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processLeaveRequestMessage(msg);
     assertTrue("Expected becomeCoordinator to be invoked", gmsJoinLeave.isCoordinator());
   }
 
@@ -700,7 +715,7 @@ public class GMSJoinLeaveJUnitTest {
     MemberIdentifier creator = view.getCreator();
     RemoveMemberMessage msg = new RemoveMemberMessage(creator, creator, reason);
     msg.setSender(creator);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processRemoveMemberMessage(msg);
     assertTrue("Expected becomeCoordinator to be invoked", gmsJoinLeave.isCoordinator());
   }
 
@@ -719,10 +734,10 @@ public class GMSJoinLeaveJUnitTest {
     prepareAndInstallView(C, createMemberList(A, B, C, D, E));
     LeaveRequestMessage msg = new LeaveRequestMessage(B, C, "leaving for test");
     msg.setSender(C);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processLeaveRequestMessage(msg);
     RemoveMemberMessage removeMemberMessage = new RemoveMemberMessage(B, A, "removing for test");
     removeMemberMessage.setSender(B);
-    gmsJoinLeave.processMessage(removeMemberMessage);
+    gmsJoinLeave.processRemoveMemberMessage(removeMemberMessage);
     assertTrue("Expected becomeCoordinator to be invoked", gmsJoinLeave.isCoordinator());
   }
 
@@ -753,7 +768,7 @@ public class GMSJoinLeaveJUnitTest {
                 new ViewAckMessage(gmsJoinLeaveMemberId, installViewMessage.getView().getViewId(),
                     installViewMessage.isPreparing());
             viewAckMessage.setSender(recipient);
-            gmsJoinLeave.processMessage(viewAckMessage);
+            gmsJoinLeave.processViewAckMessage(viewAckMessage);
           }
           return null;
         });
@@ -762,11 +777,11 @@ public class GMSJoinLeaveJUnitTest {
 
     gmsJoinLeave.recordViewRequest(new LeaveRequestMessage(B, C, "removing for test"));
 
-    gmsJoinLeave.processMessage(new JoinRequestMessage(B, E, null, 1, 1));
+    gmsJoinLeave.processJoinRequestMessage(new JoinRequestMessage(B, E, null, 1, 1));
 
     RemoveMemberMessage msg = new RemoveMemberMessage(B, A, "crashed for test");
     msg.setSender(D);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processRemoveMemberMessage(msg);
 
     await().until(() -> gmsJoinLeave.isCoordinator() && gmsJoinLeave.getViewRequests().isEmpty());
 
@@ -786,7 +801,7 @@ public class GMSJoinLeaveJUnitTest {
     view.remove(creator);
     InstallViewMessage msg = getInstallViewMessage(view, creator, false);
     msg.setSender(creator);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processInstallViewMessage(msg);
     assertTrue("Expected it to become coordinator", gmsJoinLeave.isCoordinator());
   }
 
@@ -801,11 +816,11 @@ public class GMSJoinLeaveJUnitTest {
     MemberIdentifier creator = view.getCreator();
     LeaveRequestMessage leaveRequestMessage =
         new LeaveRequestMessage(gmsJoinLeaveMemberId, mockMembers[0], "leaving for test");
-    gmsJoinLeave.processMessage(leaveRequestMessage);
+    gmsJoinLeave.processLeaveRequestMessage(leaveRequestMessage);
     assertTrue(gmsJoinLeave.isCoordinator());
     InstallViewMessage msg = getInstallViewMessage(view, creator, false);
     msg.setSender(creator);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processInstallViewMessage(msg);
     assertTrue("Expected it to remain coordinator", gmsJoinLeave.isCoordinator());
   }
 
@@ -823,7 +838,7 @@ public class GMSJoinLeaveJUnitTest {
     view.add(gmsJoinLeaveMemberId);
     InstallViewMessage msg = getInstallViewMessage(view, creator, false);
     msg.setSender(creator);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processInstallViewMessage(msg);
     assertTrue("Expected it to stop being coordinator", !gmsJoinLeave.isCoordinator());
   }
 
@@ -834,6 +849,21 @@ public class GMSJoinLeaveJUnitTest {
     return installViewMessage;
   }
 
+  @Test
+  public void testNetworkPartitionDetectedWithNullView() throws Exception {
+    initMocks(true);
+    prepareAndInstallView(mockMembers[0], createMemberList(mockMembers[0], gmsJoinLeaveMemberId));
+
+    NetworkPartitionMessage message = new NetworkPartitionMessage();
+    message.setSender(gmsJoinLeaveMemberId);
+
+
+    // this creates a NPE that must be handled appropriately
+    gmsJoinLeave.currentView = null;
+    assertThatNoException().isThrownBy(() -> gmsJoinLeave.processNetworkPartitionMessage(message));
+
+  }
+
   @Test
   public void testNetworkPartitionDetected() throws Exception {
     initMocks(true);
@@ -853,7 +883,7 @@ public class GMSJoinLeaveJUnitTest {
     GMSMembershipView newView =
         new GMSMembershipView(mockMembers[0], gmsJoinLeave.getView().getViewId() + 1, mbrs);
     InstallViewMessage installViewMessage = getInstallViewMessage(newView, credentials, false);
-    gmsJoinLeave.processMessage(installViewMessage);
+    gmsJoinLeave.processInstallViewMessage(installViewMessage);
 
     Set<MemberIdentifier> crashes = new HashSet<>();
     crashes.add(mockMembers[1]);
@@ -865,22 +895,31 @@ public class GMSJoinLeaveJUnitTest {
         new GMSMembershipView(mockMembers[0], newView.getViewId() + 1, mbrs, Collections.emptySet(),
             crashes);
     installViewMessage = getInstallViewMessage(partitionView, credentials, false);
-    gmsJoinLeave.processMessage(installViewMessage);
+    gmsJoinLeave.processInstallViewMessage(installViewMessage);
 
     verify(manager).forceDisconnect(isA(String.class));
     verify(manager).quorumLost(crashes, newView);
   }
 
-  // Possibly modify test to check for network partition message in the force disconnect
   @Test
-  public void testNetworkPartitionMessageReceived() throws Exception {
+  public void testNetworkPartitionFromViewMemberReceived() throws Exception {
     initMocks();
     becomeCoordinatorForTest(gmsJoinLeave);
     NetworkPartitionMessage message = new NetworkPartitionMessage();
-    gmsJoinLeave.processMessage(message);
-    verify(manager).forceDisconnect(isA(String.class));
+    message.setSender(gmsJoinLeaveMemberId);
+    gmsJoinLeave.processNetworkPartitionMessage(message);
+    verify(manager).forceDisconnect(contains(gmsJoinLeaveMemberId.toString()));
   }
 
+  @Test
+  public void testNetworkPartitionMessageFromNonMemberIgnored() throws Exception {
+    initMocks();
+    becomeCoordinatorForTest(gmsJoinLeave);
+    NetworkPartitionMessage message = new NetworkPartitionMessage();
+    message.setSender(mockMembers[0]);
+    gmsJoinLeave.processNetworkPartitionMessage(message);
+    verify(manager, never()).forceDisconnect(isA(String.class));
+  }
 
   @Test
   public void testQuorumLossNotificationWithNetworkPartitionDetectionDisabled() throws Exception {
@@ -904,7 +943,7 @@ public class GMSJoinLeaveJUnitTest {
         new GMSMembershipView(mockMembers[0], gmsJoinLeave.getView().getViewId() + 1, mbrs,
             shutdowns, crashes);
     InstallViewMessage installViewMessage = getInstallViewMessage(newView, credentials, false);
-    gmsJoinLeave.processMessage(installViewMessage);
+    gmsJoinLeave.processInstallViewMessage(installViewMessage);
 
     crashes = new HashSet<>(crashes);
     crashes.add(mockMembers[1]);
@@ -915,7 +954,7 @@ public class GMSJoinLeaveJUnitTest {
     GMSMembershipView partitionView =
         new GMSMembershipView(mockMembers[0], newView.getViewId() + 1, mbrs, shutdowns, crashes);
     installViewMessage = getInstallViewMessage(partitionView, credentials, false);
-    gmsJoinLeave.processMessage(installViewMessage);
+    gmsJoinLeave.processInstallViewMessage(installViewMessage);
 
     verify(manager, never()).forceDisconnect(isA(String.class));
     verify(manager).quorumLost(crashes, newView);
@@ -929,11 +968,11 @@ public class GMSJoinLeaveJUnitTest {
     GMSMembershipView gmsView = gmsJoinLeave.getView();
     GMSMembershipView newView = new GMSMembershipView(gmsView, gmsView.getViewId() + 6);
     InstallViewMessage msg = getInstallViewMessage(newView, null, true);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processInstallViewMessage(msg);
 
     GMSMembershipView alternateView = new GMSMembershipView(gmsView, gmsView.getViewId() + 1);
     msg = getInstallViewMessage(alternateView, null, true);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processInstallViewMessage(msg);
 
     assertTrue(gmsJoinLeave.getPreparedView().equals(newView));
   }
@@ -942,7 +981,7 @@ public class GMSJoinLeaveJUnitTest {
   public void testNoViewAckCausesRemovalMessage() throws Exception {
     initMocks(true);
     when(healthMonitor.checkIfAvailable(isA(MemberIdentifier.class), isA(String.class),
-        isA(Boolean.class))).thenReturn(false);
+        isA(Boolean.class), isA(Boolean.class))).thenReturn(false);
     prepareAndInstallView(mockMembers[0], createMemberList(mockMembers[0], gmsJoinLeaveMemberId));
     GMSMembershipView oldView = gmsJoinLeave.getView();
     GMSMembershipView newView = new GMSMembershipView(oldView, oldView.getViewId() + 1);
@@ -954,7 +993,7 @@ public class GMSJoinLeaveJUnitTest {
     newView.remove(mockMembers[0]);
 
     InstallViewMessage installViewMessage = getInstallViewMessage(newView, credentials, false);
-    gmsJoinLeave.processMessage(installViewMessage);
+    gmsJoinLeave.processInstallViewMessage(installViewMessage);
 
     // this test's member-timeout * 3
     await()
@@ -964,7 +1003,7 @@ public class GMSJoinLeaveJUnitTest {
 
     verify(healthMonitor, timeout(10000).atLeast(1)).checkIfAvailable(
         isA(MemberIdentifier.class),
-        isA(String.class), isA(Boolean.class));
+        isA(String.class), isA(Boolean.class), isA(Boolean.class));
     // verify(messenger, atLeast(1)).send(isA(RemoveMemberMessage.class));
   }
 
@@ -1057,13 +1096,13 @@ public class GMSJoinLeaveJUnitTest {
 
     ViewAckMessage msg = new ViewAckMessage(gmsJoinLeaveMemberId, newViewId, true);
     msg.setSender(gmsJoinLeaveMemberId);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processViewAckMessage(msg);
 
     // ack the view on behalf of the other member, returning a conflicting view coming from a
     // locator that is trying to become coordinator
     msg = new ViewAckMessage(newViewId, gmsJoinLeaveMemberId, locatorView);
     msg.setSender(otherMember);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processViewAckMessage(msg);
 
     await()
         .until(() -> gmsJoinLeave.getViewCreator() != null);
@@ -1093,7 +1132,7 @@ public class GMSJoinLeaveJUnitTest {
     GMSMembershipView netView = new GMSMembershipView(mockMembers[0], 3/* new view id */,
         createMemberList(mockMembers[0], gmsJoinLeaveMemberId, mockMembers[1], mockMembers[3]));
     InstallViewMessage installViewMessage = getInstallViewMessage(netView, credentials, false);
-    gmsJoinLeave.processMessage(installViewMessage);
+    gmsJoinLeave.processInstallViewMessage(installViewMessage);
 
     // Now coordinator leaves
     gmsJoinLeave.memberShutdown(mockMembers[0], "Shutdown");
@@ -1124,7 +1163,7 @@ public class GMSJoinLeaveJUnitTest {
     // prepare the view
     GMSMembershipView netView = new GMSMembershipView(coordinator, viewId, members);
     InstallViewMessage installViewMessage = getInstallViewMessage(netView, credentials, false);
-    gmsJoinLeave.processMessage(installViewMessage);
+    gmsJoinLeave.processInstallViewMessage(installViewMessage);
     // verify(messenger).send(isA(ViewAckMessage.class));
   }
 
@@ -1147,7 +1186,7 @@ public class GMSJoinLeaveJUnitTest {
       initMocks(false);
       System.setProperty(GMSJoinLeave.BYPASS_DISCOVERY_PROPERTY, "true");
       gmsJoinLeave.join();
-      gmsJoinLeave.processMessage(
+      gmsJoinLeave.processJoinRequestMessage(
           new JoinRequestMessage(mockMembers[0], mockMembers[0], credentials, -1, 0));
       int viewRequests = gmsJoinLeave.getViewRequests().size();
 
@@ -1255,7 +1294,7 @@ public class GMSJoinLeaveJUnitTest {
       RemoveMemberMessage msg =
           new RemoveMemberMessage(gmsJoinLeaveMemberId, mockMembers[0], "crashed");
       msg.setSender(gmsJoinLeaveMemberId);
-      gmsJoinLeave.processMessage(msg);
+      gmsJoinLeave.processRemoveMemberMessage(msg);
       Timeout to =
           new Timeout(3 * MembershipConfig.MEMBER_REQUEST_COLLECTION_INTERVAL, new Times(1));
       verify(messenger, to).send(isA(NetworkPartitionMessage.class));
@@ -1278,7 +1317,7 @@ public class GMSJoinLeaveJUnitTest {
         RemoveMemberMessage msg =
             new RemoveMemberMessage(gmsJoinLeaveMemberId, mockMembers[i], "crashed");
         msg.setSender(gmsJoinLeaveMemberId);
-        gmsJoinLeave.processMessage(msg);
+        gmsJoinLeave.processRemoveMemberMessage(msg);
       }
       Timeout to = new Timeout(2 * MembershipConfig.MEMBER_REQUEST_COLLECTION_INTERVAL, never());
       verify(messenger, to).send(isA(NetworkPartitionMessage.class));
@@ -1305,7 +1344,7 @@ public class GMSJoinLeaveJUnitTest {
         RemoveMemberMessage msg =
             new RemoveMemberMessage(gmsJoinLeaveMemberId, mockMembers[i], "crashed");
         msg.setSender(gmsJoinLeaveMemberId);
-        gmsJoinLeave.processMessage(msg);
+        gmsJoinLeave.processRemoveMemberMessage(msg);
       }
 
       await("waiting for view creator to stop")
@@ -1330,7 +1369,7 @@ public class GMSJoinLeaveJUnitTest {
     preparedView.add(mockMembers[1]);
 
     InstallViewMessage msg = getInstallViewMessage(preparedView, null, true);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processInstallViewMessage(msg);
 
     becomeCoordinatorForTest(gmsJoinLeave);
 
@@ -1344,13 +1383,13 @@ public class GMSJoinLeaveJUnitTest {
     }
     ViewAckMessage vack = new ViewAckMessage(gmsJoinLeaveMemberId, viewId, true);
     vack.setSender(mockMembers[0]);
-    gmsJoinLeave.processMessage(vack);
+    gmsJoinLeave.processViewAckMessage(vack);
     vack = new ViewAckMessage(gmsJoinLeaveMemberId, viewId, true);
     vack.setSender(mockMembers[1]);
-    gmsJoinLeave.processMessage(vack);
+    gmsJoinLeave.processViewAckMessage(vack);
     vack = new ViewAckMessage(gmsJoinLeaveMemberId, viewId, true);
     vack.setSender(gmsJoinLeaveMemberId);
-    gmsJoinLeave.processMessage(vack);
+    gmsJoinLeave.processViewAckMessage(vack);
 
     await("view creator finishes").until(() -> vc.waiting);
     GMSMembershipView newView = gmsJoinLeave.getView();
@@ -1377,7 +1416,7 @@ public class GMSJoinLeaveJUnitTest {
     preparedView.setPublicKey(newMember, newMember.toString());
 
     InstallViewMessage msg = getInstallViewMessage(preparedView, null, true);
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processInstallViewMessage(msg);
 
     becomeCoordinatorForTest(gmsJoinLeave);
 
@@ -1391,13 +1430,13 @@ public class GMSJoinLeaveJUnitTest {
     }
     ViewAckMessage vack = new ViewAckMessage(gmsJoinLeaveMemberId, viewId, true);
     vack.setSender(mockMembers[0]);
-    gmsJoinLeave.processMessage(vack);
+    gmsJoinLeave.processViewAckMessage(vack);
     vack = new ViewAckMessage(gmsJoinLeaveMemberId, viewId, true);
     vack.setSender(newMember);
-    gmsJoinLeave.processMessage(vack);
+    gmsJoinLeave.processViewAckMessage(vack);
     vack = new ViewAckMessage(gmsJoinLeaveMemberId, viewId, true);
     vack.setSender(gmsJoinLeaveMemberId);
-    gmsJoinLeave.processMessage(vack);
+    gmsJoinLeave.processViewAckMessage(vack);
 
     await("view creator finishes").until(() -> vc.waiting);
     GMSMembershipView newView = gmsJoinLeave.getView();
@@ -1423,14 +1462,7 @@ public class GMSJoinLeaveJUnitTest {
   @Test
   public void testCoordinatorFindRequestSuccess() throws Exception {
     initMocks(false);
-    HashSet<MemberIdentifier> registrants = new HashSet<>();
-    registrants.add(mockMembers[0]);
-    FindCoordinatorResponse fcr = new FindCoordinatorResponse(mockMembers[0], mockMembers[0], false,
-        null, registrants, false, true, null);
-
-    when(locatorClient.requestToServer(isA(HostAndPort.class),
-        isA(FindCoordinatorRequest.class), anyInt(), anyBoolean()))
-            .thenReturn(fcr);
+    mockRequestToServer(isA(HostAndPort.class));
 
     boolean foundCoordinator = gmsJoinLeave.findCoordinator();
     assertTrue(gmsJoinLeave.searchState.toString(), foundCoordinator);
@@ -1441,24 +1473,82 @@ public class GMSJoinLeaveJUnitTest {
   public void testCoordinatorFindRequestFailure() throws Exception {
     try {
       initMocks(false);
-      HashSet<MemberIdentifier> registrants = new HashSet<>();
-      registrants.add(mockMembers[0]);
-      FindCoordinatorResponse fcr = new FindCoordinatorResponse(mockMembers[0], mockMembers[0],
-          false, null, registrants, false, true, null);
+      mockRequestToServer(eq(new HostAndPort("localhost", 12346)));
       GMSMembershipView view = createView();
       JoinResponseMessage jrm = new JoinResponseMessage(mockMembers[0], view, 0);
       gmsJoinLeave.setJoinResponseMessage(jrm);
 
-      when(locatorClient.requestToServer(eq(new HostAndPort("localhost", 12346)),
-          isA(FindCoordinatorRequest.class), anyInt(), anyBoolean()))
-              .thenReturn(fcr);
-
-      assertFalse("Should not be able to join ", gmsJoinLeave.join());
+      assertThatThrownBy(gmsJoinLeave::join)
+          .isInstanceOf(MembershipConfigurationException.class);
     } finally {
-
     }
   }
 
+  @Test
+  public void testJoinFailureWhenSleepInterrupted() throws Exception {
+    initMocks(false);
+    mockRequestToServer(isA(HostAndPort.class));
+
+    when(mockConfig.getMemberTimeout()).thenReturn(100L);
+    when(mockConfig.getJoinTimeout()).thenReturn(1000L);
+
+    GMSJoinLeave spyGmsJoinLeave = spy(gmsJoinLeave);
+    when(spyGmsJoinLeave.pauseIfThereIsNoCoordinator(-1, GMSJoinLeave.JOIN_RETRY_SLEEP))
+        .thenThrow(new InterruptedException());
+
+    assertThatThrownBy(spyGmsJoinLeave::join)
+        .isInstanceOf(MembershipConfigurationException.class)
+        .hasMessageContaining("Retry sleep interrupted");
+  }
+
+  @Test
+  public void testJoinFailureWhenTimeout() throws Exception {
+    initMocks(false);
+    mockRequestToServer(isA(HostAndPort.class));
+
+    assertThatThrownBy(() -> gmsJoinLeave.join())
+        .isInstanceOf(MembershipConfigurationException.class)
+        .hasMessageContaining("Operation timed out");
+  }
+
+  @Test
+  public void testPauseIfThereIsNoCoordinator() throws InterruptedException {
+    locatorClient = mock(TcpClient.class);
+    gmsJoinLeave = new GMSJoinLeave(locatorClient);
+    assertThat(gmsJoinLeave.pauseIfThereIsNoCoordinator(-1, GMSJoinLeave.JOIN_RETRY_SLEEP))
+        .isFalse();
+    assertThat(gmsJoinLeave.pauseIfThereIsNoCoordinator(1, GMSJoinLeave.JOIN_RETRY_SLEEP)).isTrue();
+  }
+
+  @Test
+  public void testJoinFailureWhenNoLocator() throws Exception {
+    final String locator1 = "locator1[12345]";
+    final String locator2 = "locator2[54321]";
+    locatorClient = mock(TcpClient.class);
+
+    initMocks(false, false, locator1 + ',' + locator2, locator1);
+    when(locatorClient.requestToServer(any(), any(), anyInt(), anyBoolean()))
+        .thenThrow(IOException.class);
+
+    assertThatThrownBy(gmsJoinLeave::join)
+        .isInstanceOf(MembershipConfigurationException.class)
+        .hasMessageContaining(
+            "Could not contact any of the locators: [HostAndPort[locator1:12345], HostAndPort[locator2:54321]]")
+        .hasCauseInstanceOf(IOException.class);
+  }
+
+  private void mockRequestToServer(HostAndPort hostAndPort)
+      throws IOException, ClassNotFoundException {
+    HashSet<MemberIdentifier> registrants = new HashSet<>();
+    registrants.add(mockMembers[0]);
+
+    FindCoordinatorResponse fcr = new FindCoordinatorResponse(mockMembers[0], mockMembers[0], false,
+        null, registrants, false, true, null);
+    when(locatorClient.requestToServer(hostAndPort,
+        isA(FindCoordinatorRequest.class), anyInt(), anyBoolean()))
+            .thenReturn(fcr);
+  }
+
   private void waitForViewAndFinalCheckInProgress(int viewId) throws InterruptedException {
     // wait for the view processing thread to collect and process the requests
     int sleeps = 0;
@@ -1587,8 +1677,8 @@ public class GMSJoinLeaveJUnitTest {
         new MemberIdentifierImpl(gmsJoinLeaveMemberId.getMemberData());
 
     // this test must live in the 1.12 and later lines so pick a pre-1.12 version
-    final Version oldVersion = Version.GEODE_1_11_0;
-    myMemberIDWithWrongVersion.setVersionObjectForTest(oldVersion);
+    final KnownVersion oldVersion = KnownVersion.GEODE_1_11_0;
+    myMemberIDWithWrongVersion.setVersionForTest(oldVersion);
 
     viewWithWrongVersion.remove(gmsJoinLeaveMemberId);
     viewWithWrongVersion.add(myMemberIDWithWrongVersion);
@@ -1596,8 +1686,8 @@ public class GMSJoinLeaveJUnitTest {
     gmsJoinLeave.installView(viewWithWrongVersion);
 
     assertThat(
-        gmsJoinLeave.getView().getCanonicalID(gmsJoinLeaveMemberId).getVersionOrdinalObject())
-            .isEqualTo(Version.getCurrentVersion());
+        gmsJoinLeave.getView().getCanonicalID(gmsJoinLeaveMemberId).getVersion())
+            .isEqualTo(KnownVersion.getCurrentVersion());
   }
 
   private void becomeCoordinatorForTest(GMSJoinLeave gmsJoinLeave) {
@@ -1626,7 +1716,7 @@ public class GMSJoinLeaveJUnitTest {
   private void processJoinMessage(MemberIdentifier coordinator,
       MemberIdentifier newMember, int port) {
     JoinRequestMessage reqMsg = new JoinRequestMessage(coordinator, newMember, null, port, 0);
-    gmsJoinLeave.processMessage(reqMsg);
+    gmsJoinLeave.processJoinRequestMessage(reqMsg);
   }
 
   private void processRemoveMessage(MemberIdentifier rMember) {
@@ -1634,7 +1724,7 @@ public class GMSJoinLeaveJUnitTest {
         new RemoveMemberMessage(gmsJoinLeave.getMemberID(), rMember, "testing");
     msg.setSender(gmsJoinLeave.getMemberID());
 
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processRemoveMemberMessage(msg);
   }
 
   private void processLeaveMessage(MemberIdentifier rMember) {
@@ -1642,6 +1732,6 @@ public class GMSJoinLeaveJUnitTest {
         new LeaveRequestMessage(gmsJoinLeave.getMemberID(), rMember, "testing");
     msg.setSender(rMember);
 
-    gmsJoinLeave.processMessage(msg);
+    gmsJoinLeave.processLeaveRequestMessage(msg);
   }
 }
