@@ -72,7 +72,7 @@ import org.apache.geode.distributed.internal.tcpserver.ConnectionWatcher;
 import org.apache.geode.distributed.internal.tcpserver.HostAndPort;
 import org.apache.geode.distributed.internal.tcpserver.TcpSocketCreator;
 import org.apache.geode.internal.lang.JavaWorkarounds;
-import org.apache.geode.internal.serialization.Version;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.logging.internal.executors.LoggingExecutors;
 import org.apache.geode.util.internal.GeodeGlossary;
 
@@ -346,11 +346,10 @@ public class GMSHealthMonitor<ID extends MemberIdentifier> implements HealthMoni
 
     @Override
     public void run() {
-      try {
+      try (DataInputStream in = new DataInputStream(socket.getInputStream())) {
         socket.setTcpNoDelay(true);
-        DataInputStream in = new DataInputStream(socket.getInputStream());
         OutputStream out = socket.getOutputStream();
-        @SuppressWarnings("UnusedAssignment")
+        @SuppressWarnings("UnusedVariable")
         short version = in.readShort();
         int vmViewId = in.readInt();
         long uuidLSBs = in.readLong();
@@ -590,6 +589,9 @@ public class GMSHealthMonitor<ID extends MemberIdentifier> implements HealthMoni
         // this is expected if it is a connection-timeout or other failure
         // to connect
       } catch (IllegalStateException e) {
+        // This is expected if ConnectTimeoutTask is scheduled on a timer that was already
+        // cancelled.
+        // Once a timer has been terminated, no more tasks may be scheduled on it.
         if (!isStopping) {
           logger.trace("Unexpected exception", e);
         }
@@ -653,7 +655,7 @@ public class GMSHealthMonitor<ID extends MemberIdentifier> implements HealthMoni
   }
 
   void writeMemberToStream(ID gmbr, DataOutputStream out) throws IOException {
-    out.writeShort(Version.getCurrentVersion().ordinal());
+    out.writeShort(KnownVersion.getCurrentVersion().ordinal());
     out.writeInt(gmbr.getVmViewId());
     out.writeLong(gmbr.getUuidLeastSignificantBits());
     out.writeLong(gmbr.getUuidMostSignificantBits());
@@ -668,7 +670,13 @@ public class GMSHealthMonitor<ID extends MemberIdentifier> implements HealthMoni
   @Override
   public boolean checkIfAvailable(ID mbr, String reason,
       boolean initiateRemoval) {
-    if (membersInFinalCheck.contains(mbr)) {
+    return checkIfAvailable(mbr, reason, initiateRemoval, true);
+  }
+
+  @Override
+  public boolean checkIfAvailable(ID mbr, String reason,
+      boolean initiateRemoval, boolean assumeMembersInFinalCheckAreAvailable) {
+    if (assumeMembersInFinalCheckAreAvailable && membersInFinalCheck.contains(mbr)) {
       return true; // status unknown for now but someone is checking
     }
     return inlineCheckIfAvailable(localAddress, currentView, initiateRemoval,
@@ -677,7 +685,7 @@ public class GMSHealthMonitor<ID extends MemberIdentifier> implements HealthMoni
 
   @Override
   public void start() throws MemberStartupException {
-    scheduler = LoggingExecutors.newScheduledThreadPool("Geode Failure Detection Scheduler", 1);
+    scheduler = LoggingExecutors.newScheduledThreadPool(1, "Geode Failure Detection Scheduler");
     checkExecutor = LoggingExecutors.newCachedThreadPool("Geode Failure Detection thread ", true);
     Monitor m = this.new Monitor(memberTimeout);
     monitorInterval = memberTimeout / LOGICAL_INTERVAL;
@@ -1343,7 +1351,7 @@ public class GMSHealthMonitor<ID extends MemberIdentifier> implements HealthMoni
 
       if (!failed) {
         if (!isStopping
-            && initiator.getVersionOrdinal() >= Version.GEODE_1_4_0.ordinal()) {
+            && initiator.getVersionOrdinal() >= KnownVersion.GEODE_1_4_0.ordinal()) {
           // let others know that this member is no longer suspect
           FinalCheckPassedMessage<ID> message = new FinalCheckPassedMessage<>(initiator, mbr);
           List<ID> members = cv.getMembers();
