@@ -91,9 +91,11 @@ import org.apache.geode.distributed.internal.membership.gms.messages.JoinRequest
 import org.apache.geode.distributed.internal.membership.gms.messages.JoinResponseMessage;
 import org.apache.geode.internal.inet.LocalHostUtil;
 import org.apache.geode.internal.serialization.BufferDataOutputStream;
+import org.apache.geode.internal.serialization.KnownVersion;
 import org.apache.geode.internal.serialization.StaticSerialization;
-import org.apache.geode.internal.serialization.Version;
 import org.apache.geode.internal.serialization.VersionedDataInputStream;
+import org.apache.geode.internal.serialization.Versioning;
+import org.apache.geode.internal.serialization.VersioningIO;
 import org.apache.geode.logging.internal.OSProcess;
 import org.apache.geode.util.internal.GeodeGlossary;
 
@@ -566,7 +568,7 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
         GMSUtil.parseGroups(config.getRoles(), config.getGroups()), config.getDurableClientId(),
         config.getDurableClientTimeout(),
         config.isNetworkPartitionDetectionEnabled(), isLocator,
-        Version.getCurrentVersion().ordinal(),
+        KnownVersion.getCurrentVersion().ordinal(),
         jgAddress.getUUIDMsbs(), jgAddress.getUUIDLsbs(),
         (byte) (services.getConfig().getMemberWeight() & 0xff), false, null);
     localAddress = services.getMemberFactory().create(gmsMember);
@@ -720,7 +722,7 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
       org.jgroups.Message jmsg;
       try {
         jmsg =
-            createJGMessage(msg, local, null, Version.getCurrentVersion().ordinal());
+            createJGMessage(msg, local, null, KnownVersion.getCurrentVersion().ordinal());
       } catch (IOException e) {
         return new HashSet<>(msg.getRecipients());
       } finally {
@@ -884,11 +886,11 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
    *
    * @param gfmsg the DistributionMessage
    * @param src the sender address
-   * @param version the version of the recipient
+   * @param versionOrdinal the version of the recipient
    * @return the new message
    */
   org.jgroups.Message createJGMessage(Message<ID> gfmsg, JGAddress src, ID dst,
-      short version) throws IOException {
+      short versionOrdinal) throws IOException {
     gfmsg.registerProcessor();
     org.jgroups.Message msg = new org.jgroups.Message();
     msg.setDest(null);
@@ -896,33 +898,32 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
     setMessageFlags(gfmsg, msg);
     try {
       long start = services.getStatistics().startMsgSerialization();
-      BufferDataOutputStream out_stream =
-          new BufferDataOutputStream(Version.fromOrdinalNoThrow(version, false));
-      Version.writeOrdinal(out_stream,
-          Version.getCurrentVersion().ordinal(), true);
-      if (encrypt != null) {
-        out_stream.writeBoolean(true);
-        writeEncryptedMessage(gfmsg, dst, version, out_stream);
-      } else {
-        out_stream.writeBoolean(false);
-        serializeMessage(gfmsg, out_stream);
-      }
+      final KnownVersion version = Versioning
+          .getKnownVersionOrDefault(Versioning.getVersion(versionOrdinal), KnownVersion.CURRENT);
+      try (BufferDataOutputStream out_stream = new BufferDataOutputStream(version)) {
+        VersioningIO.writeOrdinal(out_stream, KnownVersion.getCurrentVersion().ordinal(), true);
+        if (encrypt != null) {
+          out_stream.writeBoolean(true);
+          writeEncryptedMessage(gfmsg, dst, versionOrdinal, out_stream);
+        } else {
+          out_stream.writeBoolean(false);
+          serializeMessage(gfmsg, out_stream);
+        }
 
-      msg.setBuffer(out_stream.toByteArray());
+        msg.setBuffer(out_stream.toByteArray());
+      }
       services.getStatistics().endMsgSerialization(start);
     } catch (IOException ex) {
       logger.warn("Error serializing message", ex);
       throw ex;
     } catch (Exception ex) {
       logger.warn("Error serializing message", ex);
-      IOException ioe =
-          new IOException("Error serializing message", ex.getCause());
-      throw ioe;
+      throw new IOException("Error serializing message", ex.getCause());
     }
     return msg;
   }
 
-  void writeEncryptedMessage(Message<ID> gfmsg, ID recipient, short version,
+  void writeEncryptedMessage(Message<ID> gfmsg, ID recipient, short versionOrdinal,
       BufferDataOutputStream out)
       throws Exception {
     long start = services.getStatistics().startUDPMsgEncryption();
@@ -955,9 +956,12 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
         StaticSerialization.writeByteArray(pk, out);
       }
 
-      BufferDataOutputStream out_stream =
-          new BufferDataOutputStream(Version.fromOrdinalNoThrow(version, false));
-      byte[] messageBytes = serializeMessage(gfmsg, out_stream);
+      final KnownVersion version = Versioning
+          .getKnownVersionOrDefault(Versioning.getVersion(versionOrdinal), KnownVersion.CURRENT);
+      byte[] messageBytes;
+      try (BufferDataOutputStream out_stream = new BufferDataOutputStream(version)) {
+        messageBytes = serializeMessage(gfmsg, out_stream);
+      }
 
       if (pkMbr != null) {
         // using members private key
@@ -1047,11 +1051,14 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
       DataInputStream dis =
           new DataInputStream(new ByteArrayInputStream(buf, jgmsg.getOffset(), jgmsg.getLength()));
 
-      short ordinal = Version.readOrdinal(dis);
+      short ordinal = VersioningIO.readOrdinal(dis);
 
-      if (ordinal < Version.getCurrentVersion().ordinal()) {
+      if (ordinal < KnownVersion.getCurrentVersion().ordinal()) {
+        final KnownVersion version = Versioning.getKnownVersionOrDefault(
+            Versioning.getVersion(ordinal),
+            KnownVersion.CURRENT);
         dis = new VersionedDataInputStream(dis,
-            Version.fromOrdinalNoThrow(ordinal, false));
+            version);
       }
 
       // read
@@ -1146,9 +1153,12 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
       {
         DataInputStream in = new DataInputStream(new ByteArrayInputStream(data));
 
-        if (ordinal < Version.getCurrentVersion().ordinal()) {
+        if (ordinal < KnownVersion.getCurrentVersion().ordinal()) {
+          final KnownVersion version = Versioning.getKnownVersionOrDefault(
+              Versioning.getVersion(ordinal),
+              KnownVersion.CURRENT);
           in = new VersionedDataInputStream(in,
-              Version.fromOrdinalNoThrow(ordinal, false));
+              version);
         }
 
         Message<ID> result = deserializeMessage(in, ordinal);
@@ -1191,13 +1201,15 @@ public class JGroupsMessenger<ID extends MemberIdentifier> implements Messenger<
           // get the multicast message digest and pass it with the join response
           Digest digest = (Digest) this.myChannel.getProtocolStack().getTopProtocol()
               .down(Event.GET_DIGEST_EVT);
-          BufferDataOutputStream hdos = new BufferDataOutputStream(500, Version.CURRENT);
-          try {
-            digest.writeTo(hdos);
-          } catch (Exception e) {
-            logger.fatal("Unable to serialize JGroups messaging digest", e);
+          try (BufferDataOutputStream bufferDataOutputStream =
+              new BufferDataOutputStream(500, KnownVersion.CURRENT)) {
+            try {
+              digest.writeTo(bufferDataOutputStream);
+            } catch (Exception e) {
+              logger.fatal("Unable to serialize JGroups messaging digest", e);
+            }
+            jrsp.setMessengerData(bufferDataOutputStream.toByteArray());
           }
-          jrsp.setMessengerData(hdos.toByteArray());
         }
         break;
       default:
