@@ -40,6 +40,7 @@ import org.junit.experimental.categories.Category;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 
+import org.apache.geode.annotations.internal.SuppressDeprecationForBackwardsCompatibilityTesting;
 import org.apache.geode.distributed.Locator;
 import org.apache.geode.distributed.internal.DistributionConfigImpl;
 import org.apache.geode.distributed.internal.InternalLocator;
@@ -132,6 +133,13 @@ public class TcpServerProductVersionDUnitTest implements Serializable {
       this.locatorProductVersion = locatorProductVersion;
     }
 
+    @Override
+    public String toString() {
+      return "VersionConfiguration{" +
+          "clientProductVersion=" + clientProductVersion +
+          ", locatorProductVersion=" + locatorProductVersion +
+          '}';
+    }
   }
 
   private final VersionConfiguration versions;
@@ -193,6 +201,7 @@ public class TcpServerProductVersionDUnitTest implements Serializable {
         tcpClient = getLegacyTcpClient();
       }
 
+      @SuppressDeprecationForBackwardsCompatibilityTesting
       @SuppressWarnings("deprecation")
       final InetAddress localHost = SocketCreator.getLocalHost();
       Object response;
