@@ -16,13 +16,13 @@ package org.apache.geode.internal.cache.wan.serial;
 
 import static org.junit.Assert.fail;
 
+import org.apache.logging.log4j.Logger;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 
 import org.apache.geode.internal.cache.wan.WANTestBase;
+import org.apache.geode.logging.internal.log4j.api.LogService;
 import org.apache.geode.test.dunit.AsyncInvocation;
-import org.apache.geode.test.dunit.LogWriterUtils;
-import org.apache.geode.test.dunit.Wait;
 import org.apache.geode.test.junit.categories.WanTest;
 
 @Category({WanTest.class})
@@ -30,6 +30,8 @@ public class SerialWANPersistenceEnabledGatewaySenderDUnitTest extends WANTestBa
 
   private static final long serialVersionUID = 1L;
 
+  private static Logger logger = LogService.getLogger();
+
   public SerialWANPersistenceEnabledGatewaySenderDUnitTest() {
     super();
   }
@@ -175,8 +177,8 @@ public class SerialWANPersistenceEnabledGatewaySenderDUnitTest extends WANTestBa
     String secondDStore = (String) vm5.invoke(() -> WANTestBase.createSenderWithDiskStore("ln", 2,
         false, 100, 10, false, true, null, null, true));
 
-    LogWriterUtils.getLogWriter().info("The first ds is " + firstDStore);
-    LogWriterUtils.getLogWriter().info("The first ds is " + secondDStore);
+    logger.info("The first ds is " + firstDStore);
+    logger.info("The second ds is " + secondDStore);
 
     vm2.invoke(
         () -> WANTestBase.createReplicatedRegion(getTestMethodName() + "_RR", null, isOffHeap()));
@@ -199,7 +201,7 @@ public class SerialWANPersistenceEnabledGatewaySenderDUnitTest extends WANTestBa
 
     vm4.invoke(() -> WANTestBase.doPuts(getTestMethodName() + "_RR", 1000));
 
-    LogWriterUtils.getLogWriter().info("Completed puts in the region");
+    logger.info("Completed puts in the region");
 
     // verify if the queue has all the events
     // vm4.invoke(() -> WANTestBase.checkQueueSize( "ln", 1000
@@ -218,29 +220,27 @@ public class SerialWANPersistenceEnabledGatewaySenderDUnitTest extends WANTestBa
     vm6.invoke(() -> WANTestBase.killSender());
     vm7.invoke(() -> WANTestBase.killSender());
 
-    LogWriterUtils.getLogWriter().info("Killed all the sender. ");
+    logger.info("Killed all the sender. ");
     // restart the vm
     vm4.invoke(() -> WANTestBase.createCache(lnPort));
     vm5.invoke(() -> WANTestBase.createCache(lnPort));
     vm4.invoke(() -> WANTestBase.createSenderWithDiskStore("ln", 2, false, 100, 10, false, true,
         null, firstDStore, true));
-    LogWriterUtils.getLogWriter().info("Created the sender.... in vm4 ");
+    logger.info("Created the sender.... in vm4 ");
     vm5.invoke(() -> WANTestBase.createSenderWithDiskStore("ln", 2, false, 100, 10, false, true,
         null, secondDStore, true));
-    LogWriterUtils.getLogWriter().info("Created the sender.... in vm5 ");
+    logger.info("Created the sender.... in vm5 ");
     AsyncInvocation inv1 = vm4.invokeAsync(() -> WANTestBase.startSender("ln"));
-    LogWriterUtils.getLogWriter().info("Started the sender in vm 4");
+    logger.info("Started the sender in vm 4");
 
     vm5.invoke(() -> WANTestBase.startSender("ln"));
-    LogWriterUtils.getLogWriter().info("Started the sender in vm 5");
+    logger.info("Started the sender in vm 5");
     try {
-      inv1.join();
+      inv1.await();
     } catch (InterruptedException e) {
       fail("Got interrupted exception while waiting for startSender to finish.");
     }
 
-    Wait.pause(5000);
-
     vm2.invoke(() -> WANTestBase.validateRegionSize(getTestMethodName() + "_RR", 1000));
     vm3.invoke(() -> WANTestBase.validateRegionSize(getTestMethodName() + "_RR", 1000));
 
@@ -266,8 +266,8 @@ public class SerialWANPersistenceEnabledGatewaySenderDUnitTest extends WANTestBa
     String secondDStore = (String) vm5.invoke(() -> WANTestBase.createSenderWithDiskStore("ln", 2,
         false, 100, 10, false, true, null, null, true));
 
-    LogWriterUtils.getLogWriter().info("The first ds is " + firstDStore);
-    LogWriterUtils.getLogWriter().info("The first ds is " + secondDStore);
+    logger.info("The first ds is " + firstDStore);
+    logger.info("The second ds is " + secondDStore);
 
     vm2.invoke(
         () -> WANTestBase.createReplicatedRegion(getTestMethodName() + "_RR", null, isOffHeap()));
@@ -290,23 +290,23 @@ public class SerialWANPersistenceEnabledGatewaySenderDUnitTest extends WANTestBa
 
     vm4.invoke(() -> WANTestBase.doPuts(getTestMethodName() + "_RR", 1000));
 
-    LogWriterUtils.getLogWriter().info("Completed puts in the region");
+    logger.info("Completed puts in the region");
 
     // kill the vm
     vm4.invoke(() -> WANTestBase.killSender());
     vm5.invoke(() -> WANTestBase.killSender());
 
-    LogWriterUtils.getLogWriter().info("Killed the sender. ");
+    logger.info("Killed the sender. ");
     // restart the vm
     vm4.invoke(() -> WANTestBase.createCache(lnPort));
     vm5.invoke(() -> WANTestBase.createCache(lnPort));
 
     vm4.invoke(() -> WANTestBase.createSenderWithDiskStore("ln", 2, false, 100, 10, false, true,
         null, firstDStore, true));
-    LogWriterUtils.getLogWriter().info("Created the sender.... in vm4 ");
+    logger.info("Created the sender.... in vm4 ");
     vm5.invoke(() -> WANTestBase.createSenderWithDiskStore("ln", 2, false, 100, 10, false, true,
         null, secondDStore, true));
-    LogWriterUtils.getLogWriter().info("Created the sender.... in vm5 ");
+    logger.info("Created the sender.... in vm5 ");
 
     vm4.invoke(() -> WANTestBase.createPersistentReplicatedRegion(getTestMethodName() + "_RR", "ln",
         isOffHeap()));
@@ -315,18 +315,16 @@ public class SerialWANPersistenceEnabledGatewaySenderDUnitTest extends WANTestBa
         isOffHeap()));
 
     AsyncInvocation inv1 = vm4.invokeAsync(() -> WANTestBase.startSender("ln"));
-    LogWriterUtils.getLogWriter().info("Started the sender in vm 4");
+    logger.info("Started the sender in vm 4");
 
     vm5.invoke(() -> WANTestBase.startSender("ln"));
-    LogWriterUtils.getLogWriter().info("Started the sender in vm 5");
+    logger.info("Started the sender in vm 5");
     try {
-      inv1.join();
+      inv1.await();
     } catch (InterruptedException e) {
       fail("Got interrupted exception while waiting for startSender to finish.");
     }
 
-    Wait.pause(5000);
-
     vm2.invoke(() -> WANTestBase.validateRegionSize(getTestMethodName() + "_RR", 1000));
     vm3.invoke(() -> WANTestBase.validateRegionSize(getTestMethodName() + "_RR", 1000));
 
@@ -371,37 +369,26 @@ public class SerialWANPersistenceEnabledGatewaySenderDUnitTest extends WANTestBa
 
     vm4.invoke(() -> WANTestBase.doPuts(getTestMethodName() + "_RR", 1000));
 
-    LogWriterUtils.getLogWriter().info("Completed puts in the region");
-
-    // verify if the queue has all the events
-    // vm4.invoke(() -> WANTestBase.checkQueueSize( "ln", 1000
-    // ));
-    // vm5.invoke(() -> WANTestBase.checkQueueSize( "ln", 1000
-    // ));
-    //
-    // vm2.invoke(() -> WANTestBase.validateRegionSize(
-    // testName + "_RR", 0 ));
-    // vm3.invoke(() -> WANTestBase.validateRegionSize(
-    // testName + "_RR", 0 ));
+    logger.info("Completed puts in the region");
 
     // kill the vm
     vm4.invoke(() -> WANTestBase.killSender());
     vm5.invoke(() -> WANTestBase.killSender());
 
-    LogWriterUtils.getLogWriter().info("Killed the sender. ");
+    logger.info("Killed the sender. ");
     // restart the vm
     vm4.invoke(() -> WANTestBase.createCache(lnPort));
     vm5.invoke(() -> WANTestBase.createCache(lnPort));
     vm4.invoke(() -> WANTestBase.createSender("ln", 2, false, 100, 10, false, false, null, true));
-    LogWriterUtils.getLogWriter().info("Created the sender.... in vm4 ");
+    logger.info("Created the sender.... in vm4 ");
     vm5.invoke(() -> WANTestBase.createSender("ln", 2, false, 100, 10, false, false, null, true));
-    LogWriterUtils.getLogWriter().info("Created the sender.... in vm5 ");
+    logger.info("Created the sender.... in vm5 ");
 
     vm4.invoke(() -> WANTestBase.startSender("ln"));
-    LogWriterUtils.getLogWriter().info("Started the sender in vm 4");
+    logger.info("Started the sender in vm 4");
 
     vm5.invoke(() -> WANTestBase.startSender("ln"));
-    LogWriterUtils.getLogWriter().info("Started the sender in vm 5");
+    logger.info("Started the sender in vm 5");
 
     AsyncInvocation inv1 = vm4.invokeAsync(() -> WANTestBase
         .createPersistentReplicatedRegion(getTestMethodName() + "_RR", "ln", isOffHeap()));
@@ -409,12 +396,11 @@ public class SerialWANPersistenceEnabledGatewaySenderDUnitTest extends WANTestBa
         isOffHeap()));
 
     try {
-      inv1.join();
+      inv1.await();
     } catch (InterruptedException e) {
       fail("Got interrupted exception while waiting for startSender to finish.");
     }
 
-    Wait.pause(5000);
     vm4.invoke(() -> WANTestBase.doPuts(getTestMethodName() + "_RR", 1000));
 
     vm2.invoke(() -> WANTestBase.validateRegionSize(getTestMethodName() + "_RR", 1000));
@@ -443,8 +429,8 @@ public class SerialWANPersistenceEnabledGatewaySenderDUnitTest extends WANTestBa
     String secondDStore = (String) vm5.invoke(() -> WANTestBase.createSenderWithDiskStore("ln", 2,
         false, 100, 10, false, true, null, null, true));
 
-    LogWriterUtils.getLogWriter().info("The first ds is " + firstDStore);
-    LogWriterUtils.getLogWriter().info("The first ds is " + secondDStore);
+    logger.info("The first ds is " + firstDStore);
+    logger.info("The second ds is " + secondDStore);
 
     vm2.invoke(
         () -> WANTestBase.createReplicatedRegion(getTestMethodName() + "_RR", null, isOffHeap()));
@@ -467,23 +453,23 @@ public class SerialWANPersistenceEnabledGatewaySenderDUnitTest extends WANTestBa
 
     vm4.invoke(() -> WANTestBase.doPuts(getTestMethodName() + "_RR", 1000));
 
-    LogWriterUtils.getLogWriter().info("Completed puts in the region");
+    logger.info("Completed puts in the region");
 
     // kill the vm
     vm4.invoke(() -> WANTestBase.killSender());
     vm5.invoke(() -> WANTestBase.killSender());
 
-    LogWriterUtils.getLogWriter().info("Killed the sender. ");
+    logger.info("Killed the sender. ");
     // restart the vm
     vm4.invoke(() -> WANTestBase.createCache(lnPort));
     vm5.invoke(() -> WANTestBase.createCache(lnPort));
 
     vm4.invoke(() -> WANTestBase.createSenderWithDiskStore("ln", 2, false, 100, 10, false, true,
         null, firstDStore, true));
-    LogWriterUtils.getLogWriter().info("Created the sender.... in vm4 ");
+    logger.info("Created the sender.... in vm4 ");
     vm5.invoke(() -> WANTestBase.createSenderWithDiskStore("ln", 2, false, 100, 10, false, true,
         null, secondDStore, true));
-    LogWriterUtils.getLogWriter().info("Created the sender.... in vm5 ");
+    logger.info("Created the sender.... in vm5 ");
 
     vm4.invoke(() -> WANTestBase.createPersistentReplicatedRegion(getTestMethodName() + "_RR", "ln",
         isOffHeap()));
@@ -492,20 +478,157 @@ public class SerialWANPersistenceEnabledGatewaySenderDUnitTest extends WANTestBa
         isOffHeap()));
 
     AsyncInvocation inv1 = vm4.invokeAsync(() -> WANTestBase.startSender("ln"));
-    LogWriterUtils.getLogWriter().info("Started the sender in vm 4");
+    logger.info("Started the sender in vm 4");
 
     vm5.invoke(() -> WANTestBase.startSender("ln"));
-    LogWriterUtils.getLogWriter().info("Started the sender in vm 5");
+    logger.info("Started the sender in vm 5");
     try {
-      inv1.join();
+      inv1.await();
     } catch (InterruptedException e) {
       fail("Got interrupted exception while waiting for startSender to finish.");
     }
 
-    Wait.pause(5000);
-
     vm2.invoke(() -> WANTestBase.validateRegionSize(getTestMethodName() + "_RR", 1000));
     vm3.invoke(() -> WANTestBase.validateRegionSize(getTestMethodName() + "_RR", 1000));
 
   }
+
+  /**
+   * Enable persistence for GatewaySender, stop the sender and restart it. Check if the remote site
+   * receives all the event.
+   */
+  @Test
+  public void testReplicatedRegionPersistentWanGateway_restartSender_expectAllEventsReceived() {
+    Integer lnPort = (Integer) vm0.invoke(() -> WANTestBase.createFirstLocatorWithDSId(1));
+    Integer nyPort = (Integer) vm1.invoke(() -> WANTestBase.createFirstRemoteLocator(2, lnPort));
+
+    createCacheInVMs(nyPort, vm2, vm3);
+    createReceiverInVMs(vm2, vm3);
+
+    createCacheInVMs(lnPort, vm4, vm5, vm6, vm7);
+
+    String firstDStore = (String) vm4.invoke(() -> WANTestBase.createSenderWithDiskStore("ln", 2,
+        false, 100, 10, false, true, null, null, true));
+    String secondDStore = (String) vm5.invoke(() -> WANTestBase.createSenderWithDiskStore("ln", 2,
+        false, 100, 10, false, true, null, null, true));
+
+    logger.info("The first ds is " + firstDStore);
+    logger.info("The second ds is " + secondDStore);
+
+    vm2.invoke(
+        () -> WANTestBase.createReplicatedRegion(getTestMethodName() + "_RR", null, isOffHeap()));
+    vm3.invoke(
+        () -> WANTestBase.createReplicatedRegion(getTestMethodName() + "_RR", null, isOffHeap()));
+
+    startSenderInVMs("ln", vm4, vm5);
+
+    vm4.invoke(() -> WANTestBase.createPersistentReplicatedRegion(getTestMethodName() + "_RR", "ln",
+        isOffHeap()));
+    vm5.invoke(() -> WANTestBase.createPersistentReplicatedRegion(getTestMethodName() + "_RR", "ln",
+        isOffHeap()));
+    vm6.invoke(() -> WANTestBase.createPersistentReplicatedRegion(getTestMethodName() + "_RR", "ln",
+        isOffHeap()));
+    vm7.invoke(() -> WANTestBase.createPersistentReplicatedRegion(getTestMethodName() + "_RR", "ln",
+        isOffHeap()));
+
+    vm4.invoke(() -> WANTestBase.pauseSender("ln"));
+    vm5.invoke(() -> WANTestBase.pauseSender("ln"));
+
+    vm4.invoke(() -> WANTestBase.doPuts(getTestMethodName() + "_RR", 1000));
+
+    logger.info("Completed puts in the region");
+
+    vm4.invoke(() -> WANTestBase.stopSender("ln"));
+    vm5.invoke(() -> WANTestBase.stopSender("ln"));
+
+
+    logger.info("Stopped all the senders. ");
+
+    AsyncInvocation inv1 = vm4.invokeAsync(() -> WANTestBase.startSender("ln"));
+    logger.info("Started the sender in vm 4");
+
+    vm5.invoke(() -> WANTestBase.startSender("ln"));
+    logger.info("Started the sender in vm 5");
+    try {
+      inv1.await();
+    } catch (InterruptedException e) {
+      fail("Got interrupted exception while waiting for startSender to finish.");
+    }
+
+    vm4.invoke(() -> waitForSenderRunningState("ln"));
+    vm5.invoke(() -> waitForSenderRunningState("ln"));
+
+    vm4.invoke(() -> checkQueueSize("ln", 0));
+    vm5.invoke(() -> checkQueueSize("ln", 0));
+
+    vm2.invoke(() -> WANTestBase.validateRegionSize(getTestMethodName() + "_RR", 1000));
+    vm3.invoke(() -> WANTestBase.validateRegionSize(getTestMethodName() + "_RR", 1000));
+
+  }
+
+
+  /**
+   * Enable persistence for GatewaySender, stop the sender and start it with clean-queues option.
+   * Check if the remote site receives all the event.
+   */
+  @Test
+  public void testReplicatedRegionPersistentWanGateway_restartSenderWithCleanQueues_expectNoEventsReceived() {
+    Integer lnPort = (Integer) vm0.invoke(() -> WANTestBase.createFirstLocatorWithDSId(1));
+    Integer nyPort = (Integer) vm1.invoke(() -> WANTestBase.createFirstRemoteLocator(2, lnPort));
+
+    createCacheInVMs(nyPort, vm2, vm3);
+
+    createCacheInVMs(lnPort, vm4, vm5, vm6, vm7);
+
+    vm4.invoke("Creating DS", () -> WANTestBase.createSenderWithDiskStore("ln", 2,
+        false, 100, 10, false, true, null, null, true));
+    vm5.invoke("Creating DS", () -> WANTestBase.createSenderWithDiskStore("ln", 2,
+        false, 100, 10, false, true, null, null, true));
+
+    vm2.invoke(
+        () -> WANTestBase.createReplicatedRegion(getTestMethodName() + "_RR", null, isOffHeap()));
+    vm3.invoke(
+        () -> WANTestBase.createReplicatedRegion(getTestMethodName() + "_RR", null, isOffHeap()));
+
+    startSenderInVMs("ln", vm4, vm5);
+
+    vm4.invoke(() -> WANTestBase.createPersistentReplicatedRegion(getTestMethodName() + "_RR", "ln",
+        isOffHeap()));
+    vm5.invoke(() -> WANTestBase.createPersistentReplicatedRegion(getTestMethodName() + "_RR", "ln",
+        isOffHeap()));
+    vm6.invoke(() -> WANTestBase.createPersistentReplicatedRegion(getTestMethodName() + "_RR", "ln",
+        isOffHeap()));
+    vm7.invoke(() -> WANTestBase.createPersistentReplicatedRegion(getTestMethodName() + "_RR", "ln",
+        isOffHeap()));
+
+    vm4.invoke("Puts in the region" + getTestMethodName() + "_RR",
+        () -> WANTestBase.doPuts(getTestMethodName() + "_RR", 1000));
+
+
+    vm4.invoke("Stopping ln sender", () -> WANTestBase.stopSender("ln"));
+    vm5.invoke("Stopping ln sender", () -> WANTestBase.stopSender("ln"));
+
+    createReceiverInVMs(vm2, vm3);
+
+    AsyncInvocation<?> inv1 = vm4.invokeAsync("Starting sender with clean queues",
+        () -> WANTestBase.startSenderwithCleanQueues("ln"));
+    vm5.invoke("Starting sender with clean queues",
+        () -> WANTestBase.startSenderwithCleanQueues("ln"));
+    try {
+      inv1.await();
+    } catch (InterruptedException e) {
+      fail("Got interrupted exception while waiting for startSender to finish.");
+    }
+
+    vm4.invoke(() -> waitForSenderRunningState("ln"));
+    vm5.invoke(() -> waitForSenderRunningState("ln"));
+
+    vm4.invoke(() -> checkQueueSize("ln", 0));
+    vm5.invoke(() -> checkQueueSize("ln", 0));
+
+    vm2.invoke(() -> WANTestBase.validateRegionSize(getTestMethodName() + "_RR", 0));
+    vm3.invoke(() -> WANTestBase.validateRegionSize(getTestMethodName() + "_RR", 0));
+
+  }
+
 }
