@@ -112,7 +112,7 @@ public class CreateDestroyGatewaySenderCommandDUnitTest implements Serializable
       String xml = locator.getConfigurationPersistenceService().getConfiguration("cluster")
           .getCacheXmlContent();
       assertThat(xml).contains(
-          "<gateway-sender id=\"ln\" remote-distributed-system-id=\"2\" parallel=\"false\" manual-start=\"false\" enable-batch-conflation=\"false\" enable-persistence=\"false\" disk-synchronous=\"true\"/>");
+          "<gateway-sender id=\"ln\" remote-distributed-system-id=\"2\" parallel=\"false\" manual-start=\"false\" enable-batch-conflation=\"false\" enable-persistence=\"false\" disk-synchronous=\"true\" group-transaction-events=\"false\" enforce-threads-connect-same-receiver=\"false\"/>");
     });
 
     // destroy gateway sender and verify AEQs cleaned up
@@ -167,7 +167,7 @@ public class CreateDestroyGatewaySenderCommandDUnitTest implements Serializable
     VMProvider.invokeInEveryMember(() -> {
       verifySenderState("ln", false, false);
       verifySenderAttributes("ln", 2, false, true, 1000, socketReadTimeout, true, 1000, 5000, true,
-          false, 1000, 100, 2, GatewaySender.OrderPolicy.THREAD, null, null);
+          false, 1000, 100, 2, GatewaySender.OrderPolicy.THREAD, null, null, false);
     }, server1, server2, server3);
 
     // destroy gateway sender and verify AEQs cleaned up
@@ -191,7 +191,8 @@ public class CreateDestroyGatewaySenderCommandDUnitTest implements Serializable
         + "=ln" + " --" + CliStrings.CREATE_GATEWAYSENDER__REMOTEDISTRIBUTEDSYSTEMID + "=2" + " --"
         + CliStrings.CREATE_GATEWAYSENDER__MANUALSTART + "=true" + " --"
         + CliStrings.CREATE_GATEWAYSENDER__SOCKETBUFFERSIZE + "=1000" + " --"
-        + CliStrings.CREATE_GATEWAYSENDER__DISPATCHERTHREADS + "=1";
+        + CliStrings.CREATE_GATEWAYSENDER__DISPATCHERTHREADS + "=1" + " --"
+        + CliStrings.CREATE_GATEWAYSENDER__GROUPTRANSACTIONEVENTS + "=true";
 
     gfsh.executeAndAssertThat(command).statusIsSuccess()
         .doesNotContainOutput("Did not complete waiting")
@@ -203,7 +204,7 @@ public class CreateDestroyGatewaySenderCommandDUnitTest implements Serializable
     VMProvider.invokeInEveryMember(() -> {
       verifySenderState("ln", false, false);
       verifySenderAttributes("ln", 2, false, true, 1000, 0, false, 100, 1000, false,
-          true, 100, 0, 1, null, null, null);
+          true, 100, 0, 1, null, null, null, true);
     }, server1, server2, server3);
 
     // destroy gateway sender and verify AEQs cleaned up
@@ -256,7 +257,7 @@ public class CreateDestroyGatewaySenderCommandDUnitTest implements Serializable
     VMProvider.invokeInEveryMember(() -> {
       verifySenderState("ln", false, false);
       verifySenderAttributes("ln", 2, false, true, 1000, socketReadTimeout, true, 1000, 5000, true,
-          false, 1000, 100, 2, GatewaySender.OrderPolicy.THREAD, eventFilters, null);
+          false, 1000, 100, 2, GatewaySender.OrderPolicy.THREAD, eventFilters, null, false);
     }, server1, server2, server3);
 
     // destroy gateway sender and verify AEQs cleaned up
@@ -308,7 +309,7 @@ public class CreateDestroyGatewaySenderCommandDUnitTest implements Serializable
     VMProvider.invokeInEveryMember(() -> {
       verifySenderState("ln", false, false);
       verifySenderAttributes("ln", 2, false, true, 1000, socketReadTimeout, true, 1000, 5000, true,
-          false, 1000, 100, 2, GatewaySender.OrderPolicy.THREAD, null, transportFilters);
+          false, 1000, 100, 2, GatewaySender.OrderPolicy.THREAD, null, transportFilters, false);
     }, server1, server2, server3);
 
     // destroy gateway sender and verify AEQs cleaned up
