@@ -14,6 +14,7 @@
  */
 package org.apache.geode.internal.cache.wan.misc;
 
+import static org.apache.geode.cache.Region.SEPARATOR;
 import static org.apache.geode.distributed.ConfigurationProperties.MCAST_PORT;
 import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.junit.Assert.assertEquals;
@@ -63,9 +64,10 @@ public class WANConfigurationJUnitTest {
    *
    */
   @Test
-  public void test_GatewaySender_without_Locator() throws IOException {
+  public void test_GatewaySender_without_Locator() {
     try {
       cache = new CacheFactory().set(MCAST_PORT, "0").create();
+
       GatewaySenderFactory fact = cache.createGatewaySenderFactory();
       fact.setParallel(true);
       GatewaySender sender1 = fact.create("NYSender", 2);
@@ -80,6 +82,31 @@ public class WANConfigurationJUnitTest {
     }
   }
 
+  @Test
+  public void test_create_SerialGatewaySender_ThrowsException_when_GroupTransactionEvents_isTrue_and_DispatcherThreads_is_greaterThanOne() {
+    cache = new CacheFactory().set(MCAST_PORT, "0").create();
+    GatewaySenderFactory fact = cache.createGatewaySenderFactory();
+    fact.setParallel(false);
+    fact.setDispatcherThreads(2);
+    fact.setGroupTransactionEvents(true);
+    assertThatThrownBy(() -> fact.create("NYSender", 2))
+        .isInstanceOf(GatewaySenderException.class)
+        .hasMessageContaining(
+            "SerialGatewaySender NYSender cannot be created with group transaction events set to true when dispatcher threads is greater than 1");
+  }
+
+  @Test
+  public void test_create_GatewaySender_ThrowsException_when_GroupTransactionEvents_isTrue_and_BatchConflation_is_enabled() {
+    cache = new CacheFactory().set(MCAST_PORT, "0").create();
+    GatewaySenderFactory fact = cache.createGatewaySenderFactory();
+    fact.setBatchConflationEnabled(true);
+    fact.setGroupTransactionEvents(true);
+    assertThatThrownBy(() -> fact.create("NYSender", 2))
+        .isInstanceOf(GatewaySenderException.class)
+        .hasMessageContaining(
+            "GatewaySender NYSender cannot be created with both group transaction events set to true and batch conflation enabled");
+  }
+
   /**
    * Test to validate that sender with same Id can not be added to cache.
    */
@@ -161,7 +188,8 @@ public class WANConfigurationJUnitTest {
 
     assertThatThrownBy(() -> regionFactory.create("test_GatewaySender_Parallel_DistributedRegion"))
         .isInstanceOf(GatewaySenderConfigurationException.class).hasMessage(
-            "Parallel gateway sender NYSender can not be used with replicated region /test_GatewaySender_Parallel_DistributedRegion");
+            "Parallel Gateway Sender NYSender can not be used with replicated region " + SEPARATOR
+                + "test_GatewaySender_Parallel_DistributedRegion");
   }
 
   @Test
@@ -284,8 +312,9 @@ public class WANConfigurationJUnitTest {
     fact.addGatewayTransportFilter(myStreamFilter1);
     GatewayTransportFilter myStreamFilter2 = new MyGatewayTransportFilter2();
     fact.addGatewayTransportFilter(myStreamFilter2);
+    boolean groupTransactionEvents = false;
+    fact.setGroupTransactionEvents(groupTransactionEvents);
     GatewaySender sender1 = fact.create("TKSender", 2);
-
     RegionFactory factory = cache.createRegionFactory(RegionShortcut.PARTITION);
     factory.addGatewaySenderId(sender1.getId());
     Region region = factory.create("test_ValidateGatewaySenderAttributes");
@@ -305,7 +334,7 @@ public class WANConfigurationJUnitTest {
         gatewaySender.getGatewayEventFilters().size());
     assertEquals(sender1.getGatewayTransportFilters().size(),
         gatewaySender.getGatewayTransportFilters().size());
-
+    assertEquals(sender1.mustGroupTransactionEvents(), gatewaySender.mustGroupTransactionEvents());
   }
 
   /**
