@@ -18,13 +18,16 @@ import java.io.IOException;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
+import java.util.Vector;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 import java.util.function.Consumer;
+import java.util.regex.Pattern;
 
 import org.apache.logging.log4j.Logger;
 
 import org.apache.geode.CancelException;
 import org.apache.geode.GemFireIOException;
+import org.apache.geode.annotations.VisibleForTesting;
 import org.apache.geode.cache.RegionDestroyedException;
 import org.apache.geode.cache.client.ServerConnectivityException;
 import org.apache.geode.cache.client.ServerOperationException;
@@ -33,6 +36,7 @@ import org.apache.geode.cache.client.internal.SenderProxy;
 import org.apache.geode.cache.client.internal.pooling.ConnectionDestroyedException;
 import org.apache.geode.cache.wan.GatewaySender;
 import org.apache.geode.distributed.internal.ServerLocation;
+import org.apache.geode.distributed.internal.ServerLocationAndMemberId;
 import org.apache.geode.internal.cache.InternalCache;
 import org.apache.geode.internal.cache.UpdateAttributesProcessor;
 import org.apache.geode.internal.cache.tier.sockets.MessageTooLargeException;
@@ -61,6 +65,9 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
 
   private ReentrantReadWriteLock connectionLifeCycleLock = new ReentrantReadWriteLock();
 
+  protected static final String maxAttemptsReachedConnectingServerIdExceptionMessage =
+      "Reached max attempts number trying to connect to desired server id";
+
   /*
    * Called after each attempt at processing an outbound (dispatch) or inbound (ack)
    * message, whether the attempt is successful or not. The purpose is testability.
@@ -84,7 +91,6 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
   public GatewaySenderEventRemoteDispatcher(AbstractGatewaySenderEventProcessor eventProcessor) {
     this.processor = eventProcessor;
     this.sender = eventProcessor.getSender();
-    // this.ackReaderThread = new AckReaderThread(sender);
     try {
       initializeConnection();
     } catch (GatewaySenderException e) {
@@ -108,13 +114,13 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
       if (logger.isDebugEnabled()) {
         logger.debug(" Receiving ack on the thread {}", connection);
       }
-      this.connectionLifeCycleLock.readLock().lock();
+      getConnectionLifeCycleLock().readLock().lock();
       try {
         if (connection != null && !processor.isStopped()) {
           ack = (GatewayAck) sp.receiveAckFromReceiver(connection);
         }
       } finally {
-        this.connectionLifeCycleLock.readLock().unlock();
+        getConnectionLifeCycleLock().readLock().unlock();
       }
 
     } catch (Exception e) {
@@ -198,9 +204,9 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
         isRetry = true;
       }
       SenderProxy sp = new SenderProxy(this.sender.getProxy());
-      this.connectionLifeCycleLock.readLock().lock();
+      getConnectionLifeCycleLock().readLock().lock();
       try {
-        if (connection != null) {
+        if (connection != null && !connection.isDestroyed()) {
           sp.dispatchBatch_NewWAN(connection, events, currentBatchId,
               sender.isRemoveFromQueueOnException(), isRetry);
           if (logger.isDebugEnabled()) {
@@ -213,7 +219,7 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
           throw new ConnectionDestroyedException();
         }
       } finally {
-        this.connectionLifeCycleLock.readLock().unlock();
+        getConnectionLifeCycleLock().readLock().unlock();
       }
       return true;
     } catch (ServerOperationException e) {
@@ -280,6 +286,11 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
     }
   }
 
+  @VisibleForTesting
+  ReentrantReadWriteLock getConnectionLifeCycleLock() {
+    return this.connectionLifeCycleLock;
+  }
+
   /**
    * Acquires or adds a new <code>Connection</code> to the corresponding <code>Gateway</code>
    *
@@ -295,8 +306,16 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
     // OR the connection's ServerLocation doesn't match with the one stored in sender
     // THEN initialize the connection
     if (!this.sender.isParallel()) {
-      if (this.connection == null || this.connection.isDestroyed()
-          || !this.connection.getServer().equals(this.sender.getServerLocation())) {
+      boolean needToReconnect = false;
+      getConnectionLifeCycleLock().readLock().lock();
+      try {
+        needToReconnect = this.connection == null || this.connection.isDestroyed()
+            || this.connection.getServer() == null
+            || !this.connection.getServer().equals(this.sender.getServerLocation());
+      } finally {
+        getConnectionLifeCycleLock().readLock().unlock();
+      }
+      if (needToReconnect) {
         if (logger.isDebugEnabled()) {
           logger.debug(
               "Initializing new connection as serverLocation of old connection is : {} and the serverLocation to connect is {}",
@@ -328,7 +347,7 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
   }
 
   public void destroyConnection() {
-    this.connectionLifeCycleLock.writeLock().lock();
+    getConnectionLifeCycleLock().writeLock().lock();
     try {
       Connection con = this.connection;
       if (con != null) {
@@ -343,19 +362,78 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
         this.sender.setServerLocation(null);
       }
     } finally {
-      this.connectionLifeCycleLock.writeLock().unlock();
+      getConnectionLifeCycleLock().writeLock().unlock();
     }
   }
 
+  Connection retryInitializeConnection(Connection con) {
+    final boolean isDebugEnabled = logger.isDebugEnabled();
+    String connectedServerId = con.getEndpoint().getMemberId().getUniqueId();
+    String expectedServerId = this.processor.getExpectedReceiverUniqueId();
+
+    if (expectedServerId.equals("")) {
+      if (isDebugEnabled) {
+        logger.debug("First dispatcher connected to server " + connectedServerId);
+      }
+      this.processor.setExpectedReceiverUniqueId(connectedServerId);
+      return con;
+    }
+
+    int attempt = 0;
+    final int attemptsPerServer = 5;
+    int maxAttempts = attemptsPerServer;
+    Vector<String> notExpectedServerIds = new Vector<String>();
+    boolean connectedToExpectedReceiver = connectedServerId.equals(expectedServerId);
+    while (!connectedToExpectedReceiver) {
+
+      if (isDebugEnabled) {
+        logger.debug("Dispatcher wants to connect to [" + expectedServerId
+            + "] but got connection to [" + connectedServerId + "]");
+      }
+      attempt++;
+      if (!notExpectedServerIds.contains(connectedServerId)) {
+        if (isDebugEnabled) {
+          logger.debug(
+              "Increasing dispatcher connection max retries number due to connection to unknown server ("
+                  + connectedServerId + ")");
+        }
+        notExpectedServerIds.add(connectedServerId);
+        maxAttempts += attemptsPerServer;
+      }
+
+      if (attempt >= maxAttempts) {
+        throw new ServerConnectivityException(maxAttemptsReachedConnectingServerIdExceptionMessage
+            + " [" + expectedServerId + "] (" + maxAttempts + " attempts).");
+      }
+
+      con.destroy();
+      this.sender.getProxy().returnConnection(con);
+      con = this.sender.getProxy().acquireConnection();
+
+      connectedServerId = con.getEndpoint().getMemberId().getUniqueId();
+      if (connectedServerId.equals(expectedServerId)) {
+        connectedToExpectedReceiver = true;
+      }
+    }
+
+    if (isDebugEnabled) {
+      logger.debug("Dispatcher connected to expected endpoint " + connectedServerId
+          + " after " + attempt + " retries.");
+    }
+    return con;
+  }
+
   /**
    * Initializes the <code>Connection</code>.
    *
    */
-  private void initializeConnection() throws GatewaySenderException, GemFireSecurityException {
+  @VisibleForTesting
+  void initializeConnection() throws GatewaySenderException, GemFireSecurityException {
+    final boolean isDebugEnabled = logger.isDebugEnabled();
     if (ackReaderThread != null) {
       ackReaderThread.shutDownAckReaderConnection(connection);
     }
-    this.connectionLifeCycleLock.writeLock().lock();
+    getConnectionLifeCycleLock().writeLock().lock();
     try {
       // Attempt to acquire a connection
       if (this.sender.getProxy() == null || this.sender.getProxy().isDestroyed()) {
@@ -382,26 +460,24 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
           synchronized (this.sender.getLockForConcurrentDispatcher()) {
             ServerLocation server = this.sender.getServerLocation();
             if (server != null) {
-              if (logger.isDebugEnabled()) {
+              if (isDebugEnabled) {
                 logger.debug("ServerLocation is: {}. Connecting to this serverLocation...", server);
               }
               con = this.sender.getProxy().acquireConnection(server);
             } else {
-              if (logger.isDebugEnabled()) {
+              if (isDebugEnabled) {
                 logger.debug("ServerLocation is null. Creating new connection. ");
               }
               con = this.sender.getProxy().acquireConnection();
-              // Acquired connection from pool!! Update the server location
-              // information in the sender and
-              // distribute the information to other senders ONLY IF THIS SENDER
-              // IS
-              // PRIMARY
-              if (this.sender.isPrimary()) {
-                if (sender.getServerLocation() == null) {
-                  sender.setServerLocation(con.getServer());
-                }
-                new UpdateAttributesProcessor(this.sender).distribute(false);
+            }
+            if (this.sender.getEnforceThreadsConnectSameReceiver()) {
+              con = retryInitializeConnection(con);
+            }
+            if (this.sender.isPrimary()) {
+              if (sender.getServerLocation() == null) {
+                sender.setServerLocation(con.getServer());
               }
+              new UpdateAttributesProcessor(this.sender).distribute(false);
             }
           }
         }
@@ -443,7 +519,7 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
               this.processor.getSender().getId(), e.getMessage()),
           e);
     } finally {
-      this.connectionLifeCycleLock.writeLock().unlock();
+      getConnectionLifeCycleLock().writeLock().unlock();
     }
   }
 
@@ -453,13 +529,13 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
     if (e.getCause() instanceof GemFireSecurityException) {
       gse = new GatewaySenderException(e.getCause());
     } else {
-      List<ServerLocation> servers = this.sender.getProxy().getCurrentServers();
+      List<ServerLocationAndMemberId> servers = this.sender.getProxy().getCurrentServers();
       String ioMsg;
       if (servers.size() == 0) {
         ioMsg = "There are no active servers.";
       } else {
         final StringBuilder buffer = new StringBuilder();
-        for (ServerLocation server : servers) {
+        for (ServerLocationAndMemberId server : servers) {
           String endpointName = String.valueOf(server);
           if (buffer.length() > 0) {
             buffer.append(", ");
@@ -471,6 +547,12 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
                 "No available connection was found, but the following active servers exist: %s",
                 buffer.toString());
       }
+      if (this.sender.getEnforceThreadsConnectSameReceiver() && e.getMessage() != null) {
+        if (Pattern.compile(maxAttemptsReachedConnectingServerIdExceptionMessage + ".*")
+            .matcher(e.getMessage()).find()) {
+          ioMsg += " " + e.getMessage();
+        }
+      }
       IOException ex = new IOException(ioMsg);
       gse = new GatewaySenderException(
           String.format("%s : Could not connect due to: %s",
@@ -563,6 +645,9 @@ public class GatewaySenderEventRemoteDispatcher implements GatewaySenderEventDis
       synchronized (runningStateLock) {
         while (!this.ackReaderThreadRunning) {
           try {
+            if (shutdown) {
+              break;
+            }
             this.runningStateLock.wait();
           } catch (InterruptedException e) {
             Thread.currentThread().interrupt();
