@@ -31,7 +31,6 @@ import static org.mockito.Mockito.when;
 
 import java.io.EOFException;
 import java.io.IOException;
-import java.net.InetSocketAddress;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -53,6 +52,7 @@ import org.junit.Test;
 import org.junit.contrib.java.lang.system.SystemOutRule;
 
 import org.apache.geode.distributed.internal.DistributionConfig;
+import org.apache.geode.distributed.internal.tcpserver.HostAndPort;
 import org.apache.geode.distributed.internal.tcpserver.TcpClient;
 import org.apache.geode.internal.admin.remote.DistributionLocatorId;
 import org.apache.geode.test.junit.ResultCaptor;
@@ -218,7 +218,7 @@ public class LocatorMembershipListenerTest {
         any(DistributionLocatorId.class), anyMap(), any(DistributionLocatorId.class), anyInt());
     locatorMembershipListener.locatorJoined(2, joiningLocator, locator1Site1);
     joinLocatorsDistributorThread(resultCaptor);
-    verify(tcpClient, times(0)).requestToServer(any(InetSocketAddress.class),
+    verify(tcpClient, times(0)).requestToServer(any(HostAndPort.class),
         any(LocatorJoinMessage.class), anyInt(), anyBoolean());
   }
 
@@ -356,7 +356,7 @@ public class LocatorMembershipListenerTest {
     // The sendMessage loop in the listener will try to send 4 messages. Two to the remoteLocators
     // and two to the joiningLocator. The retry loop will try to send the messages again and
     // fail (4 more messages) and then it will succeed (4 more messages, for a total of 12).
-    verify(tcpClient, times(12)).requestToServer(isA(InetSocketAddress.class),
+    verify(tcpClient, times(12)).requestToServer(isA(HostAndPort.class),
         isA(LocatorJoinMessage.class), isA(Integer.class), isA(Boolean.class));
   }
 
